(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33117,       1266]*)
(*NotebookOutlinePosition[     33830,       1291]*)
(*  CellTagsIndexPosition[     33786,       1287]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College,  6/1/98."
}], "Subsubtitle"],

Cell[TextData[{
  "Created for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.  To make matrices appear in rectangular arrays, I suggest menu \
choice:  Cell, Default Output Format Type set to TraditionalForm."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 1.1  Exercises on Linear Systems", "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  "Bonus:  Tutorial on Elementary Row Operations and RowReduce\nwith Intro to \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " System."
}], "Section"],

Cell[CellGroupData[{

Cell["Elementary Row Operations", "Subsection"],

Cell["\<\
Let's use elementary row operations to reduce an augmented matrix.\
\>", "Text"],

Cell["\<\
Evaluate the input cell below (click your cursor anywhere in the line below \
and then Shift+Enter).\
\>", "Text"],

Cell["aug = {{3,2,1,8},{0,-2,2,-2},{-6,-2,-4,-14},{3,1,3,7}}", "Input"],

Cell[TextData[{
  "Evaluation of the input cell above stores a matrix under the name ",
  StyleBox["aug", "Input"],
  " (for ",
  StyleBox["aug", "Input",
    FontWeight->"Bold"],
  "mented matrix)."
}], "Text"],

Cell[TextData[{
  "We represent matrices in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by lists of rows, where a row is a list of numbers.  A ",
  StyleBox["list",
    FontVariations->{"Underline"->True}],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a collection of items gathered in set braces ",
  StyleBox["{}", "Input"],
  ", with commas between the items.  We can refer to one item in a list by \
double bracket notation, so that ",
  StyleBox["aug[[3]]", "Input"],
  " refers to the third row.  This makes it easy to work with rows in \
Mathematica (columns are a bit trickier)."
}], "Text"],

Cell[BoxData[
    \(aug[\([3]\)]\)], "Input"],

Cell[TextData[{
  "To display matrices in a way that they look like matrices to us, go up to \
the ",
  StyleBox["Cell",
    FontFamily->"Arial"],
  " menu, choose ",
  StyleBox["Default Output Format Type",
    FontFamily->"Arial"],
  " to be ",
  StyleBox["TraditionalForm",
    FontFamily->"Arial"],
  ".  I suggest that you make this choice every time you start ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " in this Linear Algebra course.  Now, evaluate the cell below (",
  StyleBox["aug", "Input"],
  ") and a square matrix should appear.  The internal representation is still \
just a list of lists but the output will now look more familiar to us."
}], "Text"],

Cell[BoxData[
    \(aug\)], "Input"],

Cell[TextData[{
  "Our first move will be to replace the third row of ",
  StyleBox["aug", "Input"],
  " by the sum of itself with twice the first row of ",
  StyleBox["aug", "Input"],
  "."
}], "Text"],

Cell["aug[[3]] = aug[[3]] + 2 aug[[1]]", "Input"],

Cell[TextData[{
  "What is displayed above is the new third row of ",
  StyleBox["aug", "Input"],
  ".  To see what the whole matrix looks like now, we have to ask.  (Evaluate \
the next input cell.)"
}], "Text"],

Cell[BoxData[
    \(aug\)], "Input"],

Cell[TextData[{
  "We can combine several actions on one cell.  For example, do a replacement \
operation to obtain a zero in the lower left corner of ",
  StyleBox["aug", "Input"],
  ".  (Evaluate the next input cell.)"
}], "Text"],

Cell["\<\
aug[[4]] = aug[[4]] - aug[[1]]; 
aug\
\>", "Input"],

Cell[TextData[{
  "The semicolon a the end of the first line tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to suppress the display of the value of the first expression, so only the \
value of the second expression (\"",
  StyleBox["aug", "Input"],
  "\") is shown.  We could even put this second line after the semicolon on \
the first line."
}], "Text"],

Cell["\<\
Now, we could pivot on the 2,2 entry but to simplify things let's scale the \
second row by -1/2.\
\>", "Text"],

Cell[BoxData[
    \(aug[\([2]\)]\  = \ \((\(-1\)/2)\)\ aug[\([2]\)]; \ aug\)], "Input"],

Cell[TextData[{
  StyleBox["Now write and evaluate",
    FontVariations->{"Underline"->True}],
  " an expression which uses a replacement operation (with the pivot at the \
2,2 entry) to obtain a zero in the 3,2 entry of our augmented matrix.  (Click \
between this cell and the one below it and you should see a horizontal line.  \
Then just start typing.)"
}], "Text"],

Cell[TextData[{
  "To obtain a zero in the 4,2 entry, enter another expression.  Rather than \
directly typing it, try to copy, paste (note that there are short-cut \
keystrokes for these) and edit a previous input, then evaluate.  This can \
save much typing in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Your resulting matrix should be ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"3", "2", "1", "8"},
              {"0", "1", \(-1\), "1"},
              {"0", "0", "0", "0"},
              {"0", "0", "1", "0"}
              },
            ColumnAlignments->{Decimal}], ")"}], TraditionalForm]]],
  ".  If it is not, then you might have to start over again from the top, \
evaluating each input cell once -- read on:"
}], "Text"],

Cell[TextData[{
  "One tricky point is that if you evaluate a cell twice, the second \
evaluation has a different result since it works on the result of the first \
evaluation (even though the first result disappears).  This is one symptom of \
a general principle -- what appears in the notebook is different from the \
calculating session of stored values and definitions.  The calculating \
session is contained in a part of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " called the (Local) Kernel while the word processing part is called the \
Front-End.  The Kernel starts with ",
  StyleBox["In[1]", "SmallText",
    FontColor->RGBColor[0, 0, 1]],
  " and proceeds through ",
  StyleBox["In[2]", "SmallText",
    FontColor->RGBColor[0, 0, 1]],
  ", ",
  StyleBox["In[3]", "SmallText",
    FontColor->RGBColor[0, 0, 1]],
  ",... regardless of where, or even if the cells appear.  The cells could be \
in different order, in different notebooks, or even deleted.  Conversely, \
input cells that do appear have no effect until they are evaluated.  If \
things get really messed up, you can go to the Kernel menu, Quit just the \
Kernel and start over with ",
  StyleBox["In[1].  ", "SmallText",
    FontColor->RGBColor[0, 0, 1]],
  "We should strive to make our notebooks match the desired evaluation order, \
so that input cells can be evaluated from top to bottom to recreate your \
results."
}], "Text"],

Cell["Back to our matrix, that should be as shown above.", "Text"],

Cell[BoxData[
    \(aug\)], "Input"],

Cell["\<\
Our next pivot column is the third column, but the only eligible entry for \
the pivot is down in the bottom row.  We need to interchange (\"swap\") rows \
three and four.  This is accomplished by the following expression where we \
specify a list of row numbers.\
\>", "Text"],

Cell[BoxData[
    \(aug[\([{3, 4}]\)]\  = \ aug[\([{4, 3}]\)]; \ aug\)], "Input"],

Cell["\<\
Our matrix is now in echelon form and you may continue with row operations to \
find the reduced row echelon form.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "All at once: RowReduce (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s version of MATLAB's rref)"
}], "Subsection"],

Cell["Let's start over with a copy of the first input cell.", "Text"],

Cell["aug = {{3,2,1,8},{0,-2,2,-2},{-6,-2,-4,-14},{3,1,3,7}}", "Input"],

Cell[BoxData[
    \(RowReduce[aug]\)], "Input"],

Cell["\<\
So the solution of the corresponding system is:  x1=2, x2 =1, x3=0.  \
\>", "Text"],

Cell["\<\
Get in the habit of writing the final answer and other helpful explanation in \
text cells.  Let's create a text cell:  From the Format menu, choose Show \
ToolBar.  Type in any message in a new cell below.  Select (make sure to get \
it highlighted) the bracket on the right edge of the cell, then use the pull \
down menu in the upper-left corner of this window (on the ToolBar) to choose \
style Text.  You can use other styles to easily create well organized \
notebooks.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters and Pitfalls", "Subsection"],

Cell[CellGroupData[{

Cell["Parameter analysis -- where RowReduce \"fails\"", "Subsubsection"],

Cell[TextData[{
  "Find ",
  StyleBox["h",
    FontSlant->"Italic"],
  " such that the matrix is the augmented matrix of a ",
  StyleBox["consistent",
    FontVariations->{"Underline"->True}],
  " linear system."
}], "Text"],

Cell[BoxData[{
    \(Clear[h]\), 
    \(aug\  = \ {{2, \(-6\), \(-3\)}, {\(-4\), 12, h}}\)}], "Input"],

Cell[BoxData[
    \(RowReduce[aug]\)], "Input"],

Cell["\<\
This says that the corresponding system is always inconsistent.  For almost \
all values of h this is correct, but it is incorrect for one value of h.  \
Let's do row operations and see what happened and what the answer should \
be.\
\>", "Text"],

Cell[BoxData[
    \(aug[\([2]\)]\  = \ aug[\([2]\)]\  + \ 2\ aug[\([1]\)]; \ aug\)], "Input"],

Cell[TextData[{
  StyleBox["RowReduce", "Input"],
  " acted as if ",
  Cell[BoxData[
      \(TraditionalForm\`h - 6 \[NotEqual] 0\)]],
  " (i.e., ",
  Cell[BoxData[
      \(TraditionalForm\`h \[NotEqual] 6\)]],
  ") and scaled the second row by multiply it by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(h - 6\)\)]],
  ".  In this problem, however, the case where ",
  Cell[BoxData[
      \(TraditionalForm\`h = 6\)]],
  " should not be overlooked!  (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s other functions that solve equations also make the same \"mistake.\")"
}], "Text"],

Cell["The system is consistent if h = 6.", "Text"],

Cell[TextData[{
  StyleBox["The moral",
    FontVariations->{"Underline"->True}],
  ":  With numbers, you may use ",
  StyleBox["RowReduce", "Input"],
  " (or other solving functions).  With letter parameters, you can only trust \
elementary row operations for complete parameter analysis, i.e., deciding \
which values give 0, 1, or infinitely many solutions."
}], "Text"],

Cell["\<\
By the way, with h=6, let's do a final scaling operation on the first row to \
express all solutions.\
\>", "Text"],

Cell[BoxData[
    \(aug[\([1]\)]\  = \ 1/2\ \ aug[\([1]\)]; \ aug\)], "Input"],

Cell[TextData[{
  "The answer is:\n\twhen ",
  Cell[BoxData[
      \(TraditionalForm\`h = 6\)]],
  ", the system is consistent with solution ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 = \(-\(3\/2\)\) + 3  x\_2, \ x\_2\ is\ free\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Optional:  Parametric formulas", "Subsubsection"],

Cell["\<\
If you are willing to assume nonzero pivots (parametric expressions in pivot \
postitions are nonzero), then RowReduce or other solving functions are \
useful.  For example, maybe you know from physical constraints that there \
exists a unique solution to the following problem, in terms of h.\
\>", "Text"],

Cell[BoxData[{
    \(Clear[h]\), 
    \(aug\  = \ {{1, h, \(-2\)}, {\(-4\), 2, 10}}\)}], "Input"],

Cell[BoxData[
    \(RowReduce[aug]\)], "Input"],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`h \[NotEqual] \(-\(1\/2\)\)\)]],
  ", with unique solution is ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 = \(\(-5\) h - 2\)\/\(2  h + 1\), \ 
      x\_2 = 1\/\(2  h + 1\)\)]],
  "."
}], "Text"],

Cell["\<\
Comparatively, the above Parameter analysis example that preceeded this had \
only 0 or inifinitely many solutions.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 1  Elementary Row Operations", "Section"],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 1a", "Subsection"],

Cell[CellGroupData[{

Cell["Ab = {{-1,2,1,0},{0,-2,-1,2},{-1,1,0,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "2", "1", "0"},
            {"0", \(-2\), \(-1\), "2"},
            {\(-1\), "1", "0", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R = Ab;
R\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "2", "1", "0"},
            {"0", \(-2\), \(-1\), "2"},
            {\(-1\), "1", "0", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[1]] = -R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-2\), \(-1\), 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = R[[3]]+R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, \(-1\), \(-1\), 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), \(-1\), "0"},
            {"0", \(-2\), \(-1\), "2"},
            {"0", \(-1\), \(-1\), "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = (-1/2)R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 1, 1\/2, \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = R[[3]] + R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, \(-\(1\/2\)\), 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), \(-1\), "0"},
            {"0", "1", \(1\/2\), \(-1\)},
            {"0", "0", \(-\(1\/2\)\), "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = -2 R[[3]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 1, \(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), \(-1\), "0"},
            {"0", "1", \(1\/2\), \(-1\)},
            {"0", "0", "1", \(-4\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Ans:  The system has a unique solution.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 1b", "Subsection"],

Cell[CellGroupData[{

Cell["Ab =  {{0,-1,-1,1},{-1,0,1,0},{1,-2,1,-2},{1,-1,1,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-1\), \(-1\), "1"},
            {\(-1\), "0", "1", "0"},
            {"1", \(-2\), "1", \(-2\)},
            {"1", \(-1\), "1", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R = Ab;
R\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-1\), \(-1\), "1"},
            {\(-1\), "0", "1", "0"},
            {"1", \(-2\), "1", \(-2\)},
            {"1", \(-1\), "1", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R = R[[{3,2,1,4}]]; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {\(-1\), "0", "1", "0"},
            {"0", \(-1\), \(-1\), "1"},
            {"1", \(-1\), "1", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = R[[2]]+R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, \(-2\), 2, \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[4]] = R[[4]]-R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 1, 0, 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {"0", \(-2\), "2", \(-2\)},
            {"0", \(-1\), \(-1\), "1"},
            {"0", "1", "0", "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = (-1/2)R[[2]]; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {"0", "1", \(-1\), "1"},
            {"0", \(-1\), \(-1\), "1"},
            {"0", "1", "0", "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = R[[3]] + R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, \(-2\), 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[4]] = R[[4]] - R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 1, 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {"0", "1", \(-1\), "1"},
            {"0", "0", \(-2\), "2"},
            {"0", "0", "1", "4"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = (-1/2) R[[3]]; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {"0", "1", \(-1\), "1"},
            {"0", "0", "1", \(-1\)},
            {"0", "0", "1", "4"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[4]] = R[[4]] - R[[3]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 0, 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "1", \(-2\)},
            {"0", "1", \(-1\), "1"},
            {"0", "0", "1", \(-1\)},
            {"0", "0", "0", "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Ans:  The system has no solution, since 0 x1 + 0 x2 + 0 x3 = 5 can never be   \
true.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 1c", "Subsection"],

Cell[CellGroupData[{

Cell["Ab = {{-1,3,2,-3},{-2,6,3,-1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "3", "2", \(-3\)},
            {\(-2\), "6", "3", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R = Ab;
R\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "3", "2", \(-3\)},
            {\(-2\), "6", "3", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[1]] = -R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-3\), \(-2\), 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-3\), \(-2\), "3"},
            {\(-2\), "6", "3", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = R[[2]]+2*R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, \(-1\), 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = -R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 1, \(-5\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-3\), \(-2\), "3"},
            {"0", "0", "1", \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Ans:  The system has infinitely many solutions, since x2 can be a free  \
variable.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 1d", "Subsection"],

Cell[CellGroupData[{

Cell["Ab =  {{3,2,1,8},{0,-2,2,-2},{-3,-1,-2,-7},{3,1,2,7}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", "2", "1", "8"},
            {"0", \(-2\), "2", \(-2\)},
            {\(-3\), \(-1\), \(-2\), \(-7\)},
            {"3", "1", "2", "7"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R = Ab;
R\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", "2", "1", "8"},
            {"0", \(-2\), "2", \(-2\)},
            {\(-3\), \(-1\), \(-2\), \(-7\)},
            {"3", "1", "2", "7"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[1]] = (1/3)R[[1]]; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(2\/3\), \(1\/3\), \(8\/3\)},
            {"0", \(-2\), "2", \(-2\)},
            {\(-3\), \(-1\), \(-2\), \(-7\)},
            {"3", "1", "2", "7"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = R[[3]]+3*R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 1, \(-1\), 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[4]] = R[[4]]-3*R[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, \(-1\), 1, \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(2\/3\), \(1\/3\), \(8\/3\)},
            {"0", \(-2\), "2", \(-2\)},
            {"0", "1", \(-1\), "1"},
            {"0", \(-1\), "1", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[2]] = (-1/2)R[[2]]; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(2\/3\), \(1\/3\), \(8\/3\)},
            {"0", "1", \(-1\), "1"},
            {"0", "1", \(-1\), "1"},
            {"0", \(-1\), "1", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[3]] = R[[3]] - R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R[[4]] = R[[4]] + R[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(2\/3\), \(1\/3\), \(8\/3\)},
            {"0", "1", \(-1\), "1"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Ans:  The system  has infinitely many solutions, since x3 can be a free  \
variable.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1: 2  Row Reduce (randint, AppendRows)", "Section"],

Cell["\<\
randint[m_,n_,k_:9] := 
\tTable[Random[Integer,{-k,k}],{m},{n}]\
\>", "Input"],

Cell[CellGroupData[{

Cell["A = randint[3,4,5]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-3\), "1", \(-1\)},
            {"4", "0", "1", "2"},
            {"5", "4", \(-5\), "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b = randint[3,1,5]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\)},
            {"5"},
            {\(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", \(27\/47\)},
            {"0", "1", "0", \(-\(16\/47\)\)},
            {"0", "0", "1", \(-\(14\/47\)\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< \ LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ab\  = \ AppendRows[A, b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-3\), "1", \(-1\), \(-2\)},
            {"4", "0", "1", "2", "5"},
            {"5", "4", \(-5\), "3", \(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Ab]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", \(27\/47\), \(38\/47\)},
            {"0", "1", "0", \(-\(16\/47\)\), \(21\/47\)},
            {"0", "0", "1", \(-\(14\/47\)\), \(83\/47\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.1; 7  Magic Square Application", "Section"],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Ab = {{1,1,1,0,0,0,12},{0,0,0,1,1,1,12},{1,0,0,1,0,0,4},
 {0,1,0,0,1,0,11},{0,0,1,0,0,1,9},{0,1,0,0,0,1,4},{0,1,0,1,0,0,9}} \
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "0", "0", "0", "12"},
            {"0", "0", "0", "1", "1", "1", "12"},
            {"1", "0", "0", "1", "0", "0", "4"},
            {"0", "1", "0", "0", "1", "0", "11"},
            {"0", "0", "1", "0", "0", "1", "9"},
            {"0", "1", "0", "0", "0", "1", "4"},
            {"0", "1", "0", "1", "0", "0", "9"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R = Ab; R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "0", "0", "0", "12"},
            {"0", "0", "0", "1", "1", "1", "12"},
            {"1", "0", "0", "1", "0", "0", "4"},
            {"0", "1", "0", "0", "1", "0", "11"},
            {"0", "0", "1", "0", "0", "1", "9"},
            {"0", "1", "0", "0", "0", "1", "4"},
            {"0", "1", "0", "1", "0", "0", "9"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[R]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0", "0", \(-1\)},
            {"0", "1", "0", "0", "0", "0", "4"},
            {"0", "0", "1", "0", "0", "0", "9"},
            {"0", "0", "0", "1", "0", "0", "5"},
            {"0", "0", "0", "0", "1", "0", "7"},
            {"0", "0", "0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Ans:  x1=-1, x2=4, x3=9, x4=5, x5=7, x6=0, So the magic square is:\
\>", "Text"],

Cell[CellGroupData[{

Cell["{{8,1,3},{-1,4,9},{5,7,0}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"8", "1", "3"},
            {\(-1\), "4", "9"},
            {"5", "7", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b) first form", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Ab = {{1,1,0,0,0,0,5},{0,0,1,1,0,0,4},{0,0,0,0,1,1,3},
  {0,0,1,0,1,0,5},{1,0,0,0,0,1,4},{0,1,0,1,0,0,3},
 {0,1,0,0,1,0,4}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "0", "0", "0", "0", "5"},
            {"0", "0", "1", "1", "0", "0", "4"},
            {"0", "0", "0", "0", "1", "1", "3"},
            {"0", "0", "1", "0", "1", "0", "5"},
            {"1", "0", "0", "0", "0", "1", "4"},
            {"0", "1", "0", "1", "0", "0", "3"},
            {"0", "1", "0", "0", "1", "0", "4"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[Ab]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0", "1", "4"},
            {"0", "1", "0", "0", "0", \(-1\), "1"},
            {"0", "0", "1", "0", "0", \(-1\), "2"},
            {"0", "0", "0", "1", "0", "1", "2"},
            {"0", "0", "0", "0", "1", "1", "3"},
            {"0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Ans:  There are infinitely many magic squares of the first form, since x6 can \
be a free variable.
We let x6= 0 to get the following magic square:\
\>", "Text"],

Cell[CellGroupData[{

Cell["{{1,4,1},{2,2,2},{3,0,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "4", "1"},
            {"2", "2", "2"},
            {"3", "0", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b) second form", "Subsection"],

Cell["\<\
Define unknowns x1 to x6 for each question mark and let x7 bethe unknown sum \
of any row, etc.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Ab = {{1,0,0,0,0,0,-1,-4},{0,1,1,0,0,0,-1,-2},{0,0,0,1,1,1,-1,0},
  {0,1,0,1,0,0,-1,-1},{1,0,0,0,1,0,-1,-2},{0,0,1,0,0,1,-1,-3},
  {0,0,0,0,0,1,-1,-3},{0,0,0,1,0,0,-1,-5}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0", "0", \(-1\), \(-4\)},
            {"0", "1", "1", "0", "0", "0", \(-1\), \(-2\)},
            {"0", "0", "0", "1", "1", "1", \(-1\), "0"},
            {"0", "1", "0", "1", "0", "0", \(-1\), \(-1\)},
            {"1", "0", "0", "0", "1", "0", \(-1\), \(-2\)},
            {"0", "0", "1", "0", "0", "1", \(-1\), \(-3\)},
            {"0", "0", "0", "0", "0", "1", \(-1\), \(-3\)},
            {"0", "0", "0", "1", "0", "0", \(-1\), \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[Ab]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0", "0", "0", "2"},
            {"0", "1", "0", "0", "0", "0", "0", "4"},
            {"0", "0", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "1", "0", "0", "2"},
            {"0", "0", "0", "0", "0", "1", "0", "3"},
            {"0", "0", "0", "0", "0", "0", "1", "6"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Ans:  The magic square is:", "Text"],

Cell[CellGroupData[{

Cell["{{1,2,3},{4,2,0},{1,2,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3"},
            {"4", "2", "0"},
            {"1", "2", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{575, 399},
WindowMargins->{{Automatic, 107}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 162, 4, 66, "Subsubtitle"],
Cell[1896, 57, 238, 6, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2171, 68, 59, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[2255, 72, 182, 6, 74, "Section"],

Cell[CellGroupData[{
Cell[2462, 82, 47, 0, 47, "Subsection"],
Cell[2512, 84, 90, 2, 33, "Text"],
Cell[2605, 88, 124, 3, 33, "Text"],
Cell[2732, 93, 71, 0, 30, "Input"],
Cell[2806, 95, 211, 7, 34, "Text"],
Cell[3020, 104, 638, 17, 92, "Text"],
Cell[3661, 123, 45, 1, 30, "Input"],
Cell[3709, 126, 682, 18, 91, "Text"],
Cell[4394, 146, 36, 1, 30, "Input"],
Cell[4433, 149, 202, 6, 34, "Text"],
Cell[4638, 157, 49, 0, 30, "Input"],
Cell[4690, 159, 212, 5, 53, "Text"],
Cell[4905, 166, 36, 1, 30, "Input"],
Cell[4944, 169, 232, 5, 53, "Text"],
Cell[5179, 176, 61, 3, 48, "Input"],
Cell[5243, 181, 373, 9, 72, "Text"],
Cell[5619, 192, 121, 3, 33, "Text"],
Cell[5743, 197, 87, 1, 30, "Input"],
Cell[5833, 200, 370, 7, 71, "Text"],
Cell[6206, 209, 335, 8, 71, "Text"],
Cell[6544, 219, 480, 13, 99, "Text"],
Cell[7027, 234, 1421, 29, 204, "Text"],
Cell[8451, 265, 66, 0, 33, "Text"],
Cell[8520, 267, 36, 1, 30, "Input"],
Cell[8559, 270, 287, 5, 71, "Text"],
Cell[8849, 277, 81, 1, 30, "Input"],
Cell[8933, 280, 138, 3, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9108, 288, 148, 5, 32, "Subsection"],
Cell[9259, 295, 69, 0, 33, "Text"],
Cell[9331, 297, 71, 0, 30, "Input"],
Cell[9405, 299, 47, 1, 30, "Input"],
Cell[9455, 302, 93, 2, 33, "Text"],
Cell[9551, 306, 499, 8, 109, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10087, 319, 45, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[10157, 323, 72, 0, 43, "Subsubsection"],
Cell[10232, 325, 224, 8, 33, "Text"],
Cell[10459, 335, 102, 2, 50, "Input"],
Cell[10564, 339, 47, 1, 30, "Input"],
Cell[10614, 342, 256, 5, 71, "Text"],
Cell[10873, 349, 93, 1, 30, "Input"],
Cell[10969, 352, 599, 18, 74, "Text"],
Cell[11571, 372, 50, 0, 33, "Text"],
Cell[11624, 374, 373, 8, 72, "Text"],
Cell[12000, 384, 125, 3, 33, "Text"],
Cell[12128, 389, 78, 1, 30, "Input"],
Cell[12209, 392, 249, 7, 55, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12495, 404, 55, 0, 29, "Subsubsection"],
Cell[12553, 406, 317, 5, 71, "Text"],
Cell[12873, 413, 97, 2, 50, "Input"],
Cell[12973, 417, 47, 1, 30, "Input"],
Cell[13023, 420, 267, 9, 36, "Text"],
Cell[13293, 431, 139, 3, 52, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13493, 441, 59, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[13577, 445, 36, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[13638, 449, 57, 0, 30, "Input"],
Cell[13698, 451, 259, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13994, 463, 34, 3, 48, "Input"],
Cell[14031, 468, 259, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14327, 480, 33, 0, 30, "Input"],
Cell[14363, 482, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14473, 488, 39, 0, 30, "Input"],
Cell[14515, 490, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14625, 496, 18, 0, 30, "Input"],
Cell[14646, 498, 265, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14948, 510, 38, 0, 30, "Input"],
Cell[14989, 512, 71, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15097, 518, 41, 0, 30, "Input"],
Cell[15141, 520, 75, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15253, 526, 18, 0, 30, "Input"],
Cell[15274, 528, 271, 7, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15582, 540, 35, 0, 30, "Input"],
Cell[15620, 542, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15725, 548, 18, 0, 30, "Input"],
Cell[15746, 550, 264, 7, 71, "Output"]
}, Open  ]],
Cell[16025, 560, 55, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16117, 565, 36, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[16178, 569, 70, 0, 30, "Input"],
Cell[16251, 571, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16587, 584, 34, 3, 48, "Input"],
Cell[16624, 589, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16960, 602, 38, 0, 30, "Input"],
Cell[17001, 604, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17337, 617, 39, 0, 30, "Input"],
Cell[17379, 619, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17489, 625, 39, 0, 30, "Input"],
Cell[17531, 627, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17631, 633, 18, 0, 30, "Input"],
Cell[17652, 635, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17988, 648, 41, 0, 30, "Input"],
Cell[18032, 650, 296, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18365, 663, 41, 0, 30, "Input"],
Cell[18409, 665, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18514, 671, 41, 0, 30, "Input"],
Cell[18558, 673, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18658, 679, 18, 0, 30, "Input"],
Cell[18679, 681, 293, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19009, 694, 42, 0, 30, "Input"],
Cell[19054, 696, 293, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19384, 709, 41, 0, 30, "Input"],
Cell[19428, 711, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19528, 717, 18, 0, 30, "Input"],
Cell[19549, 719, 293, 8, 80, "Output"]
}, Open  ]],
Cell[19857, 730, 109, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20003, 738, 36, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[20064, 742, 47, 0, 30, "Input"],
Cell[20114, 744, 225, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20376, 755, 34, 3, 48, "Input"],
Cell[20413, 760, 225, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20675, 771, 33, 0, 30, "Input"],
Cell[20711, 773, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20821, 779, 18, 0, 30, "Input"],
Cell[20842, 781, 225, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21104, 792, 41, 0, 30, "Input"],
Cell[21148, 794, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21253, 800, 33, 0, 30, "Input"],
Cell[21289, 802, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21394, 808, 18, 0, 30, "Input"],
Cell[21415, 810, 222, 6, 44, "Output"]
}, Open  ]],
Cell[21652, 819, 107, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21796, 827, 36, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[21857, 831, 70, 0, 30, "Input"],
Cell[21930, 833, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22266, 846, 34, 3, 48, "Input"],
Cell[22303, 851, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22639, 864, 40, 0, 30, "Input"],
Cell[22682, 866, 314, 8, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23033, 879, 41, 0, 30, "Input"],
Cell[23077, 881, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23182, 887, 41, 0, 30, "Input"],
Cell[23226, 889, 73, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23336, 895, 18, 0, 30, "Input"],
Cell[23357, 897, 311, 8, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23705, 910, 41, 0, 30, "Input"],
Cell[23749, 912, 308, 8, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24094, 925, 41, 0, 30, "Input"],
Cell[24138, 927, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24238, 933, 41, 0, 30, "Input"],
Cell[24282, 935, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24382, 941, 18, 0, 30, "Input"],
Cell[24403, 943, 299, 8, 89, "Output"]
}, Open  ]],
Cell[24717, 954, 108, 3, 33, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24874, 963, 66, 0, 33, "Section"],
Cell[24943, 965, 88, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[25056, 972, 35, 0, 30, "Input"],
Cell[25094, 974, 259, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25390, 986, 35, 0, 30, "Input"],
Cell[25428, 988, 208, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25673, 1000, 45, 1, 30, "Input"],
Cell[25721, 1003, 278, 7, 89, "Output"]
}, Open  ]],
Cell[26014, 1013, 71, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[26110, 1018, 58, 1, 30, "Input"],
Cell[26171, 1021, 280, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26488, 1033, 46, 1, 30, "Input"],
Cell[26537, 1036, 314, 7, 89, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[26900, 1049, 58, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[26983, 1053, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[27033, 1057, 149, 3, 48, "Input"],
Cell[27185, 1062, 491, 11, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27713, 1078, 26, 0, 30, "Input"],
Cell[27742, 1080, 491, 11, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28270, 1096, 29, 0, 30, "Input"],
Cell[28302, 1098, 491, 11, 134, "Output"]
}, Open  ]],
Cell[28808, 1112, 90, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[28923, 1118, 43, 0, 30, "Input"],
Cell[28969, 1120, 235, 7, 62, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29253, 1133, 36, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[29314, 1137, 148, 4, 66, "Input"],
Cell[29465, 1143, 488, 11, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29990, 1159, 30, 0, 30, "Input"],
Cell[30023, 1161, 494, 11, 134, "Output"]
}, Open  ]],
Cell[30532, 1175, 171, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[30728, 1183, 42, 0, 30, "Input"],
Cell[30773, 1185, 232, 7, 62, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31054, 1198, 37, 0, 47, "Subsection"],
Cell[31094, 1200, 119, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[31238, 1207, 196, 4, 66, "Input"],
Cell[31437, 1213, 622, 12, 152, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32096, 1230, 30, 0, 30, "Input"],
Cell[32129, 1232, 577, 12, 152, "Output"]
}, Open  ]],
Cell[32721, 1247, 42, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[32788, 1251, 42, 0, 30, "Input"],
Cell[32833, 1253, 232, 7, 62, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

