(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    184808,       4336]*)
(*NotebookOutlinePosition[    185546,       4362]*)
(*  CellTagsIndexPosition[    185502,       4358]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College,  6/1/98."
}], "Subsubtitle"],

Cell[TextData[{
  "Created for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.  To make matrices appear in rectangular arrays, I suggest menu \
choice:  Cell, Default Output Format Type set to TraditionalForm."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 1.2  Projects on Linear Systems", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
Bonus:  Tutorial on LinearSolve, vectors and numerical values\
\>", "Section"],

Cell[CellGroupData[{

Cell["Numeric (Decimal Point or N[ ]) vs Exact", "Subsection"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", calculations with integers are always kept exact by using symbolic \
expressions."
}], "Text"],

Cell["{1/3, Sqrt[2], Cos[Pi/7]}", "Input"],

Cell["\<\
While this is often helpful, sometimes we prefer the numerical decimal form.  \
All it takes is one decimal point somewhere in each numeric expression to \
accomplish this.  These results are actually internally computed to about 16 \
significant digits, though only six are usually displayed.  \
\>", "Text"],

Cell["{1./3, Sqrt[2.], Cos[Pi/7.]}", "Input"],

Cell[TextData[{
  "Alternatively, the ",
  StyleBox["N[ ]", "Input"],
  " function converts to this numerical (decimal) form."
}], "Text"],

Cell[BoxData[
    \({N[1/3], \ N[Sqrt[2]], \ N[Cos[Pi/7]]}\)], "Input"],

Cell[TextData[{
  "As with many functions, when ",
  StyleBox["N", "Input"],
  " is applied to a list, it automatically operates on each entry."
}], "Text"],

Cell["N[{1/3, Sqrt[2], Cos[Pi/7]}]", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Vectors versus Matrices", "Subsection"],

Cell[TextData[{
  "A ",
  StyleBox["vector",
    FontWeight->"Bold"],
  " is represented by a list.   For example,"
}], "Text"],

Cell["{1, 2, 3}", "Input"],

Cell[TextData[{
  "A ",
  StyleBox["matrix",
    FontWeight->"Bold"],
  " is represented by a list of vectors.   Each vector represents a row of \
the matrix.  Here is an example of a 2\[Cross]3 matrix."
}], "Text"],

Cell["{{1,2,3},{4,5,6}}", "Input"],

Cell["\<\
We can create a one row matrix, where the double brace (parentheses in \
TraditionalForm output) makes it different than a vector.\
\>", "Text"],

Cell[BoxData[
    \({{1, 2, 3}}\)], "Input"],

Cell["Or a one-column matrix.", "Text"],

Cell[BoxData[
    \({{1}, {2}, {3}}\)], "Input"],

Cell[TextData[{
  "However, the vector form ",
  StyleBox["{1,2,3}", "Input"],
  " is simpler and more flexible in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  With matrices, the shape has to be exactly right to make things work.  \
In contrast, a vector can be used in matrix computations as either a column \
matrix or as a row matrix, whichever is consistent with the computation.  The \
vector form is also the way to interpret the output of many built-in matrix \
functions that return a vector or a lists of vectors."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearSolve A x = b and augmenting A with b", "Subsection"],

Cell["A = {{1,2,-1},{2,-1,1},{-1,2,3}}", "Input"],

Cell["bvec = {6,12,18}  (* vector *)", "Input"],

Cell["LinearSolve will return ONE solution of Ax=b, if one exists.", "Text"],

Cell[BoxData[
    \(LinearSolve[A, \ bvec]\)], "Input"],

Cell["\<\
LinearSolve also works if the vector b is written as a one-column matrix.\
\>", "Text"],

Cell[BoxData[
    \(bcol\  = \ {{6}, {12}, {18}}\)], "Input"],

Cell[BoxData[
    \(LinearSolve[A, \ bcol]\)], "Input"],

Cell["\<\
Alternatively, we could RowReduce the augmented matrix and interpret the \
result.  The function AppendRows is defined in a package that must be loaded \
BEFORE mentioning AppendRows.  AppendRows only works with b written as a \
one-column matrix.\
\>", "Text"],

Cell[BoxData[
    \(<< \ LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[BoxData[
    \(aug\  = \ AppendRows[A, bcol]\)], "Input"],

Cell[BoxData[
    \(RowReduce[aug]\)], "Input"],

Cell["\<\
Unfortunately, if there is more than one solution LinearSolve still only \
returns one.  Here is a different A matrix that we use with the same b.\
\>", "Text"],

Cell[BoxData[
    \(A2\  = \ {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}}\)], "Input"],

Cell[BoxData[
    \(LinearSolve[A2, bvec]\)], "Input"],

Cell["\<\
This a correct solution but there are infinitely many!  The following shows \
that x3 is a free variable.\
\>", "Text"],

Cell[BoxData[
    \(aug2\  = \ AppendRows[A2, bcol]\)], "Input"],

Cell[BoxData[
    \(RowReduce[aug2]\)], "Input"],

Cell["Here is a function that augments with a vector or matrix.", "Text"],

Cell["\<\
Clear[augment]
augment[A_, B_?MatrixQ] := 
   Transpose[Join[Transpose[A],Transpose[B]]]  
augment[A_, b_?VectorQ] := 
   Transpose[Append[Transpose[A],b]]\
\>", "Input"],

Cell[BoxData[
    \(augment[A, bvec]\)], "Input"],

Cell[BoxData[
    \(augment[A, bcol]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.2; 3 -- Ski Jump -- Tutorial and Instructions.", "Section"],

Cell[CellGroupData[{

Cell["\<\
(a & b) quadratic through (0,7), (1,6), (2,9)  -- an example tutorial.\
\>", "Subsection"],

Cell["\<\
Let's find a quadratic polynomial  a x^2 + b x + c  that goes through (0,7), \
(1,6) and (2,9).  Form three equations in unknowns {a,b,c} by plugging these \
points into the equation:  ax^2+bx+c=y.  Get the coefficient matrix A and the \
right-side vector y.\
\>", "Text"],

Cell["\<\
So:  0a+0b+c=7
       1a+1b+c=6
       4a+2b+c=9\
\>", "Text"],

Cell["A = {{0,0,1},{1,1,1},{4,2,1}}", "Input"],

Cell["y = {7,6,9}", "Input"],

Cell["p = LinearSolve[A,y]", "Input"],

Cell["These are the coefficients {a,b,c} in ax^2+bx+c.", "Text"],

Cell["Observe how the \"period\" product multiplies vectors:", "Text"],

Cell["\<\
Clear[a,b,c,r,s,t]
{a,b,c}.{r,s,t}\
\>", "Input"],

Cell["\<\
Thus we can define the polynomial as follows, make sure to include the _ \
behind x to indicate that it  will be variable.\
\>", "Text"],

Cell["f[x_] = p.{x^2,x,1}", "Input"],

Cell["Plot[f[x],{x,0,2}];", "Input"],

Cell["Plot[f[x],{x,0,2}, GridLines->Automatic, PlotRange->All];", "Input"],

Cell["Ans: 2x^2-3x+7 certainly passes through (0,7), (1,6), (2,9)", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assignment:  complete (c) through (h)", "Subsection"],

Cell["\<\
Describe, with text, where your equations come from.
As in (a & b) example, define and plot the functions (show gridlines) that \
interpolate the points.\
\>", "Text"],

Cell["\<\
(c & d)  Find a cubic polynomial thru (-2,6), (1,4), (2,3), (3,-2)\
\>", "Subsubsection"],

Cell["\<\
(e & f)  Find a 4th degree polynomial thru (0,0), (1,1), (-1,3) with slope 20 \
at -1 and 9 at 1.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
(g & h)  Design a ski jump that has the following specifications.\
\>", "Subsubsection"],

Cell["\<\
The ski jump starts at a height of 100 ft and finishes at a height of 10 ft.  \
From start to finish, the ski jump covers a horizontal distance of 120 feet.  \
A skier using the jump will start off horizontally and will fly off the end \
at a 30 degree angle from the horizontal.  Find a polynomial whose graph is a \
side view of the ski jump.\
\>", "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 1.2; 3 -- Ski Jump -- Solutions", "Section"],

Cell[CellGroupData[{

Cell["\<\
(a & b) quadratic through (0,7), (1,6), (2,9)  -- an example tutorial.\
\>", "Subsection"],

Cell["\<\
Let's find a quadratic polynomial  a x^2 + b x + c  that goes through (0,7), \
(1,6) and (2,9).  Form three equations in unknowns {a,b,c} by plugging these \
points into the equation:  ax^2+bx+c=y.  Get the coefficient matrix A and the \
right-side vector y.\
\>", "Text"],

Cell["\<\
So:  0a+0b+c=7
       1a+1b+c=6
       4a+2b+c=9\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = {{0,0,1},{1,1,1},{4,2,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "1"},
            {"1", "1", "1"},
            {"4", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y = {7,6,9}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{7, 6, 9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p = LinearSolve[A,y]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2, \(-3\), 7}\)], "Output"]
}, Open  ]],

Cell["These are the coefficients {a,b,c} in ax^2+bx+c.", "Text"],

Cell["Observe how the \"period\" product multiplies vectors:", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c,r,s,t]
{a,b,c}.{r,s,t}\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ r + b\ s + c\ t\)], "Output"]
}, Open  ]],

Cell["\<\
Thus we can define the polynomial as follows, make sure to include the _ \
behind x to indicate that it  will be variable.\
\>", "Text"],

Cell[CellGroupData[{

Cell["f[x_] = p.{x^2,x,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ x\^2 - 3\ x + 7\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,0,2}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 -1.09186 0.188353 [
[.2619 .02576 -9 -9 ]
[.2619 .02576 9 0 ]
[.5 .02576 -3 -9 ]
[.5 .02576 3 0 ]
[.7381 .02576 -9 -9 ]
[.7381 .02576 9 0 ]
[.97619 .02576 -3 -9 ]
[.97619 .02576 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22661 -6 -4.5 ]
[.01131 .22661 0 4.5 ]
[.01131 .32079 -18 -4.5 ]
[.01131 .32079 0 4.5 ]
[.01131 .41497 -6 -4.5 ]
[.01131 .41497 0 4.5 ]
[.01131 .50914 -18 -4.5 ]
[.01131 .50914 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .03826 m
.2619 .04451 L
s
[(0.5)] .2619 .02576 0 1 Mshowa
.5 .03826 m
.5 .04451 L
s
[(1)] .5 .02576 0 1 Mshowa
.7381 .03826 m
.7381 .04451 L
s
[(1.5)] .7381 .02576 0 1 Mshowa
.97619 .03826 m
.97619 .04451 L
s
[(2)] .97619 .02576 0 1 Mshowa
.125 Mabswid
.07143 .03826 m
.07143 .04201 L
s
.11905 .03826 m
.11905 .04201 L
s
.16667 .03826 m
.16667 .04201 L
s
.21429 .03826 m
.21429 .04201 L
s
.30952 .03826 m
.30952 .04201 L
s
.35714 .03826 m
.35714 .04201 L
s
.40476 .03826 m
.40476 .04201 L
s
.45238 .03826 m
.45238 .04201 L
s
.54762 .03826 m
.54762 .04201 L
s
.59524 .03826 m
.59524 .04201 L
s
.64286 .03826 m
.64286 .04201 L
s
.69048 .03826 m
.69048 .04201 L
s
.78571 .03826 m
.78571 .04201 L
s
.83333 .03826 m
.83333 .04201 L
s
.88095 .03826 m
.88095 .04201 L
s
.92857 .03826 m
.92857 .04201 L
s
.25 Mabswid
0 .03826 m
1 .03826 L
s
.02381 .13244 m
.03006 .13244 L
s
[(6.5)] .01131 .13244 1 0 Mshowa
.02381 .22661 m
.03006 .22661 L
s
[(7)] .01131 .22661 1 0 Mshowa
.02381 .32079 m
.03006 .32079 L
s
[(7.5)] .01131 .32079 1 0 Mshowa
.02381 .41497 m
.03006 .41497 L
s
[(8)] .01131 .41497 1 0 Mshowa
.02381 .50914 m
.03006 .50914 L
s
[(8.5)] .01131 .50914 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(9)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .05709 m
.02756 .05709 L
s
.02381 .07593 m
.02756 .07593 L
s
.02381 .09477 m
.02756 .09477 L
s
.02381 .1136 m
.02756 .1136 L
s
.02381 .15127 m
.02756 .15127 L
s
.02381 .17011 m
.02756 .17011 L
s
.02381 .18894 m
.02756 .18894 L
s
.02381 .20778 m
.02756 .20778 L
s
.02381 .24545 m
.02756 .24545 L
s
.02381 .26428 m
.02756 .26428 L
s
.02381 .28312 m
.02756 .28312 L
s
.02381 .30195 m
.02756 .30195 L
s
.02381 .33962 m
.02756 .33962 L
s
.02381 .35846 m
.02756 .35846 L
s
.02381 .3773 m
.02756 .3773 L
s
.02381 .39613 m
.02756 .39613 L
s
.02381 .4338 m
.02756 .4338 L
s
.02381 .45264 m
.02756 .45264 L
s
.02381 .47147 m
.02756 .47147 L
s
.02381 .49031 m
.02756 .49031 L
s
.02381 .52798 m
.02756 .52798 L
s
.02381 .54681 m
.02756 .54681 L
s
.02381 .56565 m
.02756 .56565 L
s
.02381 .58448 m
.02756 .58448 L
s
.02381 .01942 m
.02756 .01942 L
s
.02381 .00059 m
.02756 .00059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .22661 m
.06244 .18325 L
.10458 .14161 L
.14415 .10787 L
.18221 .08033 L
.22272 .05631 L
.26171 .03834 L
.28158 .03112 L
.30316 .02477 L
.31323 .02233 L
.32392 .02012 L
.33393 .01839 L
.34309 .0171 L
.3525 .01606 L
.35734 .01564 L
.36262 .01527 L
.36748 .01502 L
.36985 .01492 L
.372 .01485 L
.37422 .01479 L
.37632 .01475 L
.37747 .01474 L
.37853 .01472 L
.37969 .01472 L
.38092 .01472 L
.38214 .01472 L
.38283 .01472 L
.38347 .01473 L
.38464 .01474 L
.38588 .01476 L
.38803 .0148 L
.3904 .01486 L
.39292 .01495 L
.39564 .01507 L
.40056 .01535 L
.40522 .01569 L
.41012 .01613 L
.41889 .01711 L
.42844 .01846 L
.43863 .02024 L
.457 .02432 L
.47835 .03047 L
.4985 .03767 L
.53696 .05515 L
.57788 .07914 L
.61729 .1075 L
.65517 .13964 L
.69551 .1791 L
.73434 .22218 L
.77561 .27347 L
Mistroke
.81537 .32824 L
.85362 .38587 L
.89432 .45253 L
.9335 .52192 L
.97513 .60123 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00D03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool5000003L0oooo1@00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool3000000H0oooo000E
0?ooo`800000>03oool00`000000oooo000000070?ooo`030000003oool0000003X0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000003T0oooo00<00000
0?ooo`3oool01P3oool001D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo000000090?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo000000070?ooo`800000>`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00H0oooo0P00000k0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0000000H0oooo000E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01P3o
ool3000000l0oooo5`00000C0?ooo`800000>P3oool2000000P0oooo0`00000j0?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`800000C`3oool5000001L0oooo1`00002G0?ooo`005@3oool00`00
0000oooo0?ooo`180?ooo`H000008`3oool4000009<0oooo000E0?ooo`030000003oool0oooo04D0
oooo0`00000]0?ooo`<00000T03oool001D0oooo00<000000?ooo`3oool0@P3oool3000003<0oooo
0`00002=0?ooo`005@3oool00`000000oooo0?ooo`100?ooo`800000>@3oool2000008/0oooo000>
0?ooool000004`00000001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`80000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`040000003oool00000
000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0>@3oool20000
00<0oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`3oool2000003/0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0g0?oo
o`800000B`3oool200000880oooo000E0?ooo`030000003oool0oooo03D0oooo0P00001?0?ooo`80
0000P03oool001D0oooo0P00000d0?ooo`800000D`3oool2000007h0oooo000E0?ooo`030000003o
ool0oooo0340oooo0P00001G0?ooo`800000O03oool001D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1I0?ooo`800000NP3oool001D0oooo00<000000?ooo`3oool0;P3oool20000
05h0oooo0P00001h0?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`800000HP3oool2000007H0
oooo000E0?ooo`800000;03oool00`000000oooo0?ooo`1T0?ooo`800000M03oool001D0oooo00<0
00000?ooo`3oool0:@3oool2000006T0oooo00<000000?ooo`3oool0L@3oool001D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0700oooo000E0?oo
o`030000003oool0oooo02H0oooo0P00001^0?ooo`800000L03oool001D0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo06d0oooo000E0?ooo`800000
9@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo06`0oooo000E0?ooo`030000003o
ool0oooo0280oooo0P00001f0?ooo`030000003oool0oooo06/0oooo000E0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0M`3oool2000006/0oooo000E0?ooo`030000003oool0oooo
01l0oooo0P00001l0?ooo`030000003oool0oooo06P0oooo000E0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1W0?ooo`005@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0IP3oool001D0oooo0P00
000L0?ooo`800000P`3oool2000006H0oooo000E0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`1S0?ooo`005@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0HP3oool000@0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0H@3oool000@0oooo00<000000?ooo`000000
1`3oool00`000000oooo000000040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`1P0?ooo`00103oool00`000000oooo000000090?ooo`030000003o
ool0oooo0080oooo0`00000E0?ooo`800000S`3oool200000600oooo00040?ooo`800000203oool2
000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo05d0oooo00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0G03oool000D0
oooo0P0000070?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0F`3oool001D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo05X0oooo000E0?ooo`8000004@3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo05T0oooo000E0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`1H0?ooo`005@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo09d0oooo0P00001H0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0:00oooo00<000000?ooo`3oool0E@3oool001D0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo05@0oooo000E0?ooo`800000303o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo05<0oooo000E0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1B0?ooo`005@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0D@3oool001D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0500
oooo000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1?0?ooo`005@3oool2000000L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`1?0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`3oool0CP3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo04d0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`1<0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool0B`3oool001D0oooo0P0000030?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0BP3oool001D0oooo00D000000?ooo`3oool0oooo0000
002i0?ooo`030000003oool0oooo04X0oooo000E0?ooo`040000003oool0oooo00000;/0oooo00<0
00000?ooo`3oool0B@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000002m
0?ooo`030000003oool0oooo04P0oooo000?0?ooo`030000003oool0oooo00<0oooo0P00002o0?oo
o`030000003oool0oooo04L0oooo000?0?ooo`030000003oool0oooo00<0oooo0`00002o0?ooo`03
0000003oool0oooo04H0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`150?ooo`003P3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0<00oooo00<000000?ooo`3oool0A@3oool000h0oooo0`0000040?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool0A03oool001D0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`130?ooo`005@3oool200000<@0oooo00<000000?ooo`3oool0@P3oool001D0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`120?ooo`005@3oool00`000000oooo0?oo
o`340?ooo`030000003oool0oooo0440oooo000E0?ooo`030000003oool0oooo0<D0oooo00<00000
0?ooo`3oool0@03oool001D0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0o0?oo
o`005@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo03h0oooo000E0?ooo`800000
b03oool00`000000oooo0?ooo`0n0?ooo`005@3oool00`000000oooo0?ooo`380?ooo`030000003o
ool0oooo03d0oooo000E0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0?03oool0
01D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0k0?ooo`005@3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo03/0oooo000E0?ooo`800000c03oool00`000000oooo
0?ooo`0j0?ooo`005@3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo03T0oooo000E
0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0>03oool001D0oooo00<000000?oo
o`3oool0c@3oool00`000000oooo0?ooo`0h0?ooo`005@3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo03L0oooo000E0?ooo`800000d03oool00`000000oooo0?ooo`0f0?ooo`005@3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo03D0oooo000E0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool0=@3oool000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`0d0?ooo`001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0c0?ooo`001@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo0`00003C0?ooo`030000003oool0oooo0380oooo
00060?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo0=<0oooo00<0
00000?ooo`3oool0<P3oool000@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0<@3oool000@0oooo0`0000070?oo
o`<00000103oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0300oooo000E0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool0<03oool001D0oooo0P00003G0?ooo`030000
003oool0oooo02l0oooo000E0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0;P3o
ool001D0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0^0?ooo`005@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0oooo02d0oooo000E0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`3oool0;03oool001D0oooo0P00003J0?ooo`030000003oool0oooo02`0oooo
000E0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0:`3oool001D0oooo00<00000
0?ooo`3oool0f`3oool00`000000oooo0?ooo`0Z0?ooo`005@3oool00`000000oooo0?ooo`3L0?oo
o`030000003oool0oooo02T0oooo000E0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3o
ool0:@3oool001D0oooo0P00003N0?ooo`030000003oool0oooo02P0oooo000E0?ooo`030000003o
ool0oooo0=h0oooo00<000000?ooo`3oool09`3oool001D0oooo00<000000?ooo`3oool0gP3oool0
0`000000oooo0?ooo`0W0?ooo`005@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
02H0oooo000E0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool09@3oool001D0oooo
0P00003Q0?ooo`030000003oool0oooo02D0oooo000E0?ooo`030000003oool0oooo0>40oooo00<0
00000?ooo`3oool0903oool001D0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0T
0?ooo`005@3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo02<0oooo000?0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`0R0?ooo`00
3P3oool00`000000oooo000000040?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0
8P3oool000h0oooo00<000000?ooo`000000103oool300000>@0oooo00<000000?ooo`3oool08@3o
ool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0
oooo0240oooo000>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0i@3oool00`00
0000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>H0
oooo00<000000?ooo`3oool07`3oool001D0oooo00<000000?ooo`3oool0iP3oool00`000000oooo
0?ooo`0O0?ooo`005@3oool200000>P0oooo00<000000?ooo`3oool07P3oool001D0oooo00<00000
0?ooo`3oool0j03oool00`000000oooo0?ooo`0M0?ooo`005@3oool00`000000oooo0?ooo`3X0?oo
o`030000003oool0oooo01d0oooo000E0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3o
ool0703oool001D0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`0L0?ooo`005@3o
ool200000>/0oooo00<000000?ooo`3oool06`3oool001D0oooo00<000000?ooo`3oool0j`3oool0
0`000000oooo0?ooo`0J0?ooo`005@3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo
01X0oooo000E0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool06@3oool001D0oooo
00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0I0?ooo`005@3oool200000>h0oooo00<0
00000?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0H
0?ooo`005@3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo01L0oooo000E0?ooo`03
0000003oool0oooo0>h0oooo00<000000?ooo`3oool05`3oool001D0oooo00<000000?ooo`3oool0
k`3oool00`000000oooo0?ooo`0F0?ooo`005@3oool200000?00oooo00<000000?ooo`3oool05P3o
ool001D0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`0E0?ooo`005@3oool00`00
0000oooo0?ooo`3`0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool0503oool000@0oooo00<000000?ooo`0000001`3oool00`000000oooo
000000040?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0503oool000@0oooo00<0
00000?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`<00000lP3oool00`000000oooo0?oo
o`0C0?ooo`001@3oool00`000000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`3b
0?ooo`030000003oool0oooo01<0oooo00040?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo0180oooo00050?ooo`03
0000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3o
ool04P3oool001D0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0A0?ooo`005@3o
ool200000?H0oooo00<000000?ooo`3oool0403oool001D0oooo00<000000?ooo`3oool0m@3oool0
0`000000oooo0?ooo`0@0?ooo`005@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo
00l0oooo000E0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool03`3oool001D0oooo
00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`0>0?ooo`005@3oool200000?P0oooo00<0
00000?ooo`3oool03P3oool001D0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0=
0?ooo`005@3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo00`0oooo000E0?ooo`03
0000003oool0oooo0?T0oooo00<000000?ooo`3oool0303oool001D0oooo00<000000?ooo`3oool0
nP3oool00`000000oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo00/0oooo000E0?ooo`800000o03oool00`000000oooo0?ooo`0:0?ooo`005@3oool00`00
0000oooo0?ooo`3k0?ooo`030000003oool0oooo00X0oooo000E0?ooo`030000003oool0oooo0?`0
oooo00<000000?ooo`3oool02@3oool001D0oooo00<000000?ooo`3oool0o@3oool00`000000oooo
0?ooo`080?ooo`005@3oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo00P0oooo000E
0?ooo`800000o`3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo0?ooo`3n0?oo
o`030000003oool0oooo00L0oooo000E0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3o
ool01P3oool000h0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0
1P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<0
00000?ooo`3oool01@3oool000l0oooo0P0000040?ooo`<00000o`3oool10?ooo`030000003oool0
oooo00D0oooo000>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3oool90?oo
o`003P3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo2@3oool000l0oooo
0P0000040?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.165192, 5.69657, 
  0.00771848, 0.0195137}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,0,2}, GridLines->Automatic, PlotRange->All];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.476191 -1.09186 0.188353 [
[.2619 .02576 -9 -9 ]
[.2619 .02576 9 0 ]
[.5 .02576 -3 -9 ]
[.5 .02576 3 0 ]
[.7381 .02576 -9 -9 ]
[.7381 .02576 9 0 ]
[.97619 .02576 -3 -9 ]
[.97619 .02576 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .22661 -6 -4.5 ]
[.01131 .22661 0 4.5 ]
[.01131 .32079 -18 -4.5 ]
[.01131 .32079 0 4.5 ]
[.01131 .41497 -6 -4.5 ]
[.01131 .41497 0 4.5 ]
[.01131 .50914 -18 -4.5 ]
[.01131 .50914 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .03826 m
1 .03826 L
s
0 .13244 m
1 .13244 L
s
0 .22661 m
1 .22661 L
s
0 .32079 m
1 .32079 L
s
0 .41497 m
1 .41497 L
s
0 .50914 m
1 .50914 L
s
0 .60332 m
1 .60332 L
s
0 g
.2619 .03826 m
.2619 .04451 L
s
[(0.5)] .2619 .02576 0 1 Mshowa
.5 .03826 m
.5 .04451 L
s
[(1)] .5 .02576 0 1 Mshowa
.7381 .03826 m
.7381 .04451 L
s
[(1.5)] .7381 .02576 0 1 Mshowa
.97619 .03826 m
.97619 .04451 L
s
[(2)] .97619 .02576 0 1 Mshowa
.125 Mabswid
.07143 .03826 m
.07143 .04201 L
s
.11905 .03826 m
.11905 .04201 L
s
.16667 .03826 m
.16667 .04201 L
s
.21429 .03826 m
.21429 .04201 L
s
.30952 .03826 m
.30952 .04201 L
s
.35714 .03826 m
.35714 .04201 L
s
.40476 .03826 m
.40476 .04201 L
s
.45238 .03826 m
.45238 .04201 L
s
.54762 .03826 m
.54762 .04201 L
s
.59524 .03826 m
.59524 .04201 L
s
.64286 .03826 m
.64286 .04201 L
s
.69048 .03826 m
.69048 .04201 L
s
.78571 .03826 m
.78571 .04201 L
s
.83333 .03826 m
.83333 .04201 L
s
.88095 .03826 m
.88095 .04201 L
s
.92857 .03826 m
.92857 .04201 L
s
.25 Mabswid
0 .03826 m
1 .03826 L
s
.02381 .13244 m
.03006 .13244 L
s
[(6.5)] .01131 .13244 1 0 Mshowa
.02381 .22661 m
.03006 .22661 L
s
[(7)] .01131 .22661 1 0 Mshowa
.02381 .32079 m
.03006 .32079 L
s
[(7.5)] .01131 .32079 1 0 Mshowa
.02381 .41497 m
.03006 .41497 L
s
[(8)] .01131 .41497 1 0 Mshowa
.02381 .50914 m
.03006 .50914 L
s
[(8.5)] .01131 .50914 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(9)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .05709 m
.02756 .05709 L
s
.02381 .07593 m
.02756 .07593 L
s
.02381 .09477 m
.02756 .09477 L
s
.02381 .1136 m
.02756 .1136 L
s
.02381 .15127 m
.02756 .15127 L
s
.02381 .17011 m
.02756 .17011 L
s
.02381 .18894 m
.02756 .18894 L
s
.02381 .20778 m
.02756 .20778 L
s
.02381 .24545 m
.02756 .24545 L
s
.02381 .26428 m
.02756 .26428 L
s
.02381 .28312 m
.02756 .28312 L
s
.02381 .30195 m
.02756 .30195 L
s
.02381 .33962 m
.02756 .33962 L
s
.02381 .35846 m
.02756 .35846 L
s
.02381 .3773 m
.02756 .3773 L
s
.02381 .39613 m
.02756 .39613 L
s
.02381 .4338 m
.02756 .4338 L
s
.02381 .45264 m
.02756 .45264 L
s
.02381 .47147 m
.02756 .47147 L
s
.02381 .49031 m
.02756 .49031 L
s
.02381 .52798 m
.02756 .52798 L
s
.02381 .54681 m
.02756 .54681 L
s
.02381 .56565 m
.02756 .56565 L
s
.02381 .58448 m
.02756 .58448 L
s
.02381 .01942 m
.02756 .01942 L
s
.02381 .00059 m
.02756 .00059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .22661 m
.06244 .18325 L
.10458 .14161 L
.14415 .10787 L
.18221 .08033 L
.22272 .05631 L
.26171 .03834 L
.28158 .03112 L
.30316 .02477 L
.31323 .02233 L
.32392 .02012 L
.33393 .01839 L
.34309 .0171 L
.3525 .01606 L
.35734 .01564 L
.36262 .01527 L
.36748 .01502 L
.36985 .01492 L
.372 .01485 L
.37422 .01479 L
.37632 .01475 L
.37747 .01474 L
.37853 .01472 L
.37969 .01472 L
.38092 .01472 L
.38214 .01472 L
.38283 .01472 L
.38347 .01473 L
.38464 .01474 L
.38588 .01476 L
.38803 .0148 L
.3904 .01486 L
.39292 .01495 L
.39564 .01507 L
.40056 .01535 L
.40522 .01569 L
.41012 .01613 L
.41889 .01711 L
.42844 .01846 L
.43863 .02024 L
.457 .02432 L
.47835 .03047 L
.4985 .03767 L
.53696 .05515 L
.57788 .07914 L
.61729 .1075 L
.65517 .13964 L
.69551 .1791 L
.73434 .22218 L
.77561 .27347 L
Mistroke
.81537 .32824 L
.85362 .38587 L
.89432 .45253 L
.9335 .52192 L
.97513 .60123 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00D03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool5000003L0oooo1@00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool3000000H0oooo000E
0?ooo`800000>03oool00`000000oooo000000040?ooo`060000O`3oool0oooo0000003oool00000
>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00L0001o0?ooo`3oool0
oooo0000003oool0000003T0oooo00<000000000O`3oool01P3oool001D0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo000000040?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`000000103oool00`0007l0oooo0?ooo`02000003/0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`040000O`3oool0oooo0?ooo`80
0000>`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0000000@0oooo00@0001o0?ooo`3oool00000?03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0080oooo00D0001o0?ooo`3oool0oooo0000000k0?ooo`030000000007l00000
00H0oooo000E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`0007l0
oooo0?ooo`03000000l0oooo5`00000C0?ooo`800000>P3oool2000000@0oooo00@0001o0?ooo`3o
ool0oooo0`00000j0?ooo`030000003oool0oooo00D0oooo000E0?ooo`800000?`3oool00`0007l0
oooo0?ooo`0=0?ooo`D000005`3oool7000000d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0
oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo
00<0001o0?ooo`3oool01`3oool6000002<0oooo100000090?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`0n0?ooo`030000O`3oool0oooo00@0oooo0`00000]0?ooo`<000001P3oool00`0007l0oooo0?oo
o`0n0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool0?P3oool0100007l0oooo0?ooo`3oool3000003<0oooo0`0000030?ooo`030000O`3o
ool0oooo03h0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`0n0?ooo`040000O`3oool00000000003T0oooo0P0000000`3oool0001o0?oo
o`0o0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool000h0ooooo`00000C
000000005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0P0000000`3o
ool000000?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`00000000002@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`8000000`3oool00`00
0000oooo0?ooo`0m0?ooo`040000003oool0oooo0?ooo`800000>`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03L0oooo0P0000050?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool00`3oool2000003T0oooo00<0001o0?oo
o`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`80
00001`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00D0oooo0P00000g0?ooo`03
0000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000d0?ooo`800000
2@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00L0oooo0P00000e0?ooo`030000
O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0<@3o
ool2000000/0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`090?ooo`800000<`3o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo00/0oooo0P00000a0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool0;P3oool2000000h0oooo00<0001o0?ooo`3oool0?@3oool00`00
07l0oooo0?ooo`0=0?ooo`800000;`3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo02`0oooo0P00000@0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool03`3oool2000002d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0
oooo0?ooo`050?ooo`005@3oool2000002`0oooo00<000000?ooo`3oool0403oool00`0007l0oooo
0?ooo`0m0?ooo`030000O`3oool0oooo0140oooo0P00000[0?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0:@3oool2000001<0oooo00<0
001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<0
001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0D
0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`8000005P3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo01D0oooo0P00000W0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000U0?ooo`030000
003oool0oooo01L0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0H0?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`0R0?ooo`8000006P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3o
ool0oooo01T0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01X0oooo0P00000R0?ooo`030000O`3oool0
oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool07`3oool20000
01d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo
01l0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool2000001`0oooo0P00
000Q0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool07`3oool2000001d0oooo00<0
001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0240oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0Q
0?ooo`030000003oool0oooo01X0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo01T0oooo00<0001o0?oo
o`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`00103oool2000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3o
ool0603oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo00040?ooo`030000
003oool0000000L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02@0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
003oool0oooo01L0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`00103o
ool00`000000oooo000000070?ooo`80001o00<000000000O`0007l00P0007l3000001D0001o0P00
002?0000O`800000H00007l000@0oooo0P0000080?ooo`8000001@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0W
0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`05
0?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?oo
o`3oool01@3oool000D0oooo0P0000070?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo02T0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0180oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0
?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool200000140oooo00<000000?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0;03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo02`0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;@3oool00`00
07l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02d0oooo0P00000?0?ooo`030000O`3oool0oooo
03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0^0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0;`3oool00`000000
oooo0?ooo`0<0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool01@3oool001D0oooo0P00000<0?ooo`030000003oool0oooo0300oooo00<0
001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo00<0
001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0340oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0b
0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0c0?ooo`030000003oool0oooo00P0oooo00<0001o0?oo
o`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo03<0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0
?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool2000000L0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool01P3o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo03H0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=`3oool00`00
07l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03L0oooo00<000000?ooo`3oool0103oool00`00
07l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0m0?ooo`030000O`3oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo
0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`8000000`3oool00`000000oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0>P3oool01@000000oooo0?oo
o`3oool0001o0400oooo00<0001o0?ooo`3oool01@3oool001D0oooo00D000000?ooo`3oool0oooo
0000000l0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0>P3oool01@000000oooo
0?ooo`3oool0001o0400oooo00<0001o0?ooo`3oool01@3oool001D0oooo00@000000?ooo`3oool0
0000?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03/0oooo00@000000?ooo`3o
ool0001o@03oool00`0007l0oooo0?ooo`050?ooo`003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000003h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000003oool0001o0400oooo00<0001o0?ooo`3oool01@3oool000l0oooo00<000000?ooo`3oool0
0`3oool2000003l0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000
000007l0oooo03l0oooo00<0001o0?ooo`3oool01@3oool000h0oooo00<0001o0000000007l01000
07l300000;l0001o00<000000000O`0007l0AP0007l00100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool0
0`0007l000000?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000>0?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03h0oooo00<0001o0000003oool0?P3oool00`0007l0oooo0?ooo`050?ooo`003P3oool3000000@0
oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0
oooo00<0001o0?ooo`000000?P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo
0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool0100007l0oooo
0?ooo`00000m0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`800000?`3oool00`0007l0oooo
0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00D0001o0?ooo`3oool0oooo0000000l0?ooo`03
0000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0n0?ooo`050000O`3oool0oooo0?ooo`000000?03oool00`0007l0
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo
00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?oo
o`0h0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00@0oooo00<00000
0?ooo`3oool0=`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?oo
o`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000o0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`050?ooo`03
0000003oool0oooo03H0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0
1P3oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool0=03oool00`0007l0oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool0
0`0007l0oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03h0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo
00D0oooo000E0?ooo`800000?`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0
oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0n0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool0<@3oool00`0007l0oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0
001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo0300oooo00<0
001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m
0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0`
0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00`0oooo00<000000?oo
o`3oool0;`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool2000003l0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3o
ool0;P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0>0?ooo`030000
003oool0oooo02d0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool03P3o
ool00`000000oooo0?ooo`0]0?ooo`030000O`3oool0oooo00D0oooo00050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo00l0oooo00<000000?ooo`3oool0;03oool00`0007l0oooo0?ooo`050?ooo`001@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0?P3oool00`00
07l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0[0?ooo`030000O`3oool0oooo00D0oooo00050?ooo`030000003oool0oooo00H0
oooo0P0007l00`000000001o0000O`020000O`<00000d`0007l00`000000001o0000O`0b0000O`00
1P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`0n0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0A0?ooo`030000
003oool0oooo02X0oooo00<0001o0?ooo`3oool01@3oool000@0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`050?ooo`00103oool3000000L0oooo0`0000040?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo01<0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool01@3oool001D0
oooo0P00000o0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0
oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0n0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`0007l0oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo00<0001o
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00D0oooo000E0?ooo`800000?`3oool00`0007l0oooo0?ooo`0m0?ooo`03
0000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0I0?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo
01X0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`050?ooo`005@3oool2000003l0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo01/0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo
0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo
0?ooo`0L0?ooo`030000003oool0oooo01l0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<0
00000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0
001o0?ooo`3oool0703oool00`000000oooo0?ooo`0O0?ooo`030000O`3oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n
0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool0?P3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<0001o0?oo
o`3oool01@3oool001D0oooo0P00000o0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool0?P3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo03h0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0
oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0
oooo01/0oooo00<0001o0?ooo`3oool01@3oool000l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`00
07l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01X0oooo00<0001o0?ooo`3oool01@3oool000h0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01X0
oooo00<0001o0?ooo`3oool01@3oool000h0oooo00<000000000O`000000100007l300000>@0001o
00<000000000O`0007l08@0007l000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000003oool0oooo01T0oooo00<0001o0?ooo`3oool01@3oool000h0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo00<0001o
0?ooo`3oool01@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0T0?oo
o`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3o
ool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3o
ool0903oool00`000000oooo0?ooo`0G0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`800000
?`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3o
ool0oooo02H0oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool0
0`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03h0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0
oooo0?ooo`0n0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`0007l0
oooo0?ooo`050?ooo`005@3oool2000003l0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0n0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0
001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00<0
001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m
0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo02X0oooo00<000000?oo
o`3oool04@3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0140oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000o0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0[0?ooo`030000
003oool0oooo0100oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo02`0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`00
07l0oooo0?ooo`0/0?ooo`030000003oool0oooo00l0oooo00<0001o0?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0
oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00D0
oooo000E0?ooo`800000?`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0n0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo00<0001o
0?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0<0?oo
o`030000O`3oool0oooo00D0oooo00040?ooo`030000003oool0000000L0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool0?P3oool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3o
ool01@3oool000@0oooo00<000000?ooo`0000001`3oool20000O`030000000007l0001o0080001o
0`00003b0000O`030000000007l0001o01<0001o00050?ooo`030000003oool0oooo00H0oooo0P00
00050?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0n0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?oo
o`050?ooo`00103oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00D0oooo00050?oo
o`030000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0oooo03h0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo0340oooo00<000000?oo
o`3oool02P3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0b0?ooo`03
0000003oool0oooo00T0oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000o0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0oooo00P0oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0<`3o
ool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo03@0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`00
07l0oooo0?ooo`0d0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0
oooo00<0001o0?ooo`3oool0=@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo00D0
oooo000E0?ooo`800000?`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo
00<0001o0?ooo`3oool0=@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0n0?ooo`030000O`3oool0oooo03H0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00<0001o
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0=`3oool00`000000oooo0?ooo`040?oo
o`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3o
ool00`3oool00`0007l0oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool01@3oool001D0oooo0P00000o0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0i0?ooo`030000003o
ool0oooo0080oooo00<0001o0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0?P3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo
03X0oooo00D000000?ooo`3oool0oooo0000O`070?ooo`005@3oool00`000000oooo0?ooo`0n0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3oool00`0007l0oooo0?ooo`0k0?oo
o`040000003oool0oooo0000O`L0oooo000E0?ooo`030000003oool0oooo03h0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo03/0oooo00@000000?oo
o`3oool0001o1`3oool001D0oooo0P00000o0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool0?P3oool00`0007l0oooo0?ooo`0l0?ooo`030000003oool0001o00L0oooo000E0?ooo`03
0000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`03
0000O`3oool0oooo03`0oooo00<000000?ooo`0007l01`3oool001D0oooo00<000000?ooo`3oool0
?P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0
?@3oool00`000000001o0?ooo`060?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3o
ool00`000000001o0?ooo`060?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo03h0oooo00<000000?ooo`3oool01@3oool000h0oooo00<0001o000000000000100007l30000
0?l0001o0@0007l00`000000001o0000O`050000O`003P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`03
0000O`3oool0oooo03h0oooo00<0001o0?ooo`3oool01@3oool000h0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0
?P3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000?0?ooo`800000103o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo03h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0n0?ooo`030000O`3oool0
oooo03h0oooo00<0001o0?ooo`3oool01@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.165192, 5.69657, 
  0.00771847, 0.0195137}}]
}, Open  ]],

Cell["Ans: 2x^2-3x+7 certainly passes through (0,7), (1,6), (2,9)", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["(c & d)  Find a cubic thru (-2,6), (1,4), (2,3), (3,-2)", "Subsection"],

Cell["\<\
Solution using advanced functions for instructor, not necessarily recommended \
for beginning students.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c,d]
q[x_] = a*x^3+b*x^2+c*x+d\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ x\^3 + b\ x\^2 + c\ x + d\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eqs = {q[-2]==6,q[1]==4,q[2]==3,q[3]==-2}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-8\)\ a + 4\ b - 2\ c + d == 6, a + b + c + d == 4, 
      8\ a + 4\ b + 2\ c + d == 3, 27\ a + 9\ b + 3\ c + d == \(-2\)}\)], 
  "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(<< \ LinearAlgebra`MatrixManipulation`; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({A, y} = LinearEquationsToMatrices[eqs, {a, b, c, d}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\({\(-8\), 4, \(-2\), 1}\), \({1, 1, 1, 1}\), \({8, 4, 2, 1}\), 
              \({27, 9, 3, 1}\)},
            {"6", "4", "3", \(-2\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-8\), "4", \(-2\), "1"},
            {"1", "1", "1", "1"},
            {"8", "4", "2", "1"},
            {"27", "9", "3", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{6, 4, 3, \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p = LinearSolve[A,y]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-\(23\/60\)\), 3\/10, 47\/60, 33\/10}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f[x_] = p.{x^3,x^2,x,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(-\(\(23\ x\^3\)\/60\)\) + \(3\ x\^2\)\/10 + \(47\ x\)\/60 + 33\/10\)],
   "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,-2,3}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 -0.187206 0.131754 [
[.02381 .0638 -6 -9 ]
[.02381 .0638 6 0 ]
[.21429 .0638 -6 -9 ]
[.21429 .0638 6 0 ]
[.59524 .0638 -3 -9 ]
[.59524 .0638 3 0 ]
[.78571 .0638 -3 -9 ]
[.78571 .0638 3 0 ]
[.97619 .0638 -3 -9 ]
[.97619 .0638 3 0 ]
[.39226 .20806 -6 -4.5 ]
[.39226 .20806 0 4.5 ]
[.39226 .33981 -6 -4.5 ]
[.39226 .33981 0 4.5 ]
[.39226 .47156 -6 -4.5 ]
[.39226 .47156 0 4.5 ]
[.39226 .60332 -6 -4.5 ]
[.39226 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .0763 m
.02381 .08255 L
s
[(-2)] .02381 .0638 0 1 Mshowa
.21429 .0763 m
.21429 .08255 L
s
[(-1)] .21429 .0638 0 1 Mshowa
.59524 .0763 m
.59524 .08255 L
s
[(1)] .59524 .0638 0 1 Mshowa
.78571 .0763 m
.78571 .08255 L
s
[(2)] .78571 .0638 0 1 Mshowa
.97619 .0763 m
.97619 .08255 L
s
[(3)] .97619 .0638 0 1 Mshowa
.125 Mabswid
.0619 .0763 m
.0619 .08005 L
s
.1 .0763 m
.1 .08005 L
s
.1381 .0763 m
.1381 .08005 L
s
.17619 .0763 m
.17619 .08005 L
s
.25238 .0763 m
.25238 .08005 L
s
.29048 .0763 m
.29048 .08005 L
s
.32857 .0763 m
.32857 .08005 L
s
.36667 .0763 m
.36667 .08005 L
s
.44286 .0763 m
.44286 .08005 L
s
.48095 .0763 m
.48095 .08005 L
s
.51905 .0763 m
.51905 .08005 L
s
.55714 .0763 m
.55714 .08005 L
s
.63333 .0763 m
.63333 .08005 L
s
.67143 .0763 m
.67143 .08005 L
s
.70952 .0763 m
.70952 .08005 L
s
.74762 .0763 m
.74762 .08005 L
s
.82381 .0763 m
.82381 .08005 L
s
.8619 .0763 m
.8619 .08005 L
s
.9 .0763 m
.9 .08005 L
s
.9381 .0763 m
.9381 .08005 L
s
.25 Mabswid
0 .0763 m
1 .0763 L
s
.40476 .20806 m
.41101 .20806 L
s
[(3)] .39226 .20806 1 0 Mshowa
.40476 .33981 m
.41101 .33981 L
s
[(4)] .39226 .33981 1 0 Mshowa
.40476 .47156 m
.41101 .47156 L
s
[(5)] .39226 .47156 1 0 Mshowa
.40476 .60332 m
.41101 .60332 L
s
[(6)] .39226 .60332 1 0 Mshowa
.125 Mabswid
.40476 .10265 m
.40851 .10265 L
s
.40476 .129 m
.40851 .129 L
s
.40476 .15535 m
.40851 .15535 L
s
.40476 .18171 m
.40851 .18171 L
s
.40476 .23441 m
.40851 .23441 L
s
.40476 .26076 m
.40851 .26076 L
s
.40476 .28711 m
.40851 .28711 L
s
.40476 .31346 m
.40851 .31346 L
s
.40476 .36616 m
.40851 .36616 L
s
.40476 .39251 m
.40851 .39251 L
s
.40476 .41886 m
.40851 .41886 L
s
.40476 .44521 m
.40851 .44521 L
s
.40476 .49792 m
.40851 .49792 L
s
.40476 .52427 m
.40851 .52427 L
s
.40476 .55062 m
.40851 .55062 L
s
.40476 .57697 m
.40851 .57697 L
s
.40476 .04995 m
.40851 .04995 L
s
.40476 .0236 m
.40851 .0236 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .48292 L
.10458 .38079 L
.14415 .30972 L
.18221 .26152 L
.20178 .24361 L
.22272 .22914 L
.23293 .22372 L
.24402 .21899 L
.25449 .21556 L
.26416 .21325 L
.26882 .21242 L
.27383 .21172 L
.27626 .21145 L
.27856 .21124 L
.28083 .21108 L
.28289 .21096 L
.28416 .2109 L
.28536 .21086 L
.28663 .21083 L
.28734 .21081 L
.288 .2108 L
.2891 .2108 L
.29031 .2108 L
.29157 .21081 L
.29275 .21083 L
.29342 .21085 L
.29414 .21087 L
.29547 .21092 L
.29794 .21104 L
.30084 .21124 L
.30351 .21148 L
.30815 .21199 L
.31314 .2127 L
.32218 .21438 L
.33293 .21699 L
.34278 .21992 L
.3824 .23609 L
.42051 .25636 L
.46107 .28024 L
.50012 .30282 L
.52003 .31332 L
.54162 .32341 L
.56065 .33084 L
.57147 .33433 L
.5816 .33705 L
.59118 .33911 L
.5961 .33995 L
.60147 .3407 L
.6044 .34102 L
Mistroke
.60711 .34128 L
.60992 .34149 L
.61115 .34157 L
.61247 .34164 L
.61378 .3417 L
.61498 .34174 L
.61612 .34177 L
.61734 .34179 L
.61861 .3418 L
.61981 .3418 L
.62112 .34179 L
.62185 .34178 L
.62252 .34177 L
.6237 .34174 L
.62481 .3417 L
.62734 .34157 L
.6298 .3414 L
.63246 .34117 L
.63725 .3406 L
.64164 .33992 L
.65177 .33775 L
.66241 .33451 L
.67198 .33071 L
.6822 .3257 L
.70057 .31402 L
.72196 .29582 L
.74212 .27376 L
.78064 .21705 L
.82161 .13338 L
.86107 .0273 L
Mfstroke
.86107 .0273 m
.86915 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oM03oool0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo02@0oooo001d0?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool0903oool007@0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0U0?ooo`00M03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo02D0oooo
001d0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool09P3oool007@0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`0V0?ooo`00M03oool200000800oooo00<000000?oo
o`3oool09`3oool007@0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0W0?ooo`00
M03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02L0oooo001d0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0:03oool000P0oooo0`00000b0?ooo`D00000<P3oool0
0`000000oooo0?ooo`0a0?ooo`D00000<P3oool3000001<0oooo00<000000?ooo`3oool07P3oool2
000000P0oooo00080?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00030?ooo`<000000`3oool00`000000
oooo0?ooo`0]0?ooo`<000000`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool01P3oool000T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool000P0oooo00<0
00000?ooo`000000=03oool00`000000oooo0?ooo`0b0?ooo`800000=03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool000000180oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
00070?ooo`002@3oool00`000000oooo0?ooo`0b0?ooo`800000=03oool00`000000oooo0?ooo`0b
0?ooo`800000=@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01P3oool007@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0Z0?oo
o`00M03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo02/0oooo001d0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool0:`3oool007@0oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`0[0?ooo`00M03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo02`0oooo003o0000020000000@3oool000L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo
001d0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;@3oool007@0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0]0?ooo`00M03oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo02h0oooo001d0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0;P3oool007@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0^0?ooo`00M03o
ool2000007P0oooo00<000000?ooo`3oool0;`3oool007@0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0_0?ooo`00M03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0300oooo001d0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<03oool007@0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0`0?ooo`00M03oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo0340oooo001d0?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool0<@3oool007@0oooo0P00001f0?ooo`030000003oool0oooo0340oooo001d0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0<P3oool007@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0b0?ooo`00M03oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo03<0oooo001d0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0<`3oool0
07@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0=@3oool007@0oooo0P00001b0?ooo`030000003oool0oooo03D0oooo001d
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0=P3oool007@0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`0f0?ooo`00M03oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo03L0oooo001d0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
=`3oool007@0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0h0?ooo`00M03oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03P0oooo001d0?ooo`800000KP3oool00`00
0000oooo0?ooo`0i0?ooo`00M03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03T0
oooo001d0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0>P3oool007@0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0j0?ooo`00M03oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo03/0oooo001d0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0>`3oool006`0oooo0P0000060?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0?03oool006h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo03`0oooo001]0?ooo`030000003oool0oooo00@0oooo0`00001Y0?ooo`030000003o
ool0oooo03d0oooo001=0?ooo`h000004`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0?@3oool004P0oooo1@00000>0?ooo`<000003P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0?P3oool004H0
oooo0P00000F0?ooo`H000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0?P3oool004@0oooo0P00000N0?ooo`8000003P3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo03l0oooo00120?ooo`8000008P3oool2000000`0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`0o0?ooo`00@03oool2000002H0oooo0P00000:
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0@03oool003h0oooo0P00000Z0?oo
o`800000203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0440oooo000m0?ooo`03
0000003oool0oooo02`0oooo0P0000060?ooo`800000IP3oool00`000000oooo0?ooo`110?ooo`00
>`3oool200000340oooo0P0000040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
@P3oool003X0oooo00<000000?ooo`3oool0<`3oool200000080oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`130?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`<00000I03oool0
0`000000oooo0?ooo`140?ooo`00>03oool00`000000oooo0?ooo`0i0?ooo`800000H`3oool00`00
0000oooo0?ooo`140?ooo`00=P3oool2000003`0oooo00@000000?ooo`0000000000H03oool00`00
0000oooo0?ooo`150?ooo`00=@3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?oo
o`000000GP3oool00`000000oooo0?ooo`160?ooo`00=03oool00`000000oooo0?ooo`0m0?ooo`80
00000`3oool2000005`0oooo00<000000?ooo`3oool0AP3oool003<0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`040?ooo`800000F@3oool00`000000oooo0?ooo`170?ooo`00<P3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`180?ooo`00<P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00L0oooo0P00001E0?ooo`030000003oool0oooo04P0oooo000a0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool02@3oool200000580oooo00<000000?ooo`3oool0B@3oool00300
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0;0?ooo`800000C`3oool00`000000
oooo0?ooo`1:0?ooo`00;`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`00;P3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00h0oooo0P00001:0?ooo`030000003oool0oooo04`0oooo000^
0?ooo`030000003oool0oooo04<0oooo0P00000A0?ooo`800000A`3oool00`000000oooo0?ooo`1=
0?ooo`00;@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo0P0000140?oo
o`030000003oool0oooo04h0oooo000/0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0503oool200000440oooo00<000000?ooo`3oool0C`3oool002/0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0F0?ooo`800000?P3oool00`000000oooo0?ooo`1@0?ooo`00:`3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`1A0?ooo`00:P3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo01T0oooo0P00000h0?ooo`800000E03oool002T0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0K0?ooo`800000=@3oool00`000000oooo0?ooo`1D0?ooo`00:03oool00`000000
oooo0?ooo`190?ooo`8000007P3oool200000380oooo00<000000?ooo`3oool0E@3oool002P0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0O0?ooo`800000;`3oool00`000000oooo
0?ooo`1F0?ooo`009`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0240oooo0P00
000[0?ooo`800000F@3oool002L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0S
0?ooo`<000009`3oool00`000000oooo0?ooo`1I0?ooo`009P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo02H0oooo0P00000S0?ooo`800000G03oool002H0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0X0?ooo`<000007@3oool3000005h0oooo000U0?ooo`030000
003oool0oooo04D0oooo0`0000040?ooo`030000003oool0oooo02/0oooo0`00000G0?ooo`<00000
H@3oool002D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02h0oooo1@00000?0?ooo`<00000I03oool002@0oooo00<000000?ooo`3oool0A@3oool4
000000@0oooo0`00000c0?ooo`l00000I`3oool002<0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo000000050?ooo`030000003oool0oooo0:T0oooo000S0?ooo`030000003oool0oooo04L0
oooo0P0000050?ooo`030000003oool0oooo0:T0oooo000R0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2Y0?ooo`008P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0:T0oooo000Q0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool0Z@3oool00240oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2Y0?oo
o`00803oool00`000000oooo0?ooo`1A0?ooo`800000ZP3oool00200oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`2Y0?ooo`007`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0:T0oooo000O0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0Z@3oool0
01h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2Y0?ooo`007P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0:T0oooo000M0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0Z@3oool001d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`2Y0?ooo`00703oool00`000000oooo0?ooo`1E0?ooo`800000ZP3oool001`0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`2Y0?ooo`00703oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0:T0oooo000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
Z@3oool001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`2Y0?ooo`006P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0:T0oooo000J0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0Z@3oool001X0oooo00<000000?ooo`3oool0E`3oool200000:X0
oooo000I0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0Z@3oool001T0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`2Y0?ooo`00603oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0:T0oooo000H0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0Z@3oool001P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2Y0?ooo`00
5`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0:T0oooo000G0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool0Z@3oool001H0oooo00<000000?ooo`3oool0F`3oool2
00000:X0oooo000F0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0Z@3oool001H0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2Y0?ooo`005@3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo0:T0oooo000E0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0Z@3oool001@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:T0oooo000D0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`2Y0?ooo`00503oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo00<0oooo0`00002Y0?ooo`004`3oool00`000000oooo0?ooo`1F0?ooo`800000
1P3oool00`000000oooo0?ooo`2Y0?ooo`004`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0Z@3oool00180oooo00<000000?ooo`3oool0E`3oool3
000000D0oooo00<000000?ooo`3oool0Z@3oool00180oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`2Y0?ooo`004P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0:T0
oooo000A0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0Z@3oool00140oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`2Y0?ooo`004@3oool00`000000oooo0?ooo`1P
0?ooo`800000ZP3oool00100oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`2Y0?oo
o`00403oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0:T0oooo000@0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0Z@3oool000l0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`2Y0?ooo`003`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0:T0oooo000?0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0Z@3oool000h0
oooo00<000000?ooo`3oool0H`3oool200000:X0oooo000>0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0Z@3oool000h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`2Y0?ooo`003@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:T0oooo000=0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Z@3oool000d0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`2Y0?ooo`00303oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0:T0oooo000<0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0Z@3o
ool000`0oooo00<000000?ooo`3oool0I@3oool200000:X0oooo000<0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0Z@3oool000/0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`2Y0?ooo`002`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0:T0oooo
000;0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0Z@3oool000X0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`2Y0?ooo`002P3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo0:T0oooo000:0?ooo`030000003oool0oooo06L0oooo0P00002Z0?ooo`00
2@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0:T0oooo00090?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0Z@3oool000T0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`2Y0?ooo`00203oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
0:T0oooo00080?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0Z@3oool000P0oooo
00<000000?ooo`3oool0H@3oool2000000H0oooo00<000000?ooo`3oool0Z@3oool000L0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo000000050?ooo`030000003oool0oooo0:T0oooo0007
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`0000001@3oool300000:T0oooo001/0?oo
o`8000001P3oool00`000000oooo0?ooo`2Y0?ooo`00K03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0:T0oooo001]0?ooo`8000001@3oool00`000000oooo0?ooo`2Y0?ooo`00M03o
ool00`000000oooo0?ooo`2Y0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.13592, 1.42085, 0.0183688,
   0.0265556}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,-2,3},GridLines->Automatic,PlotRange->All];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.161866 0.0735755 [
[.02381 .14937 -6 -9 ]
[.02381 .14937 6 0 ]
[.21429 .14937 -6 -9 ]
[.21429 .14937 6 0 ]
[.59524 .14937 -3 -9 ]
[.59524 .14937 3 0 ]
[.78571 .14937 -3 -9 ]
[.78571 .14937 3 0 ]
[.97619 .14937 -3 -9 ]
[.97619 .14937 3 0 ]
[.39226 .01471 -12 -4.5 ]
[.39226 .01471 0 4.5 ]
[.39226 .30902 -6 -4.5 ]
[.39226 .30902 0 4.5 ]
[.39226 .45617 -6 -4.5 ]
[.39226 .45617 0 4.5 ]
[.39226 .60332 -6 -4.5 ]
[.39226 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01471 m
1 .01471 L
s
0 .16187 m
1 .16187 L
s
0 .30902 m
1 .30902 L
s
0 .45617 m
1 .45617 L
s
0 .60332 m
1 .60332 L
s
0 g
.02381 .16187 m
.02381 .16812 L
s
[(-2)] .02381 .14937 0 1 Mshowa
.21429 .16187 m
.21429 .16812 L
s
[(-1)] .21429 .14937 0 1 Mshowa
.59524 .16187 m
.59524 .16812 L
s
[(1)] .59524 .14937 0 1 Mshowa
.78571 .16187 m
.78571 .16812 L
s
[(2)] .78571 .14937 0 1 Mshowa
.97619 .16187 m
.97619 .16812 L
s
[(3)] .97619 .14937 0 1 Mshowa
.125 Mabswid
.0619 .16187 m
.0619 .16562 L
s
.1 .16187 m
.1 .16562 L
s
.1381 .16187 m
.1381 .16562 L
s
.17619 .16187 m
.17619 .16562 L
s
.25238 .16187 m
.25238 .16562 L
s
.29048 .16187 m
.29048 .16562 L
s
.32857 .16187 m
.32857 .16562 L
s
.36667 .16187 m
.36667 .16562 L
s
.44286 .16187 m
.44286 .16562 L
s
.48095 .16187 m
.48095 .16562 L
s
.51905 .16187 m
.51905 .16562 L
s
.55714 .16187 m
.55714 .16562 L
s
.63333 .16187 m
.63333 .16562 L
s
.67143 .16187 m
.67143 .16562 L
s
.70952 .16187 m
.70952 .16562 L
s
.74762 .16187 m
.74762 .16562 L
s
.82381 .16187 m
.82381 .16562 L
s
.8619 .16187 m
.8619 .16562 L
s
.9 .16187 m
.9 .16562 L
s
.9381 .16187 m
.9381 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
.40476 .01471 m
.41101 .01471 L
s
[(-2)] .39226 .01471 1 0 Mshowa
.40476 .30902 m
.41101 .30902 L
s
[(2)] .39226 .30902 1 0 Mshowa
.40476 .45617 m
.41101 .45617 L
s
[(4)] .39226 .45617 1 0 Mshowa
.40476 .60332 m
.41101 .60332 L
s
[(6)] .39226 .60332 1 0 Mshowa
.125 Mabswid
.40476 .0515 m
.40851 .0515 L
s
.40476 .08829 m
.40851 .08829 L
s
.40476 .12508 m
.40851 .12508 L
s
.40476 .19865 m
.40851 .19865 L
s
.40476 .23544 m
.40851 .23544 L
s
.40476 .27223 m
.40851 .27223 L
s
.40476 .3458 m
.40851 .3458 L
s
.40476 .38259 m
.40851 .38259 L
s
.40476 .41938 m
.40851 .41938 L
s
.40476 .49296 m
.40851 .49296 L
s
.40476 .52974 m
.40851 .52974 L
s
.40476 .56653 m
.40851 .56653 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .53609 L
.10458 .47905 L
.14415 .43937 L
.18221 .41245 L
.20178 .40244 L
.22272 .39437 L
.23293 .39134 L
.24402 .3887 L
.25449 .38678 L
.26416 .38549 L
.26882 .38503 L
.27383 .38464 L
.27626 .38449 L
.27856 .38437 L
.28083 .38428 L
.28289 .38421 L
.28416 .38418 L
.28536 .38416 L
.28663 .38414 L
.28734 .38413 L
.288 .38413 L
.2891 .38412 L
.29031 .38412 L
.29157 .38413 L
.29275 .38414 L
.29342 .38415 L
.29414 .38416 L
.29547 .38419 L
.29794 .38426 L
.30084 .38437 L
.30351 .3845 L
.30815 .38479 L
.31314 .38519 L
.32218 .38612 L
.33293 .38758 L
.34278 .38922 L
.3824 .39825 L
.42051 .40957 L
.46107 .4229 L
.50012 .43551 L
.52003 .44138 L
.54162 .44701 L
.56065 .45116 L
.57147 .45311 L
.5816 .45463 L
.59118 .45577 L
.5961 .45624 L
.60147 .45666 L
.6044 .45685 L
Mistroke
.60711 .45699 L
.60992 .45711 L
.61115 .45715 L
.61247 .45719 L
.61378 .45722 L
.61498 .45724 L
.61612 .45726 L
.61734 .45727 L
.61861 .45728 L
.61981 .45728 L
.62112 .45728 L
.62185 .45727 L
.62252 .45726 L
.6237 .45724 L
.62481 .45722 L
.62734 .45715 L
.6298 .45706 L
.63246 .45692 L
.63725 .45661 L
.64164 .45623 L
.65177 .45502 L
.66241 .45321 L
.67198 .45109 L
.6822 .44829 L
.70057 .44177 L
.72196 .4316 L
.74212 .41928 L
.78064 .38761 L
.82161 .34089 L
.86107 .28165 L
.89901 .21009 L
.9394 .11664 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o1`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool0
00L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo
03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo
00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0;03oool3000000D0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool006L0001o0`00
00030000O`030000000007l0001o00@0001o0`00002P0000O`030000000007l0001o00D0001o0@3o
ool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo03<0oooo00<000000?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0/0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0380oooo00<000000000O`3oool01`3oool000L0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0380
oooo00<000000000O`3oool01`3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0a0?ooo`030000003oool0001o00P0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
001o0?ooo`3oool0<@3oool00`000000oooo0000O`080?ooo`001`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo0340oooo00<000000?ooo`0007l0203oool000L0oooo00<0001o0?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0`0?ooo`040000003oool0oooo0000O`P0oooo00070?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<03oool010000000oooo0?ooo`0007l8
0?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0300oooo00@000000?oo
o`3oool0001o203oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0_0?oo
o`050000003oool0oooo0?ooo`0007l0203oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`800000=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
02l0oooo00D000000?ooo`3oool0oooo0000O`080?ooo`001`3oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`060?ooo`001`3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool00`3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo02d0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02`0
oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool0103oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02/0oooo00<0
00000?ooo`3oool01@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo0P00000d0?ooo`030000O`3oool0oooo03@0oooo00<0001o
0?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`050?oo
o`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3o
ool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0:P3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`060?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`00
0000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0:@3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0:03oool00`000000oooo
0?ooo`080?ooo`030000O`3oool0oooo00H0oooo00070?ooo`040000O`000000000000000380oooo
1@00000b0?ooo`030000003oool0oooo0340oooo1@00000b0?ooo`<00000:P3oool00`000000oooo
0?ooo`060?ooo`80000000<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0000003oool0<`3o
ool00`0007l0oooo0000000d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0000O`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool000<0oooo0`000000103oool0001o0?ooo`00000_0?ooo`<0000000@0oooo0000O`3oool00000
=03oool2000003@0oooo00<000000?ooo`3oool0<`3oool00`000000001o0?ooo`0X0?ooo`030000
003oool0oooo00P0oooo00<000000000O`3oool01`3oool000L0oooo00<0001o0?ooo`000000<`3o
ool00`0007l0oooo0000000d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3o
ool00`000000001o0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3o
ool000L0oooo00@0001o0000003oool00000<P3oool00`0007l0oooo0000000d0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0000000X0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`000000203oool000L0oooo00<0001o0?ooo`000000<`3oool0
0`0007l000000000000d0?ooo`030000003oool0oooo0380oooo0P00000e0?ooo`030000000007l0
oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000001o0?ooo`070?ooo`001`3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02D0
oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0
00000?ooo`3oool0303oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02<0oooo00<000000?oo
o`3oool03@3oool00`0007l0oooo0?ooo`060?ooo`00o`00000P00000040oooo00070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`001`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo0240oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0240
oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool0403oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0200oooo00<0
00000?ooo`3oool0403oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo01l0oooo00<000000?oo
o`3oool04@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`060?ooo`00
1`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo0P00000d0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`00
0000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0C0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0703oool00`000000oooo
0?ooo`0D0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0
001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0E
0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?oo
o`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?oo
o`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`03
0000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
=03oool2000003@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo01L0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool01P3o
ool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<0001o0?ooo`3oool01P3oool000L0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo01T0
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<0
001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0E
0?ooo`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0D0?ooo`03
0000003oool0oooo01`0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0
1P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`800000=03o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo01<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0140
oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo0100oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo00l0oooo00<000000?oo
o`3oool08@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo02`0oooo0`0000050?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3o
ool0=03oool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0/0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`060?ooo`00K@00
07l00`000000001o0000O`040000O`<00000NP0007l00`000000001o0000O`0[0000O`40oooo0007
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0<
0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo00`0oooo00<000000?oo
o`3oool0903oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo02d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
2P3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000O`3o
ool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool0
0`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0W0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo
03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo
00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0203oool00`000000
oooo0?ooo`0X0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo
00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000O`3oool0oooo00H0oooo
00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?oo
o`0Z0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o
0?ooo`3oool0=03oool2000003@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`05
0?ooo`030000003oool0oooo02/0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?oo
o`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?oo
o`3oool0=03oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0
<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<0001o0?ooo`3oool0
1P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003o
ool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool01@0007l0oooo0?ooo`3oool000000340oooo
00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool01@0007l0oooo0?oo
o`3oool000000340oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03o
ool0100007l0oooo0?ooo`00000b0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3o
ool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`000000<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`000000oooo03<0oooo00<0001o0?ooo`3oool01P3oool0
00L0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo
03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo
00H0oooo00070?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool04@3oool5000001h0
oooo0P00000d0?ooo`030000O`3oool0oooo03<0oooo00<000000000O`3oool0=03oool00`0007l0
oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00P0oooo
2@0000050?ooo`/000004`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo0380oooo
00<000000?ooo`0007l0=@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo00D0oooo0`00000I0?ooo`@000003`3oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo0340oooo00@000000?ooo`3oool0001o=@3oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00D00000803o
ool6000000T0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0_0?ooo`8000000`3o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo03<0oooo00<0001o000000000000:`3oool4000000D0oooo00<000000?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0<`3oool0
0`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0b0?ooo`800000<@3oool30000
0080oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo
00@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0
oooo0?ooo`0`0?ooo`80000000<0oooo0000O`3oool0<`3oool3000003D0oooo00<0001o0?ooo`3o
ool0;03oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0;P3oool2000000<0oooo00<0001o0?ooo`3oool0
=03oool3000003<0oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`060?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0;03o
ool2000000D0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0300000300oooo00<0
001o0?ooo`3oool0:@3oool2000000T0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`060?ooo`001`3oool00`0007l0oooo0?ooo`0Z0?ooo`8000001`3oool00`0007l0oooo0?ooo`0d
0?ooo`030000003oool0oooo00<0oooo0`00000]0?ooo`030000O`3oool0oooo02P0oooo00<00000
0?ooo`3oool02@3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo02P0oooo0P0000090?ooo`030000O`3oool0oooo03@0oooo00<000000?oo
o`3oool01P3oool3000002X0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo03@0oooo0P00000:0?ooo`<0
00009`3oool00`0007l0oooo0?ooo`0U0?ooo`8000003@3oool00`0007l0oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo02D0oooo0P00000<0?ooo`030000
O`3oool0oooo03@0oooo00<000000?ooo`3oool0303oool3000002@0oooo00<0001o0?ooo`3oool0
903oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0
1P3oool000L0oooo00<0001o0?ooo`3oool08`3oool2000000h0oooo00<0001o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0?0?ooo`@00000803oool00`0007l0oooo0?ooo`0R0?ooo`800000403o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo0280oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0
oooo01<0oooo1000000L0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3oool0403oool0
0`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo
0200oooo0P00000A0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool05`3oool30000
01T0oooo00<0001o0?ooo`3oool07`3oool2000001<0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo0140
oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?ooo`<000005P3oool00`0007l0
oooo0?ooo`0M0?ooo`8000005@3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0d0?ooo`030000003oool0oooo01d0oooo1000000B0?ooo`030000O`3oool0oooo01X0oooo
0`00000G0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool08@3oool5000000d0oooo00<0001o0?ooo`3oool0603oool2000001X0oooo00<0
001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0L
0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0;@3oool3000000@0oooo00<00000
0?ooo`3oool09P3oool2000000/0oooo00<0001o0?ooo`3oool05@3oool3000001`0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0K0?oo
o`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02P0oooo1P0000050?ooo`030000O`3oool0oooo00l0oooo1P00000O0?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool002@0001o00<000000000O`00
07l0A@0007l4000000@0001o0`00000^0000OaL00000H`0007l10?ooo`001`3oool00`0007l0oooo
0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo
000000050?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo01T0oooo00<0
00000?ooo`3oool05`3oool00`0007l0oooo0?ooo`0]0?ooo`8000001@3oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`060?ooo`001`3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<0001o
0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0d0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3o
ool06P3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3o
ool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000
O`3oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo01<0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0180
oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`0007l0oooo
0?ooo`0d0?ooo`800000=03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo
00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?oo
o`0P0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000O`3oool0oooo03@0oooo00<00000
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3o
ool03P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000
O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0303o
ool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3o
ool000L0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0
oooo03@0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0
oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`030000O`3oool0oooo03@0oooo0P00000d0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?oo
o`090?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?oo
o`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?oo
o`060?ooo`001`3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<0001o
0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o
0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo02T0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<0001o0?ooo`3o
ool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`060?ooo`030000
003oool0oooo02X0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0
oooo02/0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`00
07l0oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<0001o0?ooo`3oool0=03oool00`00
0000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo02`0
oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`030?ooo`030000003oool0oooo02d0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<0
001o0?ooo`3oool0=03oool2000003@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`0007l0oooo0?ooo`0d0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?oo
o`030000O`3oool0oooo00H0oooo00070?ooo`050000O`3oool0oooo0?ooo`000000<@3oool00`00
07l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`040000O`3oool0oooo0000
0380oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool0100007l0
oooo0?ooo`00000b0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool01P3oool000L0
oooo00<0001o0?ooo`000000<`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0000003<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo
0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l000000?ooo`0c0?ooo`030000O`3oool0oooo02`0oooo0P00
00060?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`000000oooo03<0oooo00<0001o
0?ooo`3oool0;03oool00`000000oooo000000050?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo00070000
O`030000000007l0001o0680001o00<000000000O`0000001@0007l300000:P0001o0@3oool000L0
oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0/0?ooo`8000001P3oool00`000000
oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo02`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?oo
o`0c0?ooo`030000O`3oool0oooo02d0oooo0P0000050?ooo`030000003oool0oooo03<0oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0c0?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo03<0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c
0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0<`3oool00`0007l0oooo0?ooo`06
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.14056, -2.21448, 
  0.0184011, 0.0476377}}]
}, Open  ]],

Cell["Ans: certainly passes through (-2,6), (1,4), (2,3), (3,-2).", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(e & f)  Find a 4th degree thru (0,0), (1,1), (-1,3) with slope 20 at -1 and \
9 at 1.\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c,d,e]
q[x_] = a*x^4+b*x^3+c*x^2+d*x+e\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ x\^4 + b\ x\^3 + c\ x\^2 + d\ x + e\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eqs = {q[0]==0,q[1]==1,q[-1]==3,q'[-1]==20,q'[1]==9}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{e == 0, a + b + c + d + e == 1, a - b + c - d + e == 3, 
      \(-4\)\ a + 3\ b - 2\ c + d == 20, 4\ a + 3\ b + 2\ c + d == 9}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({A, y} = LinearEquationsToMatrices[eqs, {a, b, c, d, e}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\({0, 0, 0, 0, 1}\), \({1, 1, 1, 1, 1}\), 
              \({1, \(-1\), 1, \(-1\), 1}\), \({\(-4\), 3, \(-2\), 1, 0}\), 
              \({4, 3, 2, 1, 0}\)},
            {"0", "1", "3", "20", "9"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "1"},
            {"1", "1", "1", "1", "1"},
            {"1", \(-1\), "1", \(-1\), "1"},
            {\(-4\), "3", \(-2\), "1", "0"},
            {"4", "3", "2", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 1, 3, 20, 9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p = LinearSolve[A,y]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-\(19\/4\)\), 31\/4, 27\/4, \(-\(35\/4\)\), 0}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f[x_] = p.{x^4,x^3,x^2,x,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(-\(\(19\ x\^4\)\/4\)\) + \(31\ x\^3\)\/4 + \(27\ x\^2\)\/4 - 
      \(35\ x\)\/4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,-1,1}, GridLines->Automatic, PlotRange->All];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.172361 0.0764834 [
[.02381 .15986 -6 -9 ]
[.02381 .15986 6 0 ]
[.2619 .15986 -12 -9 ]
[.2619 .15986 12 0 ]
[.7381 .15986 -9 -9 ]
[.7381 .15986 9 0 ]
[.97619 .15986 -3 -9 ]
[.97619 .15986 3 0 ]
[.4875 .01939 -12 -4.5 ]
[.4875 .01939 0 4.5 ]
[.4875 .32533 -6 -4.5 ]
[.4875 .32533 0 4.5 ]
[.4875 .47829 -6 -4.5 ]
[.4875 .47829 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01939 m
1 .01939 L
s
0 .17236 m
1 .17236 L
s
0 .32533 m
1 .32533 L
s
0 .47829 m
1 .47829 L
s
0 g
.02381 .17236 m
.02381 .17861 L
s
[(-1)] .02381 .15986 0 1 Mshowa
.2619 .17236 m
.2619 .17861 L
s
[(-0.5)] .2619 .15986 0 1 Mshowa
.7381 .17236 m
.7381 .17861 L
s
[(0.5)] .7381 .15986 0 1 Mshowa
.97619 .17236 m
.97619 .17861 L
s
[(1)] .97619 .15986 0 1 Mshowa
.125 Mabswid
.07143 .17236 m
.07143 .17611 L
s
.11905 .17236 m
.11905 .17611 L
s
.16667 .17236 m
.16667 .17611 L
s
.21429 .17236 m
.21429 .17611 L
s
.30952 .17236 m
.30952 .17611 L
s
.35714 .17236 m
.35714 .17611 L
s
.40476 .17236 m
.40476 .17611 L
s
.45238 .17236 m
.45238 .17611 L
s
.54762 .17236 m
.54762 .17611 L
s
.59524 .17236 m
.59524 .17611 L
s
.64286 .17236 m
.64286 .17611 L
s
.69048 .17236 m
.69048 .17611 L
s
.78571 .17236 m
.78571 .17611 L
s
.83333 .17236 m
.83333 .17611 L
s
.88095 .17236 m
.88095 .17611 L
s
.92857 .17236 m
.92857 .17611 L
s
.25 Mabswid
0 .17236 m
1 .17236 L
s
.5 .01939 m
.50625 .01939 L
s
[(-2)] .4875 .01939 1 0 Mshowa
.5 .32533 m
.50625 .32533 L
s
[(2)] .4875 .32533 1 0 Mshowa
.5 .47829 m
.50625 .47829 L
s
[(4)] .4875 .47829 1 0 Mshowa
.125 Mabswid
.5 .05764 m
.50375 .05764 L
s
.5 .09588 m
.50375 .09588 L
s
.5 .13412 m
.50375 .13412 L
s
.5 .2106 m
.50375 .2106 L
s
.5 .24884 m
.50375 .24884 L
s
.5 .28709 m
.50375 .28709 L
s
.5 .36357 m
.50375 .36357 L
s
.5 .40181 m
.50375 .40181 L
s
.5 .44005 m
.50375 .44005 L
s
.5 .51654 m
.50375 .51654 L
s
.5 .55478 m
.50375 .55478 L
s
.5 .59302 m
.50375 .59302 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .40181 m
.04262 .45698 L
.06244 .50434 L
.08255 .54189 L
.09409 .559 L
.10458 .57193 L
.11396 .58147 L
.12415 .58974 L
.12975 .59341 L
.13491 .59626 L
.13982 .5985 L
.14509 .60042 L
.14768 .60118 L
.15014 .60179 L
.15253 .60228 L
.15476 .60266 L
.15685 .60293 L
.15793 .60304 L
.15909 .60314 L
.16036 .60323 L
.16157 .60328 L
.16274 .60331 L
.16381 .60332 L
.16501 .60331 L
.16629 .60327 L
.16749 .60321 L
.1686 .60313 L
.16989 .60302 L
.17129 .60287 L
.17384 .60251 L
.17651 .60204 L
.17935 .60142 L
.18444 .6 L
.19381 .59644 L
.20391 .59128 L
.22219 .57872 L
.24223 .56069 L
.26333 .53756 L
.30144 .48722 L
.342 .42519 L
.38104 .3611 L
.42254 .29207 L
.46252 .22792 L
.50099 .17097 L
.54191 .11784 L
.58131 .07578 L
.6192 .04506 L
.63865 .03329 L
.65954 .02381 L
.66967 .02041 L
Mistroke
.67502 .01893 L
.68071 .0176 L
.68619 .01656 L
.69114 .01582 L
.69354 .01553 L
.69613 .01526 L
.69858 .01506 L
.70082 .01492 L
.70196 .01486 L
.7032 .0148 L
.70451 .01476 L
.70575 .01473 L
.70691 .01472 L
.70814 .01472 L
.70919 .01472 L
.71035 .01474 L
.71101 .01475 L
.7117 .01477 L
.71294 .01481 L
.71428 .01487 L
.71574 .01495 L
.71836 .01513 L
.72079 .01535 L
.72614 .01598 L
.73099 .01675 L
.74187 .01912 L
.75188 .0221 L
.76109 .0255 L
.78191 .03547 L
.80071 .04712 L
.82136 .06268 L
.86175 .10078 L
.90063 .14571 L
.94196 .20026 L
.97619 .24884 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o1`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03T0oooo
0`0000050?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`l0000000<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`060?ooo`00PP0007l3000000<0001o00<000000000O`0007l0100007l3
000002d0001o1@00000?0000O`<00000B@0007l10?ooo`001`3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo03X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?oo
o`800000503oool00`0007l0oooo0?ooo`03000003h0oooo00<0001o0?ooo`3oool01P3oool000L0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0i0?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0:@3oool2000001H0oooo00<0001o0?ooo`3oool00`3oool2000003`0
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool2000001P0oooo
00<0001o0?ooo`3oool01@3oool2000003X0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo0P00
000J0?ooo`030000O`3oool0oooo00L0oooo0P00000h0?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0S
0?ooo`800000703oool00`0007l0oooo0?ooo`090?ooo`800000=P3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<000000?oo
o`3oool08@3oool2000001h0oooo00<0001o0?ooo`3oool02`3oool2000003@0oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000003oool0oooo01l0oooo0P00000P0?ooo`030000O`3oool0oooo00d0oooo0P00000b0?ooo`03
0000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
3`3oool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0L0?ooo`8000008`3o
ool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo00<0001o0?ooo`3oool01P3o
ool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0
oooo02d0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`8000006`3oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo
0180oooo0P00000]0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0
oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo
0?ooo`0Y0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`800000:@3oool00`0007l0oooo0?oo
o`0F0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo02L0oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`0007l0oooo0?ooo`0H0?oo
o`8000009`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo01X0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`060?ooo`00
1`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0/0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`030000O`3o
ool0oooo01`0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`060?ooo`001`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0^0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool08@3oool0
0`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo
01h0oooo0P00000Q0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool2000000l0oooo00<000000?ooo`3oool0<03oool00`0007l0
oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool01P3oool000L0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<03oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<@3oool00`0007l0oooo0?oo
o`0R0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0<P3oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0T0?oo
o`030000003oool0oooo01X0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01X0oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
003oool0oooo01T0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3o
ool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool01P3o
ool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0=`3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0
oooo01L0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00`00
07l0oooo0?ooo`0X0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool01P3oool000L0
oooo1@00000l0?ooo`060000003oool0oooo0000O`3oool00000103oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0C
0?ooo`D000001P3oool000L0oooo00<0001o0?ooo`000000?@3oool01@000000oooo0000003oool0
001o00D0oooo00<000000?ooo`000000>`3oool2000000H0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo000000030?ooo`070000O`3oool0oooo0?ooo`000000oooo0000000U0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool000<0oooo0`000000103oool0001o0?oo
o`00000h0?ooo`<000000P3oool01@000000oooo0000003oool0001o00L0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo00<000000?ooo`00
00000`3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0000000m0?ooo`050000
003oool000000?ooo`0007l01@3oool2000003`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0000000<0oooo00@0001o0?ooo`3oool0oooo0P00000X0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`00
0000?@3oool01@000000oooo0000003oool0001o00D0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo00<000000?ooo`0000000`3oool01@00
07l0oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`06
0?ooo`001`3oool00`0007l000000000000n0?ooo`040000003oool0oooo0000O`D0oooo0`00000k
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`02
0?ooo`040000O`3oool0oooo0?ooo`<00000:@3oool00`000000oooo0?ooo`0@0?ooo`800000203o
ool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`050000003oool0
oooo0?ooo`000000?`3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo0140oooo00<0
001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`050000003oool0oooo0?ooo`000000?`3oool00`0007l0oooo0?ooo`0^0?ooo`030000003o
ool0oooo0100oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`040000003oool0oooo00000400oooo00<0001o0?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo000000110?ooo`030000O`3oool0
oooo0300oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo0P0000120?ooo`030000O`3oool0oooo
0300oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo0P0000120?ooo`030000O`3oool0oooo0340
oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`060?ooo`00o`00000P00000040oooo
00070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo0P00000=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool2000000`0oooo00<000000?ooo`3oool01P3oool000L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`800000@`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`0o0?ooo`030000003oool0000004<0oooo00<0001o0?oo
o`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0?P3oool010000000oooo0?ooo`0000130?oo
o`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03h0oooo00@000000?ooo`3o
ool00000@`3oool00`0007l0oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0m0?ooo`05
0000003oool0oooo0?ooo`000000@`3oool00`0007l0oooo0?ooo`0f0?ooo`030000003oool0oooo
00P0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0g0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool01P3oool000L0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0h0?ooo`030000003oool0oooo00H0oooo
00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`0k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000003oool0oooo00D0oooo0P0000120?ooo`030000O`3oool0oooo03X0oooo00<000000?oo
o`3oool0103oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo03T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`110?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`060?ooo`00
1`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0
0`3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo03L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`110?ooo`030000O`3o
ool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`060?ooo`001`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`110?ooo`030000O`3oool0oooo03`0oooo00<000000?ooo`3oool00P3oool0
0`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
03H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo
03d0oooo00D000000?ooo`3oool0oooo0000O`080?ooo`001`3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`110?oo
o`030000O`3oool0oooo03h0oooo00@000000?ooo`3oool0001o203oool000L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`0n0?ooo`040000003oool0oooo0000O`P0oooo00070?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0?`3oool00`000000oooo0000O`080?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo00<000000000O`3o
ool01`3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`030000
000007l0oooo00L0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0<0?ooo`800000@P3oool00`0007l0oooo0?ooo`110?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0340oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0]0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo02`0oooo00<000000?ooo`3oool04P3oool200000480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
02/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0W0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool09P3o
ool00`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool0
07<0001o00<000000000O`0007l04P0007l00`000000001o0000O`040000O`<00000S@0007l10?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000050?ooo`030000
003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo0200oooo0P0000120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0N0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0H0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo00H0oooo00070?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0
603oool00`000000oooo0?ooo`0V0?ooo`800000@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo00H0oooo00070?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool05`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l000000?ooo`110?ooo`030000O`3oool0
oooo01H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0000003oool0@@3oool00`00
07l0oooo0?ooo`0F0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`000000oooo0440
oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo
000000110?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0
001o0?ooo`000000@@3oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool000000440oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool0100007l0oooo0?ooo`0000100?ooo`030000O`3oool0oooo01<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00@0001o0?ooo`3oool00000@03oool00`0007l0oooo0?ooo`0B
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`040000O`3oool0oooo00000400oooo00<0001o
0?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool01@0007l0oooo0?ooo`3oool0
000003l0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`800000@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`050000O`3oool0oooo
0?ooo`000000?`3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`050000O`3oool0oooo0?ooo`000000?`3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`00
07l0oooo0?ooo`0?0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0080
oooo00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool0?03oool00`0007l0oooo
0?ooo`0=0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo00<0oooo00<0
00000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0<
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo00@0oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo02`0oooo0`0000040?oo
o`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo000?0000O`030000
000007l0001o04H0001o00<000000000O`0007l0;00007l4000000@0001o0`00002=0000O`40oooo
00070?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`090?ooo`030000003oool0oooo02d0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool0;P3oool2000000D0oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo00H0oooo00<000000?oo
o`3oool0>03oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool01P3oool000L0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0g0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
1P3oool000L0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo00H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool0
00L0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo
00@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0203oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo
00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo0080oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?oo
o`0e0?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool0?03oool200000480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0:
0?ooo`030000003oool0oooo03@0oooo00D0001o0?ooo`3oool0oooo0000000o0?ooo`030000003o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool0
0`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo00@0001o0?ooo`3oool00000@03o
ool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3o
ool000L0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0
00000440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00`00
07l0oooo000000110?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0380
oooo00<0001o0000003oool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0303oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo00d0oooo00<0
00000?ooo`3oool0<03oool00`000000001o0?ooo`120?ooo`030000003oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?ooo`001`3oool00`0007l0oooo0?ooo`0=
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`0007l0@`3oool00`000000oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?oo
o`3oool03P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo0000Od<0oooo00<00000
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?oo
o`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`0007m3
0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`06
0?ooo`001`3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo02/0oooo00D000000?oo
o`3oool0oooo0000O`130?ooo`800000@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`020?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0140
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo0440
oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0
oooo00070?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`040?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo01<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo0440oooo00<0
00000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo0007
0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0803oool2000000P0oooo00<0001o
0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3o
ool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3o
ool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool01P3oool000L0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00X0oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool05`3o
ool2000001T0oooo0P00000=0?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0
oooo0440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00H0oooo00070?ooo`030000O`3oool0oooo01X0oooo0P00000C0?ooo`800000403oool00`00
07l0oooo0?ooo`110?ooo`800000@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
00H0oooo00070?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool03P3oool200000180
oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool07@3oool3000000/0oooo
0P00000D0?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0200oooo2`00
000F0?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool01P3oool000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000003oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`060?oo
o`001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<000000?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo00070?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0526, -2.25361, 
  0.00733521, 0.0456696}}]
}, Open  ]],

Cell["\<\
Ans: certainly passes through (0,0), (1,1), (-1,3) with believable slope 20 \
at -1 and 9 at 1.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(g & h)  Design a ski jump that has the following specifications.\
\>", "Subsection"],

Cell["\<\
The ski jump starts at a height of 100 ft and finishes at a height of 10 ft.  \
From start to finish, the ski jump covers a horizontal distance of 120 feet.  \
A skier using the jump will start off horizontally and will fly off the end \
at a 30 degree angle from the horizontal.  Find a polynomial whose graph is a \
side view of the ski jump.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c,d]
q[x_] = a*x^3+b*x^2+c*x+d\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ x\^3 + b\ x\^2 + c\ x + d\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
eqs = {q[0]==100,q[120]==10,q'[0]==0,q'[120]==Tan[30 Degree]}\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{d == 100, 1728000\ a + 14400\ b + 120\ c + d == 10, c == 0, 
      43200\ a + 240\ b + c == 1\/\@3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({A, y} = LinearEquationsToMatrices[eqs, {a, b, c, d}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\({0, 0, 0, 1}\), \({1728000, 14400, 120, 1}\), 
              \({0, 0, 1, 0}\), \({43200, 240, 1, 0}\)},
            {"100", "10", "0", \(1\/\@3\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "1"},
            {"1728000", "14400", "120", "1"},
            {"0", "0", "1", "0"},
            {"43200", "240", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{100, 10, 0, 1\/\@3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p\  = \ LinearSolve[A, y]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(9 + 2\ \@3\)\/86400, \(\(-27\) - 4\ \@3\)\/1440, 0, 100}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f[x_] = p.{x^3,x^2,x,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\((9 + 2\ \@3)\)\ x\^3\)\/86400 + 
      \(\((\(-27\) - 4\ \@3)\)\ x\^2\)\/1440 + 100\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`0.000144260435360390655`\ x\^3 - 0.0235612522432468818`\ x\^2 + 100.`
      \)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[f[x],{x,0,120}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00793651 0.0147151 0.00588604 [
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .13244 -12 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -12 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -12 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -12 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .01472 m
.18254 .02097 L
s
[(20)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(40)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(60)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(80)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(100)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(120)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.06349 .01472 m
.06349 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.22222 .01472 m
.22222 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30159 .01472 m
.30159 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.42063 .01472 m
.42063 .01847 L
s
.46032 .01472 m
.46032 .01847 L
s
.53968 .01472 m
.53968 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.69841 .01472 m
.69841 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.77778 .01472 m
.77778 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.93651 .01472 m
.93651 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(20)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(40)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(60)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(80)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(100)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .60329 L
.02846 .60327 L
.03053 .60322 L
.03279 .60314 L
.03527 .60303 L
.0379 .60289 L
.04262 .60255 L
.05205 .6016 L
.06244 .60013 L
.07293 .59821 L
.0842 .59566 L
.10458 .58985 L
.1458 .57364 L
.18551 .55293 L
.22371 .52891 L
.26435 .49957 L
.30348 .46826 L
.34506 .43241 L
.38513 .396 L
.42368 .35987 L
.46468 .32092 L
.50417 .28355 L
.54214 .24833 L
.58257 .21223 L
.62148 .17948 L
.66284 .14747 L
.70268 .12005 L
.74101 .09742 L
.78179 .07805 L
.80205 .07044 L
.82106 .06461 L
.83923 .0603 L
.84944 .05844 L
.85881 .0571 L
.86355 .05656 L
.86861 .05608 L
.87339 .05573 L
.87773 .0555 L
.88039 .05539 L
.88284 .05533 L
.88412 .0553 L
.88485 .05529 L
.88553 .05528 L
.88625 .05528 L
.88691 .05527 L
.88766 .05527 L
.88838 .05527 L
Mistroke
.88959 .05528 L
.89088 .05529 L
.89209 .05531 L
.89319 .05533 L
.89589 .05541 L
.89843 .05551 L
.9031 .05578 L
.90822 .05619 L
.91357 .05674 L
.91855 .05738 L
.92748 .05881 L
.93704 .06077 L
.95716 .06637 L
.97619 .07358 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?03oool3000000<0oooo00<000000?ooo`3oool08P3oool300000080oooo00<000000?oo
o`3oool08P3oool2000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01h0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool5000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool00`3oool0
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000T0?ooo`060000003oool0oooo
0000003oool000008`3oool00`000000oooo000000020?ooo`030000003oool0000002<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0000000Q0?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`030000003oool0000001l0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0000000@0oooo000m0?ooo`070000003oool0oooo0?ooo`000000oooo0000000R
0?ooo`@0000000@0oooo0000003oool000008`3oool00`000000oooo000000020?ooo`030000003o
ool0000002<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000Q0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000001l0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool003d0oooo00L000000?oo
o`3oool0oooo0000003oool000000280oooo00<000000?ooo`0000000P3oool00`000000oooo0000
000S0?ooo`8000000`3oool00`000000oooo0000000T0?ooo`070000003oool0oooo0?ooo`000000
oooo0000000Q0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0
000001l0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool003`0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000S0?ooo`8000000P3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000008`3o
ool00`000000oooo000000020?ooo`030000003oool000000240oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`0000007`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo000000040?ooo`00?@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`8000000`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo003o0?ooob40oooo003o0?ooob40
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool000h0ooooo`00000@000000<0oooo000E0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
f`3ooolD000001T0oooo000E0?ooo`030000003oool0oooo0=L0oooo1000000D0?ooo`H000004`3o
ool001D0oooo00<000000?ooo`3oool0d`3oool4000001h0oooo0P00000A0?ooo`005@3oool00`00
0000oooo0?ooo`3A0?ooo`800000903oool3000000h0oooo000E0?ooo`030000003oool0oooo0<h0
oooo0`00000Y0?ooo`<000002`3oool001D0oooo0P00003<0?ooo`<00000;`3oool2000000T0oooo
000E0?ooo`030000003oool0oooo0<P0oooo0`00000m0?ooo`005@3oool00`000000oooo0?ooo`36
0?ooo`800000@03oool001D0oooo00<000000?ooo`3oool0a03oool200000480oooo000E0?ooo`03
0000003oool0oooo0<80oooo0P0000140?ooo`005@3oool00`000000oooo0?ooo`300?ooo`800000
AP3oool001D0oooo00<000000?ooo`3oool0_P3oool2000004P0oooo000E0?ooo`800000_@3oool2
000004X0oooo000E0?ooo`030000003oool0oooo0;X0oooo0P00001<0?ooo`005@3oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo04`0oooo000E0?ooo`030000003oool0oooo0;L0oooo
0P00001?0?ooo`005@3oool00`000000oooo0?ooo`2e0?ooo`800000D@3oool001D0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`1A0?ooo`002@3oool3000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`800000E03oool000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000040?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3o
ool0E03oool000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo0`00002_0?oo
o`800000E`3oool000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool0[@3oool2000005T0oooo00090?ooo`030000003oool000000080oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo05T0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2Z0?ooo`80
0000G03oool001D0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`1L0?ooo`005@3o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo05d0oooo000E0?ooo`030000003oool0
oooo0:H0oooo0P00001P0?ooo`005@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
0600oooo000E0?ooo`800000Y@3oool00`000000oooo0?ooo`1Q0?ooo`005@3oool00`000000oooo
0?ooo`2S0?ooo`030000003oool0oooo0680oooo000E0?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0H`3oool001D0oooo00<000000?ooo`3oool0X03oool2000006H0oooo000E0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0IP3oool001D0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`1W0?ooo`005@3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo06P0oooo000E0?ooo`030000003oool0oooo09/0oooo0P00001[0?ooo`005@3oool2
000009/0oooo00<000000?ooo`3oool0J`3oool001D0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`1/0?ooo`005@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo06d0
oooo000E0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0KP3oool001D0oooo00<0
00000?ooo`3oool0U@3oool200000740oooo000E0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0L@3oool001D0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1b0?oo
o`005@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo07<0oooo000E0?ooo`800000
TP3oool00`000000oooo0?ooo`1d0?ooo`005@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo07D0oooo000E0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0MP3oool0
01D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1g0?ooo`005@3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo07P0oooo000E0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0N@3oool000X0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`1j0?ooo`002`3oool01P000000oooo0?ooo`00
0000oooo000000@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`1k0?ooo`002@3o
ool4000000040?ooo`000000oooo000000@0oooo0`0000290?ooo`030000003oool0oooo07`0oooo
00090?ooo`030000003oool000000080oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo07d0oooo000:0?ooo`8000000P3oool00`000000oooo00000004
0?ooo`030000003oool0oooo08H0oooo0P0000200?ooo`002`3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`200?ooo`005@3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo0840oooo000E0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0PP3oool001D0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`230?ooo`005@3oool00`000000oooo0?ooo`200?ooo`800000QP3oool001D0oooo0P000020
0?ooo`030000003oool0oooo08H0oooo000E0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0Q`3oool001D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`280?ooo`00
5@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo08T0oooo000E0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0RP3oool001D0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2;0?ooo`005@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
08`0oooo000E0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0S@3oool001D0oooo
0P00001h0?ooo`030000003oool0oooo08h0oooo000E0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0S`3oool001D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`2@
0?ooo`005@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0940oooo000E0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0TP3oool001D0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`2C0?ooo`005@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo09@0oooo000E0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0U@3oool0
01D0oooo0P00001`0?ooo`030000003oool0oooo09H0oooo000E0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0U`3oool001D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`2H0?ooo`005@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo09T0oooo000E
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0VP3oool001D0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`2K0?ooo`002@3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo09`0oooo00090?ooo`030000
003oool000000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo09d0oooo00090?ooo`030000003oool000000080oooo00<000000?ooo`000000103o
ool3000006H0oooo0P00002P0?ooo`002@3oool2000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0:00oooo00090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0:40oooo000:0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0XP3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`2S0?ooo`005@3oool00`000000oooo0?ooo`1P0?ooo`800000YP3oool001D0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`2V0?ooo`005@3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0:L0oooo000E0?ooo`800000GP3oool00`000000oooo0?ooo`2X0?ooo`00
5@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0:T0oooo000E0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0ZP3oool001D0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`2[0?ooo`005@3oool00`000000oooo0?ooo`1H0?ooo`800000[P3oool001D0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`2^0?ooo`005@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0:l0oooo000E0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0/03oool001D0oooo0P00001E0?ooo`030000003oool0oooo0;40oooo000E0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0/P3oool001D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`2c0?ooo`005@3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo0;@0oooo000E0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0]@3o
ool001D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2f0?ooo`005@3oool00`00
0000oooo0?ooo`1=0?ooo`800000^@3oool001D0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`2i0?ooo`005@3oool2000004`0oooo00<000000?ooo`3oool0^P3oool001D0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`2k0?ooo`005@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0;`0oooo000E0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0_@3oool001D0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2n0?ooo`00
5@3oool00`000000oooo0?ooo`150?ooo`800000`@3oool000X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0`@3o
ool000T0oooo00<000000?ooo`0000000P3oool00`000000oooo000000040?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0`P3oool000T0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000040?ooo`<00000@P3oool00`000000oooo0?ooo`330?ooo`002P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`100?ooo`800000aP3oool0
00T0oooo00<000000?ooo`0000000P3oool00`000000oooo000000040?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0aP3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0a`3oool001D0oooo
00<000000?ooo`3oool0?03oool200000<X0oooo000E0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0bP3oool001D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3;
0?ooo`005@3oool2000003T0oooo0P00003>0?ooo`005@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0<h0oooo000E0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
c`3oool001D0oooo00<000000?ooo`3oool0=03oool200000=80oooo000E0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0dP3oool001D0oooo00<000000?ooo`3oool0<@3oool20000
0=D0oooo000E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0e@3oool001D0oooo
00<000000?ooo`3oool0;P3oool200000=P0oooo000E0?ooo`800000;@3oool200000=X0oooo000E
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0fP3oool001D0oooo00<000000?oo
o`3oool0:@3oool200000=d0oooo000E0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0g@3oool001D0oooo00<000000?ooo`3oool09P3oool200000>00oooo000E0?ooo`030000003o
ool0oooo02@0oooo0P00003R0?ooo`005@3oool00`000000oooo0?ooo`0R0?ooo`800000i03oool0
01D0oooo00<000000?ooo`3oool0803oool200000>H0oooo000E0?ooo`8000007P3oool300000>P0
oooo000E0?ooo`030000003oool0oooo01/0oooo0P00003[0?ooo`005@3oool00`000000oooo0?oo
o`0I0?ooo`800000k@3oool001D0oooo00<000000?ooo`3oool05`3oool200000>l0oooo000E0?oo
o`030000003oool0oooo01D0oooo0P00003a0?ooo`005@3oool00`000000oooo0?ooo`0A0?ooo`@0
0000l`3oool000<0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`D00000m`3oool000D0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`060?ooo`H0
0000o03oool000D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`000000103oool900000?l0oooo0`3oool000D0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo00050?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00103oool2000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.99235, -8.25899, 0.4676, 
  0.630494}}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowToolbars->"EditBar",
WindowSize->{621, 403},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 162, 4, 66, "Subsubtitle"],
Cell[1896, 57, 238, 6, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2171, 68, 58, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[2254, 72, 88, 2, 53, "Section"],

Cell[CellGroupData[{
Cell[2367, 78, 62, 0, 47, "Subsection"],
Cell[2432, 80, 176, 6, 33, "Text"],
Cell[2611, 88, 42, 0, 30, "Input"],
Cell[2656, 90, 319, 5, 71, "Text"],
Cell[2978, 97, 45, 0, 30, "Input"],
Cell[3026, 99, 138, 4, 34, "Text"],
Cell[3167, 105, 71, 1, 30, "Input"],
Cell[3241, 108, 156, 4, 34, "Text"],
Cell[3400, 114, 45, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3482, 119, 45, 0, 31, "Subsection"],
Cell[3530, 121, 127, 5, 33, "Text"],
Cell[3660, 128, 26, 0, 30, "Input"],
Cell[3689, 130, 215, 6, 52, "Text"],
Cell[3907, 138, 34, 0, 30, "Input"],
Cell[3944, 140, 154, 3, 52, "Text"],
Cell[4101, 145, 44, 1, 30, "Input"],
Cell[4148, 148, 39, 0, 33, "Text"],
Cell[4190, 150, 48, 1, 30, "Input"],
Cell[4241, 153, 551, 11, 110, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4829, 169, 65, 0, 31, "Subsection"],
Cell[4897, 171, 49, 0, 30, "Input"],
Cell[4949, 173, 47, 0, 30, "Input"],
Cell[4999, 175, 76, 0, 33, "Text"],
Cell[5078, 177, 55, 1, 30, "Input"],
Cell[5136, 180, 97, 2, 33, "Text"],
Cell[5236, 184, 61, 1, 30, "Input"],
Cell[5300, 187, 55, 1, 30, "Input"],
Cell[5358, 190, 271, 5, 71, "Text"],
Cell[5632, 197, 71, 1, 30, "Input"],
Cell[5706, 200, 62, 1, 30, "Input"],
Cell[5771, 203, 47, 1, 30, "Input"],
Cell[5821, 206, 170, 3, 52, "Text"],
Cell[5994, 211, 75, 1, 30, "Input"],
Cell[6072, 214, 54, 1, 30, "Input"],
Cell[6129, 217, 129, 3, 33, "Text"],
Cell[6261, 222, 64, 1, 30, "Input"],
Cell[6328, 225, 48, 1, 30, "Input"],
Cell[6379, 228, 73, 0, 33, "Text"],
Cell[6455, 230, 180, 6, 102, "Input"],
Cell[6638, 238, 49, 1, 30, "Input"],
Cell[6690, 241, 49, 1, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6788, 248, 74, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[6887, 252, 100, 2, 47, "Subsection"],
Cell[6990, 256, 282, 5, 71, "Text"],
Cell[7275, 263, 72, 4, 71, "Text"],
Cell[7350, 269, 46, 0, 30, "Input"],
Cell[7399, 271, 28, 0, 30, "Input"],
Cell[7430, 273, 37, 0, 30, "Input"],
Cell[7470, 275, 64, 0, 33, "Text"],
Cell[7537, 277, 70, 0, 33, "Text"],
Cell[7610, 279, 59, 3, 48, "Input"],
Cell[7672, 284, 146, 3, 52, "Text"],
Cell[7821, 289, 36, 0, 30, "Input"],
Cell[7860, 291, 36, 0, 30, "Input"],
Cell[7899, 293, 74, 0, 30, "Input"],
Cell[7976, 295, 75, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8088, 300, 59, 0, 31, "Subsection"],
Cell[8150, 302, 177, 4, 52, "Text"],
Cell[8330, 308, 99, 2, 43, "Subsubsection"],
Cell[8432, 312, 130, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8587, 319, 98, 2, 43, "Subsubsection"],
Cell[8688, 323, 368, 6, 71, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9117, 336, 57, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[9199, 340, 100, 2, 47, "Subsection"],
Cell[9302, 344, 282, 5, 52, "Text"],
Cell[9587, 351, 72, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[9684, 359, 46, 0, 30, "Input"],
Cell[9733, 361, 232, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10002, 373, 28, 0, 30, "Input"],
Cell[10033, 375, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10130, 381, 37, 0, 30, "Input"],
Cell[10170, 383, 65, 1, 29, "Output"]
}, Open  ]],
Cell[10250, 387, 64, 0, 33, "Text"],
Cell[10317, 389, 70, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[10412, 393, 59, 3, 48, "Input"],
Cell[10474, 398, 69, 1, 29, "Output"]
}, Open  ]],
Cell[10558, 402, 146, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[10729, 409, 36, 0, 30, "Input"],
Cell[10768, 411, 69, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10874, 417, 36, 0, 30, "Input"],
Cell[10913, 419, 18328, 471, 186, 4092, 291, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29278, 895, 74, 0, 30, "Input"],
Cell[29355, 897, 35115, 712, 186, 4403, 328, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[64485, 1612, 75, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[64597, 1617, 77, 0, 31, "Subsection"],
Cell[64677, 1619, 127, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[64829, 1626, 65, 3, 48, "Input"],
Cell[64897, 1631, 79, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65013, 1637, 58, 0, 30, "Input"],
Cell[65074, 1639, 184, 4, 29, "Output"]
}, Open  ]],
Cell[65273, 1646, 77, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[65375, 1651, 86, 1, 30, "Input"],
Cell[65464, 1654, 268, 7, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65769, 1666, 34, 1, 30, "Input"],
Cell[65806, 1669, 288, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66131, 1682, 34, 1, 30, "Input"],
Cell[66168, 1685, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66273, 1691, 37, 0, 30, "Input"],
Cell[66313, 1693, 91, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66441, 1699, 40, 0, 30, "Input"],
Cell[66484, 1701, 127, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66648, 1709, 37, 0, 30, "Input"],
Cell[66688, 1711, 18642, 483, 186, 4193, 300, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85367, 2199, 73, 0, 30, "Input"],
Cell[85443, 2201, 39529, 755, 186, 4367, 316, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[124987, 2959, 75, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[125099, 2964, 116, 3, 31, "Subsection"],

Cell[CellGroupData[{
Cell[125240, 2971, 73, 3, 48, "Input"],
Cell[125316, 2976, 89, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125442, 2982, 69, 0, 30, "Input"],
Cell[125514, 2984, 186, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125737, 2993, 89, 1, 30, "Input"],
Cell[125829, 2996, 328, 8, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126194, 3009, 34, 1, 30, "Input"],
Cell[126231, 3012, 352, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126620, 3026, 34, 1, 30, "Input"],
Cell[126657, 3029, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126761, 3035, 37, 0, 30, "Input"],
Cell[126801, 3037, 103, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126941, 3044, 44, 0, 30, "Input"],
Cell[126988, 3046, 138, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127163, 3054, 75, 0, 30, "Input"],
Cell[127241, 3056, 36770, 698, 186, 3913, 288, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[164026, 3757, 119, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[164182, 3765, 95, 2, 31, "Subsection"],
Cell[164280, 3769, 368, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[164673, 3779, 65, 3, 48, "Input"],
Cell[164741, 3784, 79, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164857, 3790, 86, 2, 30, "Input"],
Cell[164946, 3794, 156, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165139, 3802, 86, 1, 30, "Input"],
Cell[165228, 3805, 282, 7, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165547, 3817, 34, 1, 30, "Input"],
Cell[165584, 3820, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165920, 3833, 34, 1, 30, "Input"],
Cell[165957, 3836, 71, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166065, 3842, 58, 1, 30, "Input"],
Cell[166126, 3845, 115, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166278, 3852, 40, 0, 30, "Input"],
Cell[166321, 3854, 143, 3, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166501, 3862, 37, 1, 30, "Input"],
Cell[166541, 3865, 132, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166710, 3873, 38, 0, 30, "Input"],
Cell[166751, 3875, 18005, 455, 186, 4037, 278, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

