(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59445,       2544]*)
(*NotebookOutlinePosition[     60183,       2570]*)
(*  CellTagsIndexPosition[     60139,       2566]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College,  6/1/98."
}], "Subsubtitle"],

Cell[TextData[{
  "Created for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.  To make matrices appear in rectangular arrays, I suggest menu \
choice:  Cell, Default Output Format Type set to TraditionalForm."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 2.1  Exercises on Matrix Algebra", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
Initializations -- randint (clear 3-argument and obscure 4-argument)\
\>", "Section"],

Cell["\<\
Clear[randint]
randint[m_,n_,k_:9] :=
   Table[ Random[Integer,{-k,k}], {m},{n}]

randint[m_] := randint[m,m]

randint[m_, n_Integer?Positive, k_, r_Integer?Positive] /;
    r<=Min[m,n] :=
   Module[{p,A,done=False},
      p = Ceiling[k/r];
      While[Not[done],
         A = randint[m,r,p].randint[r,n,1];
         A = Map[(If[Abs[#]<=k,#,0])&,A,{2}];
         done = (n - Length[NullSpace[A]] == r)
      ];
      A]\
\>", "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Bonus:  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Tutorial on matrix creation and algebra"
}], "Section"],

Cell[CellGroupData[{

Cell["Rows, entries, Transpose and columns.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{ax, ay, az}, {bx, by, bz}, {cx, cy, cz}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"ax", "ay", "az"},
            {"bx", "by", "bz"},
            {"cx", "cy", "cz"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(A[\([2]\)]\ \ \ \  (*\ 2  nd\ row\ *) \)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{bx, by, bz}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(A[\([2, 3]\)]\ \ \  (*\ 2, 3\ entry\ *) \)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`bz\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"ax", "bx", "cx"},
            {"ay", "by", "cy"},
            {"az", "bz", "cz"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"ax", "ay", "az"},
            {"bx", "by", "bz"},
            {"cx", "cy", "cz"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Transpose[A]\)[\([2]\)]\ \ \  (*\ 2  nd\ column\ of\ A\ *) \)\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm\`{ay, by, cy}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IdentityMatrix, DiagonalMatrix and Changing entries.", "Subsection"],

Cell[CellGroupData[{

Cell["A = IdentityMatrix[5]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A[[4,2]] = 3  (* changing one entry *)", "Input"],

Cell[BoxData[
    \(TraditionalForm\`3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "3", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["d = DiagonalMatrix[{2,3,4,5}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "0", "0", "0"},
            {"0", "3", "0", "0"},
            {"0", "0", "4", "0"},
            {"0", "0", "0", "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating lists (vectors) and matrices with Table.", "Subsection"],

Cell[CellGroupData[{

Cell["Table[ i, {i,3,7,.5}]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, 3.5`, 4.`, 4.5`, 5.`, 5.5`, 6.`, 6.5`, 7.`}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ i, {i,3,7}]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, 4, 5, 6, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ i, {i,7}]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 2, 3, 4, 5, 6, 7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ i, {7}]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{i, i, i, i, i, i, i}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ 3, {2},{4}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", "3", "3", "3"},
            {"3", "3", "3", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Matrices", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ Random[]\ , {3}, {4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.643718158533803208`", "0.783728092882015925`", 
              "0.705326575310650127`", "0.343475886661101137`"},
           
             {"0.826854912658291851`", "0.900893018422823033`", 
              "0.614073247344067141`", "0.346105247534753956`"},
           
             {"0.374206206308581457`", "0.299119737876789137`", 
              "0.747932821955478033`", "0.643270646348855024`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ Random[Integer, {\(-5\), 5}], {3}, {4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-4\), "3", \(-1\), \(-1\)},
            {\(-5\), "0", "1", "5"},
            {\(-2\), \(-4\), "5", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Here is a useful function to define a random m\[Times]n matrix with integer \
entries.  If k is not given, it defaults to 9.\
\>", "Text"],

Cell["\<\
randint[m_,n_,k_:9] := 
   Table[Random[Integer,{-k,k}],{m},{n}]\
\>", "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(randint[3, 5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), \(-8\), \(-7\), \(-2\), "4"},
            {"0", "8", \(-5\), \(-4\), "1"},
            {"9", "7", \(-5\), \(-4\), \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Every time you execute the randint function, you get a different result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(randint[3, 5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4", "8", \(-9\), "2", "9"},
            {"4", "4", "4", \(-8\), "7"},
            {"0", "3", \(-3\), "2", "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using row i, column j, formulas for matrices.", "Subsubsection"],

Cell[CellGroupData[{

Cell["Table[ i*j, {i,4},{j,4}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "4"},
            {"2", "4", "6", "8"},
            {"3", "6", "9", "12"},
            {"4", "8", "12", "16"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ (-1)^(i+j), {i,4},{j,4}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-1\), "1", \(-1\)},
            {\(-1\), "1", \(-1\), "1"},
            {"1", \(-1\), "1", \(-1\)},
            {\(-1\), "1", \(-1\), "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ If[j >= i, \ 1, \ 0], \ {i, 4}, {j, 4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "1"},
            {"0", "1", "1", "1"},
            {"0", "0", "1", "1"},
            {"0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ If[j == i + 1, \ 1, \ 0], \ {i, 4}, {j, 4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"},
            {"0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that to TEST equality you need ==, a double equal sign, since = is use \
to assign values to names.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear combinations of matrices", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ randint[3, 4]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "1", \(-2\), \(-9\)},
            {\(-5\), "5", \(-5\), \(-2\)},
            {"4", \(-4\), \(-6\), "9"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\  = \ randint[3, 4]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-5\), "7", "3", \(-3\)},
            {"2", \(-9\), \(-8\), "1"},
            {\(-5\), "0", "8", \(-6\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(2  A - 5  B\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"21", \(-33\), \(-19\), \(-3\)},
            {\(-20\), "55", "30", \(-9\)},
            {"33", \(-8\), \(-52\), "48"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[A + B]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-7\), \(-3\), \(-1\)},
            {"8", \(-4\), \(-4\)},
            {"1", \(-13\), "2"},
            {\(-12\), \(-1\), "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[A] + Transpose[B]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-7\), \(-3\), \(-1\)},
            {"8", \(-4\), \(-4\)},
            {"1", \(-13\), "2"},
            {\(-12\), \(-1\), "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiplication -- TRICKY NOTATION", "Subsection"],

Cell["\<\
randint[m_,n_,k_:9] :=
   Table[Random[Integer,{-k,k}],{m},{n}]\
\>", "Input"],

Cell[CellGroupData[{

Cell["A = randint[3,3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "2", "4"},
            {"8", "2", "7"},
            {"4", "9", "6"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B = randint[3,3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", \(-5\), \(-4\)},
            {\(-7\), \(-1\), \(-6\)},
            {"7", "5", \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Use period for matrix mult.", "Text"],

Cell[CellGroupData[{

Cell["A.B", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"14", "18", \(-32\)},
            {"51", \(-7\), \(-79\)},
            {\(-13\), "1", \(-100\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A*B  (* This is NOT Matrix Multiplication!!!! *)", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-10\), \(-16\)},
            {\(-56\), \(-2\), \(-42\)},
            {"28", "45", \(-30\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Matrix multiplication is not commutative.", "Text"],

Cell[CellGroupData[{

Cell["B.A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-56\), \(-42\), \(-51\)},
            {\(-32\), \(-70\), \(-71\)},
            {"20", \(-21\), "33"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Powers -- EVEN TRICKIER NOTATION", "Subsection"],

Cell[CellGroupData[{

Cell["A.A  (* This is A squared. *)", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"32", "40", "38"},
            {"44", "83", "88"},
            {"96", "80", "115"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A^2  (* This is NOT A squared. *)", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "4", "16"},
            {"64", "4", "49"},
            {"16", "81", "36"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(A\^2\ \ \ 
     (*\ This\ is\ NOT\ A\ \(squared\ --\)\ VERY\ \(MISLEADING!\)\ *) \)\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "4", "16"},
            {"64", "4", "49"},
            {"16", "81", "36"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(A.A.A.A\ \ \ \ \  (*\ This\ is\ A\^4\ *) \)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"6432", "7640", "9106"},
            {"13508", "15689", "19096"},
            {"17632", "19680", "23913"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixPower[A,4]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"6432", "7640", "9106"},
            {"13508", "15689", "19096"},
            {"17632", "19680", "23913"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 2.1; 9  Solving for commutator", "Section"],

Cell[CellGroupData[{

Cell["A = {{7,6},{2,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"7", "6"},
            {"2", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[x,y,u,v]
B = {{x,y},{u,v}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"x", "y"},
            {"u", "v"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.B", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(6\ u + 7\ x\), \(6\ v + 7\ y\)},
            {\(3\ u + 2\ x\), \(3\ v + 2\ y\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(7\ x + 2\ y\), \(6\ x + 3\ y\)},
            {\(7\ u + 2\ v\), \(6\ u + 3\ v\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve[{A.B==B.A},{x,y,u,v}]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`Solve::"svars"  : \ 
      "Equations may not give solutions for all \"solve\" variables."\)], 
  "Message"],

Cell[BoxData[
    \(TraditionalForm\`{{x \[Rule] 2\ u + v, y \[Rule] 3\ u}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.B - B.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(6\ u - 2\ y\), \(6\ v - 6\ x + 4\ y\)},
            {\(\(-4\)\ u - 2\ v + 2\ x\), \(2\ y - 6\ u\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R = {{0,-2,6,0},{-6,4,0,6},{2,0,-4,-2},{0,2,-6,0}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-2\), "6", "0"},
            {\(-6\), "4", "0", "6"},
            {"2", "0", \(-4\), \(-2\)},
            {"0", "2", \(-6\), "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[R]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-2\), \(-1\)},
            {"0", "1", \(-3\), "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["So solutions are of form:", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b]
CM = {{2a+b,3a},{a,b}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(2\ a + b\), \(3\ a\)},
            {"a", "b"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify[A.CM]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(20\ a + 7\ b\), \(21\ a + 6\ b\)},
            {\(7\ a + 2\ b\), \(3\ \((2\ a + b)\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify[CM.A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(20\ a + 7\ b\), \(21\ a + 6\ b\)},
            {\(7\ a + 2\ b\), \(3\ \((2\ a + b)\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C1 = {{4,9},{3,-2}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4", "9"},
            {"3", \(-2\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C1.A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"46", "51"},
            {"17", "12"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.C1", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"46", "51"},
            {"17", "12"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 2.1; 10  Homogeneous and nonhomogeneous solutions", "Section"],

Cell["Evaluate the above intialization cell to define randint.", "Text"],

Cell[CellGroupData[{

Cell["A = randint[3,4,5,2]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0"},
            {\(-2\), \(-3\), \(-1\), "4"},
            {\(-1\), \(-2\), \(-1\), "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-1\), "1"},
            {"0", "1", "1", \(-2\)},
            {"0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["NullSpace[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "2", "0", "1"},
            {"1", \(-1\), "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b]
{a,b}.NullSpace[A]\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{b - a, 2\ a - b, b, a}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["x = Transpose[NullSpace[A]].{{a},{b}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(b - a\)},
            {\(2\ a - b\)},
            {"b"},
            {"a"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.x", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {\(4\ a - 3\ \((2\ a - b)\) - b - 2\ \((b - a)\)\)},
            {\(4\ a - 2\ \((2\ a - b)\) - 2\ b\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A.x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {"0"},
            {"0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b)", "Subsection"],

Cell[CellGroupData[{

Cell["p = randint[4,1]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"7"},
            {"5"},
            {\(-2\)},
            {\(-4\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rhs = A.p  (* note b is a parameter in the exercise *)", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {\(-43\)},
            {\(-27\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p+x", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(\(-a\) + b + 7\)},
            {\(2\ a - b + 5\)},
            {\(b - 2\)},
            {\(a - 4\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A.(p+x)", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
           
             {\(4\ \((a - 4)\) - 3\ \((2\ a - b + 5)\) - b - 
                2\ \((\(-a\) + b + 7)\) + 2\)},
            {\(3\ \((a - 4)\) + a - 2\ \((2\ a - b + 5)\) - 2\ b - 5\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify[A.(p+x)]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {\(-43\)},
            {\(-27\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rhs\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {\(-43\)},
            {\(-27\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spirit of 2.1; 10  Tutorial on solutions to linear systems in parametric \
vector form using LinearSolve + NullSpace.\
\>", "Section"],

Cell[CellGroupData[{

Cell["Ax = b  Nonhomogeneous System.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = 
      \ {{\(-3\), \(-15\), 4, 18, \(-3\)}, {5, 25, 2, \(-4\), 1}, {\(-1\), 
          \(-5\), 0, 2, 1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-15\), "4", "18", \(-3\)},
            {"5", "25", "2", \(-4\), "1"},
            {\(-1\), \(-5\), "0", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ {{13}, {17}, {\(-3\)}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"13"},
            {"17"},
            {\(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Find the solution set of A",
  StyleBox["x",
    FontWeight->"Bold"],
  "=",
  StyleBox["b",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "all vectors ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = {x1, x2, x3, x4, x5} (think of vectors as points!) in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^5\)]],
  " that satisfy the equation."
}], "Text"],

Cell[BoxData[
    \(<< \ LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ab\  = \ AppendRows[A, b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-15\), "4", "18", \(-3\), "13"},
            {"5", "25", "2", \(-4\), "1", "17"},
            {\(-1\), \(-5\), "0", "2", "1", \(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Ab]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "5", "0", \(-2\), "0", "2"},
            {"0", "0", "1", "3", "0", "4"},
            {"0", "0", "0", "0", "1", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
So x2 and x4 are free and x1 = 2 - 5 x2 + 2 x4,   x3 = 4 - 3 x4,   x5 = -1.
Let x2 = s and x4 = t, then x1 = 2 - 5 s + 2 t,   x3 = 4 - 3 t,   x5 = -1.\
\>", "Text"],

Cell[TextData[{
  "Thus ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"x1"},
              {"x2"},
              {"x3"},
              {"x4"},
              {"x5"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {\(2 - 5\ s + 2\ t\)},
              {"s"},
              {\(4 - 3\ t\)},
              {"t"},
              {\(-1\)}
              }], ")"}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        UnderscriptBox[
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {"2"},
                {"0"},
                {"4"},
                {"0"},
                {\(-1\)}
                }], "\[NegativeThinSpace]", ")"}], 
          RowBox[{"\[UpArrow]", "\n", 
            StyleBox[
              RowBox[{
                StyleBox["`",
                  FontColor->GrayLevel[1]], 
                StyleBox["p",
                  FontWeight->"Bold"]}]]}]], TraditionalForm]]],
  " + s ",
  Cell[BoxData[
      FormBox[
        UnderscriptBox[
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(-5\)},
                  {"1"},
                  {"0"},
                  {"0"},
                  {"0"}
                  },
                ColumnAlignments->{Decimal}], ")"}],
            "TraditionalForm"], 
          RowBox[{"\[UpArrow]", "\n", 
            StyleBox[
              RowBox[{
                StyleBox["`",
                  FontColor->GrayLevel[1]], 
                StyleBox["u",
                  FontWeight->"Bold"]}]]}]], TraditionalForm]]],
  " + t ",
  Cell[BoxData[
      FormBox[
        UnderscriptBox[
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {"2"},
                {"0"},
                {\(-3\)},
                {"1"},
                {"0"}
                }], "\[NegativeThinSpace]", ")"}], 
          RowBox[{"\[UpArrow]", "\n", 
            StyleBox[
              RowBox[{
                StyleBox["`",
                  FontColor->GrayLevel[1]], 
                StyleBox["v",
                  FontWeight->"Bold"]}]]}]], TraditionalForm]]],
  ".\nDefine these vectors ",
  StyleBox["p, u",
    FontWeight->"Bold"],
  ", and",
  StyleBox[" v.",
    FontWeight->"Bold"],
  "\nAll solutions are of the parametric vector form  ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = ",
  StyleBox["p",
    FontWeight->"Bold"],
  " + s ",
  StyleBox["u",
    FontWeight->"Bold"],
  " + t ",
  StyleBox["v",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ax = 0  (the corresponding) Homogeneous System.", "Subsection"],

Cell[TextData[{
  "Find the solution set of A",
  StyleBox["x",
    FontWeight->"Bold"],
  "=",
  StyleBox["0",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "all vectors ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = {x1, x2, x3, x4, x5} (think of vectors as points!) in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^5\)]],
  " that satisfy the equation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ab\  = \ AppendRows[A, {{0}, {0}, {0}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-15\), "4", "18", \(-3\), "0"},
            {"5", "25", "2", \(-4\), "1", "0"},
            {\(-1\), \(-5\), "0", "2", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Ab]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "5", "0", \(-2\), "0", "0"},
            {"0", "0", "1", "3", "0", "0"},
            {"0", "0", "0", "0", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
So x2 and x4 are free and x1 = -5 x2 + 2 x4,   x3 = -3 x4,   x5 = 0.
Let x2 = s and x4 = t, then x1 = -5 s + 2 t,   x3 = -3 t,   x5 = 0.\
\>", "Text"],

Cell[TextData[{
  "Thus ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"x1"},
              {"x2"},
              {"x3"},
              {"x4"},
              {"x5"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {\(\(-5\)\ s + 2\ t\)},
              {"s"},
              {\(\(-3\)\ t\)},
              {"t"},
              {"0"}
              }], ")"}], TraditionalForm]]],
  " =  s ",
  Cell[BoxData[
      FormBox[
        UnderscriptBox[
          FormBox[
            RowBox[{"(", GridBox[{
                  {\(-5\)},
                  {"1"},
                  {"0"},
                  {"0"},
                  {"0"}
                  },
                ColumnAlignments->{Decimal}], ")"}],
            "TraditionalForm"], 
          RowBox[{"\[UpArrow]", "\n", 
            StyleBox[
              RowBox[{
                StyleBox["`",
                  FontColor->GrayLevel[1]], 
                StyleBox["u",
                  FontWeight->"Bold"]}]]}]], TraditionalForm]]],
  " + t ",
  Cell[BoxData[
      FormBox[
        UnderscriptBox[
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {"2"},
                {"0"},
                {\(-3\)},
                {"1"},
                {"0"}
                }], "\[NegativeThinSpace]", ")"}], 
          RowBox[{"\[UpArrow]", "\n", 
            StyleBox[
              RowBox[{
                StyleBox["`",
                  FontColor->GrayLevel[1]], 
                StyleBox["v",
                  FontWeight->"Bold"]}]]}]], TraditionalForm]]],
  ".\nFor this u and v, \nall solutions are of the parametric vector form  ",
  StyleBox["x",
    FontWeight->"Bold"],
  " = s ",
  StyleBox["u",
    FontWeight->"Bold"],
  " + t ",
  StyleBox["v",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["\<\
The relation to the nonhomogeneous solution is not a coincidence!\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem with Mma application using NullSpace.", "Subsection"],

Cell[TextData[{
  "Theorem:  All solutions of the system A",
  StyleBox["x",
    FontWeight->"Bold"],
  "=",
  StyleBox["b",
    FontWeight->"Bold"],
  " are given by one particular solution ",
  StyleBox["p",
    FontWeight->"Bold"],
  " (if one exists) plus solutions ",
  StyleBox["v",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\_h\)]],
  " of the corresponding homogeneous system.  Any  ",
  StyleBox["v",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\_h\)]],
  " is in the span of the homogeneous system solution vectors corresponding \
to each free variable."
}], "Text"],

Cell[TextData[{
  "In Mma, you can ",
  StyleBox["RowReduce",
    FontWeight->"Bold"],
  " the augmented matrix and figure all these vectors by hand.  But there is \
a more direct way!  ",
  StyleBox["LinearSolve",
    FontWeight->"Bold"],
  " will return the vector ",
  StyleBox["p",
    FontWeight->"Bold"],
  ", and the function ",
  StyleBox["NullSpace",
    FontWeight->"Bold"],
  " returns the list of homogeneous system solution vectors."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), \(-15\), "4", "18", \(-3\)},
            {"5", "25", "2", \(-4\), "1"},
            {\(-1\), \(-5\), "0", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"13"},
            {"17"},
            {\(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p\  = \ LinearSolve[A, b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2"},
            {"0"},
            {"4"},
            {"0"},
            {\(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NullSpace[A]\ \ \  (*\ A\ must\ NOT\ be\ augmented\ *) \)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "0", \(-3\), "1", "0"},
            {\(-5\), "1", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Although this displays as a matrix, the best interpretation of this is just a \
list of two vectors.  Indeed, this is how Mma stores the output.  To see this \
convert the above output cell to StandardForm.\
\>", "Text"],

Cell["We can assign names to each of the vectors as follows.", "Text"],

Cell[BoxData[
    \(\({u, v}\  = \ NullSpace[A]; \)\)], "Input"],

Cell[TextData[{
  "Now, the parametric vector form of the solution is ",
  StyleBox["p",
    FontWeight->"Bold"],
  " + s ",
  StyleBox["u",
    FontWeight->"Bold"],
  " + t ",
  StyleBox["v",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[s, t]\), 
    \(x\  = \ p\  + \ s*u + t*v\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(2\ s - 5\ t + 2\)},
            {"t"},
            {\(4 - 3\ s\)},
            {"s"},
            {\(-1\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the answer:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.x\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(4\ \((4 - 3\ s)\) + 18\ s - 3\ \((2\ s - 5\ t + 2)\) - 
                15\ t + 3\)},
           
             {\(2\ \((4 - 3\ s)\) - 4\ s + 5\ \((2\ s - 5\ t + 2)\) + 25\ t - 
                1\)},
            {\(-3\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A.x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"13"},
            {"17"},
            {\(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"13"},
            {"17"},
            {\(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Application to lines and planes in 3D.", "Subsection"],

Cell[CellGroupData[{

Cell["Intersection of two planes by RowReduce Method", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Ab\  = \ {{1, \(-2\), \(-7\), 2}, {\(-2\), 3, 12, \(-5\)}}\)\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), \(-7\), "2"},
            {\(-2\), "3", "12", \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Ab]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-3\), "4"},
            {"0", "1", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Write the solution in parametric vector form.  Interpret it as a line \
through ",
  StyleBox["p",
    FontWeight->"Bold"],
  " and parallel to ",
  StyleBox["v",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Intersection of two planes by Theorem Method", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{1, \(-2\), \(-7\)}, {\(-2\), 3, 12}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), \(-7\)},
            {\(-2\), "3", "12"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ {{2}, {\(-5\)}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2"},
            {\(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p\  = \ LinearSolve[A, b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4"},
            {"1"},
            {"0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", \(-2\), "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\({v}\  = \ NullSpace[A]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\  = \ p + t\ v\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(3\ t + 4\)},
            {\(1 - 2\ t\)},
            {"t"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["One plane by RowReduce Method", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ab\  = \ {{2, \(-1\), 4, 6}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", \(-1\), "4", "6"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Ab]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-\(1\/2\)\), "2", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Write the solution in parametric vector form.  \nInterpret it as a plane \
through ",
  StyleBox["p",
    FontWeight->"Bold"],
  " and parallel to the Span{",
  StyleBox["u",
    FontWeight->"Bold"],
  ", ",
  StyleBox["v",
    FontWeight->"Bold"],
  "}."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["One plane by Theorem Method", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p\  = LinearSolve[{{2, \(-1\), 4}}, {{6}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3"},
            {"0"},
            {"0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[{{2, \(-1\), 4}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "0", "1"},
            {"1", "2", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({u, v} = NullSpace[{{2, \(-1\), 4}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "0", "1"},
            {"1", "2", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p + s*u + t*v\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(\(-2\)\ s + t + 3\)},
            {\(2\ t\)},
            {"s"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ATLAST 2.1; 11  LinearSolve vs. Inverse -- Instructions Only \
\>", "Section"],

Cell["\<\
randint[m_,n_,k_:9] :=
   Table[ Random[Integer,{-k,k}], {m},{n}]\
\>", "Input"],

Cell["\<\
Define A as randint[3,3,5] and check to see that it is nonsingular; 
if it is singular repeat the definition until you get a nonsingular matrix.
Define b as randint[3,1,5] and c as randint[1,3,5]\
\>", "Text"],

Cell["(a) use LinearSolve to solve for x in Ax=b.", "Subsubsection"],

Cell["(b) use Inverse to solve Ax=b.", "Subsubsection"],

Cell["(d) use Inverse to solve for y in yA=c.", "Subsubsection"],

Cell[TextData[{
  "(e) use LinearSolve to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`y\^T\)]],
  " in yA=c"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
(one more part)  Try to use LinearSolve and Inverse to solve the following \
Ax=b for x.  Explain what the results tell you about the solution(s) to Ax=b.\
\
\>", "Subsubsection"],

Cell[BoxData[
    \(A\  = \ {{1, 2, 3}, {0, 1, \(-1\)}, {1, 3, 2}}\)], "Input"],

Cell[BoxData[
    \(b\  = \ {5, \(-1\), 4}\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 2.1; 11  LinearSolve vs. Inverse -- Solutions ", "Section"],

Cell["\<\
randint[m_,n_,k_:9] :=
   Table[ Random[Integer,{-k,k}], {m},{n}]\
\>", "Input"],

Cell["\<\
Define A as randint[3,3,5] and check to see that it is nonsingular; 
if it is singular repeat the definition until you get a nonsingular matrix.
Define b as randint[3,1,5] and c as randint[1,3,5]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ randint[3, 3, 5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-5\), \(-4\), "4"},
            {"5", "5", "0"},
            {\(-3\), "2", \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(1\/5\)\), \(-\(12\/125\)\), \(-\(4\/25\)\)},
            {\(1\/5\), \(37\/125\), \(4\/25\)},
            {\(1\/5\), \(22\/125\), \(-\(1\/25\)\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b = randint[3,1,5]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {"0"},
            {\(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["c = randint[1,3,5]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4", "3", \(-5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(a) use LinearSolve to solve for x in Ax=b.", "Subsubsection"],

Cell[CellGroupData[{

Cell["LinearSolve[A,b]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(4\/5\)},
            {\(-\(4\/5\)\)},
            {\(1\/5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b) use Inverse to solve Ax=b.", "Subsubsection"],

Cell[CellGroupData[{

Cell["Inverse[A].b", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(4\/5\)},
            {\(-\(4\/5\)\)},
            {\(1\/5\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d) use Inverse to solve for y in yA=c.", "Subsubsection"],

Cell[CellGroupData[{

Cell["c.Inverse[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(6\/5\)\), \(-\(47\/125\)\), \(1\/25\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "(e) use LinearSolve to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`y\^T\)]],
  " in yA=c"
}], "Subsubsection"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^T\) y\^T = c\^T\)]],
  ","
}], "Text"],

Cell[CellGroupData[{

Cell["LinearSolve[Transpose[A],Transpose[c]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(6\/5\)\)},
            {\(-\(47\/125\)\)},
            {\(1\/25\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(6\/5\)\), \(-\(47\/125\)\), \(1\/25\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(one more part)  Try to use LinearSolve and Inverse to solve the following \
Ax=b for x.  Explain what the results tell you about the solution(s) to Ax=b.\
\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{1, 2, 3}, {0, 1, \(-1\)}, {1, 3, 2}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3"},
            {"0", "1", \(-1\)},
            {"1", "3", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ {5, \(-1\), 4}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{5, \(-1\), 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[A, b]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{7, \(-1\), 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Inverse::"sing"\), \( : \ \), 
        "\<\"Matrix \\!\\(TraditionalForm\\`\\((\\*GridBox[{{\\\"1\\\", \\\"2\
\\\", \\\"3\\\"}, {\\\"0\\\", \\\"1\\\", \\(-1\\)}, {\\\"1\\\", \\\"3\\\", \\\
\"2\\\"}}, ColumnAlignments -> Decimal])\\)\\) is singular.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"0", "1", \(-1\)},
              {"1", "3", "2"}
              },
            ColumnAlignments->{Decimal}], ")"}], 
        TagBox[\(-1\),
          Inverse]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
A is singular (Inverse doesn't work), so the solution is not unique.  Since \
LinearSolve returns one solution, the system is consistent and must have \
infinitely many solutions.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ATLAST 2.1;18 extended -- Roots of Identity -- Instructions Only \
\>", "Section"],

Cell["\<\
Form the 5\[Times]5 matrix A that is all zeros except for the parameter a in \
every entry along the diagonal just above the main diagonal and the parameter \
x in the lower left corner.\
\>", "Text"],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(-1\), \ A\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\^3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\^4\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^5\)]]
}], "Subsubsection"],

Cell[TextData[{
  "Define a matrix R such that ",
  Cell[BoxData[
      \(TraditionalForm\`R\^5 = I\)]],
  ".  This R should use a parameter so that it describes infinitely many \
\"5th roots of I.\""
}], "Subsubsection"],

Cell[TextData[{
  "Define a matrix Z such that ",
  Cell[BoxData[
      \(TraditionalForm\`Z\^4 \[NotEqual] 0\)]],
  " but all higher powers are the zero matrix."
}], "Subsubsection"],

Cell["\<\
There is nothing special about 5\[Times]5.  Form a 3\[Times]3 matrix \
describing infinitely many \"3rd roots of I.\"\
\>", "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 2.1;18 extended -- Roots of Identity -- Solutions", "Section"],

Cell["\<\
Form the 5\[Times]5 matrix A that is all zeros except for the parameter a in \
every entry along the diagonal just above the main diagonal and the parameter \
x in the lower left corner.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = Table[ If[j==i+1,a,0] ,{i,5},{j,5}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "a", "0", "0", "0"},
            {"0", "0", "a", "0", "0"},
            {"0", "0", "0", "a", "0"},
            {"0", "0", "0", "0", "a"},
            {"0", "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[\([5, 1]\)] = x\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "a", "0", "0", "0"},
            {"0", "0", "a", "0", "0"},
            {"0", "0", "0", "a", "0"},
            {"0", "0", "0", "0", "a"},
            {"x", "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(-1\), \ A\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\^3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\^4\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^5\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", \(1\/x\)},
            {\(1\/a\), "0", "0", "0", "0"},
            {"0", \(1\/a\), "0", "0", "0"},
            {"0", "0", \(1\/a\), "0", "0"},
            {"0", "0", "0", \(1\/a\), "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", \(a\^2\), "0", "0"},
            {"0", "0", "0", \(a\^2\), "0"},
            {"0", "0", "0", "0", \(a\^2\)},
            {\(a\ x\), "0", "0", "0", "0"},
            {"0", \(a\ x\), "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.A.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \(a\^3\), "0"},
            {"0", "0", "0", "0", \(a\^3\)},
            {\(a\^2\ x\), "0", "0", "0", "0"},
            {"0", \(a\^2\ x\), "0", "0", "0"},
            {"0", "0", \(a\^2\ x\), "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.A.A.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", \(a\^4\)},
            {\(a\^3\ x\), "0", "0", "0", "0"},
            {"0", \(a\^3\ x\), "0", "0", "0"},
            {"0", "0", \(a\^3\ x\), "0", "0"},
            {"0", "0", "0", \(a\^3\ x\), "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A.A.A.A.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(a\^4\ x\), "0", "0", "0", "0"},
            {"0", \(a\^4\ x\), "0", "0", "0"},
            {"0", "0", \(a\^4\ x\), "0", "0"},
            {"0", "0", "0", \(a\^4\ x\), "0"},
            {"0", "0", "0", "0", \(a\^4\ x\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Define a matrix R such that ",
  Cell[BoxData[
      \(TraditionalForm\`R\^5 = I\)]],
  ".  This R should use a parameter so that it describes infinitely many \
\"5th roots of I.\""
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R = A\  /. \ x -> 1/a^4\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "a", "0", "0", "0"},
            {"0", "0", "a", "0", "0"},
            {"0", "0", "0", "a", "0"},
            {"0", "0", "0", "0", "a"},
            {\(1\/a\^4\), "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixPower[R, 5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Alternative:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\  = \ A\  /. \ a -> 1/x^\((1/4)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(1\/\@x\%4\), "0", "0", "0"},
            {"0", "0", \(1\/\@x\%4\), "0", "0"},
            {"0", "0", "0", \(1\/\@x\%4\), "0"},
            {"0", "0", "0", "0", \(1\/\@x\%4\)},
            {"x", "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixPower[B, 5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Define a matrix Z such that ",
  Cell[BoxData[
      \(TraditionalForm\`Z\^4 \[NotEqual] 0\)]],
  " but all higher powers are the zero matrix."
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z\  = \ A\  /. \ x -> 0\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "a", "0", "0", "0"},
            {"0", "0", "a", "0", "0"},
            {"0", "0", "0", "a", "0"},
            {"0", "0", "0", "0", "a"},
            {"0", "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z.Z.Z.Z\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", \(a\^4\)},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z.Z.Z.Z.Z\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
There is nothing special about 5\[Times]5.  Form a 3\[Times]3 matrix \
describing infinitely many \"3rd roots of I.\"\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\  = \ {{0, a, 0}, {0, 0, a}, {1/a^2, 0, 0}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "a", "0"},
            {"0", "0", "a"},
            {\(1\/a\^2\), "0", "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(B.B\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", \(a\^2\)},
            {\(1\/a\), "0", "0"},
            {"0", \(1\/a\), "0"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(B.B.B\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{617, 351},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 162, 4, 66, "Subsubtitle"],
Cell[1896, 57, 238, 6, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2171, 68, 59, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[2255, 72, 95, 2, 53, "Section"],
Cell[2353, 76, 472, 18, 300, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2862, 99, 141, 5, 33, "Section"],

Cell[CellGroupData[{
Cell[3028, 108, 59, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[3112, 112, 83, 1, 30, "Input"],
Cell[3198, 115, 202, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3437, 126, 75, 1, 30, "Input"],
Cell[3515, 129, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3615, 135, 77, 1, 30, "Input"],
Cell[3695, 138, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3785, 144, 45, 1, 30, "Input"],
Cell[3833, 147, 202, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4072, 158, 34, 1, 30, "Input"],
Cell[4109, 161, 202, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4348, 172, 101, 2, 30, "Input"],
Cell[4452, 176, 63, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4564, 183, 74, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[4663, 187, 38, 0, 30, "Input"],
Cell[4704, 189, 340, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5081, 203, 55, 0, 30, "Input"],
Cell[5139, 205, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5228, 211, 18, 0, 30, "Input"],
Cell[5249, 213, 340, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5626, 227, 46, 0, 30, "Input"],
Cell[5675, 229, 281, 8, 80, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6005, 243, 71, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[6101, 247, 38, 0, 30, "Input"],
Cell[6142, 249, 101, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6280, 256, 35, 0, 30, "Input"],
Cell[6318, 258, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6421, 264, 33, 0, 30, "Input"],
Cell[6457, 266, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6566, 272, 31, 0, 30, "Input"],
Cell[6600, 274, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6709, 280, 35, 0, 30, "Input"],
Cell[6747, 282, 213, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6997, 293, 40, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7062, 297, 62, 1, 30, "Input"],
Cell[7127, 300, 571, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7735, 318, 80, 1, 30, "Input"],
Cell[7818, 321, 265, 7, 62, "Output"]
}, Open  ]],
Cell[8098, 331, 148, 3, 52, "Text"],
Cell[8249, 336, 89, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[8363, 343, 46, 1, 30, "Input"],
Cell[8412, 346, 289, 7, 62, "Output"]
}, Open  ]],
Cell[8716, 356, 96, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[8837, 362, 46, 1, 30, "Input"],
Cell[8886, 365, 271, 7, 62, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9206, 378, 70, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[9301, 382, 41, 0, 30, "Input"],
Cell[9345, 384, 284, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9666, 397, 48, 0, 30, "Input"],
Cell[9717, 399, 305, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10059, 412, 80, 1, 30, "Input"],
Cell[10142, 415, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10460, 428, 84, 1, 30, "Input"],
Cell[10547, 431, 281, 8, 80, "Output"]
}, Open  ]],
Cell[10843, 442, 128, 3, 52, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11020, 451, 53, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[11098, 455, 54, 1, 30, "Input"],
Cell[11155, 458, 271, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11463, 470, 54, 1, 30, "Input"],
Cell[11520, 473, 265, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11822, 485, 44, 1, 30, "Input"],
Cell[11869, 488, 277, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12183, 500, 49, 1, 30, "Input"],
Cell[12235, 503, 287, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12559, 516, 60, 1, 30, "Input"],
Cell[12622, 519, 287, 8, 80, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12958, 533, 55, 0, 31, "Subsection"],
Cell[13016, 535, 88, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[13129, 542, 33, 0, 30, "Input"],
Cell[13165, 544, 232, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13434, 556, 33, 0, 30, "Input"],
Cell[13470, 558, 250, 7, 62, "Output"]
}, Open  ]],
Cell[13735, 568, 43, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[13803, 572, 20, 0, 30, "Input"],
Cell[13826, 574, 255, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14118, 586, 65, 0, 30, "Input"],
Cell[14186, 588, 257, 7, 62, "Output"]
}, Open  ]],
Cell[14458, 598, 57, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[14540, 602, 20, 0, 30, "Input"],
Cell[14563, 604, 262, 7, 62, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14874, 617, 54, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[14953, 621, 46, 0, 30, "Input"],
Cell[15002, 623, 242, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15281, 635, 50, 0, 30, "Input"],
Cell[15334, 637, 238, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15609, 649, 121, 3, 30, "Input"],
Cell[15733, 654, 238, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16008, 666, 78, 1, 30, "Input"],
Cell[16089, 669, 265, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16391, 681, 33, 0, 30, "Input"],
Cell[16427, 683, 265, 7, 62, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16753, 697, 56, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[16834, 701, 34, 0, 30, "Input"],
Cell[16871, 703, 193, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17101, 714, 57, 3, 48, "Input"],
Cell[17161, 719, 154, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17352, 729, 20, 0, 30, "Input"],
Cell[17375, 731, 202, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17614, 741, 20, 0, 30, "Input"],
Cell[17637, 743, 202, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17876, 753, 44, 0, 30, "Input"],
Cell[17923, 755, 150, 4, 25, "Message"],
Cell[18076, 761, 89, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18202, 767, 42, 1, 30, "Input"],
Cell[18247, 770, 221, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18505, 780, 67, 0, 30, "Input"],
Cell[18575, 782, 296, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18908, 795, 29, 0, 30, "Input"],
Cell[18940, 797, 290, 8, 80, "Output"]
}, Open  ]],
Cell[19245, 808, 41, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[19311, 812, 58, 3, 48, "Input"],
Cell[19372, 817, 168, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19577, 827, 31, 0, 30, "Input"],
Cell[19611, 829, 210, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19858, 839, 31, 0, 30, "Input"],
Cell[19892, 841, 210, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20139, 851, 36, 0, 30, "Input"],
Cell[20178, 853, 196, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20411, 864, 21, 0, 30, "Input"],
Cell[20435, 866, 197, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20669, 877, 21, 0, 30, "Input"],
Cell[20693, 879, 197, 6, 44, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20939, 891, 75, 0, 33, "Section"],
Cell[21017, 893, 72, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[21114, 897, 37, 0, 30, "Input"],
Cell[21154, 899, 265, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21456, 911, 29, 0, 30, "Input"],
Cell[21488, 913, 253, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21778, 925, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[21828, 929, 29, 0, 30, "Input"],
Cell[21860, 931, 219, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22116, 942, 54, 3, 48, "Input"],
Cell[22173, 947, 74, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22284, 953, 54, 0, 30, "Input"],
Cell[22341, 955, 197, 7, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22575, 967, 20, 0, 30, "Input"],
Cell[22598, 969, 241, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22876, 980, 46, 1, 30, "Input"],
Cell[22925, 983, 202, 7, 62, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23176, 996, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[23226, 1000, 33, 0, 30, "Input"],
Cell[23262, 1002, 227, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23526, 1015, 71, 0, 30, "Input"],
Cell[23600, 1017, 210, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23847, 1029, 20, 0, 30, "Input"],
Cell[23870, 1031, 222, 7, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24129, 1043, 24, 0, 30, "Input"],
Cell[24156, 1045, 320, 8, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24513, 1058, 34, 0, 30, "Input"],
Cell[24550, 1060, 210, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24797, 1072, 36, 1, 30, "Input"],
Cell[24836, 1075, 210, 7, 62, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[25107, 1089, 144, 3, 54, "Section"],

Cell[CellGroupData[{
Cell[25276, 1096, 52, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[25353, 1100, 143, 3, 30, "Input"],
Cell[25499, 1105, 283, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25819, 1117, 63, 1, 30, "Input"],
Cell[25885, 1120, 207, 7, 62, "Output"]
}, Open  ]],
Cell[26107, 1130, 423, 17, 52, "Text"],
Cell[26533, 1149, 71, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[26629, 1154, 58, 1, 30, "Input"],
Cell[26690, 1157, 303, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27030, 1169, 46, 1, 30, "Input"],
Cell[27079, 1172, 283, 7, 62, "Output"]
}, Open  ]],
Cell[27377, 1182, 174, 3, 52, "Text"],
Cell[27554, 1187, 2683, 100, 167, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[30274, 1292, 69, 0, 31, "Subsection"],
Cell[30346, 1294, 423, 17, 52, "Text"],

Cell[CellGroupData[{
Cell[30794, 1315, 72, 1, 30, "Input"],
Cell[30869, 1318, 298, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31204, 1330, 46, 1, 30, "Input"],
Cell[31253, 1333, 280, 7, 62, "Output"]
}, Open  ]],
Cell[31548, 1343, 160, 3, 52, "Text"],
Cell[31711, 1348, 1982, 73, 167, "Text"],
Cell[33696, 1423, 89, 2, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[33822, 1430, 67, 0, 31, "Subsection"],
Cell[33892, 1432, 622, 22, 71, "Text"],
Cell[34517, 1456, 458, 15, 71, "Text"],

Cell[CellGroupData[{
Cell[35000, 1475, 34, 1, 30, "Input"],
Cell[35037, 1478, 283, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35357, 1490, 34, 1, 30, "Input"],
Cell[35394, 1493, 207, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35638, 1505, 58, 1, 30, "Input"],
Cell[35699, 1508, 243, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35979, 1522, 92, 1, 30, "Input"],
Cell[36074, 1525, 229, 6, 44, "Output"]
}, Open  ]],
Cell[36318, 1534, 230, 4, 52, "Text"],
Cell[36551, 1540, 70, 0, 33, "Text"],
Cell[36624, 1542, 64, 1, 30, "Input"],
Cell[36691, 1545, 235, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[36951, 1560, 82, 2, 50, "Input"],
Cell[37036, 1564, 229, 8, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37302, 1577, 42, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[37369, 1581, 36, 1, 30, "Input"],
Cell[37408, 1584, 355, 10, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37800, 1599, 46, 1, 30, "Input"],
Cell[37849, 1602, 207, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38093, 1614, 34, 1, 30, "Input"],
Cell[38130, 1617, 207, 7, 62, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38398, 1631, 60, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[38483, 1635, 71, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[38579, 1639, 100, 2, 30, "Input"],
Cell[38682, 1643, 226, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38945, 1654, 46, 1, 30, "Input"],
Cell[38994, 1657, 216, 6, 44, "Output"]
}, Open  ]],
Cell[39225, 1666, 224, 9, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[39486, 1680, 69, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[39580, 1684, 79, 1, 30, "Input"],
Cell[39662, 1687, 213, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39912, 1698, 56, 1, 30, "Input"],
Cell[39971, 1701, 186, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40194, 1712, 58, 1, 30, "Input"],
Cell[40255, 1715, 202, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40494, 1727, 45, 1, 30, "Input"],
Cell[40542, 1730, 177, 5, 29, "Output"]
}, Open  ]],
Cell[40734, 1738, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[40820, 1743, 49, 1, 30, "Input"],
Cell[40872, 1746, 181, 6, 62, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[41102, 1758, 54, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[41181, 1762, 61, 1, 30, "Input"],
Cell[41245, 1765, 182, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41464, 1775, 46, 1, 30, "Input"],
Cell[41513, 1778, 189, 5, 35, "Output"]
}, Open  ]],
Cell[41717, 1786, 286, 12, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[42040, 1803, 52, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[42117, 1807, 75, 1, 30, "Input"],
Cell[42195, 1810, 202, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42434, 1822, 60, 1, 30, "Input"],
Cell[42497, 1825, 206, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42740, 1836, 69, 1, 30, "Input"],
Cell[42812, 1839, 206, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43055, 1850, 46, 1, 30, "Input"],
Cell[43104, 1853, 186, 6, 62, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43363, 1867, 88, 2, 33, "Section"],
Cell[43454, 1871, 90, 3, 48, "Input"],
Cell[43547, 1876, 219, 4, 71, "Text"],
Cell[43769, 1882, 68, 0, 43, "Subsubsection"],
Cell[43840, 1884, 55, 0, 43, "Subsubsection"],
Cell[43898, 1886, 64, 0, 43, "Subsubsection"],
Cell[43965, 1888, 139, 5, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[44129, 1897, 189, 4, 60, "Subsubsection"],
Cell[44321, 1903, 79, 1, 30, "Input"],
Cell[44403, 1906, 55, 1, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[44507, 1913, 72, 0, 33, "Section"],
Cell[44582, 1915, 90, 3, 48, "Input"],
Cell[44675, 1920, 219, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[44919, 1928, 57, 1, 30, "Input"],
Cell[44979, 1931, 244, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45260, 1943, 43, 1, 30, "Input"],
Cell[45306, 1946, 309, 7, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45652, 1958, 35, 0, 30, "Input"],
Cell[45690, 1960, 205, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45932, 1972, 35, 0, 30, "Input"],
Cell[45970, 1974, 177, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46184, 1984, 68, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[46277, 1988, 33, 0, 30, "Input"],
Cell[46313, 1990, 222, 7, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46584, 2003, 55, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[46664, 2007, 29, 0, 30, "Input"],
Cell[46696, 2009, 222, 7, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46967, 2022, 64, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[47056, 2026, 29, 0, 30, "Input"],
Cell[47088, 2028, 203, 5, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47340, 2039, 139, 5, 43, "Subsubsection"],
Cell[47482, 2046, 112, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[47619, 2055, 55, 0, 30, "Input"],
Cell[47677, 2057, 231, 7, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47945, 2069, 45, 1, 30, "Input"],
Cell[47993, 2072, 203, 5, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48245, 2083, 189, 4, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[48459, 2091, 79, 1, 30, "Input"],
Cell[48541, 2094, 235, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48813, 2106, 55, 1, 30, "Input"],
Cell[48871, 2109, 65, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48973, 2115, 50, 1, 30, "Input"],
Cell[49026, 2118, 65, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49128, 2124, 43, 1, 30, "Input"],
Cell[49174, 2127, 343, 7, 58, "Message"],
Cell[49520, 2136, 314, 10, 63, "Output"]
}, Open  ]],
Cell[49849, 2149, 203, 4, 52, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[50101, 2159, 92, 2, 33, "Section"],
Cell[50196, 2163, 210, 4, 52, "Text"],
Cell[50409, 2169, 294, 13, 43, "Subsubsection"],
Cell[50706, 2184, 221, 6, 43, "Subsubsection"],
Cell[50930, 2192, 183, 5, 43, "Subsubsection"],
Cell[51116, 2199, 150, 3, 43, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[51303, 2207, 75, 0, 33, "Section"],
Cell[51381, 2209, 210, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[51616, 2217, 56, 0, 30, "Input"],
Cell[51675, 2219, 301, 8, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52013, 2232, 50, 1, 30, "Input"],
Cell[52066, 2235, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52155, 2241, 34, 1, 30, "Input"],
Cell[52192, 2244, 301, 8, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52530, 2257, 291, 13, 47, "Subsection"],

Cell[CellGroupData[{
Cell[52846, 2274, 43, 1, 30, "Input"],
Cell[52892, 2277, 326, 8, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53255, 2290, 36, 1, 30, "Input"],
Cell[53294, 2293, 326, 8, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53657, 2306, 38, 1, 30, "Input"],
Cell[53698, 2309, 335, 8, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54070, 2322, 40, 1, 30, "Input"],
Cell[54113, 2325, 338, 8, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54488, 2338, 42, 1, 30, "Input"],
Cell[54533, 2341, 341, 8, 113, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[54923, 2355, 218, 6, 66, "Subsection"],

Cell[CellGroupData[{
Cell[55166, 2365, 56, 1, 30, "Input"],
Cell[55225, 2368, 309, 8, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55571, 2381, 50, 1, 30, "Input"],
Cell[55624, 2384, 340, 9, 98, "Output"]
}, Open  ]],
Cell[55979, 2396, 28, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[56032, 2400, 68, 1, 30, "Input"],
Cell[56103, 2403, 341, 8, 162, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56481, 2416, 50, 1, 30, "Input"],
Cell[56534, 2419, 340, 9, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[56923, 2434, 180, 5, 47, "Subsection"],

Cell[CellGroupData[{
Cell[57128, 2443, 56, 1, 30, "Input"],
Cell[57187, 2446, 301, 8, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57525, 2459, 40, 1, 30, "Input"],
Cell[57568, 2462, 306, 8, 101, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57911, 2475, 42, 1, 30, "Input"],
Cell[57956, 2478, 340, 9, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58345, 2493, 147, 3, 66, "Subsection"],

Cell[CellGroupData[{
Cell[58517, 2500, 78, 1, 30, "Input"],
Cell[58598, 2503, 201, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58836, 2514, 36, 1, 30, "Input"],
Cell[58875, 2517, 208, 6, 83, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59120, 2528, 38, 1, 30, "Input"],
Cell[59161, 2531, 232, 7, 62, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

