(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    341219,       7614]*)
(*NotebookOutlinePosition[    341896,       7638]*)
(*  CellTagsIndexPosition[    341852,       7634]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College,  6/1/98."
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["ATLAST 4.2  Projects on Vector Space Concepts", "Subtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  "ATLAST 4.2; 1 -- a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version of cogame for students"
}], "Section"],

Cell[CellGroupData[{

Cell["Initializations -- norm, arrow, cogame, guess", "Subsection"],

Cell["Needs[\"Graphics`Colors`\"]", "Input",
  InitializationCell->True],

Cell["norm[v_] := Sqrt[v.v]", "Input",
  InitializationCell->True],

Cell["\<\
arrow[{a_,b_},color___] := Graphics[
   {color, Line[{{0,0},{a,b}}],
    Line[{{a,b},.9{a,b}+.04{-b,a}}],
    Line[{{a,b},.9{a,b}-.04{-b,a}}]}
]\
\>", "Input",
  InitializationCell->True],

Cell["\<\
cogame := Module[{},
   (* creates global variables v1,v2,target *)
   v1 = Table[Random[Real,{-1,1}],{2}];
   v2 = Table[Random[Real,{-1,1}],{2}];
   target = Table[Random[Real,{-1,1}],{2}];
   Show[arrow[v1],Graphics[Text[\"v1\",v1/2]],
        arrow[v2],Graphics[Text[\"v2\",v2/2]],
        arrow[target,Red],
        Axes->True, AspectRatio->Automatic, Ticks->None];
   Print[\"Try to match the red vector with a*v1+b*v2\"];
   Print[\"Enter:  guess[a,b]\"]
]\
\>", "Input",
  InitializationCell->True],

Cell["\<\
guess[a_,b_] := Module[{},
   (* uses global variables v1,v2,target *)
   Show[arrow[v1],Graphics[Text[\"v1\",v1/2]],
        arrow[v2],Graphics[Text[\"v2\",v2/2]],
        arrow[target,Red],
        arrow[a*v1+b*v2,Green],
        Axes->True, AspectRatio->Automatic, Ticks->None];
   Print[\"You are off by:  \",norm[target-(a*v1+b*v2)]]
]\
\>", "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Student Instructions -- START HERE.", "Subsection"],

Cell["Student Names:", "Text"],

Cell[CellGroupData[{

Cell["\<\
Play two games of cogame with your partner.  
Who get's closest?  Within 0.1 is pretty good, consider that a win.\
\>", "Subsubsection"],

Cell["\<\
Actually, you can play as many games as you want but only print (or dropbox \
or show instructor) two games and four total guesses.\
\>", "Text"],

Cell["cogame", "Input"],

Cell["guess[ , ]", "Input"],

Cell[TextData[{
  "Type ",
  StyleBox["guess[?,?]",
    FontFamily->"Courier New"],
  " again and try to get closer.  After you are done with this first game, \
type ",
  StyleBox["cogame",
    FontFamily->"Courier New"],
  " again to create another game."
}], "Text"]
}, Open  ]],

Cell["\<\
Answer question (a):  How could the vectors v1 and v2 make the game \
impossible to win?\
\>", "Subsubsection"],

Cell["Answer questions (c) and (d):", "Subsubsection"],

Cell[CellGroupData[{

Cell["(b)  cogame answer function -- optional", "Subsubsection"],

Cell["cogame", "Input"],

Cell["\<\
Here are the vectors (listed as rows!) and target that cogame created.\
\>", "Text"],

Cell["{v1,v2}", "Input"],

Cell["target", "Input"],

Cell["\<\
Use LinearSolve to solve for target as a linear combination of v1 and v2.  
Hint: matrix multiplication is a linear combination of columns.
target \"should\" be a 2x1 matrix but remember that you can use {t1, t2} as a \
vector that Mma will use as a column vector {{t1},{t2}} ( or row vector {{t1, \
t2}} ) whenever the context calls for it.\
\>", "Text"],

Cell["", "Input"],

Cell["\<\
Check the answer you got by typing the answer into guess but use only one \
decimal place.\
\>", "Text"],

Cell["guess[ , ]", "Input"],

Cell["\<\
After you've found a formula to solve this problem, let's learn a little \
Mathematica.  \
\>", "Text"],

Cell["\<\
Name the solution as soln by typing in the formula with assignment.\
\>", "Text"],

Cell["soln = ", "Input"],

Cell["\<\
Now you want to plug in the solution (computed to 16 digits even though the \
display only shows 6!) into guess but the following doesn't work.\
\>", "Text"],

Cell["guess[soln]", "Input"],

Cell["\<\
What went wrong is that you don't want the braces in soln.  This can be \
accomplished by the function Apply.\
\>", "Text"],

Cell["Apply[guess,soln]", "Input"],

Cell["\<\
Now let's create a program to do this everytime.  Simply use the soln = \
formula above but change to
answer := formula.  The colon-equal creates a program or function that only \
saves instructions now but will execute  these instructions whenever you type \
answer.  (It could have arguments  but your function assumes the vectors \
named v1, v2 and target from cogame.)\
\>", "Text"],

Cell["answer := ", "Input"],

Cell["Now try it.", "Text"],

Cell["answer", "Input"],

Cell["Try it on a new game.", "Text"],

Cell["cogame", "Input"],

Cell["answer", "Input"],

Cell["Apply[guess,answer]", "Input"],

Cell["\<\
Note that soln doesn't change (it was a constant set on the first problem) \
but that answer recomputes the formula using the latest values of the the \
variables.\
\>", "Text"],

Cell["soln", "Input"],

Cell["answer", "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "ATLAST 4.2; 1 -- a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version of cogame -- Example Solutions"
}], "Section"],

Cell[CellGroupData[{

Cell["Initializations -- norm, arrow, cogame, guess", "Subsection"],

Cell["Needs[\"Graphics`Colors`\"]", "Input",
  InitializationCell->True],

Cell["norm[v_] := Sqrt[v.v]", "Input",
  InitializationCell->True],

Cell["\<\
arrow[{a_,b_},color___] := Graphics[
   {color, Line[{{0,0},{a,b}}],
    Line[{{a,b},.9{a,b}+.04{-b,a}}],
    Line[{{a,b},.9{a,b}-.04{-b,a}}]}
]\
\>", "Input",
  InitializationCell->True],

Cell["\<\
cogame := Module[{},
   (* creates global variables v1,v2,target *)
   v1 = Table[Random[Real,{-1,1}],{2}];
   v2 = Table[Random[Real,{-1,1}],{2}];
   target = Table[Random[Real,{-1,1}],{2}];
   Show[arrow[v1],Graphics[Text[\"v1\",v1/2]],
        arrow[v2],Graphics[Text[\"v2\",v2/2]],
        arrow[target,Red],
        Axes->True, AspectRatio->Automatic, Ticks->None];
   Print[\"Try to match the red vector with a*v1+b*v2\"];
   Print[\"Enter:  guess[a,b]\"]
]\
\>", "Input",
  InitializationCell->True],

Cell["\<\
guess[a_,b_] := Module[{},
   (* uses global variables v1,v2,target *)
   Show[arrow[v1],Graphics[Text[\"v1\",v1/2]],
        arrow[v2],Graphics[Text[\"v2\",v2/2]],
        arrow[target,Red],
        arrow[a*v1+b*v2,Green],
        Axes->True, AspectRatio->Automatic, Ticks->None];
   Print[\"You are off by:  \",norm[target-(a*v1+b*v2)]]
]\
\>", "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Student Instructions -- START HERE.", "Subsection"],

Cell["Student Names:", "Text"],

Cell[CellGroupData[{

Cell["\<\
Play two games of cogame with your partner.  
Who get's closest?  Within 0.1 is pretty good, consider that a win.\
\>", "Subsubsection"],

Cell["\<\
Actually, you can play as many games as you want but only print (or dropbox \
or show instructor) two games and four total guesses.\
\>", "Text"],

Cell[CellGroupData[{

Cell["cogame", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .46158 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.751577 0.776415 0.450594 0.776415 [
[ 0 0 0 0 ]
[ 1 .46158 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .45059 m
1 .45059 L
s
.75158 0 m
.75158 .46158 L
s
0 0 m
1 0 L
1 .46158 L
0 .46158 L
closepath
clip
newpath
.5 Mabswid
.75158 .45059 m
.02381 .06559 L
s
.02381 .06559 m
.11199 .07498 L
s
.02381 .06559 m
.08119 .1332 L
s
gsave
.38769 .25809 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75158 .45059 m
.90986 .01099 L
s
.90986 .01099 m
.91161 .06128 L
s
.90986 .01099 m
.87645 .04862 L
s
gsave
.83072 .23079 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.75158 .45059 m
.97619 .17464 L
s
.97619 .17464 m
.96477 .21122 L
s
.97619 .17464 m
.94269 .19326 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{357.375, 164.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000Y2000`400?l00000o`00003oo`3oool<
0?ooo`030000003oool0oooo05L0oooo003o0?ooo``0oooo00<000000?ooo`3oool0E`3oool00?l0
oooo303oool00`000000oooo0?ooo`1G0?ooo`00o`3oool<0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool07`3oool00?l0oooo303oool00`000000oooo0?ooo`0d0?ooo`8000008@3o
ool00?l0oooo303oool00`000000oooo0?ooo`0c0?ooo`<000008@3oool00?l0oooo303oool00`00
0000oooo0?ooo`0b0?ooo`040000003oool0000000000240oooo003o0?ooo``0oooo00<000000?oo
o`3oool0<P3oool010000000oooo00000000000Q0?ooo`00o`3oool<0?ooo`030000003oool0oooo
0340oooo00D000000?ooo`000000oooo0000000Q0?ooo`00o`3oool<0?ooo`030000003oool0oooo
0300oooo00H000000?ooo`3oool000000?ooo`00000Q0?ooo`00o`3oool<0?ooo`030000003oool0
oooo02l0oooo00L000000?ooo`3oool0oooo0000003oool000000240oooo003o0?ooo``0oooo00<0
00000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
7`3oool00?l0oooo303oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000008@3oool00?l0oooo303oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`00o`3oool<
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01h0oooo003o0?ooo``0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool00?l0
oooo303oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0N0?ooo`00o`3oool<0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo
003o0?ooo``0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01h0oooo003o0?ooo``0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01h0oooo003o0?ooo``0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo003o0?ooo``0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo003o0?ooo``0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?ooo`002@3oool600000?`0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?ooo`002P3oool2000000<0oooo2P00003b
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool09P3oool000/0oooo0`00000;0?oo
o`X00000j03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02L0oooo000;0?ooo`03
0000003oool0oooo008000004`3oool600000>80oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0W0?ooo`00303oool010000000oooo0?ooo`3oool200000?T0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0X0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`800000
m`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo000>0?ooo`030000003o
ool0oooo00<0oooo0P00003e0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:03o
ool000l0oooo00<000000?ooo`3oool0103oool200000?<0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0Y0?ooo`00403oool00`000000oooo0?ooo`050?ooo`800000l@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02T0oooo000@0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02T0
oooo000A0?ooo`030000003oool0oooo00L0oooo0P00003^0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:P3oool00180oooo00<000000?ooo`3oool0203oool200000>`0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`004`3oool00`000000oooo0?ooo`09
0?ooo`800000jP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo000D0?oo
o`030000003oool0oooo00X0oooo0P00003X0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:`3oool001D0oooo00<000000?ooo`3oool02`3oool200000>H0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0[0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`800000
i03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02/0oooo000F0?ooo`030000003o
ool0oooo00h0oooo0P00003R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;03o
ool001L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0;03oool001P0oooo00<000000?ooo`3oool03`3oool20000
0=l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0]0?ooo`006@3oool00`000000
oooo0?ooo`0@0?ooo`800000g@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02d0
oooo000J0?ooo`030000003oool0oooo0140oooo0P00003K0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0;@3oool001X0oooo00<000000?ooo`3oool04`3oool200000=T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0^0?ooo`006`3oool00`000000oooo0?ooo`0D
0?ooo`800000e`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02h0oooo000L0?oo
o`030000003oool0oooo01D0oooo0P00003E0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0;P3oool001d0oooo00<000000?ooo`3oool05P3oool200000=<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0_0?ooo`00>03oool200000=40oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0_0?ooo`00>P3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0;`3oool003/0oooo0P00003>0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0<03oool003d0oooo0P00003<0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0<03oool003l0oooo0P00003:0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0<03oool00440oooo0P0000380?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<@3oool004<0oooo0P0000360?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0<@3oool004D0oooo0P0000340?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0<P3oool004L0oooo0P0000320?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0<P3oool004T0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0380oooo001:0?ooo`800000_`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03<0oooo001<0?ooo`800000_@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo03<0oooo001>0?ooo`800000^`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo03<0oooo001@0?ooo`800000^@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
03@0oooo001B0?ooo`800000]`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02X0
oooo00<0o`000?ooo`3oool01`3oool005@0oooo0P00002e0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0:03oool30?l000T0oooo001F0?ooo`800000/`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02L0oooo103o000:0?ooo`00F03oool200000;40oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0U0?ooo`80o`000P3oool20?l000X0oooo001J0?oo
o`030000003oool0oooo0:h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?oo
o`80o`000`3oool00`3o0000oooo0?l0000:0?ooo`00F`3oool200000:h0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0R0?ooo`80o`00103oool00`3o0000oooo0?l0000;0?ooo`00
G@3oool200000:`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0P0?ooo`80o`00
1@3oool0103o0000oooo0?ooo`3o000;0?ooo`00G`3oool200000:X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0W0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00640oooo
0P00002X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00T0oooo001S0?ooo`800000YP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02H0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`00I@3o
ool200000:@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02P3oool006L0oooo0P00002R0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00X0oooo001Y0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool006X0
oooo0P00002O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0903oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo001/0?ooo`800000W@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool04P3oool006h0oooo0P00
002K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?oo
o`0C0?ooo`00L03oool2000009T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0S
0?ooo`030?l0003oool0oooo01@0oooo001b0?ooo`800000U`3oool00`000000oooo0?ooo`0E0?oo
o`8000000P3oool3000002<0oooo00<0o`000?ooo`3oool05@3oool007@0oooo0P00002E0?ooo`03
0000003oool0oooo01D0oooo0P0000020?ooo`8000008`3oool00`3o0000oooo0?ooo`0F0?ooo`00
MP3oool2000009<0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`000000oooo0080
00008P3oool00`3o0000oooo0?ooo`0G0?ooo`00N03oool200000940oooo00<000000?ooo`3oool0
4`3oool200000080oooo00@000000?ooo`00000000008P3oool00`3o0000oooo0?ooo`0G0?ooo`00
NP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01P0oooo0P0000000`3oool00000
0?ooo`0O0?ooo`030?l0003oool0oooo01P0oooo001k0?ooo`800000SP3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool000000200oooo00<0o`000?ooo`3oool06@3oool007d0oooo0P00002<
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0J
0?ooo`00O`3oool2000008X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O0?oo
o`030?l0003oool0oooo01/0oooo00210?ooo`800000R03oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01l0oooo00<0o`000?ooo`3oool06`3oool008<0oooo0P0000260?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0L0?ooo`00Q@3o
ool3000000030?ooo`000000000000<00000O@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01h0oooo00<0o`000?ooo`3oool07@3oool008H0oooo0`0000020?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo01h0oooo00250?ooo`030000003oool0oooo0080000000<0oooo0000003oool0OP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool07`3oool008@0
oooo0P0000020?ooo`040000003oool00000000007l0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01l0oooo002;0?ooo`<00000O@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0803oool008X0oooo
0P0000020?ooo`800000N`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo
00<0o`000?ooo`3oool08@3oool00900oooo0P00001i0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0R0?ooo`00TP3oool2000007L0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02<0oooo002D0?oo
o`800000M@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01X0oooo00<0o`000?oo
o`3oool0903oool009H0oooo0P00001c0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0T0?ooo`00V03oool200000740oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02D0oooo002J0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo02H0oooo002K0?ooo`800000KP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01P0oooo00<0o`000?ooo`3oool09`3oool009d0oooo0P00001/0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0X0?ooo`00W`3oool2000006X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02P0
oooo002Q0?ooo`800000J03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo
00<0o`000?ooo`3oool0:@3oool00:<0oooo0P00001V0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0Z0?ooo`00Y@3oool2000006@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02/0oooo002W0?oo
o`800000HP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool0;03oool00:T0oooo0P00001P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`0]0?ooo`00Z`3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0]0?ooo`00[03o
ool2000005d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo02h0oooo002^0?ooo`800000F`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01@0oooo00<0o`000?ooo`3oool0;`3oool00;00oooo0P00001I0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0`0?ooo`00/P3oool2000005L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0340
oooo002d0?ooo`800000E@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo
00<0o`000?ooo`3oool0<@3oool00;H0oooo0P00001C0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0b0?ooo`00^03oool200000540oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo03<0oooo002j0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo03@0oooo002k0?ooo`800000CP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0100oooo00<0o`000?ooo`3oool0=@3oool00;d0oooo0P00001<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0f0?ooo`00_`3o
ool2000004X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo03H0oooo00310?ooo`800000B03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00l0oooo00<0o`000?ooo`3oool0=`3oool00<<0oooo0P0000160?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0h0?ooo`00a@3oool2000004@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo03T0
oooo00370?ooo`800000@P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo
00<0o`000?ooo`3oool0>P3oool00<T0oooo0P0000100?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0j0?ooo`00b`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0k
0?ooo`00c03oool2000003d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo03`0oooo003>0?ooo`800000>`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00`0oooo00<0o`000?ooo`3oool0?@3oool00=00oooo0P00000i0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0n0?ooo`00dP3o
ool2000003L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo03l0oooo003D0?ooo`800000=@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00/0oooo00<0o`000?ooo`3oool0?`3oool00=H0oooo0P00000c0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`100?ooo`00f03oool200000340
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0440
oooo003J0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030?l0003oool0oooo0480oooo003K0?ooo`800000;P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0@`3oool00=d0oooo0P00000/
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`13
0?ooo`00g`3oool2000002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030?l0003oool0oooo04@0oooo003Q0?ooo`800000:03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<0o`000?ooo`3oool0A@3oool00><0oooo0P00000V0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`160?ooo`00i@3o
ool2000002@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo04L0oooo003W0?ooo`8000008P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<0o`000?ooo`3oool0A`3oool00>T0oooo0P00000P0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`180?ooo`00j`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`190?ooo`00k03oool2000001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo04X0oooo003^0?ooo`8000006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0B`3oool00?00oooo0P00000I
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1<
0?ooo`00lP3oool2000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030?l0003oool0oooo04`0oooo003d0?ooo`8000005@3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<0o`000?ooo`3oool0C@3oool00?H0oooo0P00000C0?ooo`050000003oool0oooo0?oo
o`000000103oool00`3o0000oooo0?ooo`1>0?ooo`00n03oool200000140oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030?l0003oool0oooo04l0oooo003j0?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000000`3oool00`3o0000oooo0?ooo`1@0?ooo`00n`3oool2000000h0
oooo00@000000?ooo`3oool000000`3oool00`3o0000oooo0?ooo`1@0?ooo`00o@3oool2000000`0
oooo00<000000?ooo`0000000`3oool00`3o0000oooo0?ooo`1A0?ooo`00o`3oool2000000X0oooo
00<000000?ooo`0000000P3oool00`3o0000oooo0?ooo`1B0?ooo`00o`3oool20?ooo`800000203o
ool01@000000oooo0000003oool0o`0005D0oooo003o0?ooo`@0oooo0P0000060?ooo`80000000<0
oooo0?l0003oool0E@3oool00?l0oooo1P3oool2000000@0oooo0P0000000`3o0000oooo0?ooo`1E
0?ooo`00o`3oool80?ooo`8000000P3oool2000000030?l0003oool0oooo05D0oooo003o0?ooo`X0
oooo0`0000000`3o0000oooo0?ooo`1F0?ooo`00o`00000<000000030?l000000000000005H00000
0@3oool00?l0oooo303oool00`000000oooo0?ooo`1G0?ooo`00o`3oool<0?ooo`030000003oool0
oooo05L0oooo003o0?ooo``0oooo00<000000?ooo`3oool0E`3oool00001\
\>"],
  ImageRangeCache->{{{0, 356.375}, {163.938, 0}} -> {-0.970208, -0.580355, 
  0.00362643, 0.00362643}}],

Cell[BoxData[
    \(TraditionalForm\`"Try to match the red vector with a*v1+b*v2"\)], 
  "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Enter:  guess[a,b]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["guess[-.2,.8 ]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .43963 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.716959 0.739482 0.42916 0.739482 [
[ 0 0 0 0 ]
[ 1 .43963 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .42916 m
1 .42916 L
s
.71696 0 m
.71696 .43963 L
s
0 0 m
1 0 L
1 .43963 L
0 .43963 L
closepath
clip
newpath
.5 Mabswid
.71696 .42916 m
.02381 .06247 L
s
.02381 .06247 m
.10779 .07141 L
s
.02381 .06247 m
.07846 .12686 L
s
gsave
.37038 .24581 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.71696 .42916 m
.86771 .01047 L
s
.86771 .01047 m
.86938 .05837 L
s
.86771 .01047 m
.83589 .04631 L
s
gsave
.79233 .21981 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.71696 .42916 m
.93089 .16634 L
s
.93089 .16634 m
.92001 .20118 L
s
.93089 .16634 m
.89898 .18406 L
s
0 1 0 r
.71696 .42916 m
.97619 .16754 L
s
.97619 .16754 m
.96073 .20408 L
s
.97619 .16754 m
.9398 .18334 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 126.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000OR000`400?l00000o`00003oc@3oool0
0`000000oooo0?ooo`1@0?ooo`00c@3oool00`000000oooo0?ooo`1@0?ooo`00c@3oool00`000000
oooo0?ooo`1@0?ooo`00c@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02D0oooo
003=0?ooo`030000003oool0oooo02L0oooo0P00000W0?ooo`00c@3oool00`000000oooo0?ooo`0V
0?ooo`<000009`3oool00<d0oooo00<000000?ooo`3oool09@3oool010000000oooo00000000000W
0?ooo`00c@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo008000009`3oool00<d0
oooo00<000000?ooo`3oool08`3oool01P000000oooo0?ooo`000000oooo000002L0oooo003=0?oo
o`030000003oool0oooo02<0oooo00H000000?ooo`3oool000000?ooo`00000W0?ooo`00c@3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09@3o
ool00<d0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0903oool00<d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00<d0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool0
0<d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02@0oooo003=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0T0?ooo`00c@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0903oool00<d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02@0oooo00070?ooo`H00000`03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02X0oooo00080?ooo`8000000`3oool<00000;@0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0[0?ooo`002@3oool3000000d0oooo1`00002]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0:`3oool000X0oooo00@000000?ooo`000000
0000_`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02/0oooo000;0?ooo`030000
003oool0oooo00800000_@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02`0oooo
000;0?ooo`030000003oool0oooo0080oooo0P00002k0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0;03oool000`0oooo00<000000?ooo`3oool00`3oool200000;T0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`003@3oool00`000000oooo0?ooo`040?oo
o`800000]`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02d0oooo000>0?ooo`03
0000003oool0oooo00D0oooo0P00002e0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0;@3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool01P3o
ool200000;80oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0^0?ooo`004@3oool0
0`000000oooo0?ooo`070?ooo`800000/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo02h0oooo000B0?ooo`030000003oool0oooo00P0oooo0P00002^0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0;`3oool001<0oooo00<000000?ooo`3oool02@3oool200000:`0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`004`3oool00`000000oooo
0?ooo`0;0?ooo`800000ZP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02l0oooo
000D0?ooo`030000003oool0oooo00`0oooo0P00002X0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0<03oool001D0oooo00<000000?ooo`3oool03@3oool200000:H0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0`0?ooo`005P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0:<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0`0?oo
o`005`3oool00`000000oooo0?ooo`0>0?ooo`800000X`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0340oooo000Z0?ooo`800000X@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0340oooo000/0?ooo`800000W`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0380oooo000^0?ooo`800000W@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0380oooo000`0?ooo`800000V`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0380oooo000b0?ooo`800000V@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03<0
oooo000d0?ooo`800000U`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03<0oooo
000f0?ooo`800000U@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03<0oooo000h
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d
0?ooo`00>@3oool200000980oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool200000900oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d0?ooo`00
?@3oool2000008h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0O0?ooo`030?l0
003oool0oooo01<0oooo000o0?ooo`800000S03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01d0oooo0`3o000;0?ooo`800?l0203oool00440oooo0P00002:0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0703oool30?l000X0oooo1000o`080?ooo`00@`3oool20000
08P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0K0?ooo`80o`0000<0oooo0?l0
003o00001`3oool3003o00030?ooo`00o`000?l000T0oooo00150?ooo`800000QP3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00H0o`000?ooo`3oool0o`000?ooo`3o0005
0?ooo`800?l00`3oool00`00o`00oooo003o00090?ooo`00A`3oool2000008@0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0I0?ooo`80o`000P3oool00`3o0000oooo0?l000040?oo
o`800?l0103oool00`00o`00oooo003o000:0?ooo`00B@3oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo00<0o`000?ooo`3oool01`3oool01000o`00oooo0?ooo`00o`0:0?ooo`00BP3oool20000
0840oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`050?l0003oool0oooo
0?ooo`3o0000203oool01@00o`00oooo0?ooo`3oool00?l000X0oooo001<0?ooo`800000O`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l0
00070?ooo`05003o003oool0oooo0?ooo`00o`002`3oool004h0oooo0P00001m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo
00<00?l00?ooo`3oool00P3oool00`00o`00oooo0?ooo`090?ooo`00D03oool2000007/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00X0oooo001B
0?ooo`800000N@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<0o`00
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo001D0?oo
o`800000M`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01T0oooo00<0o`000?oo
o`3oool02@3oool00`00o`00oooo0?ooo`0A0?ooo`00EP3oool2000007D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3o
ool04P3oool005P0oooo0P00001c0?ooo`030000003oool0oooo00h0oooo0P0000020?ooo`<00000
6P3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo01<0oooo001J0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool03P3oool200000080oooo0P00000J0?ooo`030?l0003o
ool0oooo00P0oooo00<00?l00?ooo`3oool0503oool005/0oooo0P00001`0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool000000?ooo`02000001T0oooo00<0o`000?ooo`3oool0203o
ool00`00o`00oooo0?ooo`0E0?ooo`00G@3oool2000006h0oooo00<000000?ooo`3oool0303oool2
00000080oooo00@000000?ooo`0000000000603oool00`3o0000oooo0?ooo`080?ooo`03003o003o
ool0oooo01H0oooo001O0?ooo`800000K03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
000001L0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0G0?ooo`00H@3oool20000
06X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000G0?ooo`030?l0003oool0oooo
00L0oooo00<00?l00?ooo`3oool0603oool006<0oooo0P00001X0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo01T0
oooo001U0?ooo`<0000000<0oooo0000000000000`00001O0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo01X0oooo
001V0?ooo`<000000P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool05@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo01/0oooo001U
0?ooo`030000003oool0oooo0080000000<0oooo0000003oool0H03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0L
0?ooo`00I03oool200000080oooo00@000000?ooo`0000000000H@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0M
0?ooo`00J`3oool3000005l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool07P3oool006X0oooo0P0000020?ooo`80
0000G@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o
ool01P3oool00`00o`00oooo0?ooo`0O0?ooo`00L03oool2000005/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0
803oool00780oooo0P00001I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo0240oooo001d0?ooo`800000E`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0R0?ooo`00MP3oool2000005D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool08`3oool007P0
oooo0P00001C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`3o0000
oooo0?ooo`050?ooo`03003o003oool0oooo02@0oooo001j0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00D0oooo
00<00?l00?ooo`3oool09@3oool007/0oooo0P00001@0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo02H0oooo001m
0?ooo`800000CP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<0o`00
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0W0?ooo`00O`3oool2000004`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?oo
o`3oool0:03oool00840oooo0P00001:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo02T0oooo00230?ooo`800000
B03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0
103oool00`00o`00oooo0?ooo`0Z0?ooo`00Q@3oool2000004H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0:`3o
ool008L0oooo0P0000140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo02/0oooo00290?ooo`800000@P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0103oool00`00
o`00oooo0?ooo`0/0?ooo`00R`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo02d0
oooo002<0?ooo`800000?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0^0?ooo`00SP3oool2000003d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0
0?l00?ooo`3oool0;`3oool00900oooo0P00000k0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0300oooo002B0?oo
o`800000>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`0a0?ooo`00U03oool2000003L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0<P3oool009H0oooo0P00000e0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo03<0oooo002H0?ooo`800000<`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`0d0?ooo`00VP3oool200000340oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0=@3oool0
09`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0f0?ooo`00W@3oool2000002h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0080
oooo00<00?l00?ooo`3oool0=`3oool009l0oooo0P00000/0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo03P0oooo
002Q0?ooo`800000:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0i0?ooo`00X`3oool2000002P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`00o`00?03o
ool00:D0oooo0P00000V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
1@3o0000oooo0?ooo`3oool00?l003d0oooo002W0?ooo`800000903oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo003o000n0?ooo`00Z@3oool2
00000280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`050?l0003oool0
oooo0?ooo`00o`00?`3oool00:/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo003o00100?ooo`00[03oool2
000001l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040?l0003oool0
oooo003o0440oooo002^0?ooo`8000007@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00@0o`000?ooo`3oool00?l0@P3oool00;00oooo0P00000K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`00o`130?ooo`00/P3oool2
000001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040?l0003oool0
oooo003o04@0oooo002d0?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@0o`000?ooo`3oool00?l0A@3oool00;H0oooo0P00000E0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`3o0000oooo003o00160?ooo`00^03oool2000001<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030?l0003oool00?l004L0oooo002j0?ooo`8000004@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<0o`000?ooo`00o`00B03oool00;`0oooo00<00000
0?ooo`3oool03P3oool010000000oooo0?ooo`0000030?ooo`030?l0003oool00?l004T0oooo002m
0?ooo`8000003P3oool010000000oooo0?ooo`0000020?ooo`030?l0003oool00?l004X0oooo002o
0?ooo`800000303oool010000000oooo0?ooo`0000020?ooo`030?l00000o`00oooo04X0oooo0031
0?ooo`8000002P3oool00`000000oooo000000020?ooo`030?l00000o`00oooo04/0oooo00330?oo
o`800000203oool01P000000oooo0000003oool0o`00003o04d0oooo00350?ooo`8000001P3oool2
000000030?ooo`3o00000?l004h0oooo00370?ooo`800000103oool2000000030?l00000o`00oooo
04h0oooo00390?ooo`8000000P3oool200000003003o003oool0oooo04h0oooo003;0?ooo`<00000
00<00?l00?ooo`3oool0C`3oool00<d0000000<00?l0000000000000C`0000010?ooo`00c@3oool0
0`000000oooo0?ooo`1@0?ooo`00c@3oool00`000000oooo0?ooo`1@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {125.563, 0}} -> {-0.972834, -0.580352, 
  0.00473478, 0.00473478}}],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        \("You are off by:  "\[InvisibleSpace]0.0612849966612589636`\),
        SequenceForm[ "You are off by:  ", .061284996661258959],
        Editable->False], TraditionalForm]], "Print"]
}, Open  ]],

Cell[TextData[{
  "Type ",
  StyleBox["guess[?,?]",
    FontFamily->"Courier New"],
  " again and try to get closer.  After you are done with this first game, \
type ",
  StyleBox["cogame",
    FontFamily->"Courier New"],
  " again to create another game."
}], "Text"]
}, Open  ]],

Cell["\<\
Answer question (a):  How could the vectors v1 and v2 make the game \
impossible to win?\
\>", "Subsubsection"],

Cell["Answer questions (c) and (d):", "Subsubsection"],

Cell[CellGroupData[{

Cell["Solution of (b):  cogame answer function -- optional", "Subsubsection"],

Cell[CellGroupData[{

Cell["cogame", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03916 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.739612 1.1326 0.244838 1.1326 [
[ 0 0 0 0 ]
[ 1 1.03916 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .24484 m
1 .24484 L
s
.73961 0 m
.73961 1.03916 L
s
0 0 m
1 0 L
1 1.03916 L
0 1.03916 L
closepath
clip
newpath
.5 Mabswid
.73961 .24484 m
.8458 .02474 L
s
.8458 .02474 m
.84398 .051 L
s
.8458 .02474 m
.82638 .0425 L
s
gsave
.79271 .13479 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.73961 .24484 m
.97619 .72025 L
s
.97619 .72025 m
.93352 .68217 L
s
.97619 .72025 m
.97155 .66325 L
s
gsave
.8579 .48254 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.73961 .24484 m
.02381 1.01442 L
s
.02381 1.01442 m
.06461 .90883 L
s
.02381 1.01442 m
.12617 .96609 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.688, 268.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400042000132000`400?l00000o`00003o_P3oool0
0`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000
oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?oo
o`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo02H0oooo002n0?ooo`030000003oool0oooo01L0oooo0P00000X0?ooo`00
_P3oool00`000000oooo0?ooo`0F0?ooo`<00000:03oool00;h0oooo00<000000?ooo`3oool05@3o
ool010000000oooo00000000000X0?ooo`00_P3oool00`000000oooo0?ooo`0D0?ooo`050000003o
ool000000?ooo`000000:03oool00;h0oooo00<000000?ooo`3oool04`3oool01P000000oooo0?oo
o`000000oooo000002P0oooo002n0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0
0000:03oool00;h0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000X0?ooo`00
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo002n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00;h0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0[0?ooo`00_P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02/0oooo002n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;03oool00;h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02d0oooo002n0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0;@3oool00;h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?oo
o`00_P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo002n0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool00;h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0_0?ooo`00_P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02l0oooo002n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool00;h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`00_P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0340oooo002n0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0<@3oool00;h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b
0?ooo`00_P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo002n0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00;h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0c0?ooo`00_P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080000000<0oooo0000000000000`00000/0?ooo`00_P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000;P3o
ool00;h0oooo00<000000?ooo`3oool02@3oool010000000oooo0000000000020?ooo`040000003o
ool0oooo000002h0oooo002n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo0P00000^0?ooo`00_P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
03L0oooo002n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00;h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`00_P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03P0oooo002n0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0>03oool00;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?oo
o`00_P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo002n0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0>P3oool00;h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0j0?ooo`00_P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03/0oooo002n0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool00;h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`00_P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03`0oooo002n0?ooo`050000003oool0oooo0?ooo`000000
?`3oool00;h0oooo00D000000?ooo`3oool0oooo0000000o0?ooo`00_P3oool010000000oooo0?oo
o`0000100?ooo`00_P3oool010000000oooo0?ooo`0000100?ooo`00_P3oool00`000000oooo0000
00110?ooo`00_P3oool00`000000oooo000000110?ooo`00_P3oool200000480oooo002n0?ooo`80
0000@P3oool00;h0oooo00<000000?ooo`3oool0@@3oool00;h0000000<0o`00000000000000@@00
00000;d0oooo00<0o`000000003oool0@P3oool00;`0oooo00@0o`000?ooo`0000000000@P3oool0
0;/0oooo00<0o`000?ooo`3oool00P0000120?ooo`00^P3oool01`3o0000oooo0?ooo`3oool00000
0?ooo`000000@@3oool00;T0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo000000110?oo
o`00^03oool00`3o0000oooo0?ooo`030?ooo`040000003oool0oooo00000400oooo002g0?ooo`03
0?l0003oool0oooo00@0oooo00@000000?ooo`3oool00000@03oool00;L0oooo00<0o`000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000003l0oooo002f0?ooo`030?l0003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo0000000o0?ooo`00]@3oool00`3o0000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00;@0oooo00<0o`000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03`0oooo002c0?ooo`030?l0003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`00/P3oool0
0`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool0
0;40oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03X0oooo002`0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`00[`3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0>@3oool00:h0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03T0oooo002]0?ooo`030?l0003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`00[03oool00`3o0000oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>03oool00:/0oooo00<0o`000?ooo`3o
ool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03L0oooo002Z0?ooo`030?l0
003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`00ZP3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3o
ool00:T0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo03H0oooo002X0?ooo`030?l0003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0e0?ooo`00Y`3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0=@3oool00:H0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo03@0oooo002U0?ooo`030?l0003oool0oooo01H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`00Y03oool00`3o0000oooo0?ooo`0G
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00:<0oooo00<0o`000?oo
o`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo002R0?ooo`03
0?l0003oool0oooo01T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`00
X@3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<P3oool00:00oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0340oooo002O0?ooo`030?l0003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0a0?ooo`00WP3oool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool009d0oooo00<0o`000?ooo`3oool07P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo002M0?ooo`030?l0003oool0oooo01h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0_0?ooo`00W03oool00`3o0000oooo0?oo
o`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool009/0oooo00<0o`00
0?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo002J0?oo
o`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?oo
o`00V@3oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;@3oool009P0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo02d0oooo002G0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0/0?ooo`00UP3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0;03oool009D0oooo00<0o`000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02/0oooo002D0?ooo`030?l0003oool0oooo02L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`00T`3oool00`3o0000oooo
0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00980oooo00<0
o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo002A
0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y
0?ooo`00T03oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0:@3oool00900oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02P0oooo002?0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0X0?ooo`00SP3oool00`3o0000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool09`3oool008d0oooo00<0o`000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02L0oooo002<0?ooo`030?l0003oool0oooo
02l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`00R`3oool00`3o0000
oooo0?ooo`0`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool008X0oooo
00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0oooo
00290?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0U0?ooo`00R03oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0903oool008L0oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02@0oooo00260?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0S0?ooo`00Q@3oool00`3o0000oooo0?ooo`0f0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool08`3oool008@0oooo00<0o`000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0L0?ooo`040000003oool0000000000080oooo0`00000L0?ooo`00P`3o
ool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`0000000000
0P3oool00`000000oooo0?ooo`0L0?ooo`00P`3oool00`3o0000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`00PP3o
ool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo0P0000020?ooo`040000003o
ool0oooo000001d0oooo00210?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool07P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000703oool00800oooo00<0o`000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool007l0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01l0oooo001n0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0O0?ooo`00O@3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07P3oool007`0oooo00<0o`000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo001k0?ooo`030?l0003oool0oooo0400oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`00NP3oool00`3o0000oooo0?oo
o`110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool007T0oooo00<0o`00
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo001h0?oo
o`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?oo
o`00M`3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool06`3oool007H0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01/0oooo001f0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0J0?ooo`00M@3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool06P3oool007@0oooo00<0o`000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo001c0?ooo`030?l0003oool0oooo04P0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0I0?ooo`00LP3oool00`3o0000oooo
0?ooo`190?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0603oool00740oooo00<0
o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo001`
0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G
0?ooo`00K`3oool00`3o0000oooo0?ooo`1<0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool05`3oool006h0oooo00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01H0oooo001]0?ooo`030?l0003oool0oooo04h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0F0?ooo`00K03oool00`3o0000oooo0?ooo`1?0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05@3oool006/0oooo00<0o`000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030?l0003oool0oooo
0540oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0D0?ooo`00J@3oool00`3o0000
oooo0?ooo`1B0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0503oool006T0oooo
00<0o`000?ooo`3oool0DP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo
001X0?ooo`030?l0003oool0oooo05<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0C0?ooo`00I`3oool00`3o0000oooo0?ooo`1D0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool04P3oool006H0oooo00<0o`000?ooo`3oool0E@3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0180oooo001U0?ooo`030?l0003oool0oooo05H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0A0?ooo`00I03oool00`3o0000oooo0?ooo`1G0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool006<0oooo00<0o`000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo001R0?ooo`030?l0003oool0
oooo05T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`00H@3oool00`3o
0000oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03`3oool00600
oooo00<0o`000?ooo`3oool0F`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00l0
oooo001O0?ooo`030?l0003oool0oooo05`0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0>0?ooo`00GP3oool00`3o0000oooo0?ooo`1M0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool03P3oool005d0oooo00<0o`000?ooo`3oool0GP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00d0oooo001L0?ooo`030?l0003oool0oooo05l0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`00F`3oool00`3o0000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0303oool005/0oooo00<0o`000?ooo`3oool0
H03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo001J0?ooo`030?l0003o
ool0oooo0640oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo001I0?ooo`030?l0003oool0oooo0680oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo001H0?ooo`030?l0003oool0oooo
06<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo001G0?ooo`030?l0003oool0oooo06@0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo001F0?ooo`030?l0003oool0oooo06D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001`3oool005D0oooo00<0o`000?ooo`3oool0IP3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00E03oool00`3o0000oooo
0?ooo`1W0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000070?ooo`00D`3oool00`3o0000oooo0?ooo`1X0?ooo`030000003oool0oooo0380oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo001B0?ooo`030?l0
003oool0oooo06T0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00540oooo00<0o`000?ooo`3oool0JP3oool00`000000oooo
0?ooo`0d0?ooo`80000000D0oooo0000003oool0oooo000000060?ooo`00D03oool00`3o0000oooo
0?ooo`1[0?ooo`030000003oool0oooo03H0oooo00D000000?ooo`000000oooo000000060?ooo`00
C`3oool00`3o0000oooo0?ooo`1/0?ooo`030000003oool0oooo03L0oooo0P0000000`3oool00000
0?ooo`050?ooo`00CP3oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo03P0oooo0`00
00060?ooo`00CP3oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo03T0oooo0P000006
0?ooo`00C@3oool00`3o0000oooo0?ooo`1^0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0103oool004`0oooo00<0o`000?ooo`3oool0K`3oool00`000000oooo0?ooo`110?ooo`00
B`3oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0440oooo001:0?ooo`030?l0003o
ool0oooo0740oooo00<000000?ooo`3oool0@@3oool004T0oooo00<0o`000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`110?ooo`00B03oool00`3o0000oooo0?ooo`1c0?ooo`030000003oool0oooo
0440oooo00170?ooo`030?l0003oool0oooo07@0oooo00<000000?ooo`3oool0@@3oool004H0oooo
00<0o`000?ooo`3oool0M@3oool00`000000oooo0?ooo`110?ooo`00A@3oool00`3o0000oooo0?oo
o`1f0?ooo`030000003oool0oooo0440oooo00140?ooo`030?l0003oool0oooo07L0oooo00<00000
0?ooo`3oool0@@3oool004<0oooo00<0o`000?ooo`3oool0N03oool00`000000oooo0?ooo`110?oo
o`00@P3oool00`3o0000oooo0?ooo`1i0?ooo`030000003oool0oooo0440oooo00110?ooo`030?l0
003oool0oooo07X0oooo00<000000?ooo`3oool0@@3oool00440oooo00<0o`000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`110?ooo`00@03oool00`3o0000oooo0?ooo`1k0?ooo`030000003oool0
oooo0440oooo000o0?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3oool0@@3oool003h0
oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?ooo`110?ooo`00?@3oool00`3o0000oooo
0?ooo`1n0?ooo`030000003oool0oooo0440oooo000l0?ooo`030?l0003oool0oooo07l0oooo00<0
00000?ooo`3oool0@@3oool003/0oooo00<0o`000?ooo`3oool0P03oool00`000000oooo0?ooo`11
0?ooo`00>P3oool00`3o0000oooo0?ooo`210?ooo`030000003oool0oooo0440oooo000i0?ooo`03
0?l0003oool0oooo0880oooo00<000000?ooo`3oool0@@3oool003P0oooo00<0o`000?ooo`3oool0
P`3oool00`000000oooo0?ooo`110?ooo`00=`3oool00`3o0000oooo0?ooo`240?ooo`030000003o
ool0oooo0440oooo000f0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool0
03D0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`110?ooo`00=03oool00`3o0000
oooo0?ooo`270?ooo`030000003oool0oooo0440oooo000d0?ooo`030?l0003oool0oooo08L0oooo
00<000000?ooo`3oool0@@3oool003<0oooo00<0o`000?ooo`3oool0R03oool00`000000oooo0?oo
o`110?ooo`00<P3oool00`3o0000oooo0?ooo`290?ooo`030000003oool0oooo0440oooo000a0?oo
o`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0@@3oool00300oooo00<0o`000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`110?ooo`00;`3oool00`3o0000oooo0?ooo`2<0?ooo`030000
003oool0oooo0440oooo000^0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool0@@3o
ool002d0oooo00<0o`000?ooo`3oool0SP3oool00`000000oooo0?ooo`110?ooo`00;03oool00`3o
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0440oooo000[0?ooo`030?l0003oool0oooo0900
oooo00<000000?ooo`3oool0@@3oool002X0oooo00<0o`000?ooo`3oool0T@3oool00`000000oooo
0?ooo`110?ooo`00:@3oool00`3o0000oooo0?ooo`2B0?ooo`030000003oool0oooo0440oooo000X
0?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0@@3oool002L0oooo00<0o`000?oo
o`3oool0U03oool00`000000oooo0?ooo`110?ooo`009`3oool00`3o0000oooo0?ooo`2D0?ooo`03
0000003oool0oooo0440oooo000V0?ooo`030?l0003oool0oooo09D0oooo00<000000?ooo`3oool0
@@3oool002D0oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`110?ooo`00903oool0
0`3o0000oooo0?ooo`2G0?ooo`030000003oool0oooo0440oooo000S0?ooo`030?l0003oool0oooo
09P0oooo00<000000?ooo`3oool0@@3oool00280oooo00<0o`000?ooo`3oool0V@3oool00`000000
oooo0?ooo`110?ooo`008@3oool00`3o0000oooo0?ooo`2J0?ooo`030000003oool0oooo0440oooo
000P0?ooo`030?l0003oool0oooo09/0oooo00<000000?ooo`3oool0@@3oool00100oooo00<0o`00
0?ooo`3oool0303oool00`3o0000oooo0?ooo`2L0?ooo`030000003oool0oooo0440oooo000@0?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0W@3oool00`000000oooo0?ooo`110?oo
o`003`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo09h0oooo00<000000?ooo`3o
ool0@@3oool000l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`2O0?ooo`030000
003oool0oooo0440oooo000?0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0X03o
ool00`000000oooo0?ooo`110?ooo`003P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo0:40oooo00<000000?ooo`3oool0@@3oool000h0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`2Q0?ooo`030000003oool0oooo0440oooo000=0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool0XP3oool00`000000oooo0?ooo`110?ooo`003@3oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo0:<0oooo00<000000?ooo`3oool0@@3oool000d0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`2T0?ooo`030000003oool0oooo0440oooo000<
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0Y@3oool00`000000oooo0?ooo`11
0?ooo`00303oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0:H0oooo00<000000?oo
o`3oool0@@3oool000`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2W0?ooo`03
0000003oool0oooo0440oooo000;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
Z03oool00`000000oooo0?ooo`110?ooo`002`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo0:T0oooo00<000000?ooo`3oool0@@3oool000X0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0;0?ooo`80o`00W@3oool00`000000oooo0?ooo`110?ooo`002P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo0P3o002O0?ooo`030000003oool0oooo
0440oooo000:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool20?l00:40
oooo00<000000?ooo`3oool0@@3oool000T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`080?ooo`80o`00X`3oool00`000000oooo0?ooo`110?ooo`002@3oool01@3o0000oooo0?oo
o`3oool0o`0000T0oooo0P3o002U0?ooo`030000003oool0oooo0440oooo00090?ooo`050?l0003o
ool0oooo0?ooo`3o00001`3oool20?l00:L0oooo00<000000?ooo`3oool0@@3oool000P0oooo00D0
o`000?ooo`3oool0oooo0?l000050?ooo`<0o`00Z@3oool00`000000oooo0?ooo`110?ooo`00203o
ool0103o0000oooo0?ooo`3o00040?ooo`80o`00[03oool00`000000oooo0?ooo`110?ooo`001`3o
ool0103o0000oooo0?ooo`3o00030?ooo`80o`00[P3oool00`000000oooo0?ooo`110?ooo`001`3o
ool00`3o0000oooo0?l000020?ooo`80o`00/03oool00`000000oooo0?ooo`110?ooo`001`3oool2
0?l000030?ooo`3o0000o`000;80oooo00<000000?ooo`3oool0@@3oool000H0oooo103o002d0?oo
o`030000003oool0oooo0440oooo00060?ooo`80o`00]P3oool00`000000oooo0?ooo`110?ooo`00
_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool0
0`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000
oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00\
\>"],
  ImageRangeCache->{{{0, 257.688}, {267.813, 0}} -> {-0.653026, -0.216236, 
  0.00342637, 0.00342637}}],

Cell[BoxData[
    \(TraditionalForm\`"Try to match the red vector with a*v1+b*v2"\)], 
  "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Enter:  guess[a,b]"\)], "Print"]
}, Open  ]],

Cell["\<\
Here are the vectors (listed as rows!) and target that cogame created.\
\>", "Text"],

Cell[CellGroupData[{

Cell["{v1,v2}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.0937542212002846397`", \(-0.194327906344221705`\)},
            {"0.208880906195271887`", "0.419755252198664763`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["target", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-0.631999671713426103`\), 0.679482184152907464`}\)],
   "Output"]
}, Open  ]],

Cell["\<\
Use LinearSolve to solve for target as a linear combination of v1 and v2.  
Hint: matrix multiplication is a linear combination of columns.
target \"should\" be a 2x1 matrix but remember that you can use {t1, t2} as a \
vector that Mma will use as a column vector {{t1},{t2}} ( or row vector {{t1, \
t2}} ) whenever the context calls for it.\
\>", "Text"],

Cell[CellGroupData[{

Cell["LinearSolve[Transpose[{v1,v2}],target]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-5.09368861121545002`\), \(-0.739391961406848885`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Check the answer you got by typing the answer into guess but use only one \
decimal place.\
\>", "Text"],

Cell[CellGroupData[{

Cell["guess[-5.1,-.7]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06028 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.739612 1.1326 0.245341 1.1326 [
[ 0 0 0 0 ]
[ 1 1.06028 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .24534 m
1 .24534 L
s
.73961 0 m
.73961 1.06028 L
s
0 0 m
1 0 L
1 1.06028 L
0 1.06028 L
closepath
clip
newpath
.5 Mabswid
.73961 .24534 m
.8458 .02524 L
s
.8458 .02524 m
.84398 .0515 L
s
.8458 .02524 m
.82638 .04301 L
s
gsave
.79271 .13529 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.73961 .24534 m
.97619 .72076 L
s
.97619 .72076 m
.93352 .68268 L
s
.97619 .72076 m
.97155 .66375 L
s
gsave
.8579 .48305 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.73961 .24534 m
.02381 1.01492 L
s
.02381 1.01492 m
.06461 .90933 L
s
.02381 1.01492 m
.12617 .9666 L
s
0 1 0 r
.73961 .24534 m
.03246 1.03504 L
s
.03246 1.03504 m
.07159 .92778 L
s
.03246 1.03504 m
.13476 .98435 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{252.938, 268.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003l000132000`400?l00000o`00003o^P3oool0
0`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000
oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?oo
o`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?oo
o`00^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo002j0?ooo`030000
003oool0oooo01L0oooo0P00000V0?ooo`00^P3oool00`000000oooo0?ooo`0E0?ooo`@000009P3o
ool00;X0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000W0?ooo`00^P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo008000009`3oool00;X0oooo00<000000?oo
o`3oool05P3oool2000002L0oooo002j0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`00
00009`3oool00;X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0W0?ooo`00^P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo002j0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0:03oool00;X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0Y0?ooo`00^P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0
oooo002j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:P3oool00;X0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0Z0?ooo`00^P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02/0oooo002j0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0:`3oool00;X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`00
^P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo002j0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00;X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0]0?ooo`00^P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02h0oooo002j0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool00;X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0_0?ooo`00^P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02l0oooo002j0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0<03oool00;X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0`0?oo
o`00^P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0340oooo002j0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0<@3oool00;X0oooo00<000000?ooo`3oool02P3o
ool01@000000oooo000000000000oooo00D00000:`3oool00;X0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0000000000030?ooo`030000003oool0oooo02/0oooo002j0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000]0?ooo`00^P3o
ool00`000000oooo0?ooo`090?ooo`<000000P3oool010000000oooo0?ooo`00000]0?ooo`00^P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3o
ool00;X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`800000;@3oool0
0;X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`00^P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo002j0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0=P3oool00;X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0f0?ooo`00^P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo002j0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool00;X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0h0?ooo`00^P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03P0oooo002j0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3o
ool00;X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0i0?ooo`00^P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo002j0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>P3oool00;X0oooo00D000000?ooo`3oool0oooo0000000m0?ooo`00
^P3oool01@000000oooo0?ooo`3oool0000003d0oooo002j0?ooo`040000003oool0oooo000003h0
oooo002j0?ooo`040000003oool0oooo000003h0oooo002j0?ooo`030000003oool0000003l0oooo
002j0?ooo`030000003oool0000003l0oooo002j0?ooo`800000@03oool00;X0oooo0P0000100?oo
o`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P0000000`00o`0000000000000o00000000^@3o
ool00`00o`0000000?ooo`100?ooo`00^03oool01000o`00oooo0000000000100?ooo`00]`3oool0
0`00o`00oooo0?ooo`0200000400oooo002f0?ooo`07003o003oool0oooo0?ooo`000000oooo0000
000o0?ooo`00]@3oool00`3o00000?l00?ooo`020?ooo`030000003oool0000003l0oooo002d0?oo
o`030?l00000o`00oooo00<0oooo00@000000?ooo`3oool00000?P3oool00;@0oooo00<00?l00?oo
o`3oool00`3oool010000000oooo0?ooo`00000n0?ooo`00/`3oool00`00o`00oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`000000?@3oool00;80oooo00<00?l00?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000003d0oooo002a0?ooo`03003o003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`00/03oool00`00o`00oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00:l0oooo00<00?l00?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo002^0?ooo`03003o003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0i0?ooo`00[@3oool0
0`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03oool0
0:`0oooo00<0o`00003o003oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03P0oooo002[0?ooo`030?l00000o`00oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0g0?ooo`00ZP3oool00`3o00000?l00?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0=`3oool00:T0oooo00<0o`00003o003oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03H0oooo002X0?ooo`030?l00000o`00oooo00l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0f0?ooo`00Y`3oool00`3o00000?l00?ooo`0@0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3oool00:L0oooo00<00?l00?ooo`3o
ool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo002V0?ooo`03003o
003oool0oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`00Y@3o
ool00`00o`00oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=03o
ool00:@0oooo00<0o`00003o003oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03<0oooo002S0?ooo`030?l00000o`00oooo01@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0c0?ooo`00XP3oool00`3o00000?l00?ooo`0E0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0<P3oool00:40oooo00<0o`00003o003oool05P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0380oooo002P0?ooo`030?l00000o`00oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0a0?ooo`00W`3oool00`3o00000?l00?ooo`0H
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<@3oool009h0oooo00<0o`00003o
003oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0300oooo002M0?ooo`03
0?l00000o`00oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0`0?ooo`00
W03oool00`3o00000?l00?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
;`3oool009/0oooo00<0o`00003o003oool0703oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02l0oooo002J0?ooo`030?l0003oool00?l001d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0^0?ooo`00VP3oool00`3o00000?l00?ooo`0M0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0;P3oool009T0oooo00<0o`00003o003oool07P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo02d0oooo002H0?ooo`030?l00000o`00oooo01l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]0?ooo`00U`3oool00`3o00000?l00?oo
o`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;03oool009H0oooo00<0o`00
003o003oool08@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo002E0?oo
o`030?l00000o`00oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?oo
o`00U03oool00`3o00000?l00?ooo`0S0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:`3oool009<0oooo00<0o`00003o003oool0903oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo02X0oooo002B0?ooo`030?l0003oool00?l002D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0Z0?ooo`00T@3oool00`3o0000oooo003o000V0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0:@3oool00900oooo00<0o`000?ooo`00o`009`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo002?0?ooo`030?l0003oool00?l002P0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`00SP3oool00`3o0000oooo
003o000Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:03oool008d0oooo00<0
o`000?ooo`00o`00:P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02L0oooo002=
0?ooo`030?l00000o`00oooo02X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0W
0?ooo`00S03oool00`3o00000?l00?ooo`0[0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool09P3oool008/0oooo00<0o`00003o003oool0;03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02H0oooo002:0?ooo`030?l00000o`00oooo02d0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0U0?ooo`00R@3oool00`3o0000oooo003o000^0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool09@3oool008P0oooo00<0o`000?ooo`00o`00;`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00270?ooo`030?l0003oool00?l0
0300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?ooo`00QP3oool00`3o0000
oooo003o000a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08`3oool008D0oooo
00<0o`000?ooo`00o`00<P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo
00240?ooo`030?l0003oool00?l003<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0R0?ooo`00P`3oool00`3o0000oooo003o000d0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool08P3oool00880oooo00<0o`000?ooo`00o`00=@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0280oooo00210?ooo`030?l0003oool00?l003H0oooo00<000000?ooo`3o
ool06`3oool010000000oooo0000000000020?ooo`<000006`3oool00800oooo00@0o`000?ooo`3o
ool00?l0=P3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0000000000080oooo00<00000
0?ooo`3oool06`3oool00800oooo00<0o`000?ooo`00o`00=`3oool00`000000oooo0?ooo`0L0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool06P3oool007l0oooo00<0o`000?oo
o`00o`00>03oool00`000000oooo0?ooo`0K0?ooo`8000000P3oool010000000oooo0?ooo`00000L
0?ooo`00OP3oool00`3o0000oooo003o000i0?ooo`030000003oool0oooo01d0oooo00L000000?oo
o`3oool0oooo0000003oool0000001/0oooo001m0?ooo`030?l0003oool00?l003X0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo001l0?oo
o`030?l0003oool00?l003/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?oo
o`00N`3oool00`3o0000oooo003o000l0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool07P3oool007X0oooo00<0o`000?ooo`00o`00?@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01d0oooo001i0?ooo`030?l0003oool00?l003h0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0M0?ooo`00N03oool00`3o0000oooo003o000o0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0703oool007L0oooo00@0o`000?ooo`3oool00?l0?`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01`0oooo001f0?ooo`040?l0003oool0oooo
003o0400oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`00M@3oool0103o
0000oooo0?ooo`00o`110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool0
07@0oooo00@0o`000?ooo`3oool00?l0@P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01X0oooo001c0?ooo`040?l0003oool0oooo003o04<0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0J0?ooo`00L`3oool00`3o0000oooo003o00140?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool06@3oool00780oooo00<0o`000?ooo`00o`00A@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo001a0?ooo`030?l0003oool00?l004H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0H0?ooo`00L03oool00`3o0000oooo003o
00170?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool006l0oooo00@0o`00
0?ooo`3oool00?l0A`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo001^
0?ooo`040?l0003oool0oooo003o04P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0G0?ooo`00K@3oool0103o0000oooo0?ooo`00o`190?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool05P3oool006`0oooo00@0o`000?ooo`3oool00?l0BP3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo01H0oooo001[0?ooo`040?l0003oool0oooo003o04/0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool0103o0000oooo0?ooo`00
o`1<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05@3oool006T0oooo00@0o`00
0?ooo`3oool00?l0C@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo001X
0?ooo`040?l0003oool0oooo003o04h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0D0?ooo`00I`3oool0103o0000oooo0?ooo`00o`1?0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool04`3oool006H0oooo00@0o`000?ooo`3oool00?l0D03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01<0oooo001V0?ooo`040?l0003oool0oooo003o0500oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`00I@3oool0103o0000oooo0?ooo`00
o`1A0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool006@0oooo00@0o`00
0?ooo`3oool00?l0DP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo001S
0?ooo`040?l0003oool0oooo003o05<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0A0?ooo`00HP3oool0103o0000oooo0?ooo`00o`1D0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0403oool00640oooo00@0o`000?ooo`3oool00?l0E@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0100oooo001P0?ooo`040?l0003oool0oooo003o05H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0?0?ooo`00G`3oool0103o0000oooo0?ooo`00
o`1G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool005h0oooo00@0o`00
0?ooo`3oool00?l0F03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo001M
0?ooo`050?l0003oool0oooo0?ooo`00o`00F03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00h0oooo001L0?ooo`050?l0003oool0oooo0?ooo`00o`00F@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00d0oooo001K0?ooo`050?l0003oool0oooo0?ooo`00o`00FP3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00d0oooo001J0?ooo`050?l0003oool0
oooo0?ooo`00o`00F`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo001J
0?ooo`040?l0003oool0oooo003o05`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0<0?ooo`00F@3oool0103o0000oooo0?ooo`00o`1M0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02`3oool005P0oooo00@0o`000?ooo`3oool00?l0GP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool005L0oooo00@0o`00
0?ooo`3oool00?l0G`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool005H0oooo00@0o`000?ooo`3oool00?l0H03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool005D0oooo00D0o`00
0?ooo`3oool0oooo003o001P0?ooo`030000003oool0oooo03<0oooo00D000000?ooo`3oool0oooo
000000070?ooo`00E03oool01@3o0000oooo0?ooo`3oool00?l00640oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool005<0oooo
00D0o`000?ooo`3oool0oooo003o001R0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`00DP3oool01@3o0000oooo0?ooo`3oool00?l0
06<0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01@3oool00540oooo00D0o`000?ooo`3oool0oooo003o001T0?ooo`030000003oool0
oooo0340oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo001@0?ooo`050?l0003o
ool0oooo0?ooo`00o`00I@3oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool004l0oooo00D0o`000?ooo`3oool0oooo003o001V0?ooo`03
0000003oool0oooo03<0oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`00CP3oool01@3o
0000oooo0?ooo`3oool00?l006L0oooo00<000000?ooo`3oool0=03oool01@000000oooo0000003o
ool0000000H0oooo001=0?ooo`050?l0003oool0oooo0?ooo`00o`00J03oool00`000000oooo0?oo
o`0e0?ooo`040000003oool00000000000H0oooo001=0?ooo`040?l0003oool0oooo003o06T0oooo
00<000000?ooo`3oool0=P3oool3000000H0oooo001<0?ooo`050?l0003oool0oooo0?ooo`00o`00
J@3oool00`000000oooo0?ooo`0g0?ooo`8000001P3oool004/0oooo00D0o`000?ooo`3oool0oooo
003o001Z0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103oool004X0oooo00D0
o`000?ooo`3oool0oooo003o001[0?ooo`030000003oool0oooo03l0oooo00190?ooo`050?l0003o
ool0oooo0?ooo`00o`00K03oool00`000000oooo0?ooo`0o0?ooo`00B03oool01@3o0000oooo0?oo
o`3oool00?l006d0oooo00<000000?ooo`3oool0?`3oool004L0oooo00D0o`000?ooo`3oool0oooo
003o001^0?ooo`030000003oool0oooo03l0oooo00160?ooo`050?l0003oool0oooo0?ooo`00o`00
K`3oool00`000000oooo0?ooo`0o0?ooo`00A@3oool01@3o0000oooo0?ooo`3oool00?l00700oooo
00<000000?ooo`3oool0?`3oool004@0oooo00D0o`000?ooo`3oool0oooo003o001a0?ooo`030000
003oool0oooo03l0oooo00130?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0K`3o
ool00`000000oooo0?ooo`0o0?ooo`00@P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0
oooo0700oooo00<000000?ooo`3oool0?`3oool00440oooo00<0o`000?ooo`3oool00P3oool00`00
o`00oooo0?ooo`1a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030?l0003oool0oooo0080
oooo00<00?l00?ooo`3oool0LP3oool00`000000oooo0?ooo`0o0?ooo`00@03oool01@3o0000oooo
0?ooo`3oool00?l007D0oooo00<000000?ooo`3oool0?`3oool003l0oooo00D0o`000?ooo`3oool0
oooo003o001f0?ooo`030000003oool0oooo03l0oooo000n0?ooo`050?l0003oool0oooo0?ooo`00
o`00M`3oool00`000000oooo0?ooo`0o0?ooo`00?@3oool01@3o0000oooo0?ooo`3oool00?l007P0
oooo00<000000?ooo`3oool0?`3oool003`0oooo00D0o`000?ooo`3oool0oooo003o001i0?ooo`03
0000003oool0oooo03l0oooo000k0?ooo`050?l0003oool0oooo0?ooo`00o`00NP3oool00`000000
oooo0?ooo`0o0?ooo`00>P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo07P0oooo
00<000000?ooo`3oool0?`3oool003T0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?oo
o`1i0?ooo`030000003oool0oooo03l0oooo000h0?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0o0?ooo`00=`3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo07/0oooo00<000000?ooo`3oool0?`3oool003H0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`1l0?ooo`030000003oool0oooo03l0oooo000e0?ooo`030?l0
003oool0oooo0080oooo00<00?l00?ooo`3oool0O@3oool00`000000oooo0?ooo`0o0?ooo`00=03o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo07h0oooo00<000000?ooo`3oool0?`3o
ool003<0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`1o0?ooo`030000003oool0
oooo03l0oooo000c0?ooo`050?l0003oool0oooo0?ooo`00o`00PP3oool00`000000oooo0?ooo`0o
0?ooo`00<P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0800oooo00<000000?oo
o`3oool0?`3oool00340oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`210?ooo`03
0000003oool0oooo03l0oooo000`0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0
PP3oool00`000000oooo0?ooo`0o0?ooo`00;`3oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo08<0oooo00<000000?ooo`3oool0?`3oool002h0oooo00<0o`000?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`240?ooo`030000003oool0oooo03l0oooo000]0?ooo`030?l0003oool0oooo
0080oooo00<00?l00?ooo`3oool0Q@3oool00`000000oooo0?ooo`0o0?ooo`00;03oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo08H0oooo00<000000?ooo`3oool0?`3oool002/0oooo
00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`270?ooo`030000003oool0oooo03l0oooo
000Z0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0R03oool00`000000oooo0?oo
o`0o0?ooo`00:@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo08T0oooo00<00000
0?ooo`3oool0?`3oool002P0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`290?oo
o`030000003oool0oooo03l0oooo000W0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0o0?ooo`009P3oool00`3o0000oooo0?ooo`030?ooo`03003o
003oool0oooo08/0oooo00<000000?ooo`3oool0?`3oool002H0oooo00<0o`000?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`2<0?ooo`030000003oool0oooo03l0oooo000U0?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`3oool0S@3oool00`000000oooo0?ooo`0o0?ooo`00903oool00`3o
0000oooo0?ooo`020?ooo`03003o003oool0oooo08h0oooo00<000000?ooo`3oool0?`3oool002<0
oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`2?0?ooo`030000003oool0oooo03l0
oooo000R0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0T03oool00`000000oooo
0?ooo`0o0?ooo`008@3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0940oooo00<0
00000?ooo`3oool0?`3oool00200oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2A
0?ooo`030000003oool0oooo03l0oooo000@0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool00`3oool00`00o`00oooo0?ooo`2B0?ooo`030000003oool0oooo03l0oooo000@0?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2C0?ooo`03
0000003oool0oooo03l0oooo000?0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
0`3oool00`00o`00oooo0?ooo`2D0?ooo`030000003oool0oooo03l0oooo000?0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2E0?ooo`030000003o
ool0oooo03l0oooo000?0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`2F0?ooo`030000003oool0oooo03l0oooo000>0?ooo`050?l0003oool0oooo
0?ooo`00o`001`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo09L0oooo00<00000
0?ooo`3oool0?`3oool000h0oooo00D0o`000?ooo`3oool0oooo003o00060?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool0V03oool00`000000oooo0?ooo`0o0?ooo`003@3oool01@3o
0000oooo0?ooo`3oool00?l000L0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`2I
0?ooo`030000003oool0oooo03l0oooo000=0?ooo`050?l0003oool0oooo0?ooo`00o`001P3oool0
0`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo09X0oooo00<000000?ooo`3oool0?`3oool0
00d0oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3oool0VP3oool00`000000oooo0?ooo`0o0?ooo`00303oool01@3o0000oooo0?ooo`3oool0
0?l000D0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2K0?ooo`030000003oool0
oooo03l0oooo000<0?ooo`050?l0003oool0oooo0?ooo`00o`00103oool00`3o0000oooo0?ooo`03
0?ooo`03003o003oool0oooo09`0oooo00<000000?ooo`3oool0?`3oool000`0oooo00@0o`000?oo
o`3oool00?l0103oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo09d0oooo00<00000
0?ooo`3oool0?`3oool000/0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool0WP3oool00`000000oooo0?ooo`0o0?ooo`002`3oool01@3o
0000oooo0?ooo`3oool00?l00080oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2O
0?ooo`030000003oool0oooo03l0oooo000:0?ooo`050?l0003oool0oooo0?ooo`00o`000P3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo00@0oooo0P3o002J0?ooo`030000003oool0
oooo03l0oooo000:0?ooo`070?l0003oool0oooo0?ooo`00o`00oooo0?l000050?ooo`03003o003o
ool0oooo00<0oooo0P3o002L0?ooo`030000003oool0oooo03l0oooo000:0?ooo`060?l0003oool0
oooo0?ooo`00o`00o`001@3oool00`00o`00oooo0?ooo`020?ooo`80o`00WP3oool00`000000oooo
0?ooo`0o0?ooo`002@3oool01P3o0000oooo0?ooo`3oool00?l00?l000H0oooo00<00?l00?ooo`3o
ool00P3o002P0?ooo`030000003oool0oooo03l0oooo00090?ooo`050?l0003oool0oooo0?ooo`00
o`001P3oool01000o`00oooo0?l0003o00090?ooo`03003o003oool0oooo09H0oooo00<000000?oo
o`3oool0?`3oool000T0oooo00@0o`000?ooo`3oool00?l01P3oool00`00o`00o`000?l000090?oo
o`800?l0V@3oool00`000000oooo0?ooo`0o0?ooo`00203oool01@3o0000oooo0?ooo`3oool00?l0
00D0oooo00<00?l00?l0003oool0203oool2003o09/0oooo00<000000?ooo`3oool0?`3oool000P0
oooo00D0o`000?ooo`3oool0o`00003o00030?ooo`030?l00000o`00oooo00P0oooo0P00o`2M0?oo
o`030000003oool0oooo03l0oooo00070?ooo`050?l0003oool0oooo0?l00000o`000P3oool20?l0
0003003o003oool0oooo00H0oooo0P00o`2O0?ooo`030000003oool0oooo03l0oooo00070?ooo`05
0?l0003oool0o`000?ooo`00o`000P3o00000`3oool00?l00?ooo`060?ooo`800?l0X@3oool00`00
0000oooo0?ooo`0o0?ooo`001`3oool20?l000030?ooo`3o00000?l00080oooo00<00?l00?ooo`3o
ool0103oool2003o0:<0oooo00<000000?ooo`3oool0?`3oool000H0oooo103o00001000o`00oooo
0?ooo`00o`050?ooo`800?l0Y@3oool00`000000oooo0?ooo`0o0?ooo`001P3oool20?l00080oooo
00<00?l00?ooo`00o`00103oool2003o0:L0oooo00<000000?ooo`3oool0?`3oool000T0oooo00@0
0?l00?ooo`3oool00?l00P3oool2003o0:T0oooo00<000000?ooo`3oool0?`3oool000T0oooo00@0
0?l00?ooo`00o`00oooo0P00o`2[0?ooo`030000003oool0oooo03l0oooo00090?ooo`@00?l0[@3o
ool00`000000oooo0?ooo`0o0?ooo`00203oool3003o0:l0oooo00<000000?ooo`3oool0?`3oool0
00P0oooo00<00?l00?ooo`3oool0[`3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000
oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?oo
o`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?ooo`00^P3oool00`000000oooo0?ooo`0o0?oo
o`00^P3oool00`000000oooo0?ooo`0o0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 251.938}, {267.125, 0}} -> {-0.653026, -0.216623, 
  0.00350457, 0.00350457}}],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        \("You are off by:  "\[InvisibleSpace]0.0193335406491431385`\),
        SequenceForm[ "You are off by:  ", .019333540649143138],
        Editable->False], TraditionalForm]], "Print"]
}, Open  ]],

Cell["\<\
After you've found a formula to solve this problem, let's learn a little \
Mathematica.  \
\>", "Text"],

Cell["\<\
Name the solution as soln by typing in the formula with assignment.\
\>", "Text"],

Cell[CellGroupData[{

Cell["soln = LinearSolve[Transpose[{v1,v2}],target]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-5.09368861121545002`\), \(-0.739391961406848885`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Now you want to plug in the solution (computed to 16 digits even though the \
display only shows 6!) into guess but the following doesn't work.\
\>", "Text"],

Cell[CellGroupData[{

Cell["guess[soln]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`guess({\(-5.09368861121545002`\), \(-0.739391961406848885`\)})\)], 
  "Output"]
}, Open  ]],

Cell["\<\
What went wrong is that you don't want the braces in soln.  This can be \
accomplished by the function Apply.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Apply[guess,soln]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03916 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.739612 1.1326 0.244838 1.1326 [
[ 0 0 0 0 ]
[ 1 1.03916 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .24484 m
1 .24484 L
s
.73961 0 m
.73961 1.03916 L
s
0 0 m
1 0 L
1 1.03916 L
0 1.03916 L
closepath
clip
newpath
.5 Mabswid
.73961 .24484 m
.8458 .02474 L
s
.8458 .02474 m
.84398 .051 L
s
.8458 .02474 m
.82638 .0425 L
s
gsave
.79271 .13479 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.73961 .24484 m
.97619 .72025 L
s
.97619 .72025 m
.93352 .68217 L
s
.97619 .72025 m
.97155 .66325 L
s
gsave
.8579 .48254 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.73961 .24484 m
.02381 1.01442 L
s
.02381 1.01442 m
.06461 .90883 L
s
.02381 1.01442 m
.12617 .96609 L
s
0 1 0 r
.73961 .24484 m
.02381 1.01442 L
s
.02381 1.01442 m
.06461 .90883 L
s
.02381 1.01442 m
.12617 .96609 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{258.688, 268.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400042000132000`400?l00000o`00003o_P3oool0
0`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000
oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?oo
o`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo02H0oooo002n0?ooo`030000003oool0oooo01L0oooo0P00000X0?ooo`00
_P3oool00`000000oooo0?ooo`0F0?ooo`<00000:03oool00;h0oooo00<000000?ooo`3oool05@3o
ool010000000oooo00000000000X0?ooo`00_P3oool00`000000oooo0?ooo`0D0?ooo`050000003o
ool000000?ooo`000000:03oool00;h0oooo00<000000?ooo`3oool04`3oool01P000000oooo0?oo
o`000000oooo000002P0oooo002n0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0
0000:03oool00;h0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000X0?ooo`00
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo002n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00;h0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0[0?ooo`00_P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02/0oooo002n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;03oool00;h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02d0oooo002n0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0;@3oool00;h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?oo
o`00_P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo002n0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool00;h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0_0?ooo`00_P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02l0oooo002n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool00;h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`00_P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0340oooo002n0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0<@3oool00;h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b
0?ooo`00_P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo002n0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00;h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0c0?ooo`00_P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080000000<0oooo0000000000000`00000/0?ooo`00_P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000;P3o
ool00;h0oooo00<000000?ooo`3oool02@3oool010000000oooo0000000000020?ooo`040000003o
ool0oooo000002h0oooo002n0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0/0?ooo`00_P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo0P00000^0?ooo`00_P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
03L0oooo002n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00;h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`00_P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03P0oooo002n0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0>03oool00;h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?oo
o`00_P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo002n0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0>P3oool00;h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0j0?ooo`00_P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03/0oooo002n0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool00;h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`00_P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03`0oooo002n0?ooo`050000003oool0oooo0?ooo`000000
?`3oool00;h0oooo00D000000?ooo`3oool0oooo0000000o0?ooo`00_P3oool010000000oooo0?oo
o`0000100?ooo`00_P3oool010000000oooo0?ooo`0000100?ooo`00_P3oool00`000000oooo0000
00110?ooo`00_P3oool00`000000oooo000000110?ooo`00_P3oool200000480oooo002n0?ooo`80
0000@P3oool00;h0oooo00<000000?ooo`3oool0@@3oool00;h0000000<00?l0000000000000@@00
00000;d0oooo00<00?l00000003oool0@P3oool00;`0oooo00@00?l00?ooo`0000000000@P3oool0
0;/0oooo00<00?l00?ooo`3oool00P0000120?ooo`00^P3oool01`00o`00oooo0?ooo`3oool00000
0?ooo`000000@@3oool00;T0oooo00<00?l00?ooo`3oool00P3oool00`000000oooo000000110?oo
o`00^03oool00`00o`00oooo0?ooo`030?ooo`040000003oool0oooo00000400oooo002g0?ooo`03
003o003oool0oooo00@0oooo00@000000?ooo`3oool00000@03oool00;L0oooo00<00?l00?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000003l0oooo002f0?ooo`03003o003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo0000000o0?ooo`00]@3oool00`00o`00oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool00;@0oooo00<00?l00?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03`0oooo002c0?ooo`03003o003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`00/P3oool0
0`00o`00oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool0
0;40oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03X0oooo002`0?ooo`03003o003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`00[`3oool00`00o`00oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0>@3oool00:h0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03T0oooo002]0?ooo`03003o003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`00[03oool00`00o`00oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>03oool00:/0oooo00<00?l00?ooo`3o
ool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03L0oooo002Z0?ooo`03003o
003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`00ZP3o
ool00`00o`00oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3o
ool00:T0oooo00<00?l00?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo03H0oooo002X0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0e0?ooo`00Y`3oool00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0=@3oool00:H0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo03@0oooo002U0?ooo`03003o003oool0oooo01H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`00Y03oool00`00o`00oooo0?ooo`0G
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool00:<0oooo00<00?l00?oo
o`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo002R0?ooo`03
003o003oool0oooo01T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`00
X@3oool00`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<P3oool00:00oooo00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0340oooo002O0?ooo`03003o003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0a0?ooo`00WP3oool00`00o`00oooo0?ooo`0M0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool009d0oooo00<00?l00?ooo`3oool07P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo002M0?ooo`03003o003oool0oooo01h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0_0?ooo`00W03oool00`00o`00oooo0?oo
o`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;`3oool009/0oooo00<00?l0
0?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo002J0?oo
o`03003o003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?oo
o`00V@3oool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;@3oool009P0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo02d0oooo002G0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0/0?ooo`00UP3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0;03oool009D0oooo00<00?l00?ooo`3oool09P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02/0oooo002D0?ooo`03003o003oool0oooo02L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`00T`3oool00`00o`00oooo
0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00980oooo00<0
0?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo002A
0?ooo`03003o003oool0oooo02X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y
0?ooo`00T03oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0:@3oool00900oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02P0oooo002?0?ooo`03003o003oool0oooo02`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0X0?ooo`00SP3oool00`00o`00oooo0?ooo`0]0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool09`3oool008d0oooo00<00?l00?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02L0oooo002<0?ooo`03003o003oool0oooo
02l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`00R`3oool00`00o`00
oooo0?ooo`0`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool008X0oooo
00<00?l00?ooo`3oool0<@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0oooo
00290?ooo`03003o003oool0oooo0380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0U0?ooo`00R03oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0903oool008L0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02@0oooo00260?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0S0?ooo`00Q@3oool00`00o`00oooo0?ooo`0f0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool08`3oool008@0oooo00<00?l00?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0L0?ooo`040000003oool0000000000080oooo0`00000L0?ooo`00P`3o
ool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`0000000000
0P3oool00`000000oooo0?ooo`0L0?ooo`00P`3oool00`00o`00oooo0?ooo`0h0?ooo`030000003o
ool0oooo01d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`00PP3o
ool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo0P0000020?ooo`040000003o
ool0oooo000001d0oooo00210?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool07P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000703oool00800oooo00<00?l00?ooo`3oool0
>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool007l0oooo00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01l0oooo001n0?ooo`03003o003oool0oooo03d0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0O0?ooo`00O@3oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07P3oool007`0oooo00<00?l00?ooo`3oool0?`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo001k0?ooo`03003o003oool0oooo0400oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`00NP3oool00`00o`00oooo0?oo
o`110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool007T0oooo00<00?l0
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo001h0?oo
o`03003o003oool0oooo04<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?oo
o`00M`3oool00`00o`00oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool06`3oool007H0oooo00<00?l00?ooo`3oool0A@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01/0oooo001f0?ooo`03003o003oool0oooo04D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0J0?ooo`00M@3oool00`00o`00oooo0?ooo`160?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool06P3oool007@0oooo00<00?l00?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo001c0?ooo`03003o003oool0oooo04P0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0I0?ooo`00LP3oool00`00o`00oooo
0?ooo`190?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0603oool00740oooo00<0
0?l00?ooo`3oool0BP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo001`
0?ooo`03003o003oool0oooo04/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G
0?ooo`00K`3oool00`00o`00oooo0?ooo`1<0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool05`3oool006h0oooo00<00?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01H0oooo001]0?ooo`03003o003oool0oooo04h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0F0?ooo`00K03oool00`00o`00oooo0?ooo`1?0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05@3oool006/0oooo00<00?l00?ooo`3oool0D03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`03003o003oool0oooo
0540oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0D0?ooo`00J@3oool00`00o`00
oooo0?ooo`1B0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0503oool006T0oooo
00<00?l00?ooo`3oool0DP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo
001X0?ooo`03003o003oool0oooo05<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0C0?ooo`00I`3oool00`00o`00oooo0?ooo`1D0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool04P3oool006H0oooo00<00?l00?ooo`3oool0E@3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0180oooo001U0?ooo`03003o003oool0oooo05H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0A0?ooo`00I03oool00`00o`00oooo0?ooo`1G0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool006<0oooo00<00?l00?ooo`3oool0F03o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo001R0?ooo`03003o003oool0
oooo05T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`00H@3oool00`00
o`00oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03`3oool00600
oooo00<00?l00?ooo`3oool0F`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00l0
oooo001O0?ooo`03003o003oool0oooo05`0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0>0?ooo`00GP3oool00`00o`00oooo0?ooo`1M0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool03P3oool005d0oooo00<00?l00?ooo`3oool0GP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00d0oooo001L0?ooo`03003o003oool0oooo05l0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`00F`3oool00`00o`00oooo0?ooo`1P0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0303oool005/0oooo00<00?l00?ooo`3oool0
H03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo001J0?ooo`03003o003o
ool0oooo0640oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo001I0?ooo`03003o003oool0oooo0680oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo001H0?ooo`03003o003oool0oooo
06<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo001G0?ooo`03003o003oool0oooo06@0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo001F0?ooo`03003o003oool0oooo06D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001`3oool005D0oooo00<00?l00?ooo`3oool0IP3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`00E03oool00`00o`00oooo
0?ooo`1W0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000070?ooo`00D`3oool00`00o`00oooo0?ooo`1X0?ooo`030000003oool0oooo0380oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo001B0?ooo`03003o
003oool0oooo06T0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool00540oooo00<00?l00?ooo`3oool0JP3oool00`000000oooo
0?ooo`0d0?ooo`80000000D0oooo0000003oool0oooo000000060?ooo`00D03oool00`00o`00oooo
0?ooo`1[0?ooo`030000003oool0oooo03H0oooo00D000000?ooo`000000oooo000000060?ooo`00
C`3oool00`00o`00oooo0?ooo`1/0?ooo`030000003oool0oooo03L0oooo0P0000000`3oool00000
0?ooo`050?ooo`00CP3oool00`00o`00oooo0?ooo`1]0?ooo`030000003oool0oooo03P0oooo0`00
00060?ooo`00CP3oool00`00o`00oooo0?ooo`1]0?ooo`030000003oool0oooo03T0oooo0P000006
0?ooo`00C@3oool00`00o`00oooo0?ooo`1^0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0103oool004`0oooo00<00?l00?ooo`3oool0K`3oool00`000000oooo0?ooo`110?ooo`00
B`3oool00`00o`00oooo0?ooo`1`0?ooo`030000003oool0oooo0440oooo001:0?ooo`03003o003o
ool0oooo0740oooo00<000000?ooo`3oool0@@3oool004T0oooo00<00?l00?ooo`3oool0LP3oool0
0`000000oooo0?ooo`110?ooo`00B03oool00`00o`00oooo0?ooo`1c0?ooo`030000003oool0oooo
0440oooo00170?ooo`03003o003oool0oooo07@0oooo00<000000?ooo`3oool0@@3oool004H0oooo
00<00?l00?ooo`3oool0M@3oool00`000000oooo0?ooo`110?ooo`00A@3oool00`00o`00oooo0?oo
o`1f0?ooo`030000003oool0oooo0440oooo00140?ooo`03003o003oool0oooo07L0oooo00<00000
0?ooo`3oool0@@3oool004<0oooo00<00?l00?ooo`3oool0N03oool00`000000oooo0?ooo`110?oo
o`00@P3oool00`00o`00oooo0?ooo`1i0?ooo`030000003oool0oooo0440oooo00110?ooo`03003o
003oool0oooo07X0oooo00<000000?ooo`3oool0@@3oool00440oooo00<00?l00?ooo`3oool0NP3o
ool00`000000oooo0?ooo`110?ooo`00@03oool00`00o`00oooo0?ooo`1k0?ooo`030000003oool0
oooo0440oooo000o0?ooo`03003o003oool0oooo07`0oooo00<000000?ooo`3oool0@@3oool003h0
oooo00<00?l00?ooo`3oool0O@3oool00`000000oooo0?ooo`110?ooo`00?@3oool00`00o`00oooo
0?ooo`1n0?ooo`030000003oool0oooo0440oooo000l0?ooo`03003o003oool0oooo07l0oooo00<0
00000?ooo`3oool0@@3oool003/0oooo00<00?l00?ooo`3oool0P03oool00`000000oooo0?ooo`11
0?ooo`00>P3oool00`00o`00oooo0?ooo`210?ooo`030000003oool0oooo0440oooo000i0?ooo`03
003o003oool0oooo0880oooo00<000000?ooo`3oool0@@3oool003P0oooo00<00?l00?ooo`3oool0
P`3oool00`000000oooo0?ooo`110?ooo`00=`3oool00`00o`00oooo0?ooo`240?ooo`030000003o
ool0oooo0440oooo000f0?ooo`03003o003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool0
03D0oooo00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`110?ooo`00=03oool00`00o`00
oooo0?ooo`270?ooo`030000003oool0oooo0440oooo000d0?ooo`03003o003oool0oooo08L0oooo
00<000000?ooo`3oool0@@3oool003<0oooo00<00?l00?ooo`3oool0R03oool00`000000oooo0?oo
o`110?ooo`00<P3oool00`00o`00oooo0?ooo`290?ooo`030000003oool0oooo0440oooo000a0?oo
o`03003o003oool0oooo08X0oooo00<000000?ooo`3oool0@@3oool00300oooo00<00?l00?ooo`3o
ool0R`3oool00`000000oooo0?ooo`110?ooo`00;`3oool00`00o`00oooo0?ooo`2<0?ooo`030000
003oool0oooo0440oooo000^0?ooo`03003o003oool0oooo08d0oooo00<000000?ooo`3oool0@@3o
ool002d0oooo00<00?l00?ooo`3oool0SP3oool00`000000oooo0?ooo`110?ooo`00;03oool00`00
o`00oooo0?ooo`2?0?ooo`030000003oool0oooo0440oooo000[0?ooo`03003o003oool0oooo0900
oooo00<000000?ooo`3oool0@@3oool002X0oooo00<00?l00?ooo`3oool0T@3oool00`000000oooo
0?ooo`110?ooo`00:@3oool00`00o`00oooo0?ooo`2B0?ooo`030000003oool0oooo0440oooo000X
0?ooo`03003o003oool0oooo09<0oooo00<000000?ooo`3oool0@@3oool002L0oooo00<00?l00?oo
o`3oool0U03oool00`000000oooo0?ooo`110?ooo`009`3oool00`00o`00oooo0?ooo`2D0?ooo`03
0000003oool0oooo0440oooo000V0?ooo`03003o003oool0oooo09D0oooo00<000000?ooo`3oool0
@@3oool002D0oooo00<00?l00?ooo`3oool0UP3oool00`000000oooo0?ooo`110?ooo`00903oool0
0`00o`00oooo0?ooo`2G0?ooo`030000003oool0oooo0440oooo000S0?ooo`03003o003oool0oooo
09P0oooo00<000000?ooo`3oool0@@3oool00280oooo00<00?l00?ooo`3oool0V@3oool00`000000
oooo0?ooo`110?ooo`008@3oool00`00o`00oooo0?ooo`2J0?ooo`030000003oool0oooo0440oooo
000P0?ooo`03003o003oool0oooo09/0oooo00<000000?ooo`3oool0@@3oool00100oooo00<00?l0
0?ooo`3oool0303oool00`00o`00oooo0?ooo`2L0?ooo`030000003oool0oooo0440oooo000@0?oo
o`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0W@3oool00`000000oooo0?ooo`110?oo
o`003`3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo09h0oooo00<000000?ooo`3o
ool0@@3oool000l0oooo00<00?l00?ooo`3oool02P3oool00`00o`00oooo0?ooo`2O0?ooo`030000
003oool0oooo0440oooo000?0?ooo`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool0X03o
ool00`000000oooo0?ooo`110?ooo`003P3oool00`00o`00oooo0?ooo`090?ooo`03003o003oool0
oooo0:40oooo00<000000?ooo`3oool0@@3oool000h0oooo00<00?l00?ooo`3oool02@3oool00`00
o`00oooo0?ooo`2Q0?ooo`030000003oool0oooo0440oooo000=0?ooo`03003o003oool0oooo00T0
oooo00<00?l00?ooo`3oool0XP3oool00`000000oooo0?ooo`110?ooo`003@3oool00`00o`00oooo
0?ooo`080?ooo`03003o003oool0oooo0:<0oooo00<000000?ooo`3oool0@@3oool000d0oooo00<0
0?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`2T0?ooo`030000003oool0oooo0440oooo000<
0?ooo`03003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0Y@3oool00`000000oooo0?ooo`11
0?ooo`00303oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo0:H0oooo00<000000?oo
o`3oool0@@3oool000`0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`2W0?ooo`03
0000003oool0oooo0440oooo000;0?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool0
Z03oool00`000000oooo0?ooo`110?ooo`002`3oool00`00o`00oooo0?ooo`040?ooo`03003o003o
ool0oooo0:T0oooo00<000000?ooo`3oool0@@3oool000X0oooo00<00?l00?ooo`3oool0103oool0
0`00o`00oooo0?ooo`0;0?ooo`800?l0W@3oool00`000000oooo0?ooo`110?ooo`002P3oool00`00
o`00oooo0?ooo`030?ooo`03003o003oool0oooo00X0oooo0P00o`2O0?ooo`030000003oool0oooo
0440oooo000:0?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool02@3oool2003o0:40
oooo00<000000?ooo`3oool0@@3oool000T0oooo00<00?l00?ooo`3oool00P3oool00`00o`00oooo
0?ooo`080?ooo`800?l0X`3oool00`000000oooo0?ooo`110?ooo`002@3oool01@00o`00oooo0?oo
o`3oool00?l000T0oooo0P00o`2U0?ooo`030000003oool0oooo0440oooo00090?ooo`05003o003o
ool0oooo0?ooo`00o`001`3oool2003o0:L0oooo00<000000?ooo`3oool0@@3oool000P0oooo00D0
0?l00?ooo`3oool0oooo003o00050?ooo`<00?l0Z@3oool00`000000oooo0?ooo`110?ooo`00203o
ool01000o`00oooo0?ooo`00o`040?ooo`800?l0[03oool00`000000oooo0?ooo`110?ooo`001`3o
ool01000o`00oooo0?ooo`00o`030?ooo`800?l0[P3oool00`000000oooo0?ooo`110?ooo`001`3o
ool00`00o`00oooo003o00020?ooo`800?l0/03oool00`000000oooo0?ooo`110?ooo`001`3oool2
003o00030?ooo`00o`000?l00;80oooo00<000000?ooo`3oool0@@3oool000H0oooo1000o`2d0?oo
o`030000003oool0oooo0440oooo00060?ooo`800?l0]P3oool00`000000oooo0?ooo`110?ooo`00
_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool0
0`000000oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00_P3oool00`000000
oooo0?ooo`110?ooo`00_P3oool00`000000oooo0?ooo`110?ooo`00\
\>"],
  ImageRangeCache->{{{0, 257.688}, {267.813, 0}} -> {-0.653026, -0.216236, 
  0.00342637, 0.00342637}}],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("You are off by:  "\[InvisibleSpace]0.`\),
        SequenceForm[ "You are off by:  ", 0.0],
        Editable->False], TraditionalForm]], "Print"]
}, Open  ]],

Cell["\<\
Now let's create a program to do this everytime.  Simply use the soln = \
formula above but change to
answer := formula.  The colon-equal creates a program or function that only \
saves instructions now but will execute  these instructions whenever you type \
answer.  (It could have arguments as suggested in H11 but your function \
assumes the vectors named v1, v2 and target from cogame.)\
\>", "Text"],

Cell["answer := LinearSolve[Transpose[{v1,v2}],target]", "Input"],

Cell["Now try it.", "Text"],

Cell[CellGroupData[{

Cell["answer", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-5.09368861121545002`\), \(-0.739391961406848885`\)}\)], "Output"]
}, Open  ]],

Cell["Try it on a new game.", "Text"],

Cell[CellGroupData[{

Cell["cogame", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97607 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.550695 0.671631 0.604944 0.671631 [
[ 0 0 0 0 ]
[ 1 .97607 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .60494 m
1 .60494 L
s
.5507 0 m
.5507 .97607 L
s
0 0 m
1 0 L
1 .97607 L
0 .97607 L
closepath
clip
newpath
.5 Mabswid
.5507 .60494 m
.97619 .513 L
s
.97619 .513 m
.93732 .53921 L
s
.97619 .513 m
.92996 .50517 L
s
gsave
.76344 .55897 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5507 .60494 m
.03878 .02324 L
s
.03878 .02324 m
.11324 .06093 L
s
.03878 .02324 m
.0667 .10189 L
s
gsave
.29474 .31409 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.5507 .60494 m
.02381 .95283 L
s
.02381 .95283 m
.06258 .89697 L
s
.02381 .95283 m
.09041 .93912 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.625, 198.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000aR000`400?l00000o`00003oK`3oool0
0`000000oooo0?ooo`1I0?ooo`00K`3oool00`000000oooo0?ooo`1I0?ooo`00K`3oool00`000000
oooo0?ooo`1I0?ooo`00K`3oool00`000000oooo0?ooo`1I0?ooo`001`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo05T0oooo00070?ooo`<00000I@3oool00`000000oooo0?ooo`1I
0?ooo`00203oool4000006<0oooo00<000000?ooo`3oool0F@3oool000P0oooo00@000000?ooo`00
0000oooo0P00001Q0?ooo`030000003oool0oooo05T0oooo00080?ooo`040000003oool0oooo0000
0080oooo0P00001O0?ooo`030000003oool0oooo05T0oooo00090?ooo`030000003oool0000000@0
oooo0P00001M0?ooo`030000003oool0oooo05T0oooo00090?ooo`040000003oool0oooo000000D0
oooo0P00001K0?ooo`030000003oool0oooo05T0oooo000:0?ooo`040000003oool0oooo000000H0
oooo0P00001I0?ooo`030000003oool0oooo05T0oooo000:0?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05T0oooo000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1I0?ooo`002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0F@3o
ool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo05T0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`1I0?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0F@3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo05T0oooo000=0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1I0?ooo`003@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0F@3oool001H0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`005`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05T0oooo000H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
F@3oool001T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1I0?ooo`006P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo05T0oooo000J0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`1I0?ooo`00703oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo05T0oooo
000M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0F@3oool001h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`1I0?ooo`007`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo05T0oooo000P0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0F@3oool00240oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1I0?ooo`008@3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05T0oooo000R0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0F@3oool002<0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`1I0?ooo`00903oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05T0
oooo000U0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0F@3oool002H0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`1I0?ooo`009`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo05T0oooo000X0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0F@3oool002P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1I0?ooo`00
:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05T0oooo000Z0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0F@3oool002/0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`1I0?ooo`00;03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
05T0oooo000]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F@3oool002h0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1I0?ooo`00;`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo05T0oooo000`0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0F@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1I0?oo
o`00<@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05T0oooo000b0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0F@3oool003<0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`1I0?ooo`00=03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo05T0oooo000e0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0F@3oool003H0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`00=`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo05T0oooo000g0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0F@3oool003P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1I
0?ooo`00>@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05T0oooo000j0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0F@3oool003/0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`1I0?ooo`00?03oool300000080oooo0`00000[0?ooo`030000003o
ool0oooo05T0oooo000m0?ooo`8000000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo05T0oooo000l0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`1I0?ooo`00>`3oool200000080oooo00@000000?ooo`3oool00000;03oool0
0`000000oooo0?ooo`1I0?ooo`00?`3oool01@000000oooo0000003oool0000002/0oooo00<00000
0?ooo`3oool0F@3oool00400oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`1I0?oo
o`00@@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05T0oooo00120?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0F@3oool004<0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1I0?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo05T0oooo00150?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0F@3oool004H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1I0?ooo`00AP3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo05T0oooo00170?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0F@3oool004P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1I
0?ooo`00B@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001:0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0F@3oool004/0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1I0?ooo`00C03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo05T0oooo001=0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0F@3oool0
04h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1I0?ooo`00CP3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo05T0oooo001?0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F@3oool00500oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1I0?ooo`00D@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05T0oooo001B0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0F@3oool005<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1I0?ooo`00E03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05T0oooo001E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0F@3o
ool005D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1I0?ooo`00EP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo05T0oooo001G0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0F@3oool005P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1I0?ooo`00F@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo001J
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F@3oool005/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1I0?ooo`00G03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo05T0oooo001L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
F@3oool005d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1:0?ooo`<00000303o
ool005h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1=0?ooo`@00000203oool0
05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1A0?ooo`<000001@3oool00600
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1<0?ooo`L000001P3oool00640oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`180?ooo`@00000103oool00`000000oooo
0?ooo`060?ooo`00HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04<0oooo1@00
00060?ooo`8000002@3oool006<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n
0?ooo`D000002@3oool2000000/0oooo001T0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0>@3oool5000000d0oooo00<000000?ooo`3oool02`3oool006@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0d0?ooo`D00000803oool006D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0`0?ooo`@000009@3oool006H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0[0?ooo`D00000:@3oool006L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0V0?ooo`D00000;P3oool006P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`D00000103oool2000000030?ooo`000000000000<000009`3oool006T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`@000002@3oool2000000<0
oooo00<000000?ooo`3oool09`3oool006X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`D00000303oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0
oooo001[0?ooo`050000003oool0oooo0?ooo`0000005@3oool500000100oooo0P0000020?ooo`04
0000003oool0oooo000002T0oooo001[0?ooo`050000003oool0oooo0?ooo`000000403oool50000
01`0oooo00<000000?ooo`3oool09`3oool006`0oooo00@000000?ooo`3oool000002`3oool50000
0200oooo0P00000Y0?ooo`00K@3oool00`000000oooo000000070?ooo`@00000D03oool006h0oooo
0P0000020?ooo`D00000E03oool006l0000000<0o`00000000000000F@00000006d0oooo0P3o0000
0`000000oooo0?ooo`1I0?ooo`00K03oool0103o0000oooo0?ooo`00001K0?ooo`00JP3oool20?l0
00<0oooo00<000000?ooo`3oool0F@3oool006T0oooo00<0o`000?ooo`3oool00`3oool00`000000
oooo0?ooo`1I0?ooo`00I`3oool20?l000H0oooo00<000000?ooo`3oool0F@3oool006H0oooo00<0
o`000?ooo`3oool01P3oool00`000000oooo0?ooo`1I0?ooo`00I03oool20?l000T0oooo00<00000
0?ooo`3oool0F@3oool006<0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1I0?oo
o`00H@3oool20?l000`0oooo00<000000?ooo`3oool0F@3oool00600oooo00<0o`000?ooo`3oool0
303oool00`000000oooo0?ooo`1I0?ooo`00GP3oool20?l000l0oooo00<000000?ooo`3oool0F@3o
ool005d0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`00F`3oool20?l0
0180oooo00<000000?ooo`3oool0F@3oool005X0oooo00<0o`000?ooo`3oool04P3oool00`000000
oooo0?ooo`1I0?ooo`00F03oool20?l001D0oooo00<000000?ooo`3oool0F@3oool005L0oooo00<0
o`000?ooo`3oool05@3oool00`000000oooo0?ooo`1I0?ooo`00E@3oool20?l001P0oooo00<00000
0?ooo`3oool0F@3oool005@0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`1I0?oo
o`00DP3oool20?l001/0oooo00<000000?ooo`3oool0F@3oool00540oooo00<0o`000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1I0?ooo`00C`3oool20?l001h0oooo00<000000?ooo`3oool0F@3o
ool004h0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`1I0?ooo`00C03oool20?l0
0240oooo00<000000?ooo`3oool0F@3oool004/0oooo00<0o`000?ooo`3oool08@3oool00`000000
oooo0?ooo`1I0?ooo`00B@3oool20?l002@0oooo00<000000?ooo`3oool0F@3oool004P0oooo00<0
o`000?ooo`3oool0903oool00`000000oooo0?ooo`1I0?ooo`00AP3oool20?l002L0oooo00<00000
0?ooo`3oool0F@3oool004D0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`1I0?oo
o`00@`3oool20?l002X0oooo00<000000?ooo`3oool0F@3oool00480oooo00<0o`000?ooo`3oool0
:P3oool00`000000oooo0?ooo`1I0?ooo`00@03oool20?l002d0oooo00<000000?ooo`3oool0F@3o
ool003l0oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`1I0?ooo`00?@3oool20?l0
0300oooo00<000000?ooo`3oool0F@3oool003`0oooo00<0o`000?ooo`3oool0<03oool00`000000
oooo0?ooo`1I0?ooo`00>P3oool20?l003<0oooo00<000000?ooo`3oool0F@3oool003P0oooo0P3o
000e0?ooo`030000003oool0oooo05T0oooo000g0?ooo`030?l0003oool0oooo03D0oooo00<00000
0?ooo`3oool0F@3oool003D0oooo0P3o000h0?ooo`030000003oool0oooo05T0oooo000d0?ooo`03
0?l0003oool0oooo03P0oooo00<000000?ooo`3oool0F@3oool00380oooo0P3o000k0?ooo`030000
003oool0oooo05T0oooo000a0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0F@3o
ool002l0oooo0P3o000n0?ooo`030000003oool0oooo05T0oooo000^0?ooo`030?l0003oool0oooo
03h0oooo00<000000?ooo`3oool0F@3oool002`0oooo0P3o00110?ooo`030000003oool0oooo05T0
oooo000[0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0F@3oool002T0oooo0P3o
00140?ooo`030000003oool0oooo05T0oooo000X0?ooo`030?l0003oool0oooo04@0oooo00<00000
0?ooo`3oool0F@3oool002H0oooo0P3o00170?ooo`030000003oool0oooo05T0oooo000U0?ooo`03
0?l0003oool0oooo04L0oooo00<000000?ooo`3oool0F@3oool002<0oooo0P3o001:0?ooo`030000
003oool0oooo05T0oooo000R0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool0F@3o
ool00200oooo0P3o001=0?ooo`030000003oool0oooo05T0oooo000O0?ooo`030?l0003oool0oooo
04d0oooo00<000000?ooo`3oool0F@3oool001d0oooo0P3o001@0?ooo`030000003oool0oooo05T0
oooo000L0?ooo`030?l0003oool0oooo0500oooo00<000000?ooo`3oool0F@3oool001X0oooo0P3o
001C0?ooo`030000003oool0oooo05T0oooo000I0?ooo`030?l0003oool0oooo05<0oooo00<00000
0?ooo`3oool0F@3oool001L0oooo0P3o001F0?ooo`030000003oool0oooo05T0oooo000<0?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`00
2`3oool00`3o0000oooo0?ooo`060?ooo`80o`00F@3oool00`000000oooo0?ooo`1I0?ooo`002`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo05T0oooo00<000000?ooo`3oool0F@3o
ool000X0oooo00<0o`000?ooo`3oool0103oool20?l005`0oooo00<000000?ooo`3oool0F@3oool0
00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1L0?ooo`030000003oool0oooo
05T0oooo00090?ooo`030?l0003oool0oooo0080oooo0P3o001O0?ooo`030000003oool0oooo05T0
oooo00080?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0G`3oool00`000000oooo
0?ooo`1I0?ooo`001`3oool0103o0000oooo0?ooo`3oool20?l00680oooo00<000000?ooo`3oool0
F@3oool000L0oooo00@0o`000?ooo`3oool0o`00I03oool00`000000oooo0?ooo`1I0?ooo`001P3o
ool0103o0000oooo0?l0003o00060?ooo`<0o`00G03oool00`000000oooo0?ooo`1I0?ooo`001@3o
ool00`3o0000oooo0?l000040?ooo`@0o`00G`3oool00`000000oooo0?ooo`1I0?ooo`001@3oool7
0?l006<0oooo00<000000?ooo`3oool0F@3oool000@0oooo0`3o001X0?ooo`030000003oool0oooo
05T0oooo001_0?ooo`030000003oool0oooo05T0oooo001_0?ooo`030000003oool0oooo05T0oooo
001_0?ooo`030000003oool0oooo05T0oooo001_0?ooo`030000003oool0oooo05T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 202.625}, {197.75, 0}} -> {-0.820043, -0.900716, 
  0.00734917, 0.00734917}}],

Cell[BoxData[
    \(TraditionalForm\`"Try to match the red vector with a*v1+b*v2"\)], 
  "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Enter:  guess[a,b]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["answer", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-1.6449845421889635`\), \(-0.338037119369030136`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply[guess,answer]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97607 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.550695 0.671631 0.604944 0.671631 [
[ 0 0 0 0 ]
[ 1 .97607 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .60494 m
1 .60494 L
s
.5507 0 m
.5507 .97607 L
s
0 0 m
1 0 L
1 .97607 L
0 .97607 L
closepath
clip
newpath
.5 Mabswid
.5507 .60494 m
.97619 .513 L
s
.97619 .513 m
.93732 .53921 L
s
.97619 .513 m
.92996 .50517 L
s
gsave
.76344 .55897 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v1) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5507 .60494 m
.03878 .02324 L
s
.03878 .02324 m
.11324 .06093 L
s
.03878 .02324 m
.0667 .10189 L
s
gsave
.29474 .31409 -63 -5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
.5507 .60494 m
.02381 .95283 L
s
.02381 .95283 m
.06258 .89697 L
s
.02381 .95283 m
.09041 .93912 L
s
0 1 0 r
.5507 .60494 m
.02381 .95283 L
s
.02381 .95283 m
.06258 .89697 L
s
.02381 .95283 m
.09041 .93912 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.625, 198.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0000aR000`400?l00000o`00003oK`3oool0
0`000000oooo0?ooo`1I0?ooo`00K`3oool00`000000oooo0?ooo`1I0?ooo`00K`3oool00`000000
oooo0?ooo`1I0?ooo`00K`3oool00`000000oooo0?ooo`1I0?ooo`001`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo05T0oooo00070?ooo`<00000I@3oool00`000000oooo0?ooo`1I
0?ooo`00203oool4000006<0oooo00<000000?ooo`3oool0F@3oool000P0oooo00@000000?ooo`00
0000oooo0P00001Q0?ooo`030000003oool0oooo05T0oooo00080?ooo`040000003oool0oooo0000
0080oooo0P00001O0?ooo`030000003oool0oooo05T0oooo00090?ooo`030000003oool0000000@0
oooo0P00001M0?ooo`030000003oool0oooo05T0oooo00090?ooo`040000003oool0oooo000000D0
oooo0P00001K0?ooo`030000003oool0oooo05T0oooo000:0?ooo`040000003oool0oooo000000H0
oooo0P00001I0?ooo`030000003oool0oooo05T0oooo000:0?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05T0oooo000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1I0?ooo`002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0F@3o
ool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo05T0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`1I0?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0F@3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo05T0oooo000=0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1I0?ooo`003@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0F@3oool001H0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`005`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05T0oooo000H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
F@3oool001T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1I0?ooo`006P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo05T0oooo000J0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`1I0?ooo`00703oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo05T0oooo
000M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0F@3oool001h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`1I0?ooo`007`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo05T0oooo000P0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0F@3oool00240oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1I0?ooo`008@3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05T0oooo000R0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0F@3oool002<0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`1I0?ooo`00903oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05T0
oooo000U0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0F@3oool002H0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`1I0?ooo`009`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo05T0oooo000X0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0F@3oool002P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1I0?ooo`00
:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05T0oooo000Z0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0F@3oool002/0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`1I0?ooo`00;03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
05T0oooo000]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0F@3oool002h0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1I0?ooo`00;`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo05T0oooo000`0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0F@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1I0?oo
o`00<@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05T0oooo000b0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0F@3oool003<0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`1I0?ooo`00=03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo05T0oooo000e0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0F@3oool003H0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`00=`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo05T0oooo000g0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0F@3oool003P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1I
0?ooo`00>@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05T0oooo000j0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0F@3oool003/0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`1I0?ooo`00?03oool300000080oooo0`00000[0?ooo`030000003o
ool0oooo05T0oooo000m0?ooo`8000000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo05T0oooo000l0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`1I0?ooo`00>`3oool200000080oooo00@000000?ooo`3oool00000;03oool0
0`000000oooo0?ooo`1I0?ooo`00?`3oool01@000000oooo0000003oool0000002/0oooo00<00000
0?ooo`3oool0F@3oool00400oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`1I0?oo
o`00@@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05T0oooo00120?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0F@3oool004<0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1I0?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo05T0oooo00150?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0F@3oool004H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1I0?ooo`00AP3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo05T0oooo00170?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0F@3oool004P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1I
0?ooo`00B@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05T0oooo001:0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0F@3oool004/0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1I0?ooo`00C03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo05T0oooo001=0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0F@3oool0
04h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1I0?ooo`00CP3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo05T0oooo001?0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F@3oool00500oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1I0?ooo`00D@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05T0oooo001B0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0F@3oool005<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1I0?ooo`00E03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05T0oooo001E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0F@3o
ool005D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1I0?ooo`00EP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo05T0oooo001G0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0F@3oool005P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1I0?ooo`00F@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo001J
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F@3oool005/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1I0?ooo`00G03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo05T0oooo001L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
F@3oool005d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1:0?ooo`<00000303o
ool005h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1=0?ooo`@00000203oool0
05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1A0?ooo`<000001@3oool00600
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1<0?ooo`L000001P3oool00640oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`180?ooo`@00000103oool00`000000oooo
0?ooo`060?ooo`00HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04<0oooo1@00
00060?ooo`8000002@3oool006<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n
0?ooo`D000002@3oool2000000/0oooo001T0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0>@3oool5000000d0oooo00<000000?ooo`3oool02`3oool006@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0d0?ooo`D00000803oool006D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0`0?ooo`@000009@3oool006H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0[0?ooo`D00000:@3oool006L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0V0?ooo`D00000;P3oool006P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`D00000103oool2000000030?ooo`000000000000<000009`3oool006T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`@000002@3oool2000000<0
oooo00<000000?ooo`3oool09`3oool006X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`D00000303oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0
oooo001[0?ooo`050000003oool0oooo0?ooo`0000005@3oool500000100oooo0P0000020?ooo`04
0000003oool0oooo000002T0oooo001[0?ooo`050000003oool0oooo0?ooo`000000403oool50000
01`0oooo00<000000?ooo`3oool09`3oool006`0oooo00@000000?ooo`3oool000002`3oool50000
0200oooo0P00000Y0?ooo`00K@3oool00`000000oooo000000070?ooo`@00000D03oool006h0oooo
0P0000020?ooo`D00000E03oool006l0000000<00?l0000000000000F@00000006d0oooo0P00o`00
0`000000oooo0?ooo`1I0?ooo`00K03oool01000o`00oooo0?ooo`00001K0?ooo`00JP3oool2003o
00<0oooo00<000000?ooo`3oool0F@3oool006T0oooo00<00?l00?ooo`3oool00`3oool00`000000
oooo0?ooo`1I0?ooo`00I`3oool2003o00H0oooo00<000000?ooo`3oool0F@3oool006H0oooo00<0
0?l00?ooo`3oool01P3oool00`000000oooo0?ooo`1I0?ooo`00I03oool2003o00T0oooo00<00000
0?ooo`3oool0F@3oool006<0oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`1I0?oo
o`00H@3oool2003o00`0oooo00<000000?ooo`3oool0F@3oool00600oooo00<00?l00?ooo`3oool0
303oool00`000000oooo0?ooo`1I0?ooo`00GP3oool2003o00l0oooo00<000000?ooo`3oool0F@3o
ool005d0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`00F`3oool2003o
0180oooo00<000000?ooo`3oool0F@3oool005X0oooo00<00?l00?ooo`3oool04P3oool00`000000
oooo0?ooo`1I0?ooo`00F03oool2003o01D0oooo00<000000?ooo`3oool0F@3oool005L0oooo00<0
0?l00?ooo`3oool05@3oool00`000000oooo0?ooo`1I0?ooo`00E@3oool2003o01P0oooo00<00000
0?ooo`3oool0F@3oool005@0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`1I0?oo
o`00DP3oool2003o01/0oooo00<000000?ooo`3oool0F@3oool00540oooo00<00?l00?ooo`3oool0
6`3oool00`000000oooo0?ooo`1I0?ooo`00C`3oool2003o01h0oooo00<000000?ooo`3oool0F@3o
ool004h0oooo00<00?l00?ooo`3oool07P3oool00`000000oooo0?ooo`1I0?ooo`00C03oool2003o
0240oooo00<000000?ooo`3oool0F@3oool004/0oooo00<00?l00?ooo`3oool08@3oool00`000000
oooo0?ooo`1I0?ooo`00B@3oool2003o02@0oooo00<000000?ooo`3oool0F@3oool004P0oooo00<0
0?l00?ooo`3oool0903oool00`000000oooo0?ooo`1I0?ooo`00AP3oool2003o02L0oooo00<00000
0?ooo`3oool0F@3oool004D0oooo00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`1I0?oo
o`00@`3oool2003o02X0oooo00<000000?ooo`3oool0F@3oool00480oooo00<00?l00?ooo`3oool0
:P3oool00`000000oooo0?ooo`1I0?ooo`00@03oool2003o02d0oooo00<000000?ooo`3oool0F@3o
ool003l0oooo00<00?l00?ooo`3oool0;@3oool00`000000oooo0?ooo`1I0?ooo`00?@3oool2003o
0300oooo00<000000?ooo`3oool0F@3oool003`0oooo00<00?l00?ooo`3oool0<03oool00`000000
oooo0?ooo`1I0?ooo`00>P3oool2003o03<0oooo00<000000?ooo`3oool0F@3oool003P0oooo0P00
o`0e0?ooo`030000003oool0oooo05T0oooo000g0?ooo`03003o003oool0oooo03D0oooo00<00000
0?ooo`3oool0F@3oool003D0oooo0P00o`0h0?ooo`030000003oool0oooo05T0oooo000d0?ooo`03
003o003oool0oooo03P0oooo00<000000?ooo`3oool0F@3oool00380oooo0P00o`0k0?ooo`030000
003oool0oooo05T0oooo000a0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool0F@3o
ool002l0oooo0P00o`0n0?ooo`030000003oool0oooo05T0oooo000^0?ooo`03003o003oool0oooo
03h0oooo00<000000?ooo`3oool0F@3oool002`0oooo0P00o`110?ooo`030000003oool0oooo05T0
oooo000[0?ooo`03003o003oool0oooo0440oooo00<000000?ooo`3oool0F@3oool002T0oooo0P00
o`140?ooo`030000003oool0oooo05T0oooo000X0?ooo`03003o003oool0oooo04@0oooo00<00000
0?ooo`3oool0F@3oool002H0oooo0P00o`170?ooo`030000003oool0oooo05T0oooo000U0?ooo`03
003o003oool0oooo04L0oooo00<000000?ooo`3oool0F@3oool002<0oooo0P00o`1:0?ooo`030000
003oool0oooo05T0oooo000R0?ooo`03003o003oool0oooo04X0oooo00<000000?ooo`3oool0F@3o
ool00200oooo0P00o`1=0?ooo`030000003oool0oooo05T0oooo000O0?ooo`03003o003oool0oooo
04d0oooo00<000000?ooo`3oool0F@3oool001d0oooo0P00o`1@0?ooo`030000003oool0oooo05T0
oooo000L0?ooo`03003o003oool0oooo0500oooo00<000000?ooo`3oool0F@3oool001X0oooo0P00
o`1C0?ooo`030000003oool0oooo05T0oooo000I0?ooo`03003o003oool0oooo05<0oooo00<00000
0?ooo`3oool0F@3oool001L0oooo0P00o`1F0?ooo`030000003oool0oooo05T0oooo000<0?ooo`03
003o003oool0oooo00L0oooo00<00?l00?ooo`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`00
2`3oool00`00o`00oooo0?ooo`060?ooo`800?l0F@3oool00`000000oooo0?ooo`1I0?ooo`002`3o
ool00`00o`00oooo0?ooo`050?ooo`03003o003oool0oooo05T0oooo00<000000?ooo`3oool0F@3o
ool000X0oooo00<00?l00?ooo`3oool0103oool2003o05`0oooo00<000000?ooo`3oool0F@3oool0
00T0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`1L0?ooo`030000003oool0oooo
05T0oooo00090?ooo`03003o003oool0oooo0080oooo0P00o`1O0?ooo`030000003oool0oooo05T0
oooo00080?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0G`3oool00`000000oooo
0?ooo`1I0?ooo`001`3oool01000o`00oooo0?ooo`3oool2003o0680oooo00<000000?ooo`3oool0
F@3oool000L0oooo00@00?l00?ooo`3oool00?l0I03oool00`000000oooo0?ooo`1I0?ooo`001P3o
ool01000o`00oooo003o0000o`060?ooo`<00?l0G03oool00`000000oooo0?ooo`1I0?ooo`001@3o
ool00`00o`00oooo003o00040?ooo`@00?l0G`3oool00`000000oooo0?ooo`1I0?ooo`001@3oool7
003o06<0oooo00<000000?ooo`3oool0F@3oool000@0oooo0`00o`1X0?ooo`030000003oool0oooo
05T0oooo001_0?ooo`030000003oool0oooo05T0oooo001_0?ooo`030000003oool0oooo05T0oooo
001_0?ooo`030000003oool0oooo05T0oooo001_0?ooo`030000003oool0oooo05T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 202.625}, {197.75, 0}} -> {-0.820043, -0.900716, 
  0.00734917, 0.00734917}}],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        \("You are off by:  "\[InvisibleSpace]1.11022302462515654`*^-16\),
        SequenceForm[ "You are off by:  ", .11102230246251565*^-15],
        Editable->False], TraditionalForm]], "Print"]
}, Open  ]],

Cell["\<\
Note that soln doesn't change (it was a constant set on the first problem) \
but that answer recomputes the formula using the latest values of the the \
variables.\
\>", "Text"],

Cell[CellGroupData[{

Cell["soln", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-5.09368861121545002`\), \(-0.739391961406848885`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["answer", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{\(-1.6449845421889635`\), \(-0.338037119369030136`\)}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 4.2; 5  A Concrete Application (extended)", "Section"],

Cell[CellGroupData[{

Cell["SAL = {{20,18,12},{10,10,10},{20,25,15},{10,5,15},{0,2,8}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"20", "18", "12"},
            {"10", "10", "10"},
            {"20", "25", "15"},
            {"10", "5", "15"},
            {"0", "2", "8"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply[Plus,SAL]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{60, 60, 60}\)], "Output"]
}, Open  ]],

Cell["\<\
Throughout, we make the UNREALISTIC assumption that negative scoops of the \
three basic mixes are allowed.  This makes possible custom mixes into a \
subspace and is a great way to conceptualize many of the vector space \
concepts.  After you finish the problem under this assumption, you could go \
back and consider what realistically happens when possible custom mixes are \
restricted to the \"nonnegative octant\" of the subspace.\
\>", "Text",
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["RowReduce[SAL]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Since the rank of SAL is 3, you need all 3 vectors (mixes) to span the \
Col(SAL), which is all possible mixtures you can make.  (They are linearly \
independent.)\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b)", "Subsection"],

Cell["\<\
All possible custom mixes is Col(SAL) = Span{S, A, L}, this is only a 3 \
dimensional subspace of the 5 dimensional space of all possible mixes.  So \
no, can't get all.\
\>", "Text"],

Cell[CellGroupData[{

Cell["SAL.{{s},{a},{l}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(18\ a + 12\ l + 20\ s\)},
            {\(10\ a + 10\ l + 10\ s\)},
            {\(25\ a + 15\ l + 20\ s\)},
            {\(5\ a + 15\ l + 10\ s\)},
            {\(2\ a + 8\ l\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(c)", "Subsection"],

Cell[CellGroupData[{

Cell["soln = LinearSolve[SAL,{16,10,21,9,4}]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2\/25, 14\/25, 9\/25}\)], "Output"]
}, Open  ]],

Cell["\<\
This is a unique solution since rank = #columns, so Nul(SAL)={0} and \
solutions are unique.\
\>", "Text"],

Cell["To get 5000 grams:", "Text"],

Cell[CellGroupData[{

Cell["soln5000 = (5000/60)soln", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{20\/3, 140\/3, 30}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["N[soln5000]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{6.66666666666666696`, 46.6666666666666607`, 30.`}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
Use 6.7 scoops of S, 46.7 scoops of A and 30 scoops of L to get 5000 grams in \
proportion.\
\>", "Text"],

Cell[CellGroupData[{

Cell["result = SAL.soln5000", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{4000\/3, 2500\/3, 1750, 750, 1000\/3}\)], "Output"]
}, Open  ]],

Cell["check:", "Text"],

Cell[CellGroupData[{

Cell["Apply[Plus,result]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`5000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/{16,10,21,9,4}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{250\/3, 250\/3, 250\/3, 250\/3, 250\/3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell["\<\
In each basic mix, water is 1/6 the weight, sand+gravel is 1/2 the weight, \
and cement+flyash is 1/3 the weight.\
\>", "Text"],

Cell[CellGroupData[{

Cell["colspace = SAL.{s,a,l}", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{18\ a + 12\ l + 20\ s, 10\ a + 10\ l + 10\ s, 25\ a + 15\ l + 20\ s, 
      5\ a + 15\ l + 10\ s, 2\ a + 8\ l}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply[Plus,colspace]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`60\ a + 60\ l + 60\ s\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["colspace[[3]]+colspace[[4]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`30\ a + 30\ l + 30\ s\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["colspace[[1]]+colspace[[5]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`20\ a + 20\ l + 20\ s\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(e) A custom mix that's impossible:", "Subsection"],

Cell[CellGroupData[{

Cell["LinearSolve[SAL,{17,10,20,9,4}]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`LinearSolve::"nosol"  : \ 
      "Linear equation encountered which has no solution."\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"LinearSolve", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"20", "18", "12"},
                {"10", "10", "10"},
                {"20", "25", "15"},
                {"10", "5", "15"},
                {"0", "2", "8"}
                },
              ColumnAlignments->{Decimal}], ")"}], ",", 
          \({17, 10, 20, 9, 4}\)}], "]"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Can there be an impossible custom mix that satisfies the three conditions in \
(d)?\
\>", "Text"],

Cell["\<\
No, the three conditions restrict you to a \"solution subspace.\"  Since all \
three basic mixes fullfill the conditions, the subspace of possible \"custom \
mix subspace\" is contained inside it.  We now check that the solution \
subspace is 3-dimensional, so they are actually equal.\
\>", "Text"],

Cell["\<\
Let's write the conditions as equations in unknowns c, w, s, g, f.
Eg. w = (1/6)(c+w+s+g+f) gives the homogeneous equation c-5w+s+g+f = 0, etc.
Thus, the \"solution subspace\" is the nullspace of this matrix:\
\>", "Text"],

Cell[CellGroupData[{

Cell["eq = {{1,-5,1,1,1},{1,1,-1,-1,1},{-2,1,1,1,-2}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-5\), "1", "1", "1"},
            {"1", "1", \(-1\), \(-1\), "1"},
            {\(-2\), "1", "1", "1", \(-2\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSpace[eq]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "0", "0", "0", "1"},
            {"2", "1", "0", "3", "0"},
            {"2", "1", "3", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
So these three \"mixes\" span a 3-dim subspace of all mixes that satisfy the \
conditions.  But every vector in SAL is in this nullspace, so the linear \
independent vectors in SAL span the subspace of all mixes that satisfy the \
conditions.\
\>", "Text"],

Cell["\<\
Comment:  Below, we directly show that SAL and the nullspace basis span the \
same space as in 4.1; 16.\
\>", "Text"],

Cell[CellGroupData[{

Cell["basis = Transpose[NullSpace[eq]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "2", "2"},
            {"0", "1", "1"},
            {"0", "0", "3"},
            {"0", "3", "0"},
            {"1", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearSolve[SAL,basis]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(1\/5\)\), \(17\/50\), \(-\(1\/50\)\)},
            {\(1\/10\), \(-\(8\/25\)\), \(4\/25\)},
            {\(1\/10\), \(2\/25\), \(-\(1\/25\)\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearSolve[basis,SAL]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "2", "8"},
            {\(10\/3\), \(5\/3\), "5"},
            {\(20\/3\), \(25\/3\), "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Extension:  Orthogonal subspaces give 2 equations for custom mixes.\
\>", "Subsection"],

Cell["\<\
It should be a little surprising that the three equations describe a \
3-dimensional subspace.  Three restrictions in a 5-dimensional space, usually \
only leave two free parameters in the solution subpace.  Using orthogonal \
complements, we can find two equations whose solution subspace equals the \
custom mix subspace.\
\>", "Text"],

Cell["\<\
The column space of SAL is a 3 dimensional subspace of R^5, spanned by the \
columns of SAL.  The complementary subspace is the NullSpace of SAL^T.  Let's \
find a basis for this complementary subspace.\
\>", "Text"],

Cell[CellGroupData[{

Cell["NTBasis = NullSpace[Transpose[SAL]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\), "0", "0", "1"},
            {"0", \(-3\), "1", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Thus any element of the column space is orthogonal to any element of this \
complementary subspace.  In particular, a vector is in the column space if \
and only if it is orthogonal to the two basis vectors above.  This describes \
the column space (all theoretical mixes) with two equations!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[c, \ w, \ s, \ g, \ f]\), 
    \(LogicalExpand[\ NTBasis.{c, \ w, \ s, \ g, \ f}\  == \ {0, 0}\ ]\)}], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm\`g + s - 3\ w == 0 \[And] c + f - 2\ w == 0\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 4.2; 6  Row and Null Space Geometry (never used)", "Section"],

Cell["Needs[\"Graphics`Colors`\"]", "Input"],

Cell["\<\
arrow[{a_,b_},color___] := Graphics[
   {color, Line[{{0,0},{a,b}}],
    Line[{{a,b},.9{a,b}+.04{-b,a}}],
    Line[{{a,b},.9{a,b}-.04{-b,a}}]}
]\
\>", "Input"],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["A = {{2,-4},{-3,6}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", \(-4\)},
            {\(-3\), "6"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-2\)},
            {"0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["x = {1,-2}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSpace[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y = {2,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2, 1}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b)", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Show[arrow[x,Red],arrow[y,Green],
   AspectRatio->Automatic,
   Axes->True];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.988095 0.47619 [
[.2619 .9756 -9 -9 ]
[.2619 .9756 9 0 ]
[.5 .9756 -3 -9 ]
[.5 .9756 3 0 ]
[.7381 .9756 -9 -9 ]
[.7381 .9756 9 0 ]
[.97619 .9756 -3 -9 ]
[.97619 .9756 3 0 ]
[.01131 .03571 -12 -4.5 ]
[.01131 .03571 0 4.5 ]
[.01131 .27381 -24 -4.5 ]
[.01131 .27381 0 4.5 ]
[.01131 .5119 -12 -4.5 ]
[.01131 .5119 0 4.5 ]
[.01131 .75 -24 -4.5 ]
[.01131 .75 0 4.5 ]
[.01131 1.22619 -18 -4.5 ]
[.01131 1.22619 0 4.5 ]
[.01131 1.46429 -6 -4.5 ]
[.01131 1.46429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .9881 m
.2619 .99435 L
s
[(0.5)] .2619 .9756 0 1 Mshowa
.5 .9881 m
.5 .99435 L
s
[(1)] .5 .9756 0 1 Mshowa
.7381 .9881 m
.7381 .99435 L
s
[(1.5)] .7381 .9756 0 1 Mshowa
.97619 .9881 m
.97619 .99435 L
s
[(2)] .97619 .9756 0 1 Mshowa
.125 Mabswid
.07143 .9881 m
.07143 .99185 L
s
.11905 .9881 m
.11905 .99185 L
s
.16667 .9881 m
.16667 .99185 L
s
.21429 .9881 m
.21429 .99185 L
s
.30952 .9881 m
.30952 .99185 L
s
.35714 .9881 m
.35714 .99185 L
s
.40476 .9881 m
.40476 .99185 L
s
.45238 .9881 m
.45238 .99185 L
s
.54762 .9881 m
.54762 .99185 L
s
.59524 .9881 m
.59524 .99185 L
s
.64286 .9881 m
.64286 .99185 L
s
.69048 .9881 m
.69048 .99185 L
s
.78571 .9881 m
.78571 .99185 L
s
.83333 .9881 m
.83333 .99185 L
s
.88095 .9881 m
.88095 .99185 L
s
.92857 .9881 m
.92857 .99185 L
s
.25 Mabswid
0 .9881 m
1 .9881 L
s
.02381 .03571 m
.03006 .03571 L
s
[(-2)] .01131 .03571 1 0 Mshowa
.02381 .27381 m
.03006 .27381 L
s
[(-1.5)] .01131 .27381 1 0 Mshowa
.02381 .5119 m
.03006 .5119 L
s
[(-1)] .01131 .5119 1 0 Mshowa
.02381 .75 m
.03006 .75 L
s
[(-0.5)] .01131 .75 1 0 Mshowa
.02381 1.22619 m
.03006 1.22619 L
s
[(0.5)] .01131 1.22619 1 0 Mshowa
.02381 1.46429 m
.03006 1.46429 L
s
[(1)] .01131 1.46429 1 0 Mshowa
.125 Mabswid
.02381 .08333 m
.02756 .08333 L
s
.02381 .13095 m
.02756 .13095 L
s
.02381 .17857 m
.02756 .17857 L
s
.02381 .22619 m
.02756 .22619 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .36905 m
.02756 .36905 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .46429 m
.02756 .46429 L
s
.02381 .55952 m
.02756 .55952 L
s
.02381 .60714 m
.02756 .60714 L
s
.02381 .65476 m
.02756 .65476 L
s
.02381 .70238 m
.02756 .70238 L
s
.02381 .79762 m
.02756 .79762 L
s
.02381 .84524 m
.02756 .84524 L
s
.02381 .89286 m
.02756 .89286 L
s
.02381 .94048 m
.02756 .94048 L
s
.02381 1.03571 m
.02756 1.03571 L
s
.02381 1.08333 m
.02756 1.08333 L
s
.02381 1.13095 m
.02756 1.13095 L
s
.02381 1.17857 m
.02756 1.17857 L
s
.02381 1.27381 m
.02756 1.27381 L
s
.02381 1.32143 m
.02756 1.32143 L
s
.02381 1.36905 m
.02756 1.36905 L
s
.02381 1.41667 m
.02756 1.41667 L
s
.25 Mabswid
.02381 0 m
.02381 1.5 L
s
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .9881 m
.5 .03571 L
s
.5 .03571 m
.49048 .15 L
s
.5 .03571 m
.41429 .1119 L
s
0 1 0 r
.02381 .9881 m
.97619 1.46429 L
s
.97619 1.46429 m
.8619 1.45476 L
s
.97619 1.46429 m
.9 1.37857 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{192, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400030000182000`400?l00000o`00003o`03oool0
0<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03o
ool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo000J0?ooo`03
0000003oool0oooo0:<0oooo000J0?ooo`030000003oool0oooo0:<0oooo000J0?ooo`030000003o
ool0oooo0:<0oooo000J0?ooo`030000003oool0oooo0:<0oooo000D0?ooo`<000000`3oool00`00
0000oooo0?ooo`2S0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:<0
oooo000?0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`800000CP3oool00`3o0000oooo
0?ooo`1C0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04`0oooo0P3o
001E0?ooo`00503oool00`000000oooo000000030?ooo`030000003oool0oooo04/0oooo0`3o001E
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo00@0o`000?oo
o`3o0000o`00E@3oool001X0oooo00<000000?ooo`3oool0B@3oool01@3o0000oooo0?l0003oool0
o`0005D0oooo000J0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool00P3o001F0?oo
o`006P3oool00`000000oooo0?ooo`170?ooo`060?l0003oool0oooo0?l0003oool0o`00EP3oool0
01X0oooo00<000000?ooo`3oool0A@3oool20?l000<0oooo00<0o`000?ooo`3o0000EP3oool001X0
oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?l0
05H0oooo000J0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool00`3oool0103o0000
oooo0?ooo`3o001F0?ooo`006P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo00<0
oooo00D0o`000?ooo`3oool0oooo0?l0001F0?ooo`006P3oool00`000000oooo0?ooo`110?ooo`03
0?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0001F0?ooo`006P3oool00`000000
oooo0?ooo`100?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`1D0?ooo`006P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1D0?ooo`006P3oool00`000000oooo0?oo
o`160?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0E03oool001X0oooo00<00000
0?ooo`3oool0AP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo05D0oooo000J0?oo
o`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1E0?oo
o`006P3oool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0E@3oool001X0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo05D0oooo000J0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`1E0?ooo`006P3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0E@3oool001X0oooo00<000000?ooo`3oool0@`3oool00`3o
0000oooo0?ooo`1M0?ooo`006P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo05h0
oooo000J0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0GP3oool001X0oooo00<0
00000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`1O0?ooo`006P3oool00`000000oooo0?ooo`11
0?ooo`030?l0003oool0oooo05l0oooo000J0?ooo`030000003oool0oooo0400oooo00<0o`000?oo
o`3oool0H03oool001X0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`1P0?ooo`00
6P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0640oooo000J0?ooo`030000003o
ool0oooo03l0oooo00<0o`000?ooo`3oool0H@3oool001X0oooo00<000000?ooo`3oool0?P3oool0
0`3o0000oooo0?ooo`1R0?ooo`006P3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo
0680oooo000J0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0H`3oool001X0oooo
00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`1S0?ooo`006P3oool00`000000oooo0?oo
o`0l0?ooo`030?l0003oool0oooo06@0oooo000J0?ooo`030000003oool0oooo03`0oooo00<0o`00
0?ooo`3oool0I03oool001X0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`1U0?oo
o`006P3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo06D0oooo000J0?ooo`030000
003oool0oooo03X0oooo00<0o`000?ooo`3oool0IP3oool000T0oooo1@0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030?l0003o
ool0oooo06H0oooo000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo06L0oooo00050?ooo`<000000`3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`800000>P3oool00`3o0000oooo0?ooo`1W
0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo06P0oooo000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo06P0oooo000:0?ooo`800000
203oool3000000<0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`1Y0?ooo`006P3o
ool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo06T0oooo000J0?ooo`030000003oool0
oooo03H0oooo00<0o`000?ooo`3oool0JP3oool001X0oooo00<000000?ooo`3oool0=P3oool00`3o
0000oooo0?ooo`1Z0?ooo`006P3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo06/0
oooo000J0?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0J`3oool001X0oooo00<0
00000?ooo`3oool0=03oool00`3o0000oooo0?ooo`1/0?ooo`006P3oool00`000000oooo0?ooo`0d
0?ooo`030?l0003oool0oooo06`0oooo000J0?ooo`030000003oool0oooo03<0oooo00<0o`000?oo
o`3oool0K@3oool001X0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`1]0?ooo`00
6P3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo06h0oooo000J0?ooo`030000003o
ool0oooo0380oooo00<0o`000?ooo`3oool0KP3oool001X0oooo00<000000?ooo`3oool0<@3oool0
0`3o0000oooo0?ooo`1_0?ooo`006P3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo
06l0oooo000J0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool0L03oool001X0oooo
00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`1`0?ooo`006P3oool00`000000oooo0?oo
o`0_0?ooo`030?l0003oool0oooo0740oooo000J0?ooo`030000003oool0oooo02l0oooo00<0o`00
0?ooo`3oool0L@3oool001X0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`1b0?oo
o`006P3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0780oooo000J0?ooo`030000
003oool0oooo02d0oooo00<0o`000?ooo`3oool0L`3oool001X0oooo00<000000?ooo`3oool0;@3o
ool00`3o0000oooo0?ooo`1c0?ooo`006P3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0
oooo07@0oooo000J0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0M03oool001X0
oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`1e0?ooo`006P3oool00`000000oooo
0?ooo`0[0?ooo`030?l0003oool0oooo07D0oooo000J0?ooo`030000003oool0oooo02X0oooo00<0
o`000?ooo`3oool0MP3oool001X0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`1f
0?ooo`006P3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo07L0oooo000J0?ooo`03
0000003oool0oooo02T0oooo00<0o`000?ooo`3oool0M`3oool001X0oooo00<000000?ooo`3oool0
:03oool00`3o0000oooo0?ooo`1h0?ooo`006P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003o
ool0oooo07P0oooo000J0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0N@3oool0
01X0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`1i0?ooo`006P3oool00`000000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo07X0oooo000C0?ooo`D000000P3oool00`000000oooo
0?ooo`0V0?ooo`030?l0003oool0oooo07X0oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1k0?ooo`003`3oool3000000<0oooo00<00000
0?ooo`3oool00P3oool2000002H0oooo00<0o`000?ooo`3oool0N`3oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo07`0oooo000E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`1l0?ooo`00
503oool2000000@0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`1m0?ooo`006P3o
ool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo07d0oooo000J0?ooo`030000003oool0
oooo0280oooo00<0o`000?ooo`3oool0OP3oool001X0oooo00<000000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`1n0?ooo`006P3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo07l0
oooo000J0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0O`3oool001X0oooo00<0
00000?ooo`3oool0803oool00`3o0000oooo0?ooo`200?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`030?l0003oool0oooo0800oooo000J0?ooo`030000003oool0oooo01l0oooo00<0o`000?oo
o`3oool0P@3oool001X0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`210?ooo`00
6P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0880oooo000J0?ooo`030000003o
ool0oooo01h0oooo00<0o`000?ooo`3oool0PP3oool001X0oooo00<000000?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`230?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo
08<0oooo000J0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0Q03oool001X0oooo
00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`240?ooo`006P3oool00`000000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo08D0oooo000J0?ooo`030000003oool0oooo01/0oooo00<0o`00
0?ooo`3oool0Q@3oool001X0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`260?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo08H0oooo000J0?ooo`030000
003oool0oooo01T0oooo00<0o`000?ooo`3oool0Q`3oool001X0oooo00<000000?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`270?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0
oooo08P0oooo000J0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0R03oool001X0
oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`290?ooo`006P3oool00`000000oooo
0?ooo`0G0?ooo`030?l0003oool0oooo08T0oooo000J0?ooo`030000003oool0oooo01H0oooo00<0
o`000?ooo`3oool0RP3oool001X0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`2:
0?ooo`006P3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo08/0oooo000J0?ooo`03
0000003oool0oooo01D0oooo00<0o`000?ooo`3oool0R`3oool001X0oooo00<000000?ooo`3oool0
503oool00`3o0000oooo0?ooo`2<0?ooo`006P3oool00`000000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo08`0oooo000J0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0S@3oool0
01X0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`2=0?ooo`006P3oool00`000000
oooo0?ooo`0B0?ooo`030?l0003oool0oooo08h0oooo000;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo
00<0o`000?ooo`3oool0SP3oool000X0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0S`3oool000D0oooo0`000002
0?ooo`030000003oool0000000T0oooo00@000000?ooo`3oool0oooo0P00000B0?ooo`030?l0003o
ool0oooo08l0oooo000:0?ooo`030000003oool0000000L0oooo0P0000040?ooo`030000003oool0
oooo0100oooo00<0o`000?ooo`3oool0T03oool000X0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool0T03oool000/0
oooo00<000000?ooo`3oool01P3oool3000000<0oooo00<000000?ooo`3oool03`3oool00`3o0000
oooo0?ooo`2A0?ooo`006P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0940oooo
000J0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0TP3oool001X0oooo00<00000
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`2B0?ooo`006P3oool00`000000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo09<0oooo000J0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3o
ool0T`3oool001X0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`2D0?ooo`006P3o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo09@0oooo000J0?ooo`030000003oool0
oooo00/0oooo00<0o`000?ooo`3oool0U@3oool001X0oooo00<000000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`2E0?ooo`006P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo09H0
oooo000J0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0UP3oool001X0oooo00<0
00000?ooo`3oool02@3oool00`3o0000oooo0?ooo`2G0?ooo`006P3oool00`000000oooo0?ooo`09
0?ooo`030?l0003oool0oooo09L0oooo000J0?ooo`030000003oool0oooo00P0oooo00<0o`000?oo
o`3oool0V03oool001X0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`2H0?ooo`00
6P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo09T0oooo000J0?ooo`030000003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0V@3oool001X0oooo00<000000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`2J0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo
09X0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0V`3oool001X0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2K0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo09`0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0W03oool001X0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2M0?oo
o`006P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo09d0oooo000J0?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool0WP3oool001X0oooo00<000000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0O0?ooo`D000007P3oool500000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0O0?ooo`<00000103oool001X0oooo00D000000?ooo`3oool0oooo0?l0
000L0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000008P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`040?ooo`006P3oool01@000000oooo0?ooo`3oool0o`0001`0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo000J0?ooo`040000003oool0
oooo0?l001d0oooo00<000000?ooo`0000001`3oool2000002<0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`060?ooo`8000008P3oool00`000000oooo0?ooo`030?ooo`006P3oool0
10000000oooo0?ooo`3o000M0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo000000040?ooo`006P3oool00`000000oooo0?l0000O0?ooo`030000003oool0
oooo00H0oooo0`00000Q0?ooo`8000008@3oool2000000P0oooo0`00000Q0?ooo`030000003oool0
oooo00<0oooo000J0?ooo`030000003oool0o`000:<0oooo000J0?ooo`030000003o0000oooo0:<0
oooo000J0?ooo`030000003o0000oooo0:<0oooo000J0?ooo`030?l0003oool0oooo0:<0oooo000F
0?ooo`@0000000<00?l0000000000000X`00000001X0oooo00<00000003o0000o`001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo000J0?ooo`030000003oool0oooo0080
0?l0X@3oool001X0oooo00<000000?ooo`3oool00P3oool2003o09l0oooo000J0?ooo`030000003o
ool0oooo00@0oooo0P00o`2M0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`800?l0V`3oool0
01X0oooo00<000000?ooo`3oool0203oool2003o09T0oooo000J0?ooo`030000003oool0oooo00X0
oooo0P00o`2G0?ooo`006P3oool00`000000oooo0?ooo`0<0?ooo`800?l0U@3oool001X0oooo00<0
00000?ooo`3oool03P3oool2003o09<0oooo000J0?ooo`030000003oool0oooo0100oooo0P00o`2A
0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`800?l0S`3oool001X0oooo00<000000?ooo`3o
ool0503oool2003o08d0oooo000J0?ooo`030000003oool0oooo01H0oooo0P00o`2;0?ooo`006P3o
ool00`000000oooo0?ooo`0H0?ooo`800?l0R@3oool001X0oooo00<000000?ooo`3oool06P3oool2
003o08L0oooo000J0?ooo`030000003oool0oooo01`0oooo0P00o`250?ooo`006P3oool00`000000
oooo0?ooo`0N0?ooo`800?l0P`3oool001X0oooo00<000000?ooo`3oool0803oool2003o0840oooo
000J0?ooo`030000003oool0oooo0280oooo0P00o`1o0?ooo`006P3oool00`000000oooo0?ooo`0T
0?ooo`800?l0O@3oool001X0oooo00<000000?ooo`3oool09P3oool2003o07/0oooo000J0?ooo`03
0000003oool0oooo02P0oooo0P00o`1i0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`800?l0
M`3oool001X0oooo00<000000?ooo`3oool0;03oool2003o07D0oooo000J0?ooo`030000003oool0
oooo02h0oooo0P00o`1c0?ooo`006P3oool00`000000oooo0?ooo`0`0?ooo`800?l0L@3oool001X0
oooo00<000000?ooo`3oool0<P3oool2003o06l0oooo000J0?ooo`030000003oool0oooo03@0oooo
0P00o`1]0?ooo`006P3oool00`000000oooo0?ooo`0f0?ooo`800?l0J`3oool001X0oooo00<00000
0?ooo`3oool0>03oool2003o06T0oooo000J0?ooo`030000003oool0oooo03X0oooo0P00o`1W0?oo
o`006P3oool00`000000oooo0?ooo`0l0?ooo`800?l0I@3oool001X0oooo00<000000?ooo`3oool0
?P3oool2003o06<0oooo000J0?ooo`030000003oool0oooo0400oooo0P00o`1Q0?ooo`006P3oool0
0`000000oooo0?ooo`120?ooo`800?l0G`3oool001X0oooo00<000000?ooo`3oool0A03oool2003o
05d0oooo000J0?ooo`030000003oool0oooo04H0oooo0P00o`1K0?ooo`002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`180?ooo`800?l0F@3oool000X0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo04X0oooo0P00o`1G0?ooo`002P3oool00`000000oooo00000009
0?ooo`040000003oool0oooo0?ooo`800000C@3oool00`00o`00oooo0?ooo`1D0?ooo`002P3oool0
0`000000oooo000000070?ooo`800000103oool00`000000oooo0?ooo`1=0?ooo`800?l0E03oool0
00X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04l0oooo0P00o`1B0?ooo`002`3oool00`000000oooo0?ooo`060?ooo`<000000`3oool00`000000
oooo0?ooo`1A0?ooo`800?l0D03oool001X0oooo00<000000?ooo`3oool0D`3oool2003o04h0oooo
000J0?ooo`030000003oool0oooo05D0oooo0P00o`1<0?ooo`006P3oool00`000000oooo0?ooo`1G
0?ooo`800?l0BP3oool001X0oooo00<000000?ooo`3oool0F@3oool2003o04P0oooo000J0?ooo`03
0000003oool0oooo05/0oooo0P00o`160?ooo`006P3oool00`000000oooo0?ooo`1M0?ooo`800?l0
A03oool001X0oooo00<000000?ooo`3oool0G`3oool2003o0480oooo000J0?ooo`030000003oool0
oooo0640oooo0P00o`100?ooo`006P3oool00`000000oooo0?ooo`1S0?ooo`800?l0?P3oool001X0
oooo00<000000?ooo`3oool0I@3oool2003o03`0oooo000J0?ooo`030000003oool0oooo06L0oooo
0P00o`0j0?ooo`006P3oool00`000000oooo0?ooo`1Y0?ooo`800?l0>03oool001X0oooo00<00000
0?ooo`3oool0J`3oool2003o03H0oooo000J0?ooo`030000003oool0oooo06d0oooo0P00o`0d0?oo
o`006P3oool00`000000oooo0?ooo`1_0?ooo`800?l0<P3oool001X0oooo00<000000?ooo`3oool0
L@3oool2003o0300oooo000J0?ooo`030000003oool0oooo07<0oooo0P00o`0^0?ooo`006P3oool0
0`000000oooo0?ooo`1e0?ooo`800?l0;03oool001X0oooo00<000000?ooo`3oool0M`3oool2003o
02X0oooo000J0?ooo`030000003oool0oooo07T0oooo0P00o`0X0?ooo`006P3oool00`000000oooo
0?ooo`1k0?ooo`800?l09P3oool001X0oooo00<000000?ooo`3oool0O@3oool2003o02@0oooo000J
0?ooo`030000003oool0oooo07l0oooo0P00o`0@0?ooo`03003o003oool0oooo00l0oooo000J0?oo
o`030000003oool0oooo0840oooo0P00o`0?0?ooo`03003o003oool0oooo00h0oooo000J0?ooo`03
0000003oool0oooo08<0oooo0P00o`0>0?ooo`03003o003oool0oooo00d0oooo000J0?ooo`030000
003oool0oooo08D0oooo0P00o`0<0?ooo`03003o003oool0oooo00d0oooo000J0?ooo`030000003o
ool0oooo08L0oooo0P00o`0;0?ooo`03003o003oool0oooo00`0oooo000J0?ooo`030000003oool0
oooo08T0oooo0P00o`0:0?ooo`03003o003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo
08/0oooo0P00o`090?ooo`03003o003oool0oooo00X0oooo000J0?ooo`030000003oool0oooo08d0
oooo0P00o`080?ooo`03003o003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo08l0oooo
0P00o`060?ooo`03003o003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0940oooo0P00
o`050?ooo`03003o003oool0oooo00P0oooo000J0?ooo`030000003oool0oooo09<0oooo0P00o`04
0?ooo`03003o003oool0oooo00L0oooo000J0?ooo`030000003oool0oooo09D0oooo0P00o`030?oo
o`03003o003oool0oooo00H0oooo000J0?ooo`030000003oool0oooo09L0oooo0P00o`020?ooo`03
003o003oool0oooo00D0oooo000C0?ooo`D000000P3oool00`000000oooo0?ooo`2:0?ooo`D00?l0
2P3oool3003o00L0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S`3o
ool:003o0080oooo0P00o`060?ooo`005@3oool00`000000oooo0?ooo`020?ooo`800000VP3oool5
003o00D0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0X`3oool001D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2S0?ooo`00503oool2000000@0oooo
00<000000?ooo`3oool0X`3oool001X0oooo00<000000?ooo`3oool0X`3oool001X0oooo00<00000
0?ooo`3oool0X`3oool001X0oooo00<000000?ooo`3oool0X`3oool00<00oooo00300?ooo`00`03o
ool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00
`03oool00<00oooo00300?ooo`00`03oool00<00oooo0000\
\>"],
  ImageRangeCache->{{{0, 191}, {287, 0}} -> {-0.324646, -2.2841, 0.0124328, 
  0.0124328}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(c)", "Subsection"],

Cell[CellGroupData[{

Cell["A = {{-1,3},{4,-12}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "3"},
            {"4", \(-12\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-3\)},
            {"0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["x = {1,-3}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-3\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSpace[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y = {3,1}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[arrow[x,Red],arrow[y,Green],
   AspectRatio->Automatic,
   Axes->True];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.34 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.984286 0.31746 [
[.18254 .97179 -9 -9 ]
[.18254 .97179 9 0 ]
[.34127 .97179 -3 -9 ]
[.34127 .97179 3 0 ]
[.5 .97179 -9 -9 ]
[.5 .97179 9 0 ]
[.65873 .97179 -3 -9 ]
[.65873 .97179 3 0 ]
[.81746 .97179 -9 -9 ]
[.81746 .97179 9 0 ]
[.97619 .97179 -3 -9 ]
[.97619 .97179 3 0 ]
[.01131 .0319 -12 -4.5 ]
[.01131 .0319 0 4.5 ]
[.01131 .34937 -12 -4.5 ]
[.01131 .34937 0 4.5 ]
[.01131 .66683 -12 -4.5 ]
[.01131 .66683 0 4.5 ]
[.01131 1.30175 -6 -4.5 ]
[.01131 1.30175 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.34 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .98429 m
.18254 .99054 L
s
[(0.5)] .18254 .97179 0 1 Mshowa
.34127 .98429 m
.34127 .99054 L
s
[(1)] .34127 .97179 0 1 Mshowa
.5 .98429 m
.5 .99054 L
s
[(1.5)] .5 .97179 0 1 Mshowa
.65873 .98429 m
.65873 .99054 L
s
[(2)] .65873 .97179 0 1 Mshowa
.81746 .98429 m
.81746 .99054 L
s
[(2.5)] .81746 .97179 0 1 Mshowa
.97619 .98429 m
.97619 .99054 L
s
[(3)] .97619 .97179 0 1 Mshowa
.125 Mabswid
.05556 .98429 m
.05556 .98804 L
s
.0873 .98429 m
.0873 .98804 L
s
.11905 .98429 m
.11905 .98804 L
s
.15079 .98429 m
.15079 .98804 L
s
.21429 .98429 m
.21429 .98804 L
s
.24603 .98429 m
.24603 .98804 L
s
.27778 .98429 m
.27778 .98804 L
s
.30952 .98429 m
.30952 .98804 L
s
.37302 .98429 m
.37302 .98804 L
s
.40476 .98429 m
.40476 .98804 L
s
.43651 .98429 m
.43651 .98804 L
s
.46825 .98429 m
.46825 .98804 L
s
.53175 .98429 m
.53175 .98804 L
s
.56349 .98429 m
.56349 .98804 L
s
.59524 .98429 m
.59524 .98804 L
s
.62698 .98429 m
.62698 .98804 L
s
.69048 .98429 m
.69048 .98804 L
s
.72222 .98429 m
.72222 .98804 L
s
.75397 .98429 m
.75397 .98804 L
s
.78571 .98429 m
.78571 .98804 L
s
.84921 .98429 m
.84921 .98804 L
s
.88095 .98429 m
.88095 .98804 L
s
.9127 .98429 m
.9127 .98804 L
s
.94444 .98429 m
.94444 .98804 L
s
.25 Mabswid
0 .98429 m
1 .98429 L
s
.02381 .0319 m
.03006 .0319 L
s
[(-3)] .01131 .0319 1 0 Mshowa
.02381 .34937 m
.03006 .34937 L
s
[(-2)] .01131 .34937 1 0 Mshowa
.02381 .66683 m
.03006 .66683 L
s
[(-1)] .01131 .66683 1 0 Mshowa
.02381 1.30175 m
.03006 1.30175 L
s
[(1)] .01131 1.30175 1 0 Mshowa
.125 Mabswid
.02381 .0954 m
.02756 .0954 L
s
.02381 .15889 m
.02756 .15889 L
s
.02381 .22238 m
.02756 .22238 L
s
.02381 .28587 m
.02756 .28587 L
s
.02381 .41286 m
.02756 .41286 L
s
.02381 .47635 m
.02756 .47635 L
s
.02381 .53984 m
.02756 .53984 L
s
.02381 .60333 m
.02756 .60333 L
s
.02381 .73032 m
.02756 .73032 L
s
.02381 .79381 m
.02756 .79381 L
s
.02381 .8573 m
.02756 .8573 L
s
.02381 .92079 m
.02756 .92079 L
s
.02381 1.04778 m
.02756 1.04778 L
s
.02381 1.11127 m
.02756 1.11127 L
s
.02381 1.17476 m
.02756 1.17476 L
s
.02381 1.23825 m
.02756 1.23825 L
s
.25 Mabswid
.02381 0 m
.02381 1.34 L
s
0 0 m
1 0 L
1 1.34 L
0 1.34 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .98429 m
.34127 .0319 L
s
.34127 .0319 m
.34762 .13984 L
s
.34127 .0319 m
.27143 .11444 L
s
0 1 0 r
.02381 .98429 m
.97619 1.30175 L
s
.97619 1.30175 m
.86825 1.3081 L
s
.97619 1.30175 m
.89365 1.2319 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{214.875, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003F000182000`400?l00000o`00003oeP3oool0
0=H0oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00eP3oool000h0oooo00<000000?ooo`3o
ool0a@3oool000h0oooo00<000000?ooo`3oool0a@3oool000h0oooo00<000000?ooo`3oool0a@3o
ool000h0oooo00<000000?ooo`3oool0a@3oool000h0oooo00<000000?ooo`3oool0a@3oool000P0
oooo0P0000040?ooo`030000003oool0oooo0<D0oooo000:0?ooo`050000003oool0oooo0?ooo`00
0000a`3oool000<0oooo0`0000030?ooo`030000003oool0oooo0080oooo0P00000o0?ooo`030?l0
003oool0oooo08@0oooo000:0?ooo`050000003oool0oooo0?ooo`000000?`3oool20?l008H0oooo
00080?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0?03oool30?l008H0oooo0009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool30?l008H0oooo000>0?oo
o`030000003oool0oooo03/0oooo00@0o`000?ooo`3o0000o`00QP3oool000h0oooo00<000000?oo
o`3oool0>P3oool01@3o0000oooo0?l0003oool0o`0008H0oooo000>0?ooo`030000003oool0oooo
03T0oooo00H0o`000?ooo`3oool0o`000?ooo`3o00260?ooo`003P3oool00`000000oooo0?ooo`0h
0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l000260?ooo`003P3oool00`000000oooo0?oo
o`0g0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`240?ooo`003P3o
ool00`000000oooo0?ooo`0g0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo
0?ooo`240?ooo`003P3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0080oooo00@0
o`000?ooo`3oool0o`00QP3oool000h0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o0000QP3oool000h0oooo00<000000?ooo`3oool0=03o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0P`3o
ool000h0oooo0P00000d0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`230?ooo`003P3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`230?ooo`003P3oool00`000000
oooo0?ooo`0b0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`230?ooo`003P3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`230?ooo`003P3oool00`000000oooo0?oo
o`0`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`230?ooo`003P3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0P`3oool000h0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo08<0oooo000>0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`230?ooo`003P3oool00`000000oooo0?ooo`0g0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0P`3oool000h0oooo00<000000?ooo`3oool0=`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo08<0oooo000>0?ooo`030000003oool0
oooo03H0oooo00<0o`000?ooo`3oool0S03oool000h0oooo00<000000?ooo`3oool0=P3oool00`3o
0000oooo0?ooo`2<0?ooo`003P3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo08`0
oooo000>0?ooo`800000=P3oool00`3o0000oooo0?ooo`2=0?ooo`003P3oool00`000000oooo0?oo
o`0e0?ooo`030?l0003oool0oooo08d0oooo000>0?ooo`030000003oool0oooo03D0oooo00<0o`00
0?ooo`3oool0S@3oool000h0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`2>0?oo
o`003P3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo08h0oooo000>0?ooo`030000
003oool0oooo03@0oooo00<0o`000?ooo`3oool0SP3oool000h0oooo00<000000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`2?0?ooo`003P3oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0
oooo08l0oooo000>0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0S`3oool000h0
oooo00<000000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`2@0?ooo`003P3oool00`000000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo0900oooo000>0?ooo`030000003oool0oooo0380oooo00<0
o`000?ooo`3oool0T03oool000h0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`2A
0?ooo`003P3oool200000380oooo00<0o`000?ooo`3oool0T@3oool000h0oooo00<000000?ooo`3o
ool0<@3oool00`3o0000oooo0?ooo`2A0?ooo`003P3oool00`000000oooo0?ooo`0`0?ooo`030?l0
003oool0oooo0980oooo000>0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool0TP3o
ool000h0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`2B0?ooo`003P3oool00`00
0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo09<0oooo000>0?ooo`030000003oool0oooo02l0
oooo00<0o`000?ooo`3oool0T`3oool000h0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`2C0?ooo`003P3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo09@0oooo000>
0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0U03oool000h0oooo00<000000?oo
o`3oool0;P3oool00`3o0000oooo0?ooo`2D0?ooo`003P3oool00`000000oooo0?ooo`0]0?ooo`03
0?l0003oool0oooo09D0oooo000>0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0
U@3oool000h0oooo0P00000^0?ooo`030?l0003oool0oooo09D0oooo000>0?ooo`030000003oool0
oooo02`0oooo00<0o`000?ooo`3oool0UP3oool000h0oooo00<000000?ooo`3oool0;03oool00`3o
0000oooo0?ooo`2F0?ooo`003P3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo09H0
oooo000>0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0U`3oool000h0oooo00<0
00000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`2G0?ooo`003P3oool00`000000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo09L0oooo000>0?ooo`030000003oool0oooo02X0oooo00<0o`000?oo
o`3oool0V03oool000h0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`2H0?ooo`00
3P3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo09P0oooo000>0?ooo`030000003o
ool0oooo02T0oooo00<0o`000?ooo`3oool0V@3oool000P0oooo0`0000030?ooo`030000003oool0
oooo02T0oooo00<0o`000?ooo`3oool0V@3oool000P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo09T0oooo00030?ooo`<000000`3oool00`000000
oooo0?ooo`020?ooo`800000:@3oool00`3o0000oooo0?ooo`2J0?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0VP3oool000P0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo09X0oooo0009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`2K
0?ooo`003P3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo09/0oooo000>0?ooo`03
0000003oool0oooo02L0oooo00<0o`000?ooo`3oool0V`3oool000h0oooo00<000000?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`2L0?ooo`003P3oool00`000000oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo09`0oooo000>0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0W03oool0
00h0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`2M0?ooo`003P3oool00`000000
oooo0?ooo`0U0?ooo`030?l0003oool0oooo09d0oooo000>0?ooo`030000003oool0oooo02D0oooo
00<0o`000?ooo`3oool0W@3oool000h0oooo0P00000U0?ooo`030?l0003oool0oooo09h0oooo000>
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0WP3oool000h0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`2N0?ooo`003P3oool00`000000oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo09l0oooo000>0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
W`3oool000h0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`2O0?ooo`003P3oool0
0`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0:00oooo000>0?ooo`030000003oool0oooo
0280oooo00<0o`000?ooo`3oool0X03oool000h0oooo00<000000?ooo`3oool08P3oool00`3o0000
oooo0?ooo`2P0?ooo`003P3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0:40oooo
000>0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0X@3oool000h0oooo00<00000
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`2Q0?ooo`003P3oool00`000000oooo0?ooo`0P0?oo
o`030?l0003oool0oooo0:80oooo000>0?ooo`8000008@3oool00`3o0000oooo0?ooo`2R0?ooo`00
3P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0:80oooo000>0?ooo`030000003o
ool0oooo01l0oooo00<0o`000?ooo`3oool0X`3oool000h0oooo00<000000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`2S0?ooo`003P3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
0:<0oooo000>0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0Y03oool000h0oooo
00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`2T0?ooo`003P3oool00`000000oooo0?oo
o`0M0?ooo`030?l0003oool0oooo0:D0oooo000>0?ooo`030000003oool0oooo01d0oooo00<0o`00
0?ooo`3oool0Y@3oool000h0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`2U0?oo
o`003P3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0:H0oooo000>0?ooo`030000
003oool0oooo01`0oooo00<0o`000?ooo`3oool0YP3oool000h0oooo00<000000?ooo`3oool0703o
ool00`3o0000oooo0?ooo`2V0?ooo`003P3oool2000001`0oooo00<0o`000?ooo`3oool0Y`3oool0
00h0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`2W0?ooo`003P3oool00`000000
oooo0?ooo`0K0?ooo`030?l0003oool0oooo0:L0oooo000>0?ooo`030000003oool0oooo01X0oooo
00<0o`000?ooo`3oool0Z03oool000h0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?oo
o`2X0?ooo`003P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0:P0oooo000>0?oo
o`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0Z@3oool000h0oooo00<000000?ooo`3o
ool06@3oool00`3o0000oooo0?ooo`2Y0?ooo`003P3oool00`000000oooo0?ooo`0I0?ooo`030?l0
003oool0oooo0:T0oooo000>0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0ZP3o
ool000h0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`2Z0?ooo`003P3oool00`00
0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0:X0oooo000>0?ooo`030000003oool0oooo01L0
oooo00<0o`000?ooo`3oool0Z`3oool000h0oooo0P00000H0?ooo`030?l0003oool0oooo0:/0oooo
000>0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0Z`3oool000h0oooo00<00000
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`2/0?ooo`003P3oool00`000000oooo0?ooo`0F0?oo
o`030?l0003oool0oooo0:`0oooo000>0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3o
ool0[03oool000h0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`2]0?ooo`003P3o
ool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0:d0oooo000>0?ooo`030000003oool0
oooo01D0oooo00<0o`000?ooo`3oool0[@3oool000h0oooo00<000000?ooo`3oool0503oool00`3o
0000oooo0?ooo`2^0?ooo`003P3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0:h0
oooo000>0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0[P3oool000L0oooo1@00
00020?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0[`3oool000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0:l0oooo00030?oo
o`<000000`3oool00`000000oooo0?ooo`020?ooo`800000503oool00`3o0000oooo0?ooo`2_0?oo
o`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3o
ool0/03oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030?l0
003oool0oooo0;00oooo00080?ooo`800000103oool00`000000oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo0;00oooo000>0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0/@3oool0
00h0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`2a0?ooo`003P3oool00`000000
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0;40oooo000>0?ooo`030000003oool0oooo0100oooo
00<0o`000?ooo`3oool0/P3oool000h0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?oo
o`2b0?ooo`003P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0;80oooo000>0?oo
o`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0/`3oool000h0oooo00<000000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`2c0?ooo`003P3oool00`000000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0;<0oooo000>0?ooo`8000003`3oool00`3o0000oooo0?ooo`2d0?ooo`003P3oool0
0`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0;@0oooo000>0?ooo`030000003oool0oooo
00h0oooo00<0o`000?ooo`3oool0]03oool000h0oooo00<000000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`2e0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0;D0oooo
000>0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0]@3oool000h0oooo00<00000
0?ooo`3oool0303oool00`3o0000oooo0?ooo`2f0?ooo`003P3oool00`000000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0;H0oooo000>0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3o
ool0]P3oool000h0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`2g0?ooo`003P3o
ool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0;L0oooo000>0?ooo`030000003oool0
oooo00/0oooo00<0o`000?ooo`3oool0]`3oool000h0oooo00<000000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`2h0?ooo`003P3oool2000000/0oooo00<0o`000?ooo`3oool0^03oool000h0oooo
00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`2h0?ooo`003P3oool00`000000oooo0?oo
o`090?ooo`030?l0003oool0oooo0;T0oooo000>0?ooo`030000003oool0oooo00T0oooo00<0o`00
0?ooo`3oool0^@3oool000h0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`2i0?oo
o`003P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0;X0oooo000>0?ooo`030000
003oool0oooo00P0oooo00<0o`000?ooo`3oool0^P3oool000h0oooo00<000000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`2j0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0
oooo0;/0oooo000>0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0^`3oool000h0
oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`2k0?ooo`003P3oool00`000000oooo
0?ooo`060?ooo`030?l0003oool0oooo0;`0oooo000>0?ooo`030000003oool0oooo00H0oooo00<0
o`000?ooo`3oool0_03oool000h0oooo0P0000070?ooo`030?l0003oool0oooo0;`0oooo000>0?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0_@3oool000h0oooo00<000000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`2m0?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo0;d0oooo000>0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0_P3o
ool000h0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`2n0?ooo`003P3oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0;h0oooo000>0?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool0_`3oool000h0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`2o0?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0;l0oooo000>
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0`03oool000h0oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`300?ooo`003P3oool00`000000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0<00oooo000>0?ooo`8000000P3oool00`3o0000oooo0?ooo`310?ooo`003P3o
ool01@000000oooo0?ooo`3oool0o`000<<0oooo000>0?ooo`050000003oool0oooo0?ooo`3o0000
``3oool000h0oooo00@000000?ooo`3oool0o`005`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05P3oool5000001L0oooo1@0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3oool3000001T0oooo0`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3oool2000000D0oooo000>0?ooo`040000003o
ool0oooo0?l001H0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000H0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000J0?ooo`030000
003oool0oooo0080oooo000>0?ooo`040000003oool0oooo0?l001H0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo000>0?ooo`030000003o
ool0o`0001L0oooo00<000000?ooo`0000001`3oool2000001X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`8000006P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo0P00000K0?ooo`030000003oool0oooo0080oooo000>0?ooo`030000003oool0
o`0001L0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
000001T0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
000000@0oooo000>0?ooo`030000003oool0o`0001P0oooo00<000000?ooo`3oool01P3oool30000
01P0oooo0P00000J0?ooo`800000203oool3000001T0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`<000006@3oool00`000000oooo0?ooo`030?ooo`003P3oool00`000000
o`000?ooo`350?ooo`003P3oool00`000000o`000?ooo`350?ooo`003P3oool00`000000o`000?oo
o`350?ooo`003P3oool00`3o0000oooo0?ooo`350?ooo`002@3oool5000000800?l0aP00000000h0
oooo00<000000?ooo`00o`000P00o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`003P3oool00`000000oooo0?ooo`020?ooo`<00?l0
`03oool000h0oooo00<000000?ooo`3oool01@3oool3003o0;d0oooo000>0?ooo`030000003oool0
oooo00P0oooo0`00o`2j0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`<00?l0]`3oool000h0
oooo00<000000?ooo`3oool03P3oool3003o0;@0oooo000>0?ooo`030000003oool0oooo0140oooo
0`00o`2a0?ooo`003P3oool00`000000oooo0?ooo`0D0?ooo`<00?l0[P3oool000h0oooo00<00000
0?ooo`3oool05`3oool3003o0:/0oooo000>0?ooo`030000003oool0oooo01X0oooo0`00o`2X0?oo
o`003P3oool00`000000oooo0?ooo`0M0?ooo`<00?l0Y@3oool000h0oooo00<000000?ooo`3oool0
803oool3003o0:80oooo000>0?ooo`800000903oool3003o09l0oooo000>0?ooo`030000003oool0
oooo02H0oooo0`00o`2L0?ooo`003P3oool00`000000oooo0?ooo`0Y0?ooo`<00?l0V@3oool000h0
oooo00<000000?ooo`3oool0;03oool3003o09H0oooo000>0?ooo`030000003oool0oooo02l0oooo
0`00o`2C0?ooo`003P3oool00`000000oooo0?ooo`0b0?ooo`<00?l0T03oool000h0oooo00<00000
0?ooo`3oool0=@3oool3003o08d0oooo000>0?ooo`030000003oool0oooo03P0oooo0`00o`2:0?oo
o`003P3oool00`000000oooo0?ooo`0k0?ooo`<00?l0Q`3oool000h0oooo00<000000?ooo`3oool0
?P3oool3003o08@0oooo000>0?ooo`030000003oool0oooo0440oooo0`00o`210?ooo`003P3oool0
0`000000oooo0?ooo`140?ooo`<00?l0OP3oool000h0oooo00<000000?ooo`3oool0A`3oool3003o
07/0oooo000>0?ooo`800000B`3oool3003o07P0oooo000>0?ooo`030000003oool0oooo04d0oooo
0`00o`1e0?ooo`003P3oool00`000000oooo0?ooo`1@0?ooo`<00?l0LP3oool000h0oooo00<00000
0?ooo`3oool0D`3oool3003o06l0oooo000>0?ooo`030000003oool0oooo05H0oooo0`00o`1/0?oo
o`003P3oool00`000000oooo0?ooo`1I0?ooo`<00?l0J@3oool000h0oooo00<000000?ooo`3oool0
G03oool3003o06H0oooo000>0?ooo`030000003oool0oooo05l0oooo0`00o`1S0?ooo`003P3oool0
0`000000oooo0?ooo`1R0?ooo`<00?l0H03oool000h0oooo00<000000?ooo`3oool0I@3oool3003o
05d0oooo000>0?ooo`030000003oool0oooo06P0oooo0`00o`1J0?ooo`003P3oool00`000000oooo
0?ooo`1[0?ooo`<00?l0E`3oool000h0oooo00<000000?ooo`3oool0KP3oool3003o05@0oooo000>
0?ooo`800000LP3oool3003o0540oooo000>0?ooo`030000003oool0oooo07@0oooo0`00o`1>0?oo
o`003P3oool00`000000oooo0?ooo`1g0?ooo`<00?l0B`3oool000h0oooo00<000000?ooo`3oool0
NP3oool3003o04P0oooo000>0?ooo`030000003oool0oooo07d0oooo0`00o`150?ooo`003P3oool0
0`000000oooo0?ooo`200?ooo`<00?l0@P3oool000h0oooo00<000000?ooo`3oool0P`3oool3003o
03l0oooo000>0?ooo`030000003oool0oooo08H0oooo0`00o`0l0?ooo`003P3oool00`000000oooo
0?ooo`290?ooo`<00?l0>@3oool000h0oooo00<000000?ooo`3oool0S03oool3003o03H0oooo000>
0?ooo`030000003oool0oooo08l0oooo0`00o`0c0?ooo`003P3oool00`000000oooo0?ooo`2B0?oo
o`<00?l0<03oool000h0oooo00<000000?ooo`3oool0U@3oool3003o01L0oooo00<00?l00?ooo`3o
ool04`3oool000h0oooo0P00002I0?ooo`<00?l05@3oool00`00o`00oooo0?ooo`0B0?ooo`003P3o
ool00`000000oooo0?ooo`2K0?ooo`<00?l04`3oool2003o0180oooo000>0?ooo`030000003oool0
oooo09h0oooo0`00o`0B0?ooo`03003o003oool0oooo00l0oooo000>0?ooo`030000003oool0oooo
0:40oooo0`00o`0@0?ooo`03003o003oool0oooo00h0oooo000>0?ooo`030000003oool0oooo0:@0
oooo0`00o`0>0?ooo`03003o003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0:L0oooo
0`00o`0<0?ooo`03003o003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo0:X0oooo0`00
o`0:0?ooo`800?l0303oool000h0oooo00<000000?ooo`3oool0[@3oool3003o00T0oooo00<00?l0
0?ooo`3oool02@3oool000h0oooo00<000000?ooo`3oool0/03oool3003o00L0oooo00<00?l00?oo
o`3oool0203oool000h0oooo00<000000?ooo`3oool0/`3oool3003o00D0oooo00<00?l00?ooo`3o
ool01`3oool000h0oooo00<000000?ooo`3oool0]P3oool3003o00<0oooo00<00?l00?ooo`3oool0
1P3oool000L0oooo1@0000020?ooo`030000003oool0oooo0;T0oooo0`00o`000`3oool00?l0003o
00060?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;`0oooo1000o`05
0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`800000]P3oool<003o00@0oooo00090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0Z@3oool<003o0100oooo00090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0a@3oool000P0oooo0P0000040?ooo`030000003o
ool0oooo0<D0oooo000>0?ooo`030000003oool0oooo0<D0oooo000>0?ooo`030000003oool0oooo
0<D0oooo000>0?ooo`030000003oool0oooo0<D0oooo000>0?ooo`030000003oool0oooo0<D0oooo
000>0?ooo`030000003oool0oooo0<D0oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00eP3o
ool00=H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 213.875}, {287, 0}} -> {-0.224518, -3.20383, 
  0.0154274, 0.0154274}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell[CellGroupData[{

Cell["A = {{17,3},{34,6}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"17", "3"},
            {"34", "6"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(3\/17\)},
            {"0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["x = {1,3/17}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 3\/17}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSpace[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\), "17"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y = {-3,17}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-3\), 17}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[arrow[x,Red],arrow[y,Green],
   AspectRatio->Automatic,
   Axes->True];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.88128 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.758752 0.217439 0.0924114 0.217439 [
[.10644 .07991 -6 -9 ]
[.10644 .07991 6 0 ]
[.32387 .07991 -6 -9 ]
[.32387 .07991 6 0 ]
[.54131 .07991 -6 -9 ]
[.54131 .07991 6 0 ]
[.97619 .07991 -3 -9 ]
[.97619 .07991 3 0 ]
[.74625 .63601 -18 -4.5 ]
[.74625 .63601 0 4.5 ]
[.74625 1.1796 -6 -4.5 ]
[.74625 1.1796 0 4.5 ]
[.74625 1.7232 -18 -4.5 ]
[.74625 1.7232 0 4.5 ]
[.74625 2.2668 -12 -4.5 ]
[.74625 2.2668 0 4.5 ]
[.74625 2.81039 -24 -4.5 ]
[.74625 2.81039 0 4.5 ]
[.74625 3.35399 -12 -4.5 ]
[.74625 3.35399 0 4.5 ]
[ 0 0 0 0 ]
[ 1 3.88128 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.10644 .09241 m
.10644 .09866 L
s
[(-3)] .10644 .07991 0 1 Mshowa
.32387 .09241 m
.32387 .09866 L
s
[(-2)] .32387 .07991 0 1 Mshowa
.54131 .09241 m
.54131 .09866 L
s
[(-1)] .54131 .07991 0 1 Mshowa
.97619 .09241 m
.97619 .09866 L
s
[(1)] .97619 .07991 0 1 Mshowa
.125 Mabswid
.14992 .09241 m
.14992 .09616 L
s
.19341 .09241 m
.19341 .09616 L
s
.2369 .09241 m
.2369 .09616 L
s
.28039 .09241 m
.28039 .09616 L
s
.36736 .09241 m
.36736 .09616 L
s
.41085 .09241 m
.41085 .09616 L
s
.45434 .09241 m
.45434 .09616 L
s
.49783 .09241 m
.49783 .09616 L
s
.5848 .09241 m
.5848 .09616 L
s
.62829 .09241 m
.62829 .09616 L
s
.67178 .09241 m
.67178 .09616 L
s
.71526 .09241 m
.71526 .09616 L
s
.80224 .09241 m
.80224 .09616 L
s
.84573 .09241 m
.84573 .09616 L
s
.88922 .09241 m
.88922 .09616 L
s
.9327 .09241 m
.9327 .09616 L
s
.06295 .09241 m
.06295 .09616 L
s
.01946 .09241 m
.01946 .09616 L
s
.25 Mabswid
0 .09241 m
1 .09241 L
s
.75875 .63601 m
.765 .63601 L
s
[(2.5)] .74625 .63601 1 0 Mshowa
.75875 1.1796 m
.765 1.1796 L
s
[(5)] .74625 1.1796 1 0 Mshowa
.75875 1.7232 m
.765 1.7232 L
s
[(7.5)] .74625 1.7232 1 0 Mshowa
.75875 2.2668 m
.765 2.2668 L
s
[(10)] .74625 2.2668 1 0 Mshowa
.75875 2.81039 m
.765 2.81039 L
s
[(12.5)] .74625 2.81039 1 0 Mshowa
.75875 3.35399 m
.765 3.35399 L
s
[(15)] .74625 3.35399 1 0 Mshowa
.125 Mabswid
.75875 .20113 m
.7625 .20113 L
s
.75875 .30985 m
.7625 .30985 L
s
.75875 .41857 m
.7625 .41857 L
s
.75875 .52729 m
.7625 .52729 L
s
.75875 .74473 m
.7625 .74473 L
s
.75875 .85345 m
.7625 .85345 L
s
.75875 .96217 m
.7625 .96217 L
s
.75875 1.07088 m
.7625 1.07088 L
s
.75875 1.28832 m
.7625 1.28832 L
s
.75875 1.39704 m
.7625 1.39704 L
s
.75875 1.50576 m
.7625 1.50576 L
s
.75875 1.61448 m
.7625 1.61448 L
s
.75875 1.83192 m
.7625 1.83192 L
s
.75875 1.94064 m
.7625 1.94064 L
s
.75875 2.04936 m
.7625 2.04936 L
s
.75875 2.15808 m
.7625 2.15808 L
s
.75875 2.37552 m
.7625 2.37552 L
s
.75875 2.48424 m
.7625 2.48424 L
s
.75875 2.59295 m
.7625 2.59295 L
s
.75875 2.70167 m
.7625 2.70167 L
s
.75875 2.91911 m
.7625 2.91911 L
s
.75875 3.02783 m
.7625 3.02783 L
s
.75875 3.13655 m
.7625 3.13655 L
s
.75875 3.24527 m
.7625 3.24527 L
s
.75875 3.46271 m
.7625 3.46271 L
s
.75875 3.57143 m
.7625 3.57143 L
s
.75875 3.68015 m
.7625 3.68015 L
s
.75875 3.78887 m
.7625 3.78887 L
s
.25 Mabswid
.75875 0 m
.75875 3.88128 L
s
0 0 m
1 0 L
1 3.88128 L
0 3.88128 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.75875 .09241 m
.97619 .13078 L
s
.97619 .13078 m
.95291 .13564 L
s
.97619 .13078 m
.95598 .11825 L
s
0 1 0 r
.75875 .09241 m
.10644 3.78887 L
s
.10644 3.78887 m
.02381 3.39313 L
s
.10644 3.78887 m
.31953 3.44531 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{74.1875, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001:000182000`400?l00000o`00003oBP3oool0
04X0oooo001:0?ooo`00BP3oool000P0oooo0P00000>0?ooo`<000002`3oool5000001P0oooo1@00
00020?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`000`3oool3000000<0oooo00<000000?oo
o`3oool01`3oool3000000<0oooo00<000000?ooo`3oool01P3oool3000000<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00/0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`00=P3oool0
0`000000oooo0?ooo`0A0?ooo`00=P3oool00`000000oooo0?ooo`0A0?ooo`00=P3oool00`000000
oooo0?ooo`0A0?ooo`00=P0000001000o`00o`000?l0003o000>00000080oooo000f0?ooo`04003o
003oool0oooo0?ooo`P0o`00203oool003H0oooo00<00?l00?ooo`3oool02@3oool50?l000<0oooo
000e0?ooo`03003o00000000oooo00`0oooo0P3o00040?ooo`00=@3oool00`00o`0000000?ooo`0B
0?ooo`00=@3oool00`00o`0000000?ooo`0B0?ooo`00=@3oool00`00o`0000000?ooo`0B0?ooo`00
=@3oool00`00o`0000000?ooo`0B0?ooo`00=@3oool00`00o`0000000?ooo`0B0?ooo`00=03oool0
0`00o`00oooo0000000C0?ooo`00=03oool00`00o`00oooo0000000C0?ooo`00=03oool00`00o`00
oooo0000000C0?ooo`00=03oool00`00o`00oooo0000000C0?ooo`00=03oool00`00o`00oooo0000
000C0?ooo`00=03oool00`00o`00oooo0000000C0?ooo`00<`3oool01000o`00oooo0?ooo`00000C
0?ooo`00<`3oool01000o`00oooo0?ooo`00000C0?ooo`00<`3oool01000o`00oooo0?ooo`00000C
0?ooo`00<`3oool01000o`00oooo0?ooo`00000C0?ooo`00<`3oool01000o`00oooo0?ooo`00000C
0?ooo`00<P3oool01@00o`00oooo0?ooo`3oool0000001<0oooo000b0?ooo`05003o003oool0oooo
0?ooo`0000004`3oool00380oooo00D00?l00?ooo`3oool0oooo0000000C0?ooo`00<P3oool01@00
o`00oooo0?ooo`3oool0000001<0oooo000b0?ooo`05003o003oool0oooo0?ooo`0000004`3oool0
0380oooo00D00?l00?ooo`3oool0oooo0000000C0?ooo`00<@3oool00`00o`00oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo000a0?ooo`03003o003oool0oooo0080oooo00<000000?ooo`3o
ool04@3oool00340oooo00<00?l00?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00<@3o
ool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000a0?ooo`03003o003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool00340oooo00<00?l00?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`00<03oool00`00o`00oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo000`0?ooo`03003o003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00300oooo00<0
0?l00?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00<03oool00`00o`00oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo000`0?ooo`03003o003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool002L0oooo0`0000030?ooo`030000003oool00?l00080oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`009`3oool00`000000oooo0?ooo`050?ooo`05003o003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`0A0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`05
003o003oool0oooo0?ooo`0000000P3oool200000180oooo000X0?ooo`030000003oool0oooo00@0
oooo00@00?l00?ooo`00000000000`3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`000000
oooo000000050?ooo`03003o003oool0000000@0oooo00<000000?ooo`3oool04@3oool002P0oooo
00<000000?ooo`3oool0103oool00`00o`00oooo0000000200000080oooo00<000000?ooo`3oool0
4@3oool002h0oooo00<00?l00?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00;P3oool0
0`00o`00oooo0?ooo`050?ooo`030000003oool0oooo0140oooo000^0?ooo`03003o003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool002h0oooo00<00?l00?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`00;P3oool00`00o`00oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
000^0?ooo`03003o003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool002d0oooo00<00?l0
0?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00;@3oool00`00o`00oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo000]0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool002d0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00;@3o
ool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0140oooo000/0?ooo`03003o003oool0
oooo00L0oooo00<000000?ooo`3oool04@3oool002`0oooo00<00?l00?ooo`3oool01`3oool00`00
0000oooo0?ooo`0A0?ooo`00;03oool00`00o`00oooo0?ooo`070?ooo`030000003oool0oooo0140
oooo000/0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool002`0oooo00<0
0?l00?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00;03oool00`00o`00oooo0?ooo`07
0?ooo`030000003oool0oooo0140oooo000[0?ooo`03003o003oool0oooo00P0oooo00<000000?oo
o`3oool04@3oool002/0oooo00<00?l00?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`00
:`3oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo0140oooo000[0?ooo`03003o003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool002/0oooo00<00?l00?ooo`3oool0203oool0
0`000000oooo0?ooo`0A0?ooo`00:`3oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo
0140oooo000Z0?ooo`03003o003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool002X0oooo
00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`00:P3oool00`00o`00oooo0?oo
o`090?ooo`030000003oool0oooo0140oooo000Z0?ooo`03003o003oool0oooo00T0oooo00<00000
0?ooo`3oool04@3oool002X0oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?oo
o`00:@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo000Y0?ooo`03003o
003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool002T0oooo00<00?l00?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`00:@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0
oooo0140oooo000Y0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool002T0
oooo00<00?l00?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000001<0oooo000X0?ooo`03
003o003oool0oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0A0?ooo`00
:03oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo008000004P3oool002P0oooo00<0
0?l00?ooo`3oool01P3oool2000000<0oooo00<000000?ooo`3oool04@3oool002P0oooo00<00?l0
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo000X0?oo
o`03003o003oool0oooo00H0oooo0`0000020?ooo`030000003oool0oooo0140oooo000X0?ooo`03
003o003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool002L0oooo00<00?l00?ooo`3oool0
303oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`00o`00oooo0?ooo`0<0?ooo`030000003o
ool0oooo0140oooo000W0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool0
02L0oooo00<00?l00?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`00o`00
oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo000V0?ooo`03003o003oool0oooo00d0oooo
00<000000?ooo`3oool04@3oool002H0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?oo
o`0A0?ooo`009P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo000V0?oo
o`03003o003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool002H0oooo00<00?l00?ooo`3o
ool03@3oool00`000000oooo0?ooo`0A0?ooo`009P3oool00`00o`00oooo0?ooo`0=0?ooo`030000
003oool0oooo0140oooo000U0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool04@3o
ool002D0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`009@3oool00`00
o`00oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo000U0?ooo`03003o003oool0oooo00h0
oooo00<000000?ooo`3oool04@3oool002D0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo
0?ooo`0A0?ooo`009@3oool00`00o`00oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo000T
0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool002@0oooo00<00?l00?oo
o`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00o`00oooo0?ooo`0?0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0
4@3oool002@0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`00o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03003o003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool002<0oooo00<00?l00?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`00o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`03003o003oool0oooo0100oooo00<000000?ooo`3oool04@3oool002<0oooo00<00?l0
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00o`00oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo000R0?ooo`03003o003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00280oooo00<00?l00?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`00o`00oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000R0?ooo`03003o003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000004`3oool00280oooo00<00?l00?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool04@3oool00240oooo00<00?l00?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo008000004P3oool00240
oooo00<00?l00?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000
oooo0?ooo`0A0?ooo`008@3oool00`00o`00oooo0?ooo`030?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`008@3oool00`00o`00oooo0?oo
o`030?ooo`<000001`3oool300000080oooo00<000000?ooo`3oool04@3oool00240oooo00<00?l0
0?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`00803oool00`00o`00oooo0?ooo`0C0?oo
o`030000003oool0oooo0140oooo000P0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3o
ool04@3oool00200oooo00<00?l00?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00803o
ool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000P0?ooo`03003o003oool0
oooo01<0oooo00<000000?ooo`3oool04@3oool00200oooo00<00?l00?ooo`3oool04`3oool00`00
0000oooo0?ooo`0A0?ooo`007`3oool00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo0140
oooo000O0?ooo`03003o003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0
0?l00?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`00o`00oooo0?ooo`0D
0?ooo`030000003oool0oooo0140oooo000O0?ooo`03003o003oool0oooo01@0oooo00<000000?oo
o`3oool04@3oool001h0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00
7P3oool00`00o`00oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000N0?ooo`03003o003o
ool0oooo01D0oooo00<000000?ooo`3oool04@3oool001h0oooo00<00?l00?ooo`3oool05@3oool0
0`000000oooo0?ooo`0A0?ooo`007P3oool00`00o`00oooo0?ooo`0E0?ooo`030000003oool0oooo
0140oooo000N0?ooo`03003o003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool001d0oooo
00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`007@3oool00`00o`00oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo000M0?ooo`03003o003oool0oooo01H0oooo00<00000
0?ooo`3oool04@3oool001d0oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?oo
o`007@3oool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000M0?ooo`03003o
003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool001`0oooo00<00?l00?ooo`3oool05`3o
ool00`000000oooo0?ooo`0A0?ooo`00703oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0
oooo0140oooo000L0?ooo`03003o003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool001`0
oooo00<00?l00?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00703oool00`00o`00oooo
0?ooo`0G0?ooo`030000003oool0oooo0140oooo000K0?ooo`03003o003oool0oooo01P0oooo00<0
00000?ooo`3oool04@3oool001/0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`0A
0?ooo`006`3oool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo000K0?ooo`03
003o003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool001/0oooo00<00?l00?ooo`3oool0
3@3oool500000080oooo00D000000?ooo`3oool0oooo0000000C0?ooo`006`3oool00`00o`00oooo
0?ooo`0?0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo
0140oooo000J0?ooo`03003o003oool0oooo0100oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo0P00000B0?ooo`006P3oool00`00o`00oooo0?ooo`0@0?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`030000003oool0oooo0140oooo000J0?ooo`03003o003oool0
oooo0100oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0
4@3oool001X0oooo00<00?l00?ooo`3oool03`3oool2000000@0oooo00D000000?ooo`3oool0oooo
0000000C0?ooo`006P3oool00`00o`00oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo000J
0?ooo`03003o003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool001T0oooo00<00?l00?oo
o`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`006@3oool00`00o`00oooo0?ooo`0J0?ooo`03
0000003oool0oooo0140oooo000I0?ooo`03003o003oool0oooo01X0oooo00<000000?ooo`3oool0
4@3oool001T0oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`006@3oool0
0`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo000H0?ooo`03003o003oool0oooo
01/0oooo00<000000?ooo`3oool04@3oool001P0oooo00<00?l00?ooo`3oool06`3oool00`000000
oooo0?ooo`0A0?ooo`00603oool00`00o`00oooo0?ooo`0K0?ooo`030000003oool0oooo0140oooo
000H0?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool001P0oooo00<00?l0
0?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`00603oool00`00o`00oooo0?ooo`0K0?oo
o`030000003oool0oooo0140oooo000G0?ooo`03003o003oool0oooo01`0oooo00<000000?ooo`3o
ool04@3oool001L0oooo00<00?l00?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`005`3o
ool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo000G0?ooo`03003o003oool0
oooo01`0oooo00<000000?ooo`3oool04@3oool001L0oooo00<00?l00?ooo`3oool0703oool00`00
0000oooo0?ooo`0A0?ooo`005`3oool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0oooo0140
oooo000F0?ooo`03003o003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool001H0oooo00<0
0?l00?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`005P3oool00`00o`00oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000F0?ooo`03003o003oool0oooo01d0oooo00<000000?oo
o`3oool04@3oool001H0oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`00
5@3oool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo000E0?ooo`03003o003o
ool0oooo01h0oooo00<000000?ooo`3oool04@3oool001D0oooo00<00?l00?ooo`3oool07P3oool0
0`000000oooo0?ooo`0A0?ooo`005@3oool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo
0140oooo000E0?ooo`03003o003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool001D0oooo
00<00?l00?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`00503oool00`00o`00oooo0?oo
o`0O0?ooo`030000003oool0oooo0140oooo000D0?ooo`03003o003oool0oooo01l0oooo00<00000
0?ooo`3oool04@3oool001@0oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?oo
o`00503oool00`00o`00oooo0?ooo`0:0?ooo`D0000000@0oooo00000000000000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3oool001@0oooo00<00?l00?oo
o`3oool0303oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0A0?ooo`00503oool00`00o`00oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0200000180oooo000C0?ooo`03
003o003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`80
00000`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`00o`00oooo0?ooo`0=0?ooo`070000
003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool001<0oooo00<00?l00?ooo`3oool0303oool2000000@0oooo00<000000?ooo`3o
ool01P3oool300000080oooo00<000000?ooo`3oool04@3oool001<0oooo00<00?l00?ooo`3oool0
803oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`00o`00oooo0?ooo`0P0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`03003o003oool0oooo0240oooo00<000000?ooo`3oool04@3oool0
0180oooo00<00?l00?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`00o`00
oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo000B0?ooo`03003o003oool0oooo0240oooo
00<000000?ooo`3oool04@3oool00180oooo00<00?l00?ooo`3oool08@3oool00`000000oooo0?oo
o`0A0?ooo`004P3oool00`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo000A0?oo
o`03003o003oool0oooo0280oooo00<000000?ooo`3oool04@3oool00140oooo00<00?l00?ooo`3o
ool08P3oool00`000000oooo0?ooo`0A0?ooo`004@3oool00`00o`00oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo000A0?ooo`03003o003oool0oooo0280oooo00<000000?ooo`3oool04@3o
ool00140oooo00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`004@3oool00`00
o`00oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo000@0?ooo`03003o003oool0oooo02<0
oooo00<000000?ooo`3oool04@3oool00100oooo00<00?l00?ooo`3oool08`3oool00`000000oooo
0?ooo`0A0?ooo`00403oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo000@
0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool04@3oool00100oooo00<00?l00?oo
o`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`00o`00oooo0?ooo`0T0?ooo`03
0000003oool0oooo0140oooo000?0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0
4@3oool000l0oooo00<00?l00?ooo`3oool0903oool00`000000oooo0?ooo`0A0?ooo`003`3oool0
0`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo000?0?ooo`03003o003oool0oooo
02@0oooo00<000000?ooo`3oool04@3oool000l0oooo00<00?l00?ooo`3oool0903oool00`000000
oooo0?ooo`0A0?ooo`003P3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo
000>0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool000h0oooo00<00?l0
0?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`003P3oool00`00o`00oooo0?ooo`0U0?oo
o`030000003oool0oooo0140oooo000>0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3o
ool04@3oool000h0oooo00<00?l00?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`003@3o
ool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo000=0?ooo`03003o003oool0
oooo02H0oooo00<000000?ooo`3oool04@3oool000d0oooo00<00?l00?ooo`3oool06`3oool50000
0080oooo00D000000?ooo`3oool0oooo0000000C0?ooo`003@3oool00`00o`00oooo0?ooo`0M0?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo0140oooo000=
0?ooo`03003o003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
00000180oooo000<0?ooo`03003o003oool0oooo01h0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`030000003oool0oooo0140oooo000<0?ooo`03003o003oool0oooo01h0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0140oooo00000`3oool00?l00?ooo`090?oo
o`03003o003oool0oooo01d0oooo0P0000030?ooo`<000000P3oool00`000000oooo0?ooo`0A0?oo
o`0000<0oooo003o003oool02@3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo0140
oooo00000`3oool00?l00?ooo`090?ooo`03003o003oool0oooo02L0oooo00<000000?ooo`3oool0
4@3oool00080oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0W0?ooo`030000003o
ool0oooo0140oooo00020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool0203oool0
0`00o`00oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00020?ooo`03003o003oool0oooo
00H0oooo00<00?l00?ooo`3oool01`3oool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo
0140oooo00020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool01`3oool00`00o`00
oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo00020?ooo`03003o003oool0oooo00H0oooo
00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo
00030?ooo`03003o003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool00`00o`00oooo0?oo
o`0O0?ooo`030000003oool0oooo0140oooo00030?ooo`03003o003oool0oooo00D0oooo00<00?l0
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0P0?ooo`030000003oool0oooo0140oooo00030?oo
o`03003o003oool0oooo00@0oooo00<00?l00?ooo`3oool01@3oool00`00o`00oooo0?ooo`0Q0?oo
o`030000003oool0oooo0140oooo00030?ooo`03003o003oool0oooo00@0oooo00<00?l00?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo00030?ooo`03003o
003oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool00`00o`00oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo00040?ooo`03003o003oool0oooo00<0oooo00<00?l00?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00040?ooo`03003o003oool0
oooo00<0oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0
oooo0140oooo00040?ooo`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool00`3oool00`00
o`00oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo00040?ooo`03003o003oool0oooo0080
oooo00<00?l00?ooo`3oool00`3oool00`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo0140
oooo00050?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`00o`00oooo0?ooo`0U0?ooo`03
0000003oool0oooo0140oooo00050?ooo`05003o003oool0oooo0?ooo`00o`00103oool00`00o`00
oooo0?ooo`0U0?ooo`030000003oool0oooo0140oooo00050?ooo`05003o003oool0oooo0?ooo`00
o`000`3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00050?ooo`05003o
003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo0140
oooo00050?ooo`04003o003oool0oooo003o00<0oooo00<00?l00?ooo`3oool09`3oool00`000000
oooo0?ooo`0A0?ooo`001P3oool00`00o`00oooo003o00020?ooo`03003o003oool0oooo02P0oooo
00<000000?ooo`3oool04@3oool000H0oooo00<00?l00?ooo`00o`000P3oool00`00o`00oooo0?oo
o`0X0?ooo`030000003oool0oooo0140oooo00060?ooo`05003o003oool00?l00?ooo`00o`00:`3o
ool00`000000oooo0?ooo`0A0?ooo`001P3oool01000o`00oooo003o0000o`0/0?ooo`030000003o
ool0oooo0140oooo00060?ooo`04003o003oool00?l0003o02`0oooo00<000000?ooo`3oool04@3o
ool000L0oooo0P00o`0]0?ooo`030000003oool0oooo0140oooo00070?ooo`800?l0;@3oool00`00
0000oooo0?ooo`0A0?ooo`001`3oool00`00o`00oooo0?ooo`0/0?ooo`030000003oool0oooo0140
oooo000f0?ooo`030000003oool0oooo0140oooo000f0?ooo`030000003oool0oooo0140oooo000f
0?ooo`030000003oool0oooo0140oooo000f0?ooo`030000003oool0oooo0140oooo000f0?ooo`03
0000003oool0oooo0140oooo000f0?ooo`030000003oool0oooo0140oooo001:0?ooo`00BP3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 73.1875}, {287, 0}} -> {-3.48952, -0.783061, 
  0.0639649, 0.0639649}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(g)", "Subsection"],

Cell["\<\
Clear[paracols];
paracols[{{a_,b_},{c_,d_}}] := 
   Show[Graphics[Polygon[
      {{0,0},{a,c},{a+b,c+d},{b,d}}
   ]],Axes->True]
paracols[A_?MatrixQ] /; Length[A[[1]]]==3 :=
   Module[{o,u,v,w},
      o = {0,0,0};
      {u,v,w} = Transpose[A];
      Show[Graphics3D[{
         Polygon[{o,u,u+v,v}],
         Polygon[{o,u,u+w,w}],
         Polygon[{o,v,v+w,w}],
         Polygon[{w,u+w,u+v+w,v+w}],
         Polygon[{v,u+v,u+v+w,v+w}],
         Polygon[{u,u+v,u+v+w,u+w}]
      }],Axes->True]
   ]\
\>", "Input"],

Cell["\<\
para3d[x_List,y_List,color___] := Graphics3D[
   {color, Polygon[{{0,0,0},x,x+y,y}]}]\
\>", "Input"],

Cell["\<\
arrow[{a_,b_},color___] := Graphics[
   {color, Line[{{0,0},{a,b}}],
    Line[{{a,b},.9{a,b}+.04{-b,a}}],
    Line[{{a,b},.9{a,b}-.04{-b,a}}]}
]\
\>", "Input"],

Cell["z = {0,.5,1}; u = {1,0,0}; v = {0,1,-.5};", "Input"],

Cell["\<\
arrow[{a_,b_,c_},color___] := Graphics3D[
   {color, Line[{{0,0,0},{a,b,c}}],
    Line[{{a,b,c},.9{a,b,c}+.04{-b,a,c}}],
    Line[{{a,b,c},.9{a,b,c}-.04{-b,a,c}}]}
]\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[para3d[u,v,Red],arrow[z,Green],
   AspectRatio->Automatic,
   Axes->True];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33948 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166765 1.36779 -1.11022e-016 1.36779 [
[.40445 1.35073 -3.0642 0 ]
[.40445 1.35073 2.9358 9 ]
[.54188 1.31794 -11.9432 0 ]
[.54188 1.31794 12.0568 9 ]
[.68436 1.28393 -8.71048 0 ]
[.68436 1.28393 9.28952 9 ]
[.83218 1.24864 -11.2678 0 ]
[.83218 1.24864 12.7322 9 ]
[.98563 1.21199 -2.72585 0 ]
[.98563 1.21199 3.27415 9 ]
[.00872 1.07688 -3.30556 0 ]
[.00872 1.07688 2.69444 9 ]
[.10945 1.15277 -12.9654 0 ]
[.10945 1.15277 11.0346 9 ]
[.20313 1.22335 -9.55001 0 ]
[.20313 1.22335 8.44999 9 ]
[.29047 1.28915 -12.5227 0 ]
[.29047 1.28915 11.4773 9 ]
[.3721 1.35064 -3.08264 0 ]
[.3721 1.35064 2.91736 9 ]
[.06795 .25323 -24 -2.70336 ]
[.06795 .25323 0 6.29664 ]
[.04367 .48438 -6 -2.84104 ]
[.04367 .48438 0 6.15896 ]
[.01654 .74277 -18 -2.99604 ]
[.01654 .74277 0 6.00396 ]
[-0.01397 1.03349 -6 -3.17183 ]
[-0.01397 1.03349 0 5.82817 ]
[ 0 0 0 0 ]
[ 1 1.33948 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.38041 1.33948 m
1 1.19115 L
s
.40482 1.33363 m
.405 1.32509 L
s
[(0)] .40445 1.35073 .0214 -1 Mshowa
.5418 1.30084 m
.54176 1.29229 L
s
[(0.25)] .54188 1.31794 -0.00473 -1 Mshowa
.68381 1.26685 m
.68354 1.2583 L
s
[(0.5)] .68436 1.28393 -0.03217 -1 Mshowa
.83114 1.23158 m
.83062 1.22305 L
s
[(0.75)] .83218 1.24864 -0.06102 -1 Mshowa
.98407 1.19497 m
.98329 1.18645 L
s
[(1)] .98563 1.21199 -0.09138 -1 Mshowa
.125 Mabswid
.43183 1.32717 m
.43191 1.32204 L
s
.45903 1.32066 m
.45908 1.31553 L
s
.48642 1.3141 m
.48645 1.30897 L
s
.51401 1.30749 m
.51402 1.30237 L
s
.56979 1.29414 m
.56974 1.28901 L
s
.59799 1.28739 m
.59791 1.28226 L
s
.62639 1.28059 m
.62628 1.27546 L
s
.655 1.27374 m
.65486 1.26862 L
s
.71284 1.2599 m
.71265 1.25477 L
s
.74209 1.2529 m
.74187 1.24777 L
s
.77155 1.24584 m
.7713 1.24072 L
s
.80123 1.23874 m
.80095 1.23362 L
s
.86126 1.22437 m
.86092 1.21925 L
s
.89162 1.2171 m
.89125 1.21198 L
s
.9222 1.20978 m
.9218 1.20466 L
s
.95302 1.2024 m
.95259 1.19729 L
s
.25 Mabswid
0 1.05197 m
.38041 1.33948 L
s
.01045 1.05987 m
.01132 1.05137 L
s
[(0)] .00872 1.07688 .10185 -1 Mshowa
.11083 1.13573 m
.11151 1.12721 L
s
[(0.25)] .10945 1.15277 .08045 -1 Mshowa
.20418 1.20628 m
.2047 1.19775 L
s
[(0.5)] .20313 1.22335 .06111 -1 Mshowa
.29122 1.27207 m
.29159 1.26353 L
s
[(0.75)] .29047 1.28915 .04356 -1 Mshowa
.37257 1.33355 m
.3728 1.325 L
s
[(1)] .3721 1.35064 .02755 -1 Mshowa
.125 Mabswid
.03113 1.0755 m
.03162 1.07039 L
s
.05149 1.09089 m
.05197 1.08578 L
s
.07156 1.10606 m
.07202 1.10095 L
s
.09134 1.121 m
.09177 1.11589 L
s
.13003 1.15025 m
.13042 1.14513 L
s
.14897 1.16456 m
.14934 1.15944 L
s
.16763 1.17866 m
.16798 1.17355 L
s
.18603 1.19257 m
.18636 1.18745 L
s
.22207 1.21981 m
.22236 1.21468 L
s
.23971 1.23314 m
.23999 1.22802 L
s
.25712 1.24629 m
.25737 1.24117 L
s
.27428 1.25927 m
.27452 1.25414 L
s
.30792 1.28469 m
.30813 1.27957 L
s
.32441 1.29715 m
.3246 1.29203 L
s
.34067 1.30945 m
.34085 1.30432 L
s
.35672 1.32158 m
.35688 1.31645 L
s
.25 Mabswid
.08553 .2305 m
0 1.05197 L
s
.08383 .24689 m
.09177 .24372 L
s
[(-0.5)] .06795 .25323 1 -0.39925 Mshowa
.05971 .47847 m
.06773 .47551 L
s
[(0)] .04367 .48438 1 -0.36866 Mshowa
.03276 .73735 m
.04087 .73464 L
s
[(0.5)] .01654 .74277 1 -0.33421 Mshowa
.00243 1.02865 m
.01063 1.02623 L
s
[(1)] -0.01397 1.03349 1 -0.29515 Mshowa
.125 Mabswid
.07921 .29123 m
.08398 .28935 L
s
.07449 .33653 m
.07928 .33467 L
s
.06967 .38281 m
.07447 .38098 L
s
.06475 .43011 m
.06955 .42831 L
s
.05457 .52792 m
.05939 .52617 L
s
.0493 .57849 m
.05413 .57677 L
s
.04391 .63022 m
.04876 .62853 L
s
.0384 .68316 m
.04325 .6815 L
s
.02698 .79283 m
.03186 .79124 L
s
.02107 .84965 m
.02595 .84809 L
s
.01501 .90786 m
.0199 .90633 L
s
.00879 .96751 m
.0137 .96602 L
s
.25 Mabswid
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.38041 1.33948 L
s
.38041 1.33948 m
.40038 .572 L
s
.40038 .572 m
.08553 .2305 L
s
.65975 0 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.65975 0 m
.08553 .2305 L
s
.40038 .572 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.38041 1.33948 L
s
.38041 1.33948 m
.40038 .572 L
s
0 0 m
1 0 L
1 1.33948 L
0 1.33948 L
closepath
clip
newpath
.5 Mabswid
.90716 .40628 m .41431 .57336 L .09267 .4786 L p .613 .895 .988 r
F P
0 g
s
.09267 .4786 m .66096 .27005 L .90716 .40628 L p .613 .895 .988 r
F P
0 g
s
0 1 0 r
.09267 .4786 m
.23103 1.17721 L
s
.23103 1.17721 m
.22914 1.07815 L
s
.23103 1.17721 m
.20401 1.13088 L
s
0 g
.25 Mabswid
.65975 0 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.65975 0 m
.08553 .2305 L
s
0 1.05197 m
.38041 1.33948 L
s
.01045 1.05987 m
.01132 1.05137 L
s
[(0)] .00872 1.07688 .10185 -1 Mshowa
.11083 1.13573 m
.11151 1.12721 L
s
[(0.25)] .10945 1.15277 .08045 -1 Mshowa
.20418 1.20628 m
.2047 1.19775 L
s
[(0.5)] .20313 1.22335 .06111 -1 Mshowa
.29122 1.27207 m
.29159 1.26353 L
s
[(0.75)] .29047 1.28915 .04356 -1 Mshowa
.37257 1.33355 m
.3728 1.325 L
s
[(1)] .3721 1.35064 .02755 -1 Mshowa
.125 Mabswid
.03113 1.0755 m
.03162 1.07039 L
s
.05149 1.09089 m
.05197 1.08578 L
s
.07156 1.10606 m
.07202 1.10095 L
s
.09134 1.121 m
.09177 1.11589 L
s
.13003 1.15025 m
.13042 1.14513 L
s
.14897 1.16456 m
.14934 1.15944 L
s
.16763 1.17866 m
.16798 1.17355 L
s
.18603 1.19257 m
.18636 1.18745 L
s
.22207 1.21981 m
.22236 1.21468 L
s
.23971 1.23314 m
.23999 1.22802 L
s
.25712 1.24629 m
.25737 1.24117 L
s
.27428 1.25927 m
.27452 1.25414 L
s
.30792 1.28469 m
.30813 1.27957 L
s
.32441 1.29715 m
.3246 1.29203 L
s
.34067 1.30945 m
.34085 1.30432 L
s
.35672 1.32158 m
.35688 1.31645 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{215, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003G000182000`400?l00000o`00003oe`3oool0
0=L0oooo003G0?ooo`00e`3oool00=L0oooo002@0?ooo`800000A@3oool008h0oooo0P0000000`3o
ool00000000000140?ooo`00R`3oool3000000<0oooo0P0000140?ooo`00R@3oool2000000H0oooo
00<000000?ooo`000000@`3oool008H0oooo0`0000080?ooo`040000003oool0oooo00000480oooo
00240?ooo`8000002`3oool010000000oooo0?ooo`0000120?ooo`00P@3oool3000000d0oooo00D0
00000?ooo`3oool0oooo000000110?ooo`00O`3oool200000100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0n0?ooo`00O03oool300000180oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`00NP3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0m0?ooo`00M`3oool3000001L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0l0?ooo`00M@3oool2000001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0l0?ooo`00L`3oool2000001`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0k0?ooo`00L03oool3000001l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j
0?ooo`00KP3oool200000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?oo
o`00J`3oool3000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0i0?ooo`00
J@3oool2000002L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`00IP3o
ool3000002T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`00I03oool2
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?ooo`00H@3oool30000
02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?ooo`00G`3oool200000340
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?ooo`00G03oool3000003<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0e0?ooo`00FP3oool2000003H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool3000003P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool2000003/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0c0?ooo`00DP3oool3000003d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0b0?ooo`00D03oool200000400oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0b0?ooo`00C@3oool300000480oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0a0?ooo`00B`3oool2000004D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0`0?ooo`00B03oool3000004L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0`0?ooo`00AP3oool2000004X0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0_0?ooo`00@`3oool3000004`0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0^0?ooo`00@@3oool2000004l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0^0?ooo`00?P3oool300000540oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0]
0?ooo`00?03oool2000005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0/0?oo
o`00>P3oool2000005H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0/0?ooo`00
=`3oool3000005P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0[0?ooo`00=@3o
ool2000005`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`00<P3oool3
000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`00<03oool20000
0640oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`00;@3oool3000006<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X0?ooo`00:`3oool2000006H0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0W0?ooo`00:03oool3000006P0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0W0?ooo`009P3oool2000006/0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`008`3oool3000006d0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0U0?ooo`008@3oool200000700oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0U0?ooo`007`3oool200000780oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0T0?ooo`007`3oool200000780oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0S0?ooo`007`3oool00`000000oooo0000001a0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool08`3oool001l0oooo0P0000000`3oool000000?ooo`1_0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool001l0oooo00D000000?ooo`3o
ool0oooo0000001_0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool000l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool08@3oool000h0oooo00<000000?ooo`0000001`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0200oooo00090?ooo`<000000P3oool00`000000oooo0000
00090?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool000h0oooo00<000000?ooo`0000001`3o
ool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?ooo`<000008@3o
ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`000000oooo000000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1T0?ooo`<000000P2LiO`2
00000240oooo00<000000?ooo`3oool07P3oool000l0oooo00<000000?ooo`3oool01P3oool30000
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1Q0?ooo`8000001@2LiO`01000
0000W>Gl00000000000P0?ooo`030000003oool0oooo01d0oooo000N0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0G@3oool3000000L0W>Gl00@0000009cUo02LiO`0W>Gl0P00000N
0?ooo`030000003oool0oooo01d0oooo000N0?ooo`8000002P3oool00`000000oooo0?ooo`1I0?oo
o`<000002P2LiO`00`000000W>Gl09cUo00309cUo08000007@3oool00`000000oooo0?ooo`0L0?oo
o`007P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05D0oooo0`00000=09cUo003
0000002LiO`0W>Gl00D0W>Gl00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`00
7P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0580oooo0P00000@09cUo0030000
002LiO`0W>Gl00H0W>Gl0P00000K0?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0CP3oool3000001<0W>Gl00<0000009cUo02LiO`01`2L
iO`2000001X0oooo00<000000?ooo`3oool06P3oool001d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1:0?ooo`<000005P2LiO`00`000000W>Gl09cUo00909cUo08000006@3oool0
0`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
04H0oooo0`00000I09cUo0030000002LiO`0W>Gl00/0W>Gl0P00000G0?ooo`030000003oool0oooo
01T0oooo000M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@`3oool2000001`0
W>Gl00<0000009cUo02LiO`03@2LiO`2000001H0oooo00<000000?ooo`3oool0603oool001d0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`<000007P2LiO`00`000000W>Gl
09cUo00?09cUo0030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool001d0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0k0?ooo`<000008@2LiO`00`000000W>Gl09cU
o00@09cUo0800000503oool00`000000oooo0?ooo`0G0?ooo`007@3oool2000001<0oooo00<00000
0?ooo`3oool0>03oool3000002@0W>Gl00<0000009cUo02LiO`04P2LiO`2000001<0oooo00<00000
0?ooo`3oool05P3oool001d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0e0?oo
o`8000009`2LiO`00`000000W>Gl09cUo00D09cUo08000004P3oool00`000000oooo0?ooo`0E0?oo
o`007@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0340oooo0`00000Y09cUo003
0000002LiO`0W>Gl01H0W>Gl0P00000@0?ooo`030000003oool0oooo01D0oooo000L0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool3000002`0W>Gl00<0000009cUo02LiO`0
602LiO`00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0oooo000L0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0:@3oool3000002l0W>Gl00<0000009cUo02LiO`06@2L
iO`2000000l0oooo00<000000?ooo`3oool04`3oool001`0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0V0?ooo`800000<P2LiO`00`000000W>Gl09cUo00K09cUo08000003@3oool0
0`000000oooo0?ooo`0C0?ooo`00703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0280oooo0`00000d09cUo0030000002LiO`0W>Gl01d0W>Gl0P00000<0?ooo`030000003oool0oooo
0180oooo000L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool3000003L0
W>Gl00<0000009cUo02LiO`07`2LiO`2000000/0oooo00<000000?ooo`3oool04@3oool001`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`<00000>P2LiO`00`000000W>Gl
09cUo00Q09cUo08000002@3oool00`000000oooo0?ooo`0A0?ooo`00703oool2000001d0oooo00<0
00000?ooo`3oool05P3oool3000003d0W>Gl00<0000009cUo02LiO`08`2LiO`00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0100oooo000L0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04`3oool200000400W>Gl00<0000009cUo02LiO`0902LiO`2000000P0oooo00<00000
0?ooo`3oool03`3oool001`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?oo
o`<00000@P2LiO`00`000000W>Gl09cUo00V09cUo08000001P3oool00`000000oooo0?ooo`0?0?oo
o`00703oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00/0oooo0`00001509cUo003
0000002LiO`0W>Gl02P0W>Gl0P0000040?ooo`800000403oool001/0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`080?ooo`<00000B02LiO`00`000000W>Gl09cUo00Z09cUo0@00000
00<0oooo0000003oool03`3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`050?ooo`800000B`2LiO`00`000000W>Gl09cUo00/09cUo0040000003oool0oooo00000100oooo
000K0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool0oooo0`00001=09cUo0030000
002LiO`0W>Gl02P0W>Gl0`0000040?ooo`030000003oool0oooo00h0oooo000K0?ooo`030000003o
ool0oooo02<0oooo0`00001@09cUo0030000002LiO`0W>Gl02D0W>Gl0`0000070?ooo`030000003o
ool0oooo00h0oooo000K0?ooo`030000003oool0oooo0200oooo0`00001C09cUo0030000002LiO`0
W>Gl0280W>Gl0`00000:0?ooo`030000003oool0oooo00h0oooo000K0?ooo`8000007`3oool20000
05L0W>Gl00<0000009cUo02LiO`07P2LiO`3000000h0oooo00<000000?ooo`3oool03@3oool001/0
oooo00<000000?ooo`3oool06`3oool3000005T0W>Gl00<0000009cUo02LiO`06`2LiO`300000140
oooo00<000000?ooo`3oool03@3oool001/0oooo00<000000?ooo`3oool0603oool3000005`0W>Gl
00<0000009cUo02LiO`0602LiO`3000001@0oooo00<000000?ooo`3oool03@3oool001/0oooo00<0
00000?ooo`3oool05@3oool3000005l0W>Gl00<0000009cUo02LiO`05@2LiO`3000001L0oooo00<0
00000?ooo`3oool03@3oool001/0oooo00<000000?ooo`3oool04`3oool200000680W>Gl00<00000
09cUo02LiO`04P2LiO`3000001X0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?oo
o`3oool04@3oool3000006@0W>Gl00<0000009cUo02LiO`03`2LiO`3000001d0oooo00<000000?oo
o`3oool03@3oool001X0oooo00<000000?ooo`3oool03P3oool3000006L0W>Gl00<0000009cUo02L
iO`0302LiO`300000200oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool0
2`3oool3000006X0W>Gl00<0000009cUo02LiO`02@2LiO`3000002<0oooo00<000000?ooo`3oool0
3@3oool001X0oooo00<000000?ooo`3oool02@3oool2000006d0W>Gl00<0000009cUo02LiO`01P2L
iO`3000002H0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool01P3oool3
000006l0W>Gl00<0000009cUo02LiO`00`2LiO`3000002T0oooo00<000000?ooo`3oool03@3oool0
01X0oooo0`0000040?ooo`03003o00000000W>Gl0740W>Gl00<0000009cUo02LiO`00`00000]0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`00
00000`00001^09cUo0<00000<03oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`3oool00`3oool3000006T0W>Gl
0`00000b0?ooo`030000003oool0oooo00`0oooo000C0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`00o`00oooo0?ooo`050?ooo`<00000H`2LiO`300000080oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`004`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0203oool4000005`0W>Gl0`000005
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0303oool001<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo00`0oooo0`00001F09cU
o0<00000203oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo000C0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0?0?ooo`<0
0000D02LiO`3000000/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`00
503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0
4P3oool4000004T0W>Gl0`00000>0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
303oool001T0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0E0?ooo`<00000@`2L
iO`300000140oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`006@3oool0
0`000000oooo0?ooo`070?ooo`03003o003oool0oooo01P0oooo0`00000m09cUo0<00000503oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo000I0?ooo`800000203oool00`00
o`00oooo0?ooo`0K0?ooo`@00000=P2LiO`3000001L0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0<0?ooo`006@3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo01l0
oooo0`00000`09cUo0<000006P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0
oooo000I0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool08P3oool4000002T0W>Gl
0`00000M0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001T0oooo00<0
00000?ooo`3oool0203oool00`00o`00oooo0?ooo`0U0?ooo`<000008`2LiO`300000200oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00603oool00`000000oooo0?ooo`09
0?ooo`03003o003oool0oooo02P0oooo0`00000M09cUo0<00000903oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00/0oooo000H0?ooo`030000003oool0oooo00T0oooo00<00?l00?oo
o`3oool0:`3oool4000001H0W>Gl0`00000W0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02`3oool001P0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0_0?ooo`<0
0000402LiO`3000002X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`00
603oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo0380oooo0`00000:09cUo0<00000
;@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00/0oooo000H0?ooo`030000003o
ool0oooo00T0oooo00<00?l00?ooo`3oool0=@3oool4000000<0W>Gl0`00000`0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02`3oool001P0oooo00<000000?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`0f0?ooo`D00000<`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00/0oooo000H0?ooo`8000002`3oool00`00o`00oooo0?ooo`0f0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`00603oool00`000000
oooo0?ooo`0:0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000H0?ooo`030000003oool0oooo00X0oooo
00<00?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?oo
o`0f0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`03003o003oool0oooo03D0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000G0?oo
o`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3o
ool0303oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`03003o
003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00X0oooo000G0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001L0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0d0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool20000
00h0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?ooo`3oool03@3oool00`00o`00
oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo03@0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00T0oooo
000F0?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool001H0oooo00<00000
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`005P3oool00`000000oooo0?ooo`0?0?oo
o`03003o003oool0oooo03<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00T0oooo000F0?ooo`030000003oool0oooo00l0oooo00<00?l00?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool02@3oool001H0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0c0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`005P3o
ool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo000F0?ooo`030000003oool0
oooo0100oooo00<00?l00?ooo`3oool0<@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02@3oool001H0oooo00<000000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0a0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`090?ooo`005P3oool200000140oooo00<00?l00?ooo`3oool0<@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02@3oool001H0oooo
00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`0a0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`080?ooo`005@3oool00`000000oooo0?oo
o`0A0?ooo`03003o003oool0oooo0340oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00P0oooo000E0?ooo`030000003oool0oooo0180oooo00<00?l0
0?ooo`3oool0<03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0203oool001D0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`0`0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`080?oo
o`005@3oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo0300oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo000E0?ooo`030000
003oool0oooo0180oooo00<00?l00?ooo`3oool0<03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0203oool001D0oooo00<000000?ooo`3oool04P3o
ool00`00o`00oooo0?ooo`0`0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`080?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`03003o003oool0
oooo02l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00P0oooo000E0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0203oool001D0
oooo0P00000D0?ooo`03003o003oool0oooo02l0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo000D0?ooo`8000005@3oool00`00o`00oooo
0?ooo`0_0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`080?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo02l0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo0004
0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0D
0?ooo`03003o003oool0oooo02l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00L0oooo00040?ooo`030000003oool0000000T0oooo00D000000?oo
o`3oool0oooo0000000G0?ooo`03003o003oool0oooo02h0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo00040?ooo`030000003oool00000
00L0oooo0P0000040?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool000@0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0
oooo00<00?l00?ooo`3oool0;P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool01`3oool000D0oooo00<000000?ooo`3oool01P3oool3000000<0oooo
00<000000?ooo`3oool05@3oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`00503oool00`000000oooo0?oo
o`0E0?ooo`03003o003oool0oooo02h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00L0oooo000D0?ooo`030000003oool0oooo01H0oooo00<00?l0
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool01`3oool001@0oooo00<000000?ooo`3oool05P3oool00`00o`00oooo0?ooo`0]0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?oo
o`004`3oool00`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo02d0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00L0oooo000C0?ooo`<00000
5`3oool00`00o`00oooo0?ooo`0]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`070?ooo`004`3oool00`000000oooo0?ooo`0G0?ooo`03003o003o
ool0oooo02d0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00H0oooo000C0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3oool0;03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01P3oool0
01<0oooo00<000000?ooo`3oool0603oool00`00o`00oooo0?ooo`0/0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`060?ooo`004`3oool00`000000
oooo0?ooo`0H0?ooo`03003o003oool0oooo02`0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00H0oooo000C0?ooo`030000003oool0oooo01P0oooo
00<00?l00?ooo`3oool0;03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool01P3oool001<0oooo00<000000?ooo`3oool0603oool00`00o`00oooo0?oo
o`0/0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`060?ooo`004`3oool00`000000oooo0?ooo`0I0?ooo`03003o003oool0oooo02/0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00H0oooo000B0?oo
o`030000003oool0oooo01X0oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool01P3oool00180oooo00<000000?ooo`3o
ool06P3oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`060?ooo`004P3oool00`000000oooo0?ooo`0J0?ooo`03003o
003oool0oooo02/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00H0oooo000B0?ooo`8000006`3oool00`00o`00oooo0?ooo`0[0?ooo`030000003o
ool0oooo03L0oooo0P00000f0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0
oooo01/0oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`0c0?ooo`@000000P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0oooo
01/0oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`<000001`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0oooo01/0
oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0]0?ooo`@000002`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0oooo01/0oooo
00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`<00000403oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0oooo01/0oooo00<0
0?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`<000004`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030000003oool0oooo01`0oooo00<00?l0
0?ooo`3oool0:03oool00`000000oooo0?ooo`0S0?ooo`@000005`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00D0oooo000A0?ooo`030000003oool0oooo01d0oooo00<00?l00?oo
o`3oool0:03oool00`000000oooo0?ooo`0P0?ooo`<00000703oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00D0oooo000A0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3o
ool0:03oool00`000000oooo0?ooo`0L0?ooo`@00000803oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00D0oooo000A0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0
:03oool00`000000oooo0?ooo`0I0?ooo`<000009@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00D0oooo000A0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0:03o
ool00`000000oooo0?ooo`0E0?ooo`@00000:@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00D0oooo000A0?ooo`8000007`3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0
oooo0180oooo0`00000^0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0103oool0
0140oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo
00h0oooo1000000b0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00140
oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo00/0
oooo0`00000g0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool00140oooo
00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo
1000000k0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool00140oooo00<0
00000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo0`00
000o0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool00140oooo00<00000
0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0W0?ooo`040000003oool0oooo0?ooo`<00000@`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo000@0?ooo`030000003oool0
oooo0200oooo00<00?l00?ooo`3oool09P3oool4000004L0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`040?ooo`00403oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo
02<0oooo1000001;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool00100
oooo00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`0O0?ooo`@000000`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00100oooo
00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`0L0?ooo`<000001`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00100oooo00<0
00000?ooo`3oool0803oool00`00o`00oooo0?ooo`0H0?ooo`@000002P3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00100oooo00<00000
0?ooo`3oool08@3oool00`00o`00oooo0?ooo`0D0?ooo`<000003P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00100oooo0P00000R0?oo
o`03003o003oool0oooo0100oooo1000000A0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`030?ooo`00403oool00`000000oooo0?ooo`0Q0?ooo`03
003o003oool0oooo00d0oooo0`00000E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`030?ooo`00403oool00`000000oooo0?ooo`0Q0?ooo`03003o
003oool0oooo00X0oooo0`00000H0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`030?ooo`003`3oool00`000000oooo0?ooo`0R0?ooo`03003o003o
ool0oooo00H0oooo1000000K0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`030?ooo`003`3oool00`000000oooo0?ooo`0S0?ooo`03003o003oool0
oooo0080oooo0`00000O0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`030?ooo`003`3oool00`000000oooo0?ooo`0S0?ooo`03003o000000000000
008000008P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool000l0oooo00<000000?ooo`3oool08@3oool3000002H0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo000?0?ooo`030000
003oool0oooo01d0oooo100000020?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo000?0?ooo`030000003o
ool0oooo01X0oooo0`0000060?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo000?0?ooo`030000003oool0
oooo01H0oooo1000000:0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo000?0?ooo`030000003oool0oooo
01<0oooo0`00000>0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo000?0?ooo`030000003oool0oooo00l0
oooo1000000A0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo000?0?ooo`8000003@3oool3000001D0oooo
00<00?l00?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00P3oool000h0oooo0P00000;0?ooo`<00000603oool00`00o`00oooo0?oo
o`0S0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`020?ooo`001P3oool5000000<0oooo00<000000?ooo`3oool01P3oool4000001`0oooo00<00?l0
0?ooo`3oool08P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`<00000803oool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000<000008`3oool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo
0?ooo`030?ooo`<000009P3oool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?oo
o`040?ooo`8000009P3oool00`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`001`3oool2000000L0oooo0P00000V
0?ooo`03003o003oool0oooo0200oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003oool0oooo02<0oooo00<00?l00?oo
o`3oool0803oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00@3oool001<0oooo00<000000?ooo`0000008P3oool00`00o`00oooo0?ooo`0P0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`010?ooo`00
503oool200000280oooo00<00?l00?ooo`3oool0803oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00@3oool001H0oooo00<000000?ooo`3oool07`3o
ool01@00o`00oooo0?ooo`3oool00?l001h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0040oooo000G0?ooo`030000003oool0000001l0oooo00@0
0?l00?ooo`3oool00?l07P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00@3oool001P0oooo0P00000O0?ooo`04003o003oool0oooo003o01h0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040oooo
000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool01000o`00oooo0?oo
o`00o`0N0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`010?ooo`003P3oool00`000000oooo0000000:0?ooo`030000003oool0000001/0oooo00@0
0?l00?ooo`3oool00?l07P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00@3oool000h0oooo00<000000?ooo`0000002`3oool2000001/0oooo00@0
0?l00?ooo`3oool00?l07P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00@3oool000h0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`0H0?ooo`04003o003oool0oooo003o01h0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0040oooo000>0?ooo`030000003oool0000000h0oooo0P00
000I0?ooo`03003o003oool00?l001h0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`090?ooo`4000000@3oool10?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01L0oooo00<00?l00?ooo`00o`007P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo00T0oooo0@0000010?ooo`40oooo000Q0?ooo`80000000<0oooo0000003oool0503oool00`00
o`00oooo003o000N0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0203oool10000
0040oooo0@3oool002<0oooo0P00000B0?ooo`06003o003oool0oooo003o003oool00?l07P3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo000T0?oo
o`030000003oool0oooo0140oooo00D00?l00?ooo`00o`00oooo003o000N0?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool002D0oooo0P00000A0?oo
o`03003o003oool0oooo00800?l07P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`40oooo000W0?ooo`800000403oool01000o`00oooo003o0000o`0N0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool002P0
oooo00<000000?ooo`3oool03P3oool01000o`00oooo003o0000o`0N0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool00`3oool100000040oooo0@3oool002T0oooo0P00000?0?ooo`<0
0?l07P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`40
oooo000[0?ooo`8000003@3oool3003o01h0oooo00<000000?ooo`3oool0LP3oool01@000000oooo
0?ooo`3oool000000080oooo000/0?ooo`030000003oool0oooo00`0oooo0P00o`0N0?ooo`030000
003oool0oooo07<0oooo00D000000?ooo`3oool0oooo000000010?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`02000000`0
oooo0P00o`0N0?ooo`030000003oool0oooo07<0oooo00D000000?ooo`3oool0oooo000000010?oo
o`006P3oool00`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool2000000/0oooo00<00?l00?ooo`3oool0703oool00`000000oooo0?ooo`1d0?ooo`04
0000003oool0oooo00000040oooo000J0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo000000010?ooo`006P3oool00`000000oooo000000080?ooo`040000
003oool0oooo0?ooo`8000001P3oool3000002L0oooo00<000000?ooo`3oool0M03oool010000000
oooo0000000000010?ooo`006P3oool00`000000oooo000000070?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07@0
oooo100000010?ooo`006`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`<0
0000203oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0100000040?ooo`00=@3oool00`000000oooo0000000S0?ooo`030000003oool0oooo06d0
oooo100000080?ooo`00=P3oool2000002<0oooo00<000000?ooo`3oool0J03oool5000000`0oooo
000h0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0H@3oool010000000oooo0?oo
o`3oool400000100oooo000i0?ooo`800000803oool00`000000oooo0?ooo`1Q0?ooo`@00000503o
ool003X0oooo0P00000O0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo00000003000001P0oooo000l0?ooo`030000003oool0000001`0oooo00<000000?oo
o`3oool0E@3oool010000000oooo0?ooo`3oool4000001`0oooo000m0?ooo`800000703oool00`00
0000oooo0?ooo`1E0?ooo`@000006@3oool500000080oooo000n0?ooo`8000006`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0000000<000007`3oool00`000000oooo0?ooo`020?ooo`00
<@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool2000001T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo00000004000002<0oooo
00<000000?ooo`3oool00P3oool00300oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool010000000oooo0?oo
o`3oool4000002P0oooo00<000000?ooo`3oool00P3oool00300oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`030?ooo`8000005P3oool00`000000oooo0?ooo`150?ooo`@00000;03o
ool00`000000oooo0?ooo`020?ooo`00<03oool00`000000oooo000000070?ooo`800000203oool2
000001@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<00000;`3oool2000000@0oooo000`0?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool0oooo1000000i0?ooo`00<@3oool00`000000oooo0?ooo`060?ooo`<000002@3oool0
0`000000oooo0000000A0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool4
000003d0oooo00170?ooo`8000004@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool00000
00<000005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`00B@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool01000000I0?ooo`030000003oool0000000P0
oooo00L000000?ooo`3oool0oooo0000003oool0000001X0oooo001:0?ooo`8000003P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo1000000M0?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`00B`3oool2000000d0
oooo00<000000?ooo`3oool0:03oool500000240oooo00<000000?ooo`0000002@3oool00`000000
oooo0?ooo`02000001/0oooo001=0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`030?ooo`H000009@3oool00`000000oooo000000070?ooo`030000
003oool000000080oooo00<000000?ooo`3oool06P3oool004h0oooo0P00000:0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01000000[0?ooo`030000003oool0oooo00H0oooo0`00
00020?ooo`<000006P3oool004l0oooo0P0000090?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool00P3oool4000005X0oooo001A0?ooo`8000001`3oool00`000000oooo0?ooo`0G0?oo
o`D00000603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>@3oool00400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0000000<000006`3oool00`000000oooo000000070?ooo`030000003oool00000
03X0oooo000o0?ooo`030000003oool0000000P0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01000000O
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0>03oool003l0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo1000000S0?oo
o`030000003oool0000000L0oooo0P00000k0?ooo`00?`3oool00`000000oooo000000090?ooo`03
0000003oool0oooo008000001P3oool01@000000oooo0000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool5000002L0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0j0?oo
o`00?`3oool00`000000oooo000000070?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`00000/0?ooo`03
0000003oool0oooo00H0oooo0`00000j0?ooo`00@03oool00`000000oooo0?ooo`060?ooo`<00000
0P3oool3000000P0oooo0P0000020?ooo`@000004@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`1C0?ooo`00FP3oool3000001@0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000005@0oooo
001a0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1B0?ooo`00L@3oool00`000000oooo000000080?ooo`040000003oool0oooo0?ooo`800000E@3o
ool00740oooo00<000000?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003oool0
oooo05@0oooo001b0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0`00001D
0?ooo`00e`3oool005H0oooo1@0000030?ooo`030000003oool0oooo07H0oooo001H0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000M`3oool005P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000001g0?ooo`00F03oool00`000000oooo0?ooo`020?ooo`030000003oool0
000007L0oooo001H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000M`3oool005L0
oooo0P0000050?ooo`030000003oool0oooo07H0oooo003G0?ooo`00e`3oool00=L0oooo003G0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 214}, {287, 0}} -> {0.0678388, -0.0172398, 
  0.00367628, 0.00367628}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[para3d[u,v,Red],arrow[z,Green]];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33948 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166765 1.36779 -1.11022e-016 1.36779 [
[ 0 0 0 0 ]
[ 1 1.33948 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.38041 1.33948 L
s
.38041 1.33948 m
.40038 .572 L
s
.40038 .572 m
.08553 .2305 L
s
.65975 0 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.65975 0 m
.08553 .2305 L
s
.40038 .572 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.38041 1.33948 L
s
.38041 1.33948 m
.40038 .572 L
s
0 0 m
1 0 L
1 1.33948 L
0 1.33948 L
closepath
clip
newpath
.5 Mabswid
.90716 .40628 m .41431 .57336 L .09267 .4786 L p .613 .895 .988 r
F P
0 g
s
.09267 .4786 m .66096 .27005 L .90716 .40628 L p .613 .895 .988 r
F P
0 g
s
0 1 0 r
.09267 .4786 m
.23103 1.17721 L
s
.23103 1.17721 m
.22914 1.07815 L
s
.23103 1.17721 m
.20401 1.13088 L
s
0 g
.25 Mabswid
.65975 0 m
.9246 .39387 L
s
.9246 .39387 m
1 1.19115 L
s
1 1.19115 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.08553 .2305 m
0 1.05197 L
s
0 1.05197 m
.69073 .85027 L
s
.69073 .85027 m
.65975 0 L
s
.65975 0 m
.08553 .2305 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{215, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003G000182000`400?l00000o`00003oe`3oool0
08`0oooo0P0000190?ooo`00RP3oool2000000030?ooo`000000000004P0oooo00270?ooo`<00000
0`3oool2000004P0oooo00250?ooo`8000001P3oool00`000000oooo000000170?ooo`00PP3oool3
000000P0oooo00@000000?ooo`3oool00000AP3oool00800oooo0P00000;0?ooo`040000003oool0
oooo000004H0oooo001m0?ooo`<000003@3oool01@000000oooo0?ooo`3oool0000004D0oooo001k
0?ooo`800000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo001h0?oo
o`<000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo001f0?ooo`80
00005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0440oooo001c0?ooo`<00000
5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo001a0?ooo`8000006P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo001^0?ooo`<00000703oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo03l0oooo001/0?ooo`8000007`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo03h0oooo001Y0?ooo`<000008@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo03h0oooo001W0?ooo`800000903oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo03d0oooo001T0?ooo`<000009`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo03`0oooo001R0?ooo`800000:P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo03`0oooo001O0?ooo`<00000;03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03/0oooo001M0?ooo`800000;`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03X0oooo001J0?ooo`<00000<@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03X0oooo001H0?ooo`800000=03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo03T0oooo001E0?ooo`<00000=P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03P0oooo001C0?ooo`800000>@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03P0oooo001@0?ooo`<00000>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03L0
oooo001=0?ooo`<00000?P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03H0oooo
001;0?ooo`800000@@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03H0oooo0018
0?ooo`<00000@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03D0oooo00160?oo
o`800000AP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03@0oooo00130?ooo`<0
0000B03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03@0oooo00110?ooo`800000
B`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03<0oooo000n0?ooo`<00000C@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo000l0?ooo`800000D03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo000i0?ooo`<00000DP3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0340oooo000g0?ooo`800000E@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0300oooo000d0?ooo`<00000E`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0300oooo000b0?ooo`800000FP3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo02l0oooo000_0?ooo`<00000G03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo02h0oooo000]0?ooo`800000G`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02h0oooo000Z0?ooo`<00000H@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02d0oooo000X0?ooo`800000I03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02`0oooo000U0?ooo`<00000IP3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo02`0oooo000S0?ooo`800000J@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02/0oooo000P0?ooo`<00000J`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02X0oooo000N0?ooo`800000KP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02X0
oooo000K0?ooo`<00000L03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02T0oooo
000I0?ooo`800000M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02P0oooo000F
0?ooo`<00000MP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02P0oooo000D0?oo
o`800000N@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02L0oooo000B0?ooo`80
0000N`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02H0oooo000B0?ooo`800000
N`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02H0oooo000B0?ooo`030000003o
ool0000007X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0U0?ooo`004P3oool0
10000000oooo0?ooo`00001i0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0903o
ool00180oooo00D000000?ooo`3oool0oooo0000001h0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0903oool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00140oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool08P3oool00140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool08P3oool00140oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1`0?ooo`80000000<0oooo0000003oool08P3oool00`000000oooo
0?ooo`0Q0?ooo`004@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06`0oooo0`00
000209cUo0800000903oool00`000000oooo0?ooo`0P0?ooo`004@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo06T0oooo0P00000609cUo0<000008P3oool00`000000oooo0?ooo`0P
0?ooo`004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo0`00000809cU
o0030000002LiO`0W>Gl008000008@3oool00`000000oooo0?ooo`0O0?ooo`004@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0640oooo0`00000;09cUo0030000002LiO`0W>Gl0080
W>Gl00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`004@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo05h0oooo0P00000>09cUo0030000002LiO`0W>Gl00<0W>Gl
0P00000O0?ooo`030000003oool0oooo01h0oooo000A0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0FP3oool300000100W>Gl00<0000009cUo02LiO`01@2LiO`2000001h0oooo00<0
00000?ooo`3oool07@3oool00100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1F
0?ooo`<000004`2LiO`00`000000W>Gl09cUo00709cUo08000007@3oool00`000000oooo0?ooo`0L
0?ooo`00403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0580oooo0`00000F09cU
o0030000002LiO`0W>Gl00T0W>Gl0P00000K0?ooo`030000003oool0oooo01`0oooo000@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0C`3oool2000001T0W>Gl00<0000009cUo02L
iO`02`2LiO`00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo000@0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0B`3oool3000001/0W>Gl00<0000009cUo02LiO`0
302LiO`2000001X0oooo00<000000?ooo`3oool06P3oool00100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`180?ooo`<000007P2LiO`00`000000W>Gl09cUo00>09cUo0800000603o
ool00`000000oooo0?ooo`0J0?ooo`00403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04D0oooo0P00000Q09cUo0030000002LiO`0W>Gl0100W>Gl0P00000G0?ooo`030000003oool0
oooo01T0oooo000@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@@3oool30000
02<0W>Gl00<0000009cUo02LiO`04P2LiO`00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01P0oooo000@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool3000002H0
W>Gl00<0000009cUo02LiO`04`2LiO`2000001D0oooo00<000000?ooo`3oool0603oool00100oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0i0?ooo`<00000:@2LiO`00`000000W>Gl
09cUo00E09cUo0800000503oool00`000000oooo0?ooo`0G0?ooo`00403oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo03H0oooo0P00000/09cUo0030000002LiO`0W>Gl01L0W>Gl0P00
000C0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0<P3oool3000002h0W>Gl00<0000009cUo02LiO`06@2LiO`00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0;P3oool300000340W>Gl00<0000009cUo02LiO`06P2LiO`200000140oooo00<000000?oo
o`3oool05@3oool000l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`80
0000=@2LiO`00`000000W>Gl09cUo00K09cUo0800000403oool00`000000oooo0?ooo`0D0?ooo`00
3`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo0`00000g09cUo0030000
002LiO`0W>Gl01d0W>Gl0P00000>0?ooo`030000003oool0oooo01@0oooo000?0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool08`3oool3000003X0W>Gl00<0000009cUo02LiO`07`2L
iO`00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo000?0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0803oool2000003d0W>Gl00<0000009cUo02LiO`0802LiO`2
000000d0oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0M0?ooo`<00000?`2LiO`00`000000W>Gl09cUo00R09cUo08000002`3oool00`00
0000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01T0
oooo0`00001209cUo0030000002LiO`0W>Gl02@0W>Gl0P00000:0?ooo`030000003oool0oooo0140
oooo000?0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool3000004D0W>Gl
00<0000009cUo02LiO`09P2LiO`2000000T0oooo00<000000?ooo`3oool0403oool000l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`800000B02LiO`00`000000W>Gl09cU
o00X09cUo0030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool000h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0>0?ooo`<00000BP2LiO`00`000000W>Gl09cUo00Y
09cUo08000001P3oool200000140oooo000>0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool02P3oool3000004d0W>Gl00<0000009cUo02LiO`0:`2LiO`2000000060?ooo`0000000000
0000003oool000004@3oool000h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`07
0?ooo`800000D02LiO`00`000000W>Gl09cUo00]09cUo08000000`3oool00`000000oooo0?ooo`0?
0?ooo`003P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo0`00001B09cU
o0030000002LiO`0W>Gl02l0W>Gl00@000000?ooo`3oool000004@3oool000h0oooo00<000000?oo
o`3oool09@3oool00`000000oooo00000002000005D0W>Gl00<0000009cUo02LiO`0:`2LiO`30000
00@0oooo00<000000?ooo`3oool03`3oool000h0oooo00<000000?ooo`3oool0903oool3000005P0
W>Gl00<0000009cUo02LiO`0:02LiO`3000000L0oooo00<000000?ooo`3oool03`3oool000h0oooo
00<000000?ooo`3oool08P3oool2000005/0W>Gl00<0000009cUo02LiO`09@2LiO`3000000/0oooo
00<000000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3oool07`3oool3000005d0W>Gl00<0
000009cUo02LiO`08P2LiO`3000000h0oooo00<000000?ooo`3oool03P3oool000h0oooo00<00000
0?ooo`3oool0703oool300000600W>Gl00<0000009cUo02LiO`07`2LiO`300000140oooo00<00000
0?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool06`3oool2000006<0W>Gl00<0000009cU
o02LiO`0702LiO`3000001@0oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3o
ool0603oool3000006D0W>Gl00<0000009cUo02LiO`06@2LiO`3000001L0oooo00<000000?ooo`3o
ool03P3oool000d0oooo00<000000?ooo`3oool05@3oool3000006P0W>Gl00<0000009cUo02LiO`0
5P2LiO`3000001X0oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool04P3o
ool3000006/0W>Gl00<0000009cUo02LiO`04`2LiO`3000001d0oooo00<000000?ooo`3oool03P3o
ool000d0oooo00<000000?ooo`3oool0403oool2000006h0W>Gl00<0000009cUo02LiO`0402LiO`3
00000200oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool03@3oool30000
0700W>Gl00<0000009cUo02LiO`03@2LiO`3000002<0oooo00<000000?ooo`3oool03P3oool000d0
oooo00<000000?ooo`3oool02P3oool3000007<0W>Gl00<0000009cUo02LiO`02P2LiO`3000002H0
oooo00<000000?ooo`3oool03P3oool000d0oooo00<000000?ooo`3oool0203oool2000007H0W>Gl
00<0000009cUo02LiO`01`2LiO`3000002X0oooo00<000000?ooo`3oool03@3oool000d0oooo00<0
00000?ooo`3oool01@3oool3000007P0W>Gl00<0000009cUo02LiO`0102LiO`3000002d0oooo00<0
00000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3oool00`3oool00`00o`00000009cUo01j
09cUo0040000002LiO`0W>Gl09cUo0<00000<03oool00`000000oooo0?ooo`0=0?ooo`00303oool0
0`000000oooo0?ooo`040?ooo`03003o003oool0000000<00000M`2LiO`4000003<0oooo00<00000
0?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0103oool00`00o`00oooo0?ooo`030?oo
o`<00000LP2LiO`3000003H0oooo00<000000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`050?ooo`@00000JP2LiO`400000080oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`050?ooo`03003o
003oool0oooo00T0oooo0`00001T09cUo0<000001P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0303o
ool3000005h0W>Gl0`00000:0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3o
ool000`0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0?0?ooo`@00000E`2LiO`3
000000d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`00
0000oooo0?ooo`050?ooo`03003o003oool0oooo01<0oooo0`00001A09cUo0<00000403oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo00H0
oooo00<00?l00?ooo`3oool05@3oool4000004X0W>Gl0`00000C0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0303oool000`0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo
0?ooo`0I0?ooo`<00000A02LiO`3000001H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo01`0oooo1000
000m09cUo0<000006@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo000;
0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0803oool3000003L0W>Gl0`00000L
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0S0?ooo`@00000<02LiO`3000001l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0<0?ooo`002`3oool00`000000oooo0?ooo`080?ooo`03
003o003oool0oooo02H0oooo0`00000Z09cUo0<000008P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00`0oooo000;0?ooo`030000003oool0oooo00P0oooo00<00?l00?ooo`3oool0
:@3oool4000002<0W>Gl0`00000U0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
303oool000/0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0]0?ooo`<000007@2L
iO`3000002P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0<0?ooo`002`3oool0
0`000000oooo0?ooo`080?ooo`03003o003oool0oooo0300oooo0`00000G09cUo0<00000:`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo000;0?ooo`030000003oool0oooo
00P0oooo00<00?l00?ooo`3oool0<`3oool400000100W>Gl0`00000^0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0303oool000/0oooo00<000000?ooo`3oool02@3oool00`00o`00
oooo0?ooo`0f0?ooo`<000002P2LiO`300000340oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo03T0oooo
1000000309cUo0<00000=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000;0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0>`3oool5000003L0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`000000oooo0?ooo`0:
0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0oooo00X0oooo00<00?l00?oo
o`3oool0>`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool000X0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0j0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00
2P3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003o
ool0oooo00/0oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02`3oool000X0oooo00<000000?ooo`3oool02`3oool0
0`00o`00oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0;0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo
03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00/0oooo000:0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0>@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool000X0oooo
00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?oo
o`0<0?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo00d0oooo00<00?l0
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool02P3oool000T0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0i0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?oo
o`002@3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo03P0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00090?ooo`030000
003oool0oooo00h0oooo00<00?l00?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool000T0oooo00<000000?ooo`3oool03P3o
ool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0
oooo03P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00X0oooo00090?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool0>03oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02P3oool000T0
oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo
0?ooo`0?0?ooo`03003o003oool0oooo03L0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00080?ooo`030000003oool0oooo0100oooo00<0
0?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`0f
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`09
0?ooo`00203oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo03H0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00080?ooo`03
0000003oool0oooo0140oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02@3oool000P0oooo00<000000?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`090?ooo`00203oool00`000000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo03D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00T0oooo00080?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02@3oool0
00P0oooo00<000000?ooo`3oool04@3oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`090?ooo`00203oool00`000000
oooo0?ooo`0B0?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo0180oooo
00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0203oool000L0oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?oo
o`0d0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`080?ooo`001`3oool00`000000oooo0?ooo`0C0?ooo`03003o003oool0oooo03@0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo00070?oo
o`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool000L0oooo00<000000?ooo`3o
ool0503oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`080?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`03003o
003oool0oooo03<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00P0oooo00070?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203o
ool000L0oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo00070?ooo`030000003oool0oooo01D0
oooo00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool05@3oool00`00o`00oooo
0?ooo`0b0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`070?ooo`001P3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo0380oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00L0oooo0006
0?ooo`030000003oool0oooo01H0oooo00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?oo
o`3oool05P3oool00`00o`00oooo0?ooo`0b0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo0?ooo`0G0?ooo`03
003o003oool0oooo0340oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0
<@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
1`3oool000H0oooo00<000000?ooo`3oool05`3oool00`00o`00oooo0?ooo`0a0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`001P3oool0
0`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo0340oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003oool0oooo
01L0oooo00<00?l00?ooo`3oool0<@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool0603oool00`00o`00
oooo0?ooo`0`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`0H0?ooo`03003o003oool0oooo0300oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00H0oooo
00050?ooo`030000003oool0oooo01T0oooo00<00?l00?ooo`3oool0<03oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01P3oool000D0oooo00<00000
0?ooo`3oool06@3oool00`00o`00oooo0?ooo`0`0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`060?ooo`001@3oool00`000000oooo0?ooo`0I0?oo
o`03003o003oool0oooo0300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00H0oooo00050?ooo`030000003oool0oooo01X0oooo00<00?l00?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool01P3oool000D0oooo00<000000?ooo`3oool06P3oool00`00o`00oooo0?ooo`0_0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`060?ooo`001@3o
ool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo02l0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00H0oooo00050?ooo`030000003oool0
oooo01X0oooo00<00?l00?ooo`3oool0;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool01P3oool000D0oooo00<000000?ooo`3oool06P3oool00`00
o`00oooo0?ooo`0_0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`060?ooo`001@3oool00`000000oooo0?ooo`0K0?ooo`03003o003oool0oooo02h0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0
oooo00040?ooo`030000003oool0oooo01`0oooo00<00?l00?ooo`3oool0;P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool000@0oooo00<0
00000?ooo`3oool0703oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo03/0oooo0P00
000k0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo01`0oooo00<00?l0
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0g0?ooo`@000000P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo01`0oooo00<00?l00?oo
o`3oool0;@3oool00`000000oooo0?ooo`0e0?ooo`<000001`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3o
ool0;03oool00`000000oooo0?ooo`0b0?ooo`<000002`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00D0oooo00040?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0
;03oool00`000000oooo0?ooo`0^0?ooo`@000003`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00D0oooo00040?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0;03o
ool00`000000oooo0?ooo`0[0?ooo`<00000503oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00D0oooo00040?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0;03oool0
0`000000oooo0?ooo`0W0?ooo`@00000603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00D0oooo00040?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0;03oool00`00
0000oooo0?ooo`0T0?ooo`<00000703oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00D0oooo00040?ooo`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool0:`3oool00`000000
oooo0?ooo`0P0?ooo`@00000803oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0
oooo00030?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo
0?ooo`0M0?ooo`<000009@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00@0oooo
00030?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?oo
o`0J0?ooo`<00000:@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00@0oooo0003
0?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`0F
0?ooo`@00000;@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00@0oooo00030?oo
o`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?oo
o`<00000<P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00030?ooo`03
0000003oool0oooo0200oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`0?0?ooo`@0
0000=P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00030?ooo`030000
003oool0oooo0200oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`<00000
>`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo00030?ooo`030000003o
ool0oooo0200oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`<00000?`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00@0oooo00030?ooo`030000003oool0
oooo0200oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`@00000@`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo00030?ooo`030000003oool0oooo
0200oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`<00000B03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo00030?ooo`030000003oool0oooo0240
oooo00<00?l00?ooo`3oool0:@3oool5000004`0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`030?ooo`000P3oool00`000000oooo0?ooo`0R0?ooo`03003o003oool0oooo02L0oooo
0`00001@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00080oooo00<0
00000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0S0?ooo`@000000P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00`3oool00080oooo00<00000
0?ooo`3oool08P3oool00`00o`00oooo0?ooo`0P0?ooo`<000001P3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?oo
o`3oool08P3oool00`00o`00oooo0?ooo`0M0?ooo`<000002@3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3o
ool08`3oool00`00o`00oooo0?ooo`0H0?ooo`@00000303oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool0
8`3oool00`00o`00oooo0?ooo`0E0?ooo`<00000403oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool08`3o
ool00`00o`00oooo0?ooo`0A0?ooo`@000004`3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool08`3oool0
0`00o`00oooo0?ooo`0>0?ooo`<000005`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool08`3oool00`00
o`00oooo0?ooo`0:0?ooo`@000006P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00`3oool00080oooo00<000000?ooo`3oool0903oool00`00o`00
oooo0?ooo`060?ooo`<000007P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00P3oool000030?ooo`000000oooo02H0oooo00<00?l00?ooo`3oool0
0`3oool300000240oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0080oooo00000`3oool000000?ooo`0V0?ooo`03003o003oool0000000<00000903o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000oooo02D0oooo0`00000X0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000003oool08@3oool40000
00030?ooo`00o`00oooo02P0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0080oooo00000`3oool000000?ooo`0N0?ooo`<000001P3oool00`00o`00
oooo0?ooo`0V0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`020?ooo`0000<0oooo0000003oool06`3oool3000000T0oooo00<00?l00?ooo`3oool0
9P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
0P3oool000030?ooo`000000oooo01L0oooo1000000<0?ooo`03003o003oool0oooo02H0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo0000
0`3oool000000?ooo`0D0?ooo`<00000403oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`0000<0oooo0000
003oool0403oool4000001<0oooo00<00?l00?ooo`3oool09P3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000oooo00d0
oooo0`00000H0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0040oooo00000`000000oooo0?ooo`090?ooo`@00000
6`3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`010?ooo`0000<000000?ooo`3oool01P3oool3000001l0oooo00<0
0?l00?ooo`3oool09@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool00@3oool000030000003oool0oooo00<0oooo0`00000R0?ooo`03003o003oool0
oooo02D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0040oooo00000`000000oooo00000003000002D0oooo00<00?l00?ooo`3oool09@3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00@3oool00080
0000:P3oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`010?ooo`0000<0oooo0000003oool0:@3oool00`00o`00oooo
0?ooo`0S0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`010?ooo`000P3oool2000002P0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00@3oool000@0oooo00<00000
0?ooo`3oool09@3oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?ooo`0T0?oo
o`03003o003oool0oooo02<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0040oooo00060?ooo`8000009@3oool01@00o`00oooo0?ooo`3oool00?l0
0200oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool10?oo
o`00203oool00`000000oooo0?ooo`0R0?ooo`05003o003oool0oooo0?ooo`00o`00803oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo0240oooo00D00?l00?ooo`3oool0oooo003o000P0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0403oool100000040oooo0@3oool000X0oooo0P00000Q0?ooo`05
003o003oool0oooo0?ooo`00o`00803oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00l0oooo0@0000010?ooo`40oooo000<0?ooo`030000003oool0oooo01h0oooo00D00?l00?ooo`3o
ool0oooo003o000P0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool03P3oool10000
0040oooo0@3oool000d0oooo00<000000?ooo`3oool07P3oool01000o`00oooo0?ooo`00o`0P0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool03@3oool100000040oooo0@3oool000h0
oooo0P00000N0?ooo`04003o003oool0oooo003o0200oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`0<0?ooo`4000000@3oool10?ooo`00403oool00`000000oooo0?ooo`0K0?ooo`04
003o003oool0oooo003o0200oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0<0?oo
o`4000000@3oool10?ooo`004@3oool00`000000oooo0?ooo`0J0?ooo`04003o003oool0oooo003o
0200oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool10?oo
o`004P3oool2000001X0oooo00@00?l00?ooo`3oool00?l0803oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo00X0oooo0@0000010?ooo`40oooo000D0?ooo`030000003oool0oooo01P0
oooo00<00?l00?ooo`00o`00803oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00X0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0G0?ooo`03003o003oool00?l00200oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`090?ooo`4000000@3oool001H0oooo0P00
000C0?ooo`07003o003oool0oooo0?ooo`00o`00oooo003o000P0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0203oool100000040oooo000H0?ooo`030000003oool0oooo0140oooo
00H00?l00?ooo`3oool00?l00?ooo`00o`0P0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool01`3oool100000040oooo000I0?ooo`030000003oool0oooo0100oooo00H00?l00?ooo`3o
ool00?l00?ooo`00o`0P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool01P3oool1
00000040oooo000J0?ooo`8000004@3oool00`00o`00oooo0?ooo`02003o0200oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`050?ooo`4000000@3oool001`0oooo00<000000?ooo`3o
ool03P3oool00`00o`00oooo0?ooo`02003o0200oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`040?ooo`4000000@3oool001d0oooo00<000000?ooo`3oool03P3oool01000o`00oooo
003o0000o`0P0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool00`3oool100000040
oooo000N0?ooo`8000003`3oool3003o0200oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`4000000@3oool00200oooo00<000000?ooo`3oool0303oool3003o0200oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool00240oooo00<00000
0?ooo`3oool0303oool2003o0200oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`02
0?ooo`400000000R0?ooo`800000303oool2003o0200oooo00<000000?ooo`3oool0O@3oool01000
0000oooo0?ooo`3oool100000000903oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo
01h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`01000000009@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo0@0000010?ooo`400000000V0?ooo`800000
:P3oool00`000000oooo0?ooo`200?ooo`800000000X0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0O`3oool300000000:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo07/0oooo100000030?ooo`00:P3oool2000002H0oooo00<000000?ooo`3oool0M`3oool40000
00L0oooo000/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0LP3oool5000000/0
oooo000]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0KP3oool400000100oooo
000^0?ooo`8000008P3oool00`000000oooo0?ooo`1Z0?ooo`@00000503oool00300oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1V0?ooo`@00000603oool00340oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1Q0?ooo`D00000703oool00380oooo0P00000N0?ooo`03
0000003oool0oooo05d0oooo1000000Q0?ooo`00=03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo05T0oooo1000000U0?ooo`00=@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo05@0oooo1@00000Y0?ooo`00=P3oool2000001T0oooo00<000000?ooo`3oool0D@3oool4
000002h0oooo000h0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0C@3oool40000
0380oooo000i0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0B@3oool4000003H0
oooo000j0?ooo`8000005@3oool00`000000oooo0?ooo`140?ooo`D00000>P3oool003`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`100?ooo`@00000?`3oool003d0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0l0?ooo`@00000@`3oool003h0oooo0P00000A0?oo
o`030000003oool0oooo03L0oooo1@0000170?ooo`00@03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo03<0oooo1000001<0?ooo`00@@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo02l0oooo1000001@0?ooo`00@P3oool2000000d0oooo00<000000?ooo`3oool0:`3o
ool4000005@0oooo00140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool5
000005P0oooo00150?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool40000
05d0oooo00160?ooo`8000002@3oool00`000000oooo0?ooo`0N0?ooo`@00000H@3oool004P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`D00000I@3oool004T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`@00000JP3oool004X0oooo0P000005
0?ooo`030000003oool0oooo0140oooo1000001^0?ooo`00C03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo1000001b0?ooo`00C@3oool01@000000oooo0?ooo`3oool00000
00X0oooo1@00001f0?ooo`00CP3oool2000000030?ooo`000000oooo00D0oooo1000001k0?ooo`00
D03oool200000080oooo1000001o0?ooo`00D@3oool3000008<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 214}, {287, 0}} -> {0.121919, -0.000604956, 
  0.00341642, 0.00341642}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "ATLAST 4.2; 9 -- Commute with Me -- ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " help for (c)"
}], "Section"],

Cell["\<\
Define A, B, and M = AB-BA.  Make sure to Clear any variable names that \
should be undefined parameters.\
\>", "Text"],

Cell["Coefficient[M,r]", "Input"],

Cell["Flatten[Coefficient[M,r]]", "Input"],

Cell["Flatten[Coefficient[M,s]]", "Input"],

Cell["\<\
coefs = Map[ Flatten[Coefficient[M,#]]&,
             {r,s,t,u,v,w,x,y,z}]\
\>", "Input"],

Cell["\<\
Use the coefs matrix to find solutions for {r,s,t,u,v,w,x,y,z}, name the \
result solns (you should find more than one).  Beware, you don't want to use \
coefs directly; you have to do one more operation on it.\
\>", "Text"],

Cell["solns = ", "Input"],

Cell["soln1 = solns[[1]]", "Input"],

Cell["B1 = Partition[soln1,3]", "Input"],

Cell["soln2 = solns[[2]]", "Input"],

Cell["B2 = Partition[soln2,3]", "Input"],

Cell["continue...", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 4.2; 9 -- Commute with Me (centralizer) -- Solutions", "Section"],

Cell[CellGroupData[{

Cell["(c)", "Subsection"],

Cell["\<\
Define A, B, and M = AB-BA.  Make sure to Clear any variable names that \
should be undefined parameters.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A = {{2,3,0},{-5,-7,-3},{3,4,2}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "3", "0"},
            {\(-5\), \(-7\), \(-3\)},
            {"3", "4", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[r,s,t,u,v,w,x,y,z]
B = {{r,s,t},{u,v,w},{x,y,z}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"r", "s", "t"},
            {"u", "v", "w"},
            {"x", "y", "z"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["M = A.B-B.A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(5\ s - 3\ t + 3\ u\), \(\(-3\)\ r + 9\ s - 4\ t + 3\ v\), 
              \(3\ s + 3\ w\)},
           
             {\(\(-5\)\ r - 9\ u + 5\ v - 3\ w - 3\ x\), 
              \(\(-5\)\ s - 3\ u - 4\ w - 3\ y\), 
              \(\(-5\)\ t + 3\ v - 9\ w - 3\ z\)},
           
             {\(3\ r + 4\ u + 5\ y - 3\ z\), 
              \(3\ s + 4\ v - 3\ x + 9\ y - 4\ z\), \(3\ t + 4\ w + 3\ y\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficient[M,r]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-3\), "0"},
            {\(-5\), "0", "0"},
            {"3", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flatten[Coefficient[M,r]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, \(-3\), 0, \(-5\), 0, 0, 3, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flatten[Coefficient[M,s]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{5, 9, 3, 0, \(-5\), 0, 0, 3, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
coefs = Map[ Flatten[Coefficient[M,#]]&,
             {r,s,t,u,v,w,x,y,z}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", \(-3\), "0", \(-5\), "0", "0", "3", "0", "0"},
            {"5", "9", "3", "0", \(-5\), "0", "0", "3", "0"},
            {\(-3\), \(-4\), "0", "0", "0", \(-5\), "0", "0", "3"},
            {"3", "0", "0", \(-9\), \(-3\), "0", "4", "0", "0"},
            {"0", "3", "0", "5", "0", "3", "0", "4", "0"},
            {"0", "0", "3", \(-3\), \(-4\), \(-9\), "0", "0", "4"},
            {"0", "0", "0", \(-3\), "0", "0", "0", \(-3\), "0"},
            {"0", "0", "0", "0", \(-3\), "0", "5", "9", "3"},
            {"0", "0", "0", "0", "0", \(-3\), \(-3\), \(-4\), "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Use the coefs matrix to find solutions for {r,s,t,u,v,w,x,y,z}, name the \
result solns (you should find more than one).  Beware, you don't want to use \
coefs directly; you have to do one more operation on it.\
\>", "Text"],

Cell[CellGroupData[{

Cell["solns = NullSpace[Transpose[coefs]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "1", "0", "0", "0", "1"},
            {"9", "21", "27", \(-8\), \(-18\), \(-21\), "0", "1", "0"},
            {\(-12\), \(-27\), \(-36\), "9", "21", "27", "1", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["soln1 = solns[[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 0, 0, 0, 1, 0, 0, 0, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B1 = Partition[soln1,3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["soln2 = solns[[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{9, 21, 27, \(-8\), \(-18\), \(-21\), 0, 1, 0}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B2 = Partition[soln2,3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"9", "21", "27"},
            {\(-8\), \(-18\), \(-21\)},
            {"0", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln3\  = \ solns[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-12\), \(-27\), \(-36\), 9, 21, 27, 1, 0, 0}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B3 = Partition[soln3,3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-12\), \(-27\), \(-36\)},
            {"9", "21", "27"},
            {"1", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c]
commuter = a*B1+b*B2+c*B3\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(a + 9\ b - 12\ c\), \(21\ b - 27\ c\), \(27\ b - 36\ c\)},
            {\(9\ c - 8\ b\), \(a - 18\ b + 21\ c\), \(27\ c - 21\ b\)},
            {"c", "b", "a"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A.commuter\  == \ commuter.A]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alternatives", "Subsubsection"],

Cell[CellGroupData[{

Cell["col = Transpose[{Flatten[A.B-B.A]}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(5\ s - 3\ t + 3\ u\)},
            {\(\(-3\)\ r + 9\ s - 4\ t + 3\ v\)},
            {\(3\ s + 3\ w\)},
            {\(\(-5\)\ r - 9\ u + 5\ v - 3\ w - 3\ x\)},
            {\(\(-5\)\ s - 3\ u - 4\ w - 3\ y\)},
            {\(\(-5\)\ t + 3\ v - 9\ w - 3\ z\)},
            {\(3\ r + 4\ u + 5\ y - 3\ z\)},
            {\(3\ s + 4\ v - 3\ x + 9\ y - 4\ z\)},
            {\(3\ t + 4\ w + 3\ y\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficient[col,r]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0"},
            {\(-3\)},
            {"0"},
            {\(-5\)},
            {"0"},
            {"0"},
            {"3"},
            {"0"},
            {"0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TableForm[Map[Coefficient[A.B-B.A,#]&,{r,s}]]", "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"0"},
                  {\(-3\)},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {\(-5\)},
                  {"0"},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"3"},
                  {"0"},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {GridBox[{
                  {"5"},
                  {"9"},
                  {"3"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"0"},
                  {\(-5\)},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"0"},
                  {"3"},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[
         {{{0, -3, 0}, {-5, 0, 0}, {3, 0, 0}}, {{5, 9, 3}, {0, -5, 0}, {0, 3, 
          0}}}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flatten[Solve[A.B-B.A==0,{r,s,t,u,v,w,x,y,z}]]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`Solve::"svars" \( : \ \) 
      "Equations may not give solutions for all \"solve\" variables."\)], 
  "Message"],

Cell[BoxData[
    \(TraditionalForm
    \`{r \[Rule] \(-12\)\ x + 9\ y + z, s \[Rule] 21\ y - 27\ x, 
      t \[Rule] 27\ y - 36\ x, u \[Rule] 9\ x - 8\ y, 
      v \[Rule] 21\ x - 18\ y + z, w \[Rule] 27\ x - 21\ y}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B /. %", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(\(-12\)\ x + 9\ y + z\), \(21\ y - 27\ x\), \(27\ y - 36\ x\)},
            
            {\(9\ x - 8\ y\), \(21\ x - 18\ y + z\), \(27\ x - 21\ y\)},
            {"x", "y", "z"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell[CellGroupData[{

Cell["B1", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2*B1+4*B2+3*B3", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "3", "0"},
            {\(-5\), \(-7\), \(-3\)},
            {"3", "4", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell["(e) dimension of V is 3.", "Subsection"],

Cell[CellGroupData[{

Cell["(f)", "Subsection"],

Cell[CellGroupData[{

Cell["Elem = {{2,0,0},{0,1,0},{0,0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["central = {{a,0,0},{0,b,c},{0,d,e}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"a", "0", "0"},
            {"0", "b", "c"},
            {"0", "d", "e"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elem.central", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(2\ a\), "0", "0"},
            {"0", "b", "c"},
            {"0", "d", "e"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["central.Elem", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(2\ a\), "0", "0"},
            {"0", "b", "c"},
            {"0", "d", "e"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["This is a five dimensional subspace.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(g)", "Subsection"],

Cell["\<\
Let A be any square matrix of 2x2 or greater.  Both I and A are in the \
centralizer.  Case 1:  If I and A are linearly independent then the \
centralizer contains two linearly independent \"vectors\" so that the \
centralizer must be at least two dimensional.  Case 2:  If I and A are \
dependent, then A = cI for some scalar c.  In this case, every matrix \
commutes with A (AB=cB=BA), so the centralizer is the entire (>= 4 \
dimensional) space.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ATLAST 4.2; 11  Basis for the Intersection of Two Vector Spaces\
\>", "Section"],

Cell[CellGroupData[{

Cell["Vmat = {{-2,3},{1,1},{0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "3"},
            {"1", "1"},
            {"0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wmat = {{1,1,0},{-1,1,1},{-5,-1,2}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`Wmat\\)\\\" is similar to existing symbol \\\"\\!\
\\(TraditionalForm\\`Vmat\\)\\\".\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "0"},
            {\(-1\), "1", "1"},
            {\(-5\), \(-1\), "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["RowReduce[Vmat]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0"},
            {"0", "1"},
            {"0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Columns of Vmat form a basis of space V.  dim V = 2.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b)", "Subsection"],

Cell[CellGroupData[{

Cell["RowReduce[Wmat]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-\(1\/2\)\)},
            {"0", "1", \(1\/2\)},
            {"0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
First two columns of Wmat form a basis of space W.  dim W = 2.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(c)", "Subsection"],

Cell[CellGroupData[{

Cell["Vus = {{-2,3,-1,4,-1},{1,1,3,8,0},{0,1,1,4,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "3", \(-1\), "4", \(-1\)},
            {"1", "1", "3", "8", "0"},
            {"0", "1", "1", "4", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[Vus]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "2", "4", "0"},
            {"0", "1", "1", "4", "0"},
            {"0", "0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["u1 and u2 are in V but u3 is not.", "Text"],

Cell[CellGroupData[{

Cell["Wus = {{1,1,0,-1,4,-1},{-1,1,1,3,8,0},{-5,-1,2,1,4,3}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "0", \(-1\), "4", \(-1\)},
            {\(-1\), "1", "1", "3", "8", "0"},
            {\(-5\), \(-1\), "2", "1", "4", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RowReduce[Wus]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-\(1\/2\)\), "0", \(-2\), \(-\(1\/2\)\)},
            {"0", "1", \(1\/2\), "0", "6", \(-\(1\/2\)\)},
            {"0", "0", "0", "1", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["u2 and u3 are in W but u1 is not.", "Text"],

Cell["So, of these three vectors, only u2 is in both V and W.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell[CellGroupData[{

Cell["NullSpace[Transpose[Vmat]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), \(-2\), "5"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["So, -x1-2x2+5x3 = 0 is the plane that is V.", "Text"],

Cell[CellGroupData[{

Cell["NullSpace[Transpose[Wmat]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", \(-2\), "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["So, 3x1-2x2+x3 = 0 is the plane that is W.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(e)", "Subsection"],

Cell["\<\
V is a two dimensional plane, W is a two dimensional plane, V intersect W is \
a one-dim line.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(f)", "Subsection"],

Cell["\<\
So V intersect W is given by:  -x1-2x2+5x3 = 0 and 3x1-2x2+x3 = 0.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(g)", "Subsection"],

Cell[CellGroupData[{

Cell["NullSpace[{{-1,-2,5},{3,-2,1}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["So dim V intersect W is 1.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(h)", "Subsection"],

Cell[CellGroupData[{

Cell["Vmat = Transpose[{{1,3,-2,-2},{4,0,1,4},{-3,-3,1,2}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "4", \(-3\)},
            {"3", "0", \(-3\)},
            {\(-2\), "1", "1"},
            {\(-2\), "4", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wmat = {{4,2,1,5},{3,-3,-2,3},{0,3,2,0},{-4,4,0,4}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4", "2", "1", "5"},
            {"3", \(-3\), \(-2\), "3"},
            {"0", "3", "2", "0"},
            {\(-4\), "4", "0", "4"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eq1 = NullSpace[Transpose[Vmat]][[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-2\), 4, 4, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eq2 = NullSpace[Transpose[Wmat]][[1]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-8\), 12, 16, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{eq1,eq2}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "4", "4", "1"},
            {\(-8\), "12", "16", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSpace[{eq1,eq2}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-4\), \(-3\), "0", "4"},
            {"2", "0", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[%]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-4\), "2"},
            {\(-3\), "0"},
            {"0", "1"},
            {"4", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["These vectors are a basis of V intersect W.", "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{588, 388},
WindowMargins->{{-1, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 162, 4, 66, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1896, 57, 65, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[1986, 61, 143, 5, 53, "Section"],

Cell[CellGroupData[{
Cell[2154, 70, 67, 0, 47, "Subsection"],
Cell[2224, 72, 72, 1, 30, "Input",
  InitializationCell->True],
Cell[2299, 75, 66, 1, 30, "Input",
  InitializationCell->True],
Cell[2368, 78, 197, 7, 102, "Input",
  InitializationCell->True],
Cell[2568, 87, 516, 14, 228, "Input",
  InitializationCell->True],
Cell[3087, 103, 393, 11, 174, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3517, 119, 57, 0, 31, "Subsection"],
Cell[3577, 121, 30, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[3632, 125, 146, 3, 60, "Subsubsection"],
Cell[3781, 130, 155, 3, 33, "Text"],
Cell[3939, 135, 23, 0, 30, "Input"],
Cell[3965, 137, 27, 0, 30, "Input"],
Cell[3995, 139, 268, 9, 33, "Text"]
}, Open  ]],
Cell[4278, 151, 121, 3, 43, "Subsubsection"],
Cell[4402, 156, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4481, 160, 64, 0, 43, "Subsubsection"],
Cell[4548, 162, 23, 0, 30, "Input"],
Cell[4574, 164, 94, 2, 33, "Text"],
Cell[4671, 168, 24, 0, 30, "Input"],
Cell[4698, 170, 23, 0, 30, "Input"],
Cell[4724, 172, 365, 6, 90, "Text"],
Cell[5092, 180, 17, 0, 30, "Input"],
Cell[5112, 182, 114, 3, 33, "Text"],
Cell[5229, 187, 27, 0, 30, "Input"],
Cell[5259, 189, 113, 3, 33, "Text"],
Cell[5375, 194, 91, 2, 33, "Text"],
Cell[5469, 198, 24, 0, 30, "Input"],
Cell[5496, 200, 167, 3, 33, "Text"],
Cell[5666, 205, 28, 0, 30, "Input"],
Cell[5697, 207, 133, 3, 33, "Text"],
Cell[5833, 212, 34, 0, 30, "Input"],
Cell[5870, 214, 396, 7, 71, "Text"],
Cell[6269, 223, 27, 0, 30, "Input"],
Cell[6299, 225, 27, 0, 33, "Text"],
Cell[6329, 227, 23, 0, 30, "Input"],
Cell[6355, 229, 37, 0, 33, "Text"],
Cell[6395, 231, 23, 0, 30, "Input"],
Cell[6421, 233, 23, 0, 30, "Input"],
Cell[6447, 235, 36, 0, 30, "Input"],
Cell[6486, 237, 187, 4, 52, "Text"],
Cell[6676, 243, 21, 0, 30, "Input"],
Cell[6700, 245, 23, 0, 30, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6784, 252, 151, 5, 54, "Section"],

Cell[CellGroupData[{
Cell[6960, 261, 67, 0, 47, "Subsection"],
Cell[7030, 263, 72, 1, 30, "Input",
  InitializationCell->True],
Cell[7105, 266, 66, 1, 30, "Input",
  InitializationCell->True],
Cell[7174, 269, 197, 7, 102, "Input",
  InitializationCell->True],
Cell[7374, 278, 516, 14, 228, "Input",
  InitializationCell->True],
Cell[7893, 294, 393, 11, 174, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8323, 310, 57, 0, 31, "Subsection"],
Cell[8383, 312, 30, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[8438, 316, 146, 3, 60, "Subsubsection"],
Cell[8587, 321, 155, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[8767, 328, 23, 0, 30, "Input"],
Cell[8793, 330, 19305, 345, 173, 2790, 137, "GraphicsData", 
"PostScript", "Graphics"],
Cell[28101, 677, 97, 2, 25, "Print"],
Cell[28201, 681, 70, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28308, 687, 31, 0, 30, "Input"],
Cell[28342, 689, 16899, 324, 135, 2899, 147, "GraphicsData", 
"PostScript", "Graphics"],
Cell[45244, 1015, 242, 5, 25, "Print"]
}, Open  ]],
Cell[45501, 1023, 268, 9, 33, "Text"]
}, Open  ]],
Cell[45784, 1035, 121, 3, 43, "Subsubsection"],
Cell[45908, 1040, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[45987, 1044, 77, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[46089, 1048, 23, 0, 30, "Input"],
Cell[46115, 1050, 23823, 401, 277, 2776, 137, "GraphicsData", 
"PostScript", "Graphics"],
Cell[69941, 1453, 97, 2, 25, "Print"],
Cell[70041, 1457, 70, 1, 25, "Print"]
}, Open  ]],
Cell[70126, 1461, 94, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[70245, 1467, 24, 0, 30, "Input"],
Cell[70272, 1469, 277, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70586, 1480, 23, 0, 30, "Input"],
Cell[70612, 1482, 105, 2, 29, "Output"]
}, Open  ]],
Cell[70732, 1487, 365, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[71122, 1497, 55, 0, 30, "Input"],
Cell[71180, 1499, 111, 2, 29, "Output"]
}, Open  ]],
Cell[71306, 1504, 114, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[71445, 1511, 32, 0, 30, "Input"],
Cell[71480, 1513, 25946, 436, 277, 2890, 147, "GraphicsData", 
"PostScript", "Graphics"],
Cell[97429, 1951, 242, 5, 25, "Print"]
}, Open  ]],
Cell[97686, 1959, 113, 3, 33, "Text"],
Cell[97802, 1964, 91, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[97918, 1970, 62, 0, 30, "Input"],
Cell[97983, 1972, 111, 2, 29, "Output"]
}, Open  ]],
Cell[98109, 1977, 167, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[98301, 1984, 28, 0, 30, "Input"],
Cell[98332, 1986, 121, 3, 29, "Output"]
}, Open  ]],
Cell[98468, 1992, 133, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[98626, 1999, 34, 0, 30, "Input"],
Cell[98663, 2001, 23936, 411, 277, 2889, 147, "GraphicsData", 
"PostScript", "Graphics"],
Cell[122602, 2414, 198, 4, 25, "Print"]
}, Open  ]],
Cell[122815, 2421, 415, 7, 71, "Text"],
Cell[123233, 2430, 65, 0, 30, "Input"],
Cell[123301, 2432, 27, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[123353, 2436, 23, 0, 30, "Input"],
Cell[123379, 2438, 111, 2, 29, "Output"]
}, Open  ]],
Cell[123505, 2443, 37, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[123567, 2447, 23, 0, 30, "Input"],
Cell[123593, 2449, 15975, 304, 207, 2767, 137, "GraphicsData", 
"PostScript", "Graphics"],
Cell[139571, 2755, 97, 2, 25, "Print"],
Cell[139671, 2759, 70, 1, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139778, 2765, 23, 0, 30, "Input"],
Cell[139804, 2767, 110, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139951, 2774, 36, 0, 30, "Input"],
Cell[139990, 2776, 16084, 314, 207, 2876, 147, "GraphicsData", 
"PostScript", "Graphics"],
Cell[156077, 3092, 249, 5, 26, "Print"]
}, Open  ]],
Cell[156341, 3100, 187, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[156553, 3108, 21, 0, 30, "Input"],
Cell[156577, 3110, 111, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156725, 3117, 23, 0, 30, "Input"],
Cell[156751, 3119, 110, 2, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[156934, 3129, 67, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[157026, 3133, 75, 0, 30, "Input"],
Cell[157104, 3135, 301, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157442, 3149, 32, 0, 30, "Input"],
Cell[157477, 3151, 63, 1, 29, "Output"]
}, Open  ]],
Cell[157555, 3155, 492, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[158072, 3167, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[158122, 3171, 31, 0, 30, "Input"],
Cell[158156, 3173, 290, 9, 98, "Output"]
}, Open  ]],
Cell[158461, 3185, 187, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158685, 3194, 25, 0, 47, "Subsection"],
Cell[158713, 3196, 193, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[158931, 3204, 34, 0, 30, "Input"],
Cell[158968, 3206, 300, 8, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[159317, 3220, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[159367, 3224, 55, 0, 30, "Input"],
Cell[159425, 3226, 73, 1, 44, "Output"]
}, Open  ]],
Cell[159513, 3230, 116, 3, 33, "Text"],
Cell[159632, 3235, 34, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[159691, 3239, 41, 0, 30, "Input"],
Cell[159735, 3241, 70, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159842, 3247, 28, 0, 30, "Input"],
Cell[159873, 3249, 104, 2, 29, "Output"]
}, Open  ]],
Cell[159992, 3254, 115, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[160132, 3261, 38, 0, 30, "Input"],
Cell[160173, 3263, 89, 1, 44, "Output"]
}, Open  ]],
Cell[160277, 3267, 22, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[160324, 3271, 35, 0, 30, "Input"],
Cell[160362, 3273, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160454, 3279, 38, 0, 30, "Input"],
Cell[160495, 3281, 91, 1, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[160635, 3288, 25, 0, 47, "Subsection"],
Cell[160663, 3290, 137, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[160825, 3297, 39, 0, 30, "Input"],
Cell[160867, 3299, 167, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161071, 3307, 37, 0, 30, "Input"],
Cell[161111, 3309, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161220, 3315, 44, 0, 30, "Input"],
Cell[161267, 3317, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161376, 3323, 44, 0, 30, "Input"],
Cell[161423, 3325, 72, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[161544, 3332, 57, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[161626, 3336, 48, 0, 30, "Input"],
Cell[161677, 3338, 142, 3, 25, "Message"],
Cell[161822, 3343, 434, 12, 98, "Output"]
}, Open  ]],
Cell[162271, 3358, 107, 3, 33, "Text"],
Cell[162381, 3363, 309, 5, 52, "Text"],
Cell[162693, 3370, 232, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[162950, 3378, 64, 0, 30, "Input"],
Cell[163017, 3380, 277, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163331, 3392, 30, 0, 30, "Input"],
Cell[163364, 3394, 265, 7, 62, "Output"]
}, Open  ]],
Cell[163644, 3404, 266, 5, 52, "Text"],
Cell[163913, 3411, 127, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[164065, 3418, 49, 0, 30, "Input"],
Cell[164117, 3420, 293, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164447, 3434, 39, 0, 30, "Input"],
Cell[164489, 3436, 306, 7, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164832, 3448, 39, 0, 30, "Input"],
Cell[164874, 3450, 255, 7, 80, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[165178, 3463, 97, 2, 47, "Subsection"],
Cell[165278, 3467, 347, 6, 71, "Text"],
Cell[165628, 3475, 226, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[165879, 3483, 52, 0, 30, "Input"],
Cell[165934, 3485, 229, 6, 44, "Output"]
}, Open  ]],
Cell[166178, 3494, 316, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[166519, 3503, 141, 3, 50, "Input"],
Cell[166663, 3508, 93, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[166817, 3516, 74, 0, 33, "Section"],
Cell[166894, 3518, 44, 0, 30, "Input"],
Cell[166941, 3520, 169, 6, 102, "Input"],

Cell[CellGroupData[{
Cell[167135, 3530, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[167185, 3534, 36, 0, 30, "Input"],
Cell[167224, 3536, 199, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167460, 3547, 29, 0, 30, "Input"],
Cell[167492, 3549, 196, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167725, 3560, 27, 0, 30, "Input"],
Cell[167755, 3562, 62, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167854, 3568, 29, 0, 30, "Input"],
Cell[167886, 3570, 169, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168092, 3580, 26, 0, 30, "Input"],
Cell[168121, 3582, 57, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[168227, 3589, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[168277, 3593, 101, 4, 66, "Input"],
Cell[168381, 3599, 22043, 483, 296, 3292, 247, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[190473, 4088, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[190523, 4092, 37, 0, 30, "Input"],
Cell[190563, 4094, 200, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190800, 4105, 29, 0, 30, "Input"],
Cell[190832, 4107, 196, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191065, 4118, 27, 0, 30, "Input"],
Cell[191095, 4120, 62, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191194, 4126, 29, 0, 30, "Input"],
Cell[191226, 4128, 169, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191432, 4138, 26, 0, 30, "Input"],
Cell[191461, 4140, 57, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191555, 4146, 101, 4, 66, "Input"],
Cell[191659, 4152, 23038, 495, 296, 3338, 247, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[214746, 4653, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[214796, 4657, 36, 0, 30, "Input"],
Cell[214835, 4659, 195, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215067, 4670, 29, 0, 30, "Input"],
Cell[215099, 4672, 199, 6, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215335, 4683, 29, 0, 30, "Input"],
Cell[215367, 4685, 61, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215465, 4691, 29, 0, 30, "Input"],
Cell[215497, 4693, 173, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215707, 4703, 28, 0, 30, "Input"],
Cell[215738, 4705, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215838, 4711, 101, 4, 66, "Input"],
Cell[215942, 4717, 23858, 520, 296, 3603, 265, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[239849, 5243, 25, 0, 47, "Subsection"],
Cell[239877, 5245, 521, 19, 336, "Input"],
Cell[240401, 5266, 110, 3, 48, "Input"],
Cell[240514, 5271, 169, 6, 102, "Input"],
Cell[240686, 5279, 58, 0, 30, "Input"],
Cell[240747, 5281, 190, 6, 102, "Input"],

Cell[CellGroupData[{
Cell[240962, 5291, 104, 4, 66, "Input"],
Cell[241069, 5297, 43055, 893, 296, 6118, 432, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284161, 6195, 54, 0, 30, "Input"],
Cell[284218, 6197, 36460, 564, 296, 1572, 129, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[320739, 6768, 142, 5, 33, "Section"],
Cell[320884, 6775, 129, 3, 33, "Text"],
Cell[321016, 6780, 33, 0, 30, "Input"],
Cell[321052, 6782, 42, 0, 30, "Input"],
Cell[321097, 6784, 42, 0, 30, "Input"],
Cell[321142, 6786, 99, 3, 48, "Input"],
Cell[321244, 6791, 234, 4, 52, "Text"],
Cell[321481, 6797, 25, 0, 30, "Input"],
Cell[321509, 6799, 35, 0, 30, "Input"],
Cell[321547, 6801, 40, 0, 30, "Input"],
Cell[321590, 6803, 35, 0, 30, "Input"],
Cell[321628, 6805, 40, 0, 30, "Input"],
Cell[321671, 6807, 27, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[321735, 6812, 78, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[321838, 6816, 25, 0, 47, "Subsection"],
Cell[321866, 6818, 129, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[322020, 6825, 49, 0, 30, "Input"],
Cell[322072, 6827, 241, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322350, 6839, 79, 3, 48, "Input"],
Cell[322432, 6844, 193, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322662, 6855, 28, 0, 30, "Input"],
Cell[322693, 6857, 532, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323262, 6875, 33, 0, 30, "Input"],
Cell[323298, 6877, 238, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323573, 6889, 42, 0, 30, "Input"],
Cell[323618, 6891, 88, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323743, 6897, 42, 0, 30, "Input"],
Cell[323788, 6899, 83, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323908, 6905, 99, 3, 48, "Input"],
Cell[324010, 6910, 727, 13, 170, "Output"]
}, Open  ]],
Cell[324752, 6926, 234, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[325011, 6934, 52, 0, 30, "Input"],
Cell[325066, 6936, 349, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325452, 6948, 35, 0, 30, "Input"],
Cell[325490, 6950, 78, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325605, 6956, 40, 0, 30, "Input"],
Cell[325648, 6958, 232, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325917, 6970, 35, 0, 30, "Input"],
Cell[325955, 6972, 100, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326092, 6979, 40, 0, 30, "Input"],
Cell[326135, 6981, 245, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326417, 6993, 59, 1, 30, "Input"],
Cell[326479, 6996, 101, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326617, 7003, 40, 0, 30, "Input"],
Cell[326660, 7005, 246, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326943, 7017, 63, 3, 48, "Input"],
Cell[327009, 7022, 282, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327328, 7033, 71, 1, 30, "Input"],
Cell[327402, 7036, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327494, 7042, 37, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[327556, 7046, 52, 0, 30, "Input"],
Cell[327611, 7048, 517, 12, 170, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[328165, 7065, 35, 0, 30, "Input"],
Cell[328203, 7067, 322, 13, 170, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[328562, 7085, 62, 0, 30, "Input"],
Cell[328627, 7087, 1937, 60, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[330601, 7152, 63, 0, 30, "Input"],
Cell[330667, 7154, 155, 4, 25, "Message"],
Cell[330825, 7160, 230, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331092, 7169, 23, 0, 30, "Input"],
Cell[331118, 7171, 300, 7, 62, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[331479, 7185, 25, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[331529, 7189, 19, 0, 30, "Input"],
Cell[331551, 7191, 232, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331820, 7203, 31, 0, 30, "Input"],
Cell[331854, 7205, 241, 7, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[332122, 7216, 46, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[332193, 7220, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[332243, 7224, 49, 0, 30, "Input"],
Cell[332295, 7226, 232, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332564, 7238, 52, 0, 30, "Input"],
Cell[332619, 7240, 193, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332849, 7251, 29, 0, 30, "Input"],
Cell[332881, 7253, 198, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333116, 7264, 29, 0, 30, "Input"],
Cell[333148, 7266, 198, 6, 62, "Output"]
}, Open  ]],
Cell[333361, 7275, 52, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333450, 7280, 25, 0, 47, "Subsection"],
Cell[333478, 7282, 472, 8, 90, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[333999, 7296, 90, 2, 33, "Section"],

Cell[CellGroupData[{
Cell[334114, 7302, 44, 0, 30, "Input"],
Cell[334161, 7304, 220, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[334418, 7316, 52, 0, 30, "Input"],
Cell[334473, 7318, 289, 6, 25, "Message"],
Cell[334765, 7326, 241, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335043, 7338, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[335093, 7342, 32, 0, 30, "Input"],
Cell[335128, 7344, 217, 7, 62, "Output"]
}, Open  ]],
Cell[335360, 7354, 68, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335465, 7359, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[335515, 7363, 32, 0, 30, "Input"],
Cell[335550, 7365, 247, 7, 80, "Output"]
}, Open  ]],
Cell[335812, 7375, 86, 2, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335935, 7382, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[335985, 7386, 63, 0, 30, "Input"],
Cell[336051, 7388, 271, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336359, 7400, 31, 0, 30, "Input"],
Cell[336393, 7402, 262, 7, 62, "Output"]
}, Open  ]],
Cell[336670, 7412, 49, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[336744, 7416, 71, 0, 30, "Input"],
Cell[336818, 7418, 292, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337147, 7430, 31, 0, 30, "Input"],
Cell[337181, 7432, 315, 7, 80, "Output"]
}, Open  ]],
Cell[337511, 7442, 49, 0, 33, "Text"],
Cell[337563, 7444, 71, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337671, 7449, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[337721, 7453, 43, 0, 30, "Input"],
Cell[337767, 7455, 180, 5, 29, "Output"]
}, Open  ]],
Cell[337962, 7463, 59, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[338046, 7467, 43, 0, 30, "Input"],
Cell[338092, 7469, 177, 5, 29, "Output"]
}, Open  ]],
Cell[338284, 7477, 58, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338379, 7482, 25, 0, 47, "Subsection"],
Cell[338407, 7484, 118, 3, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338562, 7492, 25, 0, 47, "Subsection"],
Cell[338590, 7494, 90, 2, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338717, 7501, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[338767, 7505, 48, 0, 30, "Input"],
Cell[338818, 7507, 174, 5, 29, "Output"]
}, Open  ]],
Cell[339007, 7515, 42, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339086, 7520, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[339136, 7524, 70, 0, 30, "Input"],
Cell[339209, 7526, 273, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339519, 7539, 68, 0, 30, "Input"],
Cell[339590, 7541, 290, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339917, 7554, 54, 0, 30, "Input"],
Cell[339974, 7556, 68, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340079, 7562, 54, 0, 30, "Input"],
Cell[340136, 7564, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340243, 7570, 26, 0, 30, "Input"],
Cell[340272, 7572, 221, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340530, 7583, 37, 0, 30, "Input"],
Cell[340570, 7585, 219, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340826, 7596, 29, 0, 30, "Input"],
Cell[340858, 7598, 247, 8, 80, "Output"]
}, Open  ]],
Cell[341120, 7609, 59, 0, 33, "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

