(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1149327,      29592]*)
(*NotebookOutlinePosition[   1150003,      29616]*)
(*  CellTagsIndexPosition[   1149959,      29612]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College,  6/1/98."
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["\<\
ATLAST 5.2  
Projects on Linear Transformations\
\>", "Subtitle"],

Cell["\<\
Always delete any \"movies\" output (consecutive frames for antimation take \
up to much memory).\
\>", "Text",
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell["\<\
ATLAST 5.2; 2 -- Computer Graphics -- Tutorial & Instructions\
\>", "Section"],

Cell["Ignore the business about MATLAB pause.", "Text"],

Cell[CellGroupData[{

Cell["(a) Graphing Figures using ListPlot", "Subsection"],

Cell[CellGroupData[{

Cell["(i) using ListPlot", "Subsubsection"],

Cell["\<\
For use in Mma's ListPlot command, points are given by a list of ordered \
pairs (instead of vectors x,y and plot(x,y) as in MATLAB).\
\>", "Text"],

Cell["pts = {{.5,-1},{0,1},{-.5,-1},{.5,-1}}", "Input"],

Cell["ListPlot[pts,PlotJoined->True];", "Input"],

Cell["\<\
ListPlot[pts,PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell["\<\
However, for use in matrix transformations it is best to store the points in \
a 2x(n+1) matrix.  There are n+1 points since the first point is repeated at \
the end in order to \"close the loop.\"  I will use lower case letters for \
matices in this problem (since several capitals are Mma functions).  The \
matrices in this ATLAST problem are of this shape.  Using this form, we will \
ListPlot[Transpose[matrix], \"with options\"] (instead of MATLAB's \
plot(T(1,:), T(2,:))).\
\>", "Text"],

Cell["t = Transpose[pts]", "Input"],

Cell["\<\
ListPlot[Transpose[t],PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"]
}, Open  ]],

Cell["\<\
(ii)  Save a 2x(n+1) matrix r and ListPlot the matrix with all of the above \
options.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
(iii)  To superimpose to images in Mma you must (List)Plot them both and save \
the result with names.  
Then Show[ names...].\
\>", "Subsubsection"],

Cell["t1 = Transpose[{{-1,.5},{1,.5},{0,-1},{-1,.5}}]", "Input"],

Cell["\<\
t1Plot = ListPlot[Transpose[t1],PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell["Define matrix t2 and t2Plot.  Then Show[t1Plot, t2Plot].", "Text"],

Cell["Show[t1Plot,t2Plot];", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Supplement to (a) -- defining a function view[matrix, scale].\
\>", "Subsection"],

Cell["\<\
You may be getting tired of typing (or pasting) \"ListPlot[Transpose..., \
PlotJoined..., PlotRange..., AspectRatio...];\" 
To make life easier define a function
    view[matrix_, scale_] := 
that will take a 2x(n+1) matrix and axis scale (2 in the above examples) and \
do the ListPlot with all the options.
Test your function.\
\>", "Text"],

Cell["view[t,1.5];", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["(b) Dilation and Contraction  (making a movie)", "Subsection"],

Cell[CellGroupData[{

Cell["(i)  Before and after", "Subsubsection"],

Cell["t = Transpose[{{.5,-1},{0,1},{-.5,-1},{.5,-1}}]", "Input"],

Cell["Define the matrices d and c.  ", "Text"],

Cell["\<\
All the business about hold on-off is getting MATLAB to superimpose the \
before and after transformation pictures.  Accomplish this by beforePlot = \
view[t,2]; and afterPlot = view[c,2]; and use Show to superimpose.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii)  Making a movie.", "Subsubsection"],

Cell["\<\
The following Mma accomplishes the movie effect in the MATLAB code.\
\>", "Text"],

Cell["\<\
Go to your two separate images above, beforePlot and afterPlot.  Select the \
two cell groups that contain these two plots (and only these two plots) -- \
click on the cell bracket and hold the button while you move until the two \
cell brackets are blackened.  Scroll the notebook until one of the image is \
in the center of the screen.  From the menu choose:  Cell, Animate Selected \
Graphics.  If you don't see the images flashing call for help.\
\>", "Text"],

Cell["\<\
Now let's create ten consecutive images (with scale 10), starting with t and \
repeatedly multiplying by d.  Rather than overwriting the original t, I \
prefer to call all of the transformed matrices c.\
\>", "Text"],

Cell["\<\
c = t;
view[c,10];
Do[
   c = d.c;
   view[c,10]
,{i,1,10}]\
\>", "Input"],

Cell["\<\
Now, Select the cell bracket containing all the plots (second from the \
inside) and animate the plots.
While the movie is playing, play with the \"play-back controls\" down on the \
lower bar.  Describe what each does.\
\>", "Text"],

Cell["\<\
You should probably DELETE all of these PLOTS before saving the notebook.  If \
you are CAREFUL NOT TO DELETE YOUR PROGRAM, you (or I) can always recreate \
them.  Many graphics take up lots of space on the disk and in computer memory \
(RAM) while using the notebook.  If you encounter such problems delete movie \
frames.  One good way to delete only the plots is to Select the cell bracket \
containing all the plots (second from the inside), scroll up to the top to \
make sure that all the plots but NOT the program are selected, then Cut \
(Ctrl-X).\
\>", "Text"]
}, Open  ]],

Cell["(iii)  Make a contraction movie.", "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{

Cell["(c) Reflections", "Subsection"],

Cell["(i) Find A, reflect t and r (from (a)(i)(ii)).", "Subsubsection"],

Cell["\<\
(ii)  Up to the last sentence, do what the problem says as scratch work.  \
Report your result by defining 
A[w_] = the transformation matrix for reflection about a line of angle w.
For the last sentence, use A[Pi/3] to reflect t and r.\
\>", "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{

Cell["(d) Rotations", "Subsection"],

Cell["t = Transpose[{{.5,-1},{0,1},{-.5,-1},{.5,-1}}]", "Input"],

Cell["\<\
(i)  Just define A[theta_] = matrix of rotation through angle theta\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["(ii)  Find A[Pi/4], and use it to rotate t.", "Subsubsection"],

Cell["A[Pi/4]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(iii)  Make a movie as described.  Use transformation matrix defined below.\
\>", "Subsubsection"],

Cell["\<\
Use the following transformation matrix.  It is important to use N[ ] to get \
numerical (\"decimal\") values; otherwise, Mma will bog down (really slows to \
a halt) when it tries to compute many exact compostions.\
\>", "Text"],

Cell["a = N[A[Pi/20]]", "Input"],

Cell["\<\
c = t;
view[c,1.5];
Do[
   c = a.c;
   view[c,1.5]
,{i,1,40}]\
\>", "Input"],

Cell["\<\
When you animate the resulting graphics, it will not stop at the last frame \
but the control buttons allow time and direction (order in which frames are \
displayed) control.\
\>", "Text"],

Cell["\<\
Remember to DELETE all of these PLOTS before saving the notebook.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell["\<\
(e) Combinations of Transformations (i).  (Omit (ii) since animation does \
it.)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
(f) Translations (ii).  (Omit (i) since it was done in homework.)\
\>", "Subsection"],

Cell["t = Transpose[{{1,0},{2,2},{3,0},{1,0}}]", "Input"],

Cell["\<\
Adding one number to a vector is not usually defined in mathematics but Mma \
and MATLAB just add it to every entry.\
\>", "Text"],

Cell["t[[1]]+2", "Input"],

Cell["w = {t[[1]]+2, t[[2]]+3}", "Input"],

Cell["\<\
Save a beforePlot and afterPlot (any scale) and use
Show[beforePlot, afterPlot, PlotRange->{{0,6},{0,6}}];\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(g) Homogeneous Coordinates -- defining function viewhomo
Dilation, Contraction, Reflection, Rotation redone\
\>", "Subsection"],

Cell["m = DiagonalMatrix[{1.25,1.25,1}]", "Input"],

Cell["t = Transpose[{{1,0,1},{2,2,1},{3,0,1},{1,0,1}}]", "Input"],

Cell["\<\
We need to change the view function to a viewhomo function that uses only the \
first two rows of the matrix.  This is easily done by using matrix[[{1,2}]].  \
Observe\
\>", "Text"],

Cell["t[[{1,2}]]", "Input"],

Cell["\<\
Now copy the view function and adapt it to define viewhomo that takes a \
3x(n+1) matrix.
While we're at it, let's allow any PlotRange for given {xmin, xmax, ymin, \
ymax} instead of just scale.\
\>", "Text"],

Cell["\<\
Clear[viewhomo]
viewhomo[matrix_, {xmin_,xmax_,ymin_,ymax_}] := 
\
\>", "Input"],

Cell[CellGroupData[{

Cell["(i) Use m and viewhomo to plot the dialation of t.", "Subsubsection"],

Cell["viewhomo[t,{0,6,0,6}];", "Input"]
}, Open  ]],

Cell["(ii)  Rotate 45 degrees with a 3x3.", "Subsubsection"],

Cell["\<\
(iii)  Just READ and understand this part.  You don't have to turn in \
anything.\
\>", "Subsubsection"]
}, Closed]],

Cell["(h) Translation -- do it.", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Animations in homogeneous coordinates (i), (j), (k) -- movefig\
\>", "Subsection"],

Cell["\<\
The following definition of movefig uses viewhomo[matrix, {xmin, xmax, ymin, \
ymax}], so viewhomo must be working right first.  In range_:{-10,10,-10,10}, \
the colon indicates that what follows is a \"default value\" -- if the user \
doesn't put in any fourth argument, it will assume this value.  Do you \
understand the following program?\
\>", "Text"],

Cell["\<\
movefig[fig_, mat_, n_, range_:{-10,10,-10,10}] := 
Module[{tempfig},
   tempfig = fig;
   viewhomo[tempfig, range];
   Do[
      tempfig = mat.tempfig;
      viewhomo[tempfig, range]
   ,{i,1,n}]
]\
\>", "Input"],

Cell["\<\
The MATLAB movefig command in the book has one additional (fourth) argument \
for pause that we never need, so we don't include it.  Thus when the book \
says movefig(T,D,30,0,[-10,60,-10,40]), we would use \
movefig[t,d,30,{-10,60,-10,40}]  (assuming our matrices are given lowercase \
names).  Also, movefig(T,R,60,0) would simply be movefig[t,r,60].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) Define translation matrix and use movefig as directed.", 
  "Subsection"],

Cell["\<\
Remember to delete the plots (but save the movefig command) after watching \
every movie.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["(j) Define matrices d, r, and s and use movefig as directed.", 
  "Subsection"],

Cell["\<\
For the r matrix, be sure to use N[ ] to define it with numerical entries.\
\>", "Text"],

Cell["\<\
For the s matrix, \"reflection of 180 degrees\" is ambiguous; assume that the \
book means reflection across the x-axis.\
\>", "Text"]
}, Closed]],

Cell["(k)  Use movefig as directed.", "Subsection"],

Cell[CellGroupData[{

Cell["Rising spinning pinwheel example (in spirit of (l)).", "Subsection"],

Cell["p = N[1/Sqrt[2]]", "Input"],

Cell["\<\
pinwheelpts = Transpose[{{0,0},{0,1},{p,p},{0,0},{1,0},
   {p,-p},{0,0},{0,-1},{-p,-p},{0,0},{-1,0},{-p,p},{0,0}}]\
\>", "Input"],

Cell["\<\
pinwheel = Append[pinwheelpts,
                  Table[1,{Length[pinwheelpts[[1]]]}]
           ]\
\>", "Input"],

Cell["viewhomo[pinwheel,{-2,2,-2,2}];", "Input"],

Cell["Let's rotate the pinwheel.", "Text"],

Cell["\<\
rot = N[{{Cos[-Pi/10], -Sin[-Pi/10], 0},
         {Sin[-Pi/10], Cos[-Pi/10],  0},
         {0,           0,            1}}]\
\>", "Input"],

Cell["movefig[pinwheel,rot,20,{-2,2,-2,2}]", "Input"],

Cell["Let's make it rise straight up.", "Text"],

Cell["up = {{1,0,0},{0,1,.2},{0,0,1}}", "Input"],

Cell["movefig[pinwheel,up,20,{-2,2,-1,5}]", "Input"],

Cell["\<\
The real objective of this problem is to make the pinwheel do both \
simultaeously.  Your first idea might be to just multiply by both matrices, \
rot and up, on each step.  But you may be surprised what this does.\
\>", "Text"],

Cell["movefig[pinwheel,up.rot,20,{-2,2,-1,5}]", "Input"],

Cell["Explain why the pinwheel doesn't move straight up.", "Text"],

Cell["\<\
This really is a problem because matrix multiplication is not commutative.  
Explain why the actaion of matrix up.rot is different than the action of \
matrix rot.up.\
\>", "Text"],

Cell["\<\
If we want to rise straight up, we really want to do all of the rotations \
first and then all of the ups.  In particular, after two steps the image \
should be accomplished by up.up.rot.rot and not by up.rot.up.rot.  The idea \
here is to never save a changed figure of points but to always start with the \
original figure and on each step find the new transformation matrix.  We will \
accumulate the net result of n rotations in rotmat and the net result of n \
shifts up in upmat.  These matrices are then alway applied to the original \
image pinwheel. This program will take no input but just use the variables \
pinwheel, up and rot defined above.\
\>", "Text"],

Cell["\<\
Clear[risespin]
risespin :=
Module[{rotmat,upmat},
   rotmat = IdentityMatrix[3];
   upmat = IdentityMatrix[3];
   viewhomo[pinwheel,{-2,2,-1,5}];
   Do[
      rotmat = rot.rotmat;
      upmat = up.upmat;
      viewhomo[upmat.rotmat.pinwheel,{-2,2,-1,5}]
   ,{i,1,20}]
]\
\>", "Input"],

Cell["risespin", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tumbling stickman problem (in spirit of (m)).", "Subsection"],

Cell["\<\
stickman = Transpose[{{-1,-3},{0,-1},{0,0},{-2,1},{0,0},
   {0,1},{-1,2},{0,3},{1,2},{0,1},{0,0},{2,1},{0,0},
   {0,-1},{1,-3}}]\
\>", "Input"],

Cell["stickman = Append[stickman,Table[1,{15}]]", "Input"],

Cell["viewhomo[stickman,{-4,4,-4,4}];", "Input"],

Cell["\<\
Your mission is to adapt the risespin program to make this stickman do \
cartwheels across the screen.  The final result should show him starting by \
standing on the x-axis and tumbling across the x-axis floor for two total \
revolutions.\
\>", "Text"],

Cell["\<\
For extra credit, make him bounce in the air and back down on his feet as he \
tumbles.  To do this realize that, since the original image stays at the \
origin, you can compute the new translation by any formula you want -- it \
doesn't have to be an accumulation of the same translation every time.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 5.2; 2 -- Computer Graphics -- Solutions", "Section"],

Cell["Ignore the business about MATLAB pause.", "Text"],

Cell[CellGroupData[{

Cell["(a) Graphing Figures using ListPlot", "Subsection"],

Cell[CellGroupData[{

Cell["(i)  using ListPlot", "Subsubsection"],

Cell["\<\
For use in Mma's ListPlot command, points are given by a list of ordered \
pairs (instead of vectors x,y and plot(x,y) as in MATLAB).\
\>", "Text"],

Cell[CellGroupData[{

Cell["pts = {{.5,-1},{0,1},{-.5,-1},{.5,-1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], \(-1\)},
            {"0", "1"},
            {
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], \(-1\)},
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ListPlot[pts,PlotJoined->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.294302 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .01472 m
.5 .60332 L
.02381 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oS`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00QP3oool5000000@0
oooo00<000000?ooo`3oool0SP3oool008P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`001`3ooooo000001800000203oool000P0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0N`3oool2000000H0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool02@3oool000/0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00X0oooo000<
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0;
0?ooo`003@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0O`3oool200000800oooo00<000000?ooo`3o
ool0303oool000h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool03`3oool00140oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool04@3oool001<0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0180oooo000D
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0C
0?ooo`005@3oool00`000000oooo0?ooo`1g0?ooo`800000N03oool00`000000oooo0?ooo`0D0?oo
o`005P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool05@3oool001H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06@3oool001/0oooo00<0
00000?ooo`3oool0L@3oool200000780oooo00<000000?ooo`3oool06P3oool001`0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01/0oooo000M0?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0L0?oo
o`007P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool07@3oool001h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo01d0oooo000O0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0N0?ooo`00803oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool07`3oool00240oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000oooo
0?ooo`1Y0?ooo`800000JP3oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08P3oool002@0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo02<0oooo000U0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0T0?oo
o`009P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool09@3oool002L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`0V0?ooo`00:03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo02L0oooo000Y0?ooo`030000003oool0oooo04`0oooo0`0000020?ooo`030000003oool00000
00T0oooo00<000000?ooo`3oool00`3oool3000006<0oooo00<000000?ooo`3oool0:03oool002X0
oooo00<000000?ooo`3oool0D03oool00`000000oooo000000070?ooo`8000001P3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo02T0oooo000[0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`060?ooo`<000001@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02X0oooo000/
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0[
0?ooo`00;@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0;03oool002h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo02d0oooo000_0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`1M0?ooo`800000GP3o
ool00`000000oooo0?ooo`0^0?ooo`00<03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo0300oooo000b0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0a0?ooo`00<`3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0<P3oool003@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03<0oooo000d
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0c
0?ooo`00=@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0=03oool003H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo03D0oooo000g0?ooo`030000003oool0oooo05D0oooo0P00001F0?ooo`030000
003oool0oooo03H0oooo000h0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0g0?ooo`00>03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0i0?ooo`00>`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0>P3oool003`0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03/0oooo000l
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0k
0?ooo`00?@3oool00`000000oooo0?ooo`1?0?ooo`800000D03oool00`000000oooo0?ooo`0l0?oo
o`00?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0?@3oool003l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo03h0oooo00100?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0?`3oool001l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0`00000]0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool300000140oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00000M0?ooo`007P3oool0
0`000000oooo000000090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool0
0`000000oooo000000070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool0
0`000000oooo000000090?ooo`030000003oool0oooo01`0oooo000I0?ooo`<000000P3oool00`00
0000oooo000000070?ooo`@000005`3oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool00`00
0000oooo000000080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo000000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo000000070?ooo`@000007@3oool001h0oooo00<000000?ooo`0000001`3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000001`3oool00`000000
oooo0000000N0?ooo`007P3oool00`000000oooo000000080?ooo`8000006P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000;@3oool2000002h0oooo
00<000000?ooo`0000001`3oool00`000000oooo0000000=0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`000000203oool2000001h0oooo000O0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0703oool004H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04P0oooo00190?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`180?ooo`00BP3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0B@3oool0
0?l00000800000010?ooo`001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo0P00000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`8000003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo000R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0240oooo001=0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`1<0?ooo`00CP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0C@3oool004l0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo04h0oooo001@0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1?0?ooo`00
D@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
D03oool00540oooo00<000000?ooo`3oool0>`3oool2000003`0oooo00<000000?ooo`3oool0D03o
ool00580oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0540oooo001C0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`1B0?ooo`00E03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0D`3oool005D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo05@0oooo001F0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`1E0?ooo`00EP3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0E@3oool005L0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo05H0oooo001H0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1G0?ooo`00
F@3oool00`000000oooo0?ooo`0c0?ooo`800000=03oool00`000000oooo0?ooo`1H0?ooo`00FP3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0F@3o
ool005X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo05T0oooo001K0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`1J0?ooo`00G03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0F`3oool005d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo05`0oooo001N0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1M0?ooo`00GP3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0G@3oool005l0oooo00<000000?oo
o`3oool0;@3oool2000002h0oooo00<000000?ooo`3oool0GP3oool00600oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05l0oooo001Q0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1P0?ooo`00HP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0H@3o
ool00680oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0640oooo001S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0H`3oool006D0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo06@0oooo001V0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?ooo`00I`3oool00`000000oooo0?ooo`0U
0?ooo`8000009P3oool00`000000oooo0?ooo`1V0?ooo`00I`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1X0?ooo`00JP3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J@3o
ool006/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo06X0oooo001[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000L0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06/0
oooo001]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`030?ooo`<000007`3oool00`000000oooo0?ooo`1/0?ooo`00KP3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0K@3oool006l0oooo00<000000?ooo`3oool02`3oool00`000000oooo00000007
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1^
0?ooo`00K`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0`0000050?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0KP3oool00700oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06l0oooo001a0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1`0?ooo`00LP3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0L@3o
ool007<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0780oooo001c0?ooo`030000003oool0oooo01T0oooo0P00000J0?ooo`030000003oool0oooo
0780oooo001d0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1c0?ooo`00M@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0M03oool007H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo07D0oooo001g0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1f0?ooo`00N03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool007P0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07L0oooo001i0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1h0?ooo`00NP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0N@3o
ool007/0oooo00<000000?ooo`3oool04@3oool200000180oooo00<000000?ooo`3oool0NP3oool0
07`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
07/0oooo001l0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1k0?ooo`00O@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0O03oool007h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo07d0oooo001o0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`1n0?ooo`00P03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O`3oool00800oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07l0oooo00210?ooo`030000
003oool0oooo00/0oooo0P00000<0?ooo`030000003oool0oooo0800oooo00220?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`210?ooo`00P`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0PP3oool0
08@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
08<0oooo00240?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`230?ooo`00Q@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0Q03oool008H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08D0oooo00270?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`260?ooo`00R03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q`3oool008T0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo00<000000?ooo`3oool0R03oool008T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08P0oooo002:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`290?ooo`00R`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0RP3oool008`0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`2;0?ooo`00S@3oool01@000000oooo0000003o
ool0000008h0oooo00260?ooo`D000000P3oool01@000000oooo0000003oool0000008h0oooo0028
0?ooo`030000003oool0oooo00<0oooo0`00002?0?ooo`00R03oool00`000000oooo0?ooo`040?oo
o`<00000SP3oool008P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00
R03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00270?ooo`8000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.528102, -1.05358, 
  0.00368016, 0.0119092}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[pts,PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .25 m
.5 .75 L
.375 .25 L
.625 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00KP3ooom6000006`0oooo001^0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06X0oooo001_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000003oool0oooo01L0
oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool006l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo
001_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1[0?ooo`00L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0J`3oool00700oooo00<000000?ooo`3oool07P3oool2000001h0oooo00<000000?oo
o`3oool0K03oool00700oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06`0oooo001`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0K03oool00740oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001a0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`00L@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0K@3oool00780oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001b
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1^
0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0KP3oool007<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06h0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0K`3oool007<0oooo00<000000?ooo`3oool06`3oool2
000001/0oooo00<000000?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001d0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700oooo001e
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`
0?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool2000001T0oooo00<000000?ooo`3o
ool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1a0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0780oooo001g0?ooo`030000003oool0oooo00<000000P3o
ool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`030000003o
ool0oooo07<0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001h0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1c0?ooo`00N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0M03oool007P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo07@0oooo001h0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?oo
o`8000005P3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool007T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001i0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?ooo`00NP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool0
07X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
07D0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1f0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`800000503oool00`000000oooo
0?ooo`1f0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0MP3oool007/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07H0oooo001k0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00O03oool0
0`000000oooo0?ooo`0B0?ooo`8000004P3oool00`000000oooo0?ooo`1h0?ooo`00O03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0N03oool007d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0
oooo00070?ooo`<000006@3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0I0?ooo`D000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool5000001P0oooo1@0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06P3oool3000000<0oooo00070?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`0000001`3oool00`000000oooo000000060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0oooo00<0
00000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`000P3oool3000000<0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D
0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool00`000000oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01P3oool2000001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000070?oo
o`800000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000070?ooo`8000007@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00070?ooo`03
0000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo00080?ooo`030000
003oool0oooo01T0oooo0P0000080?ooo`<000006`3oool2000001d0oooo00<000000?ooo`3oool0
1P3oool3000000L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool3000001/0oooo0P00000K0?ooo`800000
203oool3000001`0oooo00<000000?ooo`3oool00P3oool007h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001o0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0
oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1k0?ooo`001P3ooooo000001P000000`3oool000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`010?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00840oooo00<0
00000?ooo`3oool03@3oool2000000d0oooo00<000000?ooo`3oool0O@3oool00880oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?oo
o`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0OP3oool00880oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool20000
00/0oooo00<000000?ooo`3oool0O`3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00240?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?oo
o`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0P03oool008D0oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<000000?ooo`3oool0
P03oool008D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0840oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0P@3oool008H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<00000
0?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00
Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08<0oooo00200?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P`3oool007l0oooo00<0
00000?ooo`0000001P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`230?ooo`00O`3oool00`000000oooo000000060?ooo`040000003oool0
oooo000000D0oooo0P0000060?ooo`030000003oool0oooo08@0oooo001o0?ooo`030000003oool0
000000L0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool0
07l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0Q03oool00800oooo00<000000?ooo`3oool01P3oool3000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00R@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`25
0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`250?oo
o`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo08H0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo
0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`280?ooo`00S@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`290?ooo`00SP3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo08X0oooo002>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool0
08h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool01P00
0000oooo0?ooo`000000oooo000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03o
ool008l0oooo00D000000?ooo`000000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003o
ool0000008`0oooo002?0?ooo`040000003oool00000000008d0oooo002@0?ooo`<00000S@3oool0
0900oooo0`00002=0?ooo`00T03oool3000008d0oooo00280?ooo`D000000`3oool2000008h0oooo
002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<00000
0?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`00
0000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo002:
0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`2C0?oo
o`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell["\<\
However, for use in matrix transformations it is best to store the points in \
a 2x(n+1) matrix.  There are n+1 points since the first point is repeated at \
the end in order to \"close the loop.\"  I will use lower case letters for \
matices in this problem (since several capitals are Mma functions).  The \
matrices in this ATLAST problem are of this shape.  Using this form, we will \
ListPlot[Transpose[matrix], \"with options\"] (instead of MATLAB's \
plot(T(1,:), T(2,:))).\
\>", "Text"],

Cell[CellGroupData[{

Cell["t = Transpose[pts]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "0", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {\(-1\), "1", \(-1\), \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Transpose[t],PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .25 m
.5 .75 L
.375 .25 L
.625 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00KP3ooom6000006`0oooo001^0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06X0oooo001_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000003oool0oooo01L0
oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool006l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo
001_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1[0?ooo`00L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0J`3oool00700oooo00<000000?ooo`3oool07P3oool2000001h0oooo00<000000?oo
o`3oool0K03oool00700oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06`0oooo001`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0K03oool00740oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001a0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`00L@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0K@3oool00780oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001b
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1^
0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0KP3oool007<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06h0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0K`3oool007<0oooo00<000000?ooo`3oool06`3oool2
000001/0oooo00<000000?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001d0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700oooo001e
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`
0?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool2000001T0oooo00<000000?ooo`3o
ool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1a0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0780oooo001g0?ooo`030000003oool0oooo00<000000P3o
ool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`030000003o
ool0oooo07<0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001h0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1c0?ooo`00N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0M03oool007P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo07@0oooo001h0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?oo
o`8000005P3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool007T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001i0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?ooo`00NP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool0
07X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
07D0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1f0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`800000503oool00`000000oooo
0?ooo`1f0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0MP3oool007/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07H0oooo001k0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00O03oool0
0`000000oooo0?ooo`0B0?ooo`8000004P3oool00`000000oooo0?ooo`1h0?ooo`00O03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0N03oool007d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0
oooo00070?ooo`<000006@3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0I0?ooo`D000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool5000001P0oooo1@0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06P3oool3000000<0oooo00070?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`0000001`3oool00`000000oooo000000060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0oooo00<0
00000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`000P3oool3000000<0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D
0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool00`000000oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01P3oool2000001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000070?oo
o`800000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000070?ooo`8000007@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00070?ooo`03
0000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo00080?ooo`030000
003oool0oooo01T0oooo0P0000080?ooo`<000006`3oool2000001d0oooo00<000000?ooo`3oool0
1P3oool3000000L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool3000001/0oooo0P00000K0?ooo`800000
203oool3000001`0oooo00<000000?ooo`3oool00P3oool007h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001o0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0
oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1k0?ooo`001P3ooooo000001P000000`3oool000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`010?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00840oooo00<0
00000?ooo`3oool03@3oool2000000d0oooo00<000000?ooo`3oool0O@3oool00880oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?oo
o`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0OP3oool00880oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool20000
00/0oooo00<000000?ooo`3oool0O`3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00240?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?oo
o`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0P03oool008D0oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<000000?ooo`3oool0
P03oool008D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0840oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0P@3oool008H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<00000
0?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00
Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08<0oooo00200?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P`3oool007l0oooo00<0
00000?ooo`0000001P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`230?ooo`00O`3oool00`000000oooo000000060?ooo`040000003oool0
oooo000000D0oooo0P0000060?ooo`030000003oool0oooo08@0oooo001o0?ooo`030000003oool0
000000L0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool0
07l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0Q03oool00800oooo00<000000?ooo`3oool01P3oool3000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00R@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`25
0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`250?oo
o`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo08H0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo
0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`280?ooo`00S@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`290?ooo`00SP3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo08X0oooo002>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool0
08h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool01P00
0000oooo0?ooo`000000oooo000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03o
ool008l0oooo00D000000?ooo`000000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003o
ool0000008`0oooo002?0?ooo`040000003oool00000000008d0oooo002@0?ooo`<00000S@3oool0
0900oooo0`00002=0?ooo`00T03oool3000008d0oooo00280?ooo`D000000`3oool2000008h0oooo
002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<00000
0?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`00
0000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo002:
0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`2C0?oo
o`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(ii)  Save a 2x(n+1) matrix r and ListPlot the matrix with all of the above \
options.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["r = Transpose[{{.5,1},{-.5,1},{-.5,-.5},{.5,-.5},{.5,1}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {"1", "1", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Transpose[r],PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .75 m
.375 .75 L
.375 .375 L
.625 .375 L
.625 .75 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0103o
ool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool0S03oool006h0ooooAP00001/0?ooo`00KP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?oo
o`00KP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool0
06h0oooo00<000000?ooo`3oool0803oool200000200oooo00<000000?ooo`3oool0JP3oool006h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0
oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0
803oool200000200oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0
oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool200000200oooo00<00000
0?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`1Z0?ooo`001`3oool3000001T0oooo1@0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06@3oool5000001/0oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool50000
01P0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool30000
00<0oooo00070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0000000L0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`000000oooo000000050?oo
o`030000003oool0000001X0oooo00<000000?ooo`3oool06@3oool00`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo0000000L0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000K0?ooo`030000003oool0oooo00<0oooo0002
0?ooo`<000000`3oool00`000000oooo0?ooo`0D0?ooo`<000000`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`030000003oool0oooo01D0oooo0`000002
0?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`060?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0
00000?ooo`0000001@3oool2000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0000
00030?ooo`040000003oool0oooo0?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003o
ool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01X0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo01X0oooo
0P00000J0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0000000<0oooo00080?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`<00000
6`3oool2000001d0oooo00@000000?ooo`3oool000001@3oool3000001X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000006`3oool20000
01/0oooo0P0000080?ooo`<00000703oool00`000000oooo0?ooo`020?ooo`00KP3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo
001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06X0oooo00060?ooool00000600000030?ooo`001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00060?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`010?ooo`00KP3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00
KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
JP3oool006h0oooo00<000000?ooo`3oool0803oool200000200oooo00<000000?ooo`3oool0JP3o
ool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?oo
o`3oool0803oool200000200oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3o
ool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool200000200oooo
00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3o
ool006h0oooo00<000000?ooo`3oool0803oool200000200oooo00<000000?ooo`3oool0JP3oool0
06h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00002@3oool00`000000oooo0?ooo`030?ooo`800000803oool00`000000oooo0?ooo`1Z0?ooo`00
KP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000L0oooo0P0000060?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo0`0000050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool0
06h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool200000200oooo00<0
00000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool0
06h0oooo00<000000?ooo`3oool0803oool200000200oooo00<000000?ooo`3oool0JP3oool006h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0
oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0
803oool200000200oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0
oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool200000200oooo00<00000
0?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool05`3o
ool5000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00KP3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1Z0?ooo`00KP3ooom6000006`0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000
oooo0?ooo`2C0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?oo
o`2C0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(iii)  To superimpose two images in Mma you must (List)Plot them both and \
save the result with names.  
Then Show[ names...].\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["t1 = Transpose[{{-1,.5},{1,.5},{0,-1},{-1,.5}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "1", "0", \(-1\)},
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], \(-1\), 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
t1Plot = ListPlot[Transpose[t1],PlotJoined->True,
   PlotRange->{{-2,2},{-2,2}},AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.25 .625 m
.75 .625 L
.5 .25 L
.25 .625 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{226.375, 226.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003R0000hR000`400?l00000o`00003ohP3oool0
0>80oooo003R0?ooo`00J`3oool3000007@0oooo001[0?ooo`030000003oool0oooo07@0oooo001V
0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`800000KP3oool006`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1]0?ooo`00J`3oool00`000000oooo000000040?ooo`03
0000003oool0oooo06d0oooo001/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00LP3oool00`00
0000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo
0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool2000006h0oooo001b0?oo
o`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000
003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0
oooo06d0oooo001b0?ooo`800000KP3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<00000
0?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00
LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00H03oool5
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06d0oooo001R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`1]0?ooo`00G03oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`800000KP3oool00680oooo00<000000?ooo`3oool01P3oool2000000D0oooo
00<000000?ooo`3oool0K@3oool00680oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06d0oooo001Q0?ooo`800000203oool3000000@0oooo00<00000
0?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00
LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool0
0`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool2000006h0
oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b
0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`03
0000003oool0oooo06d0oooo001b0?ooo`800000KP3oool00780oooo00<000000?ooo`3oool0K@3o
ool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780
oooo00<000000?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00LP3oool00`000000oooo0?oo
o`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?oo
o`00JP3oool5000000<0oooo00<000000?ooo`3oool0K@3oool006`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1]0?ooo`00IP3oool3000000<0oooo00<000000?ooo`3oool00`3o
ool2000006h0oooo001/0?ooo`030000003oool0oooo0080oooo0`00001^0?ooo`00K03oool00`00
0000oooo0?ooo`020?ooo`<00000KP3oool006/0oooo0P0000030?ooo`050000003oool000000?oo
o`000000K@3oool006l0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1Z0?oo
o`00K`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo06/0oooo001^0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1Y0?ooo`00K@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool006d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06P0oooo001/
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1W
0?ooo`00J`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0IP3oool006/0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3o
ool0IP3oool006X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo06D0oooo001Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1T0?ooo`00J@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0I03oool006P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06<0oooo001W0?ooo`030000003oool0oooo00P0
oooo0P0000090?ooo`030000003oool0oooo0680oooo001W0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1R0?ooo`00IP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H@3oool006D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0600oooo001U0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1P0?oo
o`00I03oool00`000000oooo0?ooo`0;0?ooo`800000303oool00`000000oooo0?ooo`1O0?ooo`00
H`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
GP3oool006<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo05h0oooo001R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1M0?ooo`00H@3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G03oool00640
oooo00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0G03oool005`0oooo0`0000001@3oool000000000003oool0000000T0
oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool0F`3oool005l0oooo
00D000000?ooo`000000oooo000000070?ooo`8000001@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo05X0oooo001O0?ooo`050000003oool000000?ooo`0000001`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0FP3oool005h0oooo
00D000000?ooo`3oool0oooo000000080?ooo`<00000103oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo05T0oooo001M0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1H0?ooo`00G@3oool00`000000oooo0?ooo`0B0?ooo`8000004`3o
ool00`000000oooo0?ooo`1H0?ooo`00G03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0E`3oool005/0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo05H0oooo001K0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1F0?ooo`00FP3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool005T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05@0oooo001I
0?ooo`030000003oool0oooo01H0oooo0P00000G0?ooo`030000003oool0oooo05@0oooo001H0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1C0?oo
o`00E`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0DP3oool005L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0580oooo001F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1A0?ooo`001`3oool300000180oooo1@0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool5000001<0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool2000001<0oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000001<0oooo1@00000A0?ooo`D000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo0`0000030?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000503oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0000000H0oooo0P0000000`3oool000000?ooo`0C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000C0?ooo`030000003o
ool0oooo00<0oooo00020?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`<000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo0`0000030?ooo`030000003oool0
oooo00d0oooo0`0000020?ooo`<000002@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`0000001`3oool00`000000oooo0000000D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0080oooo00080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool20000
01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000070?ooo`8000004`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0000000L0oooo0P00000E0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01P3oool2000001D0oooo00<000000?ooo`3oool00P3oool000L0
oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo000000070?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04@3oool00`000000oooo000000070?ooo`8000005@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo000000030?ooo`00203oool00`000000oooo0?ooo`0B0?ooo`800000203oool3000001<0oooo
0P00000C0?ooo`030000003oool0000000P0oooo0`00000B0?ooo`8000004`3oool00`000000oooo
0?ooo`060?ooo`<000004`3oool2000001@0oooo0P0000080?ooo`<00000503oool00`000000oooo
0?ooo`020?ooo`00D@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0C03oool00540oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo04`0oooo001@0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1;0?ooo`00C`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0BP3oool004l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04X0oooo00060?ooomT000000`3o
ool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00@3oool004d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo04P0oooo001<0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`170?ooo`00B`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0AP3oool004/0oooo00<0
00000?ooo`3oool0903oool2000002D0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04D0oooo00190?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`140?oo
o`00B@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0A03oool004P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo04<0oooo00170?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`120?ooo`00A`3oool00`000000oooo0?ooo`0X0?ooo`800000:@3oool0
0`000000oooo0?ooo`120?ooo`00AP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0@@3oool004D0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0400oooo00150?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`100?ooo`00A03oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0?`3oool004<0oooo00<00000
0?ooo`3oool0;03oool2000002d0oooo00<000000?ooo`3oool0?P3oool004<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03h0oooo00120?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0m0?ooo`00
@@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
?03oool00440oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo03`0oooo00100?ooo`030000003oool0oooo02l0oooo0P00000`0?ooo`030000003oool0
oooo03/0oooo000o0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0j0?ooo`00?`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0>P3oool003h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo03T0oooo000m0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0h0?ooo`00?@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03P0oooo000l0?ooofd00000>@3oool00640oooo00<000000?ooo`00
00001`3oool2000000D0oooo00<000000?ooo`3oool0K@3oool00640oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06d0oooo001R0?ooo`030000003o
ool0oooo00H0oooo0`0000040?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0
oooo06d0oooo001b0?ooo`800000KP3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<00000
0?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00
LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool0
0`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool2000006h0
oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b
0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`80
0000KP3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3o
ool00780oooo00<000000?ooo`3oool0K@3oool006X0oooo1@0000030?ooo`030000003oool0oooo
06d0oooo001/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0K@3oool006`0oooo
00<000000?ooo`3oool00`3oool2000006h0oooo001/0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0K@3oool006`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1]
0?ooo`00J`3oool2000000D0oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3o
ool0K@3oool00780oooo0P00001^0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool0
0`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000
oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool2000006h0oooo001b
0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`03
0000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`800000KP3o
ool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780
oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<0
00000?ooo`3oool0K@3oool00780oooo0P00001^0?ooo`00LP3oool00`000000oooo0?ooo`1]0?oo
o`00LP3oool00`000000oooo0?ooo`1]0?ooo`00H03oool500000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06d0oooo001R0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`1]0?ooo`00HP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P00001^0?ooo`00HP3oool00`00
0000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`1]0?ooo`00HP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0K@3oool00640oooo
0P0000080?ooo`<00000103oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?oo
o`1]0?ooo`00LP3oool2000006h0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`03
0000003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`030000003o
ool0oooo06d0oooo001b0?ooo`030000003oool0oooo06d0oooo001b0?ooo`800000KP3oool00780
oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo00<0
00000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0K@3oool00780oooo0P00001^0?oo
o`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3o
ool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`1]0?ooo`00LP3oool00`00
0000oooo0?ooo`1]0?ooo`00LP3oool2000006h0oooo001b0?ooo`030000003oool0oooo06d0oooo
001b0?ooo`030000003oool0oooo06d0oooo001[0?ooo`<00000103oool00`000000oooo0?ooo`1]
0?ooo`00J`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06d0oooo001/0?ooo`03
0000003oool0oooo00<0oooo0P00001^0?ooo`00K03oool00`000000oooo0?ooo`1c0?ooo`00J`3o
ool00`000000oooo0000001d0?ooo`00K03oool00`000000oooo0?ooo`1c0?ooo`00hP3oool00001
\
\>"],
  ImageRangeCache->{{{0, 225.375}, {225.375, 0}} -> {-2.11094, -2.08321, 
  0.0184866, 0.0184866}}]
}, Open  ]],

Cell["Define matrix t2 and t2Plot.  Show[t1Plot, t2Plot].", "Text"],

Cell[CellGroupData[{

Cell["T2 = {{-1,-.5},{1,-.5},{0,1},{-1,-.5}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]},
            {"1", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]},
            {"0", "1"},
            {\(-1\), 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t2Plot = ListPlot[T2,PlotJoined->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.210916 0.392403 [
[.02381 .19842 -6 -9 ]
[.02381 .19842 6 0 ]
[.2619 .19842 -12 -9 ]
[.2619 .19842 12 0 ]
[.7381 .19842 -9 -9 ]
[.7381 .19842 9 0 ]
[.97619 .19842 -3 -9 ]
[.97619 .19842 3 0 ]
[.4875 .05396 -24 -4.5 ]
[.4875 .05396 0 4.5 ]
[.4875 .13244 -24 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .2894 -18 -4.5 ]
[.4875 .2894 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .44636 -18 -4.5 ]
[.4875 .44636 0 4.5 ]
[.4875 .52484 -18 -4.5 ]
[.4875 .52484 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .21092 m
.02381 .21717 L
s
[(-1)] .02381 .19842 0 1 Mshowa
.2619 .21092 m
.2619 .21717 L
s
[(-0.5)] .2619 .19842 0 1 Mshowa
.7381 .21092 m
.7381 .21717 L
s
[(0.5)] .7381 .19842 0 1 Mshowa
.97619 .21092 m
.97619 .21717 L
s
[(1)] .97619 .19842 0 1 Mshowa
.125 Mabswid
.07143 .21092 m
.07143 .21467 L
s
.11905 .21092 m
.11905 .21467 L
s
.16667 .21092 m
.16667 .21467 L
s
.21429 .21092 m
.21429 .21467 L
s
.30952 .21092 m
.30952 .21467 L
s
.35714 .21092 m
.35714 .21467 L
s
.40476 .21092 m
.40476 .21467 L
s
.45238 .21092 m
.45238 .21467 L
s
.54762 .21092 m
.54762 .21467 L
s
.59524 .21092 m
.59524 .21467 L
s
.64286 .21092 m
.64286 .21467 L
s
.69048 .21092 m
.69048 .21467 L
s
.78571 .21092 m
.78571 .21467 L
s
.83333 .21092 m
.83333 .21467 L
s
.88095 .21092 m
.88095 .21467 L
s
.92857 .21092 m
.92857 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
.5 .05396 m
.50625 .05396 L
s
[(-0.4)] .4875 .05396 1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(-0.2)] .4875 .13244 1 0 Mshowa
.5 .2894 m
.50625 .2894 L
s
[(0.2)] .4875 .2894 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.4)] .4875 .36788 1 0 Mshowa
.5 .44636 m
.50625 .44636 L
s
[(0.6)] .4875 .44636 1 0 Mshowa
.5 .52484 m
.50625 .52484 L
s
[(0.8)] .4875 .52484 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .07358 m
.50375 .07358 L
s
.5 .0932 m
.50375 .0932 L
s
.5 .11282 m
.50375 .11282 L
s
.5 .15206 m
.50375 .15206 L
s
.5 .17168 m
.50375 .17168 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .23054 m
.50375 .23054 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .26978 m
.50375 .26978 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .32864 m
.50375 .32864 L
s
.5 .34826 m
.50375 .34826 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .40712 m
.50375 .40712 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .46598 m
.50375 .46598 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .50522 m
.50375 .50522 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .56408 m
.50375 .56408 L
s
.5 .5837 m
.50375 .5837 L
s
.5 .03434 m
.50375 .03434 L
s
.5 .01472 m
.50375 .01472 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.97619 .01472 L
.5 .60332 L
.02381 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oS`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`001`3ooooo000001800000203o
ool000P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo00L0oooo00090?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo0840oooo0P00
00220?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<00000
103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0I@3oool3
00000080oooo00<000000?ooo`0000001`3oool4000000@0oooo0`00001l0?ooo`030000003oool0
oooo00l0oooo000A0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`0000001`3oool00`00
0000oooo000000050?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0403oool00180
oooo00<000000?ooo`3oool0J03oool00`000000oooo000000080?ooo`8000001@3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`1g0?oo
o`800000N03oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0F0?ooo`00603oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool05`3oool0
01T0oooo00<000000?ooo`3oool0L`3oool2000007@0oooo00<000000?ooo`3oool0603oool001X0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01T0
oooo000J0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool06P3oool001`0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0L0?ooo`007P3oool00`000000oooo0?ooo`1^0?ooo`80
0000K`3oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo06h0oooo00<000000?ooo`3oool07@3oool001l0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01h0oooo000P0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0O0?ooo`008@3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0oooo05<0oooo0`0000020?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool0103oool3000006X0oooo00<000000?oo
o`3oool08@3oool002<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo000000080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0R0?ooo`00
8`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0280oooo000T0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool08`3oool002D0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0U0?ooo`009`3oool00`000000
oooo0?ooo`1U0?ooo`800000IP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool09P3oool002P0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02L0oooo000Y
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0X
0?ooo`00:P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0:@3oool000L0oooo1@00000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0O0?ooo`D000001P3oool000T0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
>`3oool2000003`0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01P3oool000<0oooo0`0000030?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool04`3oool300000080oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3o
ool000T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
000000L0oooo0P00000l0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000001`3oool2
000001P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`002@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool000P0
oooo0P00000U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool3000003/0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`060?ooo`<000005@3oool00`000000
oooo0?ooo`0T0?ooo`800000203oool002l0oooo00<000000?ooo`3oool0G@3oool2000005h0oooo
00<000000?ooo`3oool0;P3oool00300oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo02l0oooo000a0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0380oooo000d0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0c0?ooo`00o`00
000P00000040oooo00070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
00L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool01P3oool003L0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo03H0oooo000h0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0g0?ooo`00>03oool00`000000oooo0?oo
o`1D0?ooo`800000E@3oool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0>03oool003X0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03T0oooo000k0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0j0?ooo`00
?03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
>`3oool003`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo03/0oooo000m0?ooo`030000003oool0oooo04l0oooo0P00001@0?ooo`030000003oool0
oooo03`0oooo000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0?P3oool00400oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0o0?ooo`00@@3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0@03oool00480oooo00<000000?oo
o`3oool0BP3oool2000004/0oooo00<000000?ooo`3oool0@@3oool004<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0480oooo00140?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`130?ooo`00A@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0`0000050?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A03oool004D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0103oool3000004H0oooo00<00000
0?ooo`3oool0A@3oool004L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo000000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`160?oo
o`00B03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0000000L0oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04L0oooo00190?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0B03oool004T0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`190?ooo`00B`3oool00`00
0000oooo0?ooo`110?ooo`800000@P3oool00`000000oooo0?ooo`1:0?ooo`00C03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0B`3oool004d0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04`0oooo
001=0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1<0?ooo`00CP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0C@3oool004l0oooo00<000000?ooo`3oool0?@3oool2000003h0oooo00<000000?oo
o`3oool0CP3oool00500oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0D03oool00580oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0540oooo001C0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1B0?ooo`00E03oool00`000000
oooo0?ooo`0h0?ooo`800000>@3oool00`000000oooo0?ooo`1C0?ooo`00E@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0E03oool005H0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05D0oooo001F
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1E
0?ooo`00E`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1F0?oo
o`00F03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05L0oooo001I0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`0000001`3oool4000000@0oooo0`00000c0?ooo`030000
003oool0oooo05P0oooo001J0?ooo`030000003oool0oooo0200oooo00<000000?ooo`0000001`3o
ool00`000000oooo000000050?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0F@3o
ool005X0oooo00<000000?ooo`3oool0803oool00`000000oooo000000080?ooo`8000001@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05T0oooo001K0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0FP3oool005`0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo02l0oooo
0P00000`0?ooo`030000003oool0oooo05`0oooo001N0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1M0?ooo`00GP3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0G@3oool005l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05h0oooo001P0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1O0?ooo`00
H@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
H03oool00680oooo00<000000?ooo`3oool0:P3oool2000002/0oooo00<000000?ooo`3oool0H@3o
ool00680oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0640oooo001S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0H`3oool006D0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo06@0oooo001V0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?ooo`00I`3oool00`000000oooo0?ooo`0U
0?ooo`8000009P3oool00`000000oooo0?ooo`1V0?ooo`00I`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1X0?ooo`00JP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo06T0oooo001[0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000001`3oool00`000000oooo000000050?ooo`<000008@3oool00`000000oooo0?oo
o`1Z0?ooo`00J`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000L0oooo0P000006
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0JP3oool006`0oooo00<000000?oo
o`3oool03P3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1[0?ooo`00K@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0K03oool006h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo06d0oooo001_0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1^0?ooo`00K`3oool00`000000oooo0?ooo`0M0?ooo`8000007P3oool0
0`000000oooo0?ooo`1^0?ooo`00L03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0K`3oool00740oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0700oooo001b0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1a0?ooo`00L`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0LP3oool007<0oooo00<00000
0?ooo`3oool06@3oool2000001X0oooo00<000000?ooo`3oool0LP3oool007@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo07<0oooo001e0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1d0?ooo`00
MP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
M@3oool007L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo07H0oooo001h0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1g0?ooo`00N03oool00`000000oooo0?ooo`0D0?ooo`8000005@3oool00`00
0000oooo0?ooo`1g0?ooo`00N@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0N03oool007X0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo07T0oooo001k0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1j0?ooo`00O03oool00`000000oooo00000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo07/0oooo001l0?ooo`80000000<0oooo0000003oool01P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N`3oool007d0
oooo00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`<000003`3oool00`000000
oooo0?ooo`1l0?ooo`00O@3oool3000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo07d0oooo001m0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07h0oooo001n
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo07l0oooo00200?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1o0?ooo`00P@3oool00`000000oooo0?ooo`0;0?ooo`80
0000303oool00`000000oooo0?ooo`200?ooo`00PP3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0P@3oool008<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0880oooo00240?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`230?ooo`00Q03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P`3oool008D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08@0
oooo00260?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo08D0oooo
00270?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`260?ooo`00R03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0Q`3oool008T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo08P0oooo00290?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`280?ooo`00RP3oool00`000000oooo0?ooo`020?ooo`800000
0`3oool00`000000oooo0?ooo`290?ooo`00R`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0RP3oool008`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`2;0?ooo`00S@3oool01@000000oooo0000003oool0000008h0oooo00260?ooo`D000000P3o
ool01@000000oooo0000003oool0000008h0oooo00280?ooo`030000003oool0oooo00<0oooo0`00
002?0?ooo`00R03oool00`000000oooo0?ooo`040?ooo`<00000SP3oool008P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00R03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08h0oooo00270?ooo`8000001P3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.05437, -0.537506, 
  0.00734751, 0.00891637}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[t1Plot,t2Plot];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.25 .625 m
.75 .625 L
.5 .25 L
.25 .625 L
s
.25 .375 m
.75 .375 L
.5 .75 L
.25 .375 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0103o
ool2000008d0oooo002:0?ooo`030000003oool0oooo00<0oooo0`00002=0?ooo`00RP3oool00`00
0000oooo0?ooo`030?ooo`<00000S@3oool008T0oooo0P0000040?ooo`050000003oool000000?oo
o`000000S03oool008h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`290?oo
o`00SP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08T0oooo002=0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`280?ooo`00S03oool00`000000
oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`25
0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0Q@3oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08@0oooo00280?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`060?ooo`8000001`3o
ool00`000000oooo0?ooo`230?ooo`00Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0PP3oool008H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00Q@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool008@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo0024
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o
0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`800000303oool00`000000oooo0?ooo`1n0?oo
o`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0OP3oool00880oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo07d0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1l0?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0O03oool00800oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo001o0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00OP3oool00`000000oooo
0?ooo`0@0?ooo`800000403oool00`000000oooo0?ooo`1j0?ooo`00OP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool007d0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0oooo001l0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1h0?oo
o`00O03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0M`3oool007/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo07H0oooo001j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3o
ool00`000000oooo000000050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0MP3o
ool004/0ooooS00000190?ooo`00C03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000001`3oool2000000H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo04P0oooo001<0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04P0
oooo001=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0B@3oool004h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`1:0?ooo`00CP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04X0oooo001?0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00500oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0I0?ooo`8000006P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo04`0oooo001@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
C03oool00540oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1=0?ooo`00DP3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001B0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0CP3oool005<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1?0?ooo`00E03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0500oooo
001D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07P3oool2000001h0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1@0?ooo`00E@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0540oooo001F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0DP3oool005H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1B0?ooo`00
E`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05<0oooo001H0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0E03oool005P0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1D0?ooo`00F@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0280oooo0P00000S0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool005X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1F0?ooo`00FP3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo05H0oooo00070?ooo`<000006@3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`D000002`3oool00`000000oooo0?oo
o`0<0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`D00000603oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`<000000`3oool000L0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000001`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000003oool01P3oool0
0`000000oooo0000000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`0000001`3oool3
000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`000P3oool30000
00<0oooo00<000000?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0D0?ooo`<000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00H0oooo10000000103oool000000?ooo`0000090?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo000000090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool01@000000oooo0000003oool0000000L0oooo0P00000K0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`0000001`3oool2000000030?ooo`000000oooo00P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00000M
0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0000001/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool06P3o
ool2000001X0oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`0000000`3oool000P0oooo00<000000?ooo`3oool06@3o
ool2000000P0oooo0`00000K0?ooo`8000004@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool3000001X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`<0000000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0?0?ooo`8000006`3oool2000000P0oooo0`00000L0?ooo`030000003oool0oooo0080oooo001O
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00600oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1L0?ooo`00H@3oool010000000oooo0?ooo`00000/0?oo
o`030000003oool0oooo02T0oooo00D000000?ooo`3oool0oooo0000001N0?ooo`00H@3oool01000
0000oooo0?ooo`00000/0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`000000G`3oool0
0680oooo0P00000]0?ooo`030000003oool0oooo02X0oooo0P00001P0?ooo`001P3ooooo000001P0
00000`3oool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0000000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00060?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00@3oool00600oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00D00000
0?ooo`3oool0oooo0000001N0?ooo`00H03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05/0oooo001O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F`3oool005h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`00GP3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02L0oooo0P00000W0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0F@3oool005d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1I0?ooo`00G03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05P0oooo001L0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool005/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1G0?ooo`00FP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05H0oooo001J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3o
ool005T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?ooo`8000008P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0E03oool005P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1C0?ooo`00E`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05<0oooo
001F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0DP3oool005H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1B0?ooo`00E@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0540oooo001D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool07@3oool2000001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1@0?ooo`00
E03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0500oooo001C0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0C`3oool00580oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1>0?ooo`00DP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
04h0oooo001A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C@3oool00500oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1<0?ooo`00D03oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01T0oooo0P00000I0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0C03oool004l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;
0?ooo`00CP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04X0oooo001>0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0BP3oool004d0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`190?ooo`00C03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04P0oooo001<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04P0oooo001;0?oooh`00000B@3oool007/0
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo0P0000060?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0MP3oool007/0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo07L0oooo001l0?ooo`050000003oool0oooo0?ooo`000000203oool3000000D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00O@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0N03oool007d0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001n0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00
O`3oool00`000000oooo0?ooo`0?0?ooo`800000403oool00`000000oooo0?ooo`1j0?ooo`00O`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N`3o
ool00800oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo07/0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1l0?ooo`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0O@3oool00880oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00230?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`00Q03oool00`000000oooo0?ooo`0:
0?ooo`8000002`3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00260?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P@3o
ool008L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0880oooo00280?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`060?ooo`8000001`3oool00`000000
oooo0?ooo`230?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0Q03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`250?ooo`00R`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool008`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00S@3o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0R03oool008h0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo08T0oooo002?0?ooo`050000003oool000000?ooo`000000
S03oool008P0oooo1@0000030?ooo`<00000S@3oool008X0oooo00<000000?ooo`3oool00`3oool3
000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool007h0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<000000?ooo`3o
ool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo001o0?ooo`800000203o
ool3000000D0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2
000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`80
0000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00
002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R@3o
ool3000000D0oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008X0
oooo00<000000?ooo`3oool0T`3oool008T0oooo00<000000?ooo`000000U03oool008X0oooo00<0
00000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Supplement to (a) -- defining a function view[matrix, scale].\
\>", "Subsection"],

Cell["\<\
You may be getting tired of typing (or pasting) \"ListPlot[Transpose..., \
PlotJoined..., PlotRange..., AspectRatio...];\" 
To make life easier define a function
    view[matrix_, scale_] := 
that will take a 2x(n+1) matrix and axis scale (2 in the above examples) and \
do the ListPlot with all the options.
Test your function.\
\>", "Text"],

Cell["\<\
view[T_,scale_] := ListPlot[Transpose[T],PlotJoined->True,
   PlotRange->{{-scale,scale},{-scale,scale}},
   AspectRatio->Automatic];\
\>", "Input"],

Cell[CellGroupData[{

Cell["view[t,1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66667 .16667 m
.5 .83333 L
.33333 .16667 L
.66667 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00I03ooomJ
00000680oooo001T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001U0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001U0?ooo`030000003oool0oooo0240oooo0P0000060?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0H@3oool006D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0640oooo001U0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`1Q0?ooo`00IP3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0H@3oool006H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0680oooo001V0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1R0?ooo`00IP3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0HP3o
ool006L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0680oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1S0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0H`3oool006L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo06<0oooo001X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`00J03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03oool006P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo001X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1T0?ooo`00
J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
I03oool006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo06D0oooo001Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1U0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0I@3oool006X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo06D0oooo001Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00JP3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool006X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001[0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?oo
o`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0I`3oool006/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06L0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`1W0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0I`3oool006`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001/0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1X0?ooo`00K03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool006d0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001]
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Y
0?ooo`00K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0J@3oool006d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo06T0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`1Y0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00K`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo
001_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool006l0oooo00<00000
0?ooo`3oool0203oool300000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`03
0?ooo`8000007`3oool00`000000oooo0?ooo`1[0?ooo`00L03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0J`3oool00700oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00
L03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00700oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00740
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0
oooo001a0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06h0oooo001b0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1^0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0KP3oool007<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001c0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K`3oool0
07<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
06l0oooo001d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1_0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0L03oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0700oooo001d0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo001e0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1a0?ooo`00M@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3o
ool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1b0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0780oooo001g0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool007L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001g0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00
1`3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`D00000
903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8`3oool500000280oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000U0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`000000103oool000<0oooo0`0000030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07@3oool3000000<0oooo00<000000?ooo`3oool07P3oool3
00000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool000T0oooo00<000000?ooo`3oool01P3oool20000
02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?ooo`800000303oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo000000070?ooo`8000009`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00H0oooo0P0000050?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00203oool2000000P0oooo
0`00000T0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`<00000303oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`<000009@3oool2000002D0oooo0P0000080?ooo`<00000103oool007T0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001i
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e
0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0M@3oool007X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo07H0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1f0?ooo`00303ooooo000000`000002@3oool000`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`00N`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00
O03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
M`3oool007`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo07P0oooo001m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1h0?ooo`00O@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0N03oool007d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo07P0oooo001m0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00OP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool007h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001n0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?oo
o`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0NP3oool007l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07X0oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo00200?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`00P03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N`3oool00800oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo0020
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l
0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00880oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`00PP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00880oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo
00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool008D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800
oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`200?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo001o
0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00O`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<0
00000?ooo`3oool0P@3oool007l0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00O`3oool00`00
0000oooo000000040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`210?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00
Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
PP3oool008L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0880oooo00270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo00280?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool008T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo00290?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?oo
o`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0Q03oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`26
0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0Q`3oool008`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`280?ooo`00S@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`290?ooo`00SP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08T0oooo002>
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool008h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool01P000000oooo0?ooo`00
0000oooo000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03oool008l0oooo00D0
00000?ooo`000000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003oool0000008`0oooo
002?0?ooo`040000003oool00000000008d0oooo002@0?ooo`<00000S@3oool00900oooo0`00002=
0?ooo`00T03oool3000008d0oooo00280?ooo`D000000`3oool2000008h0oooo002:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103o
ool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<0
00000?ooo`3oool01P3oool2000009D0oooo00200?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0U03oool007l0oooo0P0000080?ooo`<00000U03oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(b) Dilation and Contraction  (making a movie)", "Subsection"],

Cell[CellGroupData[{

Cell["(i)  Before and after", "Subsubsection"],

Cell[CellGroupData[{

Cell["t = Transpose[{{.5,-1},{0,1},{-.5,-1},{.5,-1}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "0", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {\(-1\), "1", \(-1\), \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Define the matrices d and c.  ", "Text"],

Cell["\<\
All the business about hold on-off is getting MATLAB to superimpose the \
before and after transformation pictures.  Accomplish this by beforePlot = \
view[t,2]; and afterPlot = view[c,2]; and use Show to superimpose.\
\>", "Text"],

Cell[CellGroupData[{

Cell["d = {{1.25,0},{0,1.25}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["1.25`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3], "0"},
            {"0", 
              StyleBox["1.25`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["c = d.t", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.625`", "0.`", \(-0.625`\), "0.625`"},
            {\(-1.25`\), "1.25`", \(-1.25`\), \(-1.25`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["beforePlot = view[t,2];", "Input",
  AnimationDisplayTime->0.597327,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .25 m
.5 .75 L
.375 .25 L
.625 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.597327,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00KP3ooom6000006`0oooo001^0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo06X0oooo001_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000003oool0oooo01L0
oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool006l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo
001_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1[0?ooo`00L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0J`3oool00700oooo00<000000?ooo`3oool07P3oool2000001h0oooo00<000000?oo
o`3oool0K03oool00700oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06`0oooo001`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0K03oool00740oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001a0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`00L@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0K@3oool00780oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001b
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1^
0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0KP3oool007<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06h0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0K`3oool007<0oooo00<000000?ooo`3oool06`3oool2
000001/0oooo00<000000?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001d0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700oooo001e
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`
0?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool2000001T0oooo00<000000?ooo`3o
ool0L@3oool007D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1a0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0780oooo001g0?ooo`030000003oool0oooo00<000000P3o
ool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`030000003o
ool0oooo07<0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001h0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1c0?ooo`00N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0M03oool007P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo07@0oooo001h0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?oo
o`8000005P3oool00`000000oooo0?ooo`1d0?ooo`00N@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool007T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001i0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?ooo`00NP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool0
07X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
07D0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1f0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`800000503oool00`000000oooo
0?ooo`1f0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0MP3oool007/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07H0oooo001k0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00O03oool0
0`000000oooo0?ooo`0B0?ooo`8000004P3oool00`000000oooo0?ooo`1h0?ooo`00O03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0N03oool007d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0
oooo00070?ooo`<000006@3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0I0?ooo`D000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool5000001P0oooo1@0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06P3oool3000000<0oooo00070?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`0000001`3oool00`000000oooo000000060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0oooo00<0
00000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`000P3oool3000000<0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D
0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool00`000000oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01P3oool2000001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000070?oo
o`800000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000070?ooo`8000007@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00070?ooo`03
0000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo00080?ooo`030000
003oool0oooo01T0oooo0P0000080?ooo`<000006`3oool2000001d0oooo00<000000?ooo`3oool0
1P3oool3000000L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool3000001/0oooo0P00000K0?ooo`800000
203oool3000001`0oooo00<000000?ooo`3oool00P3oool007h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001o0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0
oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1k0?ooo`001P3ooooo000001P000000`3oool000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`010?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00840oooo00<0
00000?ooo`3oool03@3oool2000000d0oooo00<000000?ooo`3oool0O@3oool00880oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?oo
o`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0OP3oool00880oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool20000
00/0oooo00<000000?ooo`3oool0O`3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00240?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?oo
o`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0P03oool008D0oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<000000?ooo`3oool0
P03oool008D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0840oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0P@3oool008H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<00000
0?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00
Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08<0oooo00200?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P`3oool007l0oooo00<0
00000?ooo`0000001P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`230?ooo`00O`3oool00`000000oooo000000060?ooo`040000003oool0
oooo000000D0oooo0P0000060?ooo`030000003oool0oooo08@0oooo001o0?ooo`030000003oool0
000000L0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool0
07l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0Q03oool00800oooo00<000000?ooo`3oool01P3oool3000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00R@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`25
0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`250?oo
o`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo08H0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo
0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`280?ooo`00S@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`290?ooo`00SP3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo08X0oooo002>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool0
08h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool01P00
0000oooo0?ooo`000000oooo000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03o
ool008l0oooo00D000000?ooo`000000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003o
ool0000008`0oooo002?0?ooo`040000003oool00000000008d0oooo002@0?ooo`<00000S@3oool0
0900oooo0`00002=0?ooo`00T03oool3000008d0oooo00280?ooo`D000000`3oool2000008h0oooo
002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<00000
0?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`00
0000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo002:
0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`2C0?oo
o`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["afterPlot = view[c,2];", "Input",
  AnimationDisplayTime->0.597327,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.65625 .1875 m
.5 .8125 L
.34375 .1875 L
.65625 .1875 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.597327,
  AnimationCycleOffset->-3,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001U0?oooeP00000H`3oool006D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0640oooo
001V0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1Q0?ooo`00IP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0HP3oool006H0oooo00<000000?ooo`3oool0:03oool2000002P0oooo00<000000?oo
o`3oool0HP3oool006H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0680oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1R0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0H`3oool006L0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06<0oooo001W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`00J03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H`3oool006P0oooo
00<000000?ooo`3oool09P3oool2000002H0oooo00<000000?ooo`3oool0I03oool006P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo001X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1T
0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0I03oool006T0oooo00<000000?ooo`3oool0703oool5000000@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1U0?ooo`00J@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U0?ooo`00J@3o
ool00`000000oooo0?ooo`0H0?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`8000009@3o
ool00`000000oooo0?ooo`1U0?ooo`00JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U0?ooo`00JP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1V0?ooo`00JP3oool00`000000oooo0?ooo`0L0?ooo`8000001P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00J`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool006/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06L0oooo001[0?oo
o`030000003oool0oooo02<0oooo0P00000S0?ooo`030000003oool0oooo06L0oooo001[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`00
K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
I`3oool006`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo06P0oooo001/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1X0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0J03oool006d0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001]0?ooo`030000003oool0oooo0240oooo
0P00000Q0?ooo`030000003oool0oooo06T0oooo001]0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1Y0?ooo`00K@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0J@3oool006h0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06T0oooo001^0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00
KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo06X0oooo001_0?ooo`030000003oool0oooo01l0oooo0P00000P0?ooo`030000003oool0
oooo06X0oooo001_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1[0?ooo`00K`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0J`3oool006l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo06/0oooo001`0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1[0?ooo`00L03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00700oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo001`0?ooo`03
0000003oool0oooo01h0oooo0P00000N0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00L@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3o
ool00740oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo06d0oooo001a0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool02P3oool00`000000oooo
000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1^0?ooo`00LP3oool00`000000oooo0?ooo`050?ooo`<000000P3oool00`000000oooo0000
00090?ooo`030000003oool0oooo00<0oooo0P00000L0?ooo`030000003oool0oooo06h0oooo001b
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001`3oool2000000H0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`1^0?ooo`00L`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo06h0oooo001c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01P3oool3000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00
L`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
K`3oool007<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo06l0oooo001d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1_0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`8000006P3oool00`00
0000oooo0?ooo`1`0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0L03oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0700oooo001e0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3oool007D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo001e0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1a0?ooo`00
MP3oool00`000000oooo0?ooo`0H0?ooo`8000006@3oool00`000000oooo0?ooo`1a0?ooo`00MP3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0LP3o
ool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0780oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0LP3oool007L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001g0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`000000oooo0?ooo`0G
0?ooo`8000005`3oool00`000000oooo0?ooo`1c0?ooo`00N03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool007P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07@0oooo00070?ooo`<00000
6@3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`D00000
6`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo1@00000H0?ooo`D0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0`0000030?ooo`00
1`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000L0oooo00D000000?ooo`000000
oooo0000000H0?ooo`030000003oool0oooo01D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`030?ooo`000P3oool30000
00<0oooo00<000000?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0D0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool00`00
0000oooo000000090?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool05@3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0080oooo00080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool2000001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000070?ooo`8000000`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000070?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0
000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01D0oooo0P00000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo00080?ooo`030000003oool0oooo
01T0oooo0P0000080?ooo`<000006`3oool2000001d0oooo00<000000?ooo`3oool01P3oool30000
0080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool3000001/0oooo0P00000K0?ooo`800000203oool30000
01`0oooo00<000000?ooo`3oool00P3oool007X0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001j0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1f0?ooo`00NP3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0MP3oool007X0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07H0oooo001k0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1f0?oo
o`001P3ooooo000001P000000`3oool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`010?ooo`00O03oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1h0?ooo`00
O@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
N03oool007d0oooo00<000000?ooo`3oool04@3oool200000180oooo00<000000?ooo`3oool0N03o
ool007d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo07P0oooo001m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1i0?ooo`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0N@3oool007h0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001n0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00OP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0oooo00<000000?oo
o`3oool03`3oool200000100oooo00<000000?ooo`3oool0NP3oool007l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001o0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N`3o
ool00800oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo07/0oooo00200?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1k0?ooo`00P03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0N`3oool00800oooo00<000000?ooo`3oool03P3oool2000000h0oooo
00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`00PP3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3o
ool00880oooo00<000000?ooo`3oool0303oool2000000d0oooo00<000000?ooo`3oool0O@3oool0
0880oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07h0oooo00200?ooo`060000003oool0oooo0000003oool00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
O`3oool007l0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00O`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2
000000/0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
07l0oooo001o0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool00800oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`200?ooo`00Q@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool008D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00250?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3oool00`00
0000oooo0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`210?ooo`00QP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P@3oool008H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0840oooo
00260?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`220?ooo`00Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0PP3oool008L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0880oooo00270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`220?ooo`00Q`3oool00`000000oooo0?ooo`070?ooo`800000
1`3oool00`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0P`3oool008P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo00280?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?ooo`00R03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool008T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo
00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`240?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`24
0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0Q@3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000
oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo002<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`27
0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?oo
o`00RP3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0Q`3oool008X0oooo00<000000?ooo`000000103oool200000080oooo00<000000?ooo`3oool0
R03oool008X0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000008X0
oooo002:0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000002:0?oo
o`00R@3oool200000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`290?oo
o`00SP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08T0oooo002>0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool008h0oooo00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`2:0?ooo`00SP3oool01P000000oooo0?ooo`000000oooo0000
08`0oooo002?0?ooo`050000003oool000000?ooo`000000S03oool008l0oooo00D000000?ooo`00
0000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003oool0000008`0oooo002?0?ooo`04
0000003oool00000000008d0oooo002@0?ooo`<00000S@3oool00900oooo0`00002=0?ooo`00T03o
ool3000008d0oooo002@0?ooo`800000SP3oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo001n0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool0
1P3oool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0
oooo00H0oooo0P0000060?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool2000000P0
oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2
000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`80
0000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0
oooo0`0000050?ooo`030000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:
0?ooo`030000003oool0oooo09<0oooo00290?ooo`030000003oool0000009@0oooo002:0?ooo`03
0000003oool0oooo09<0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[beforePlot,afterPlot];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .25 m
.5 .75 L
.375 .25 L
.625 .25 L
s
.65625 .1875 m
.5 .8125 L
.34375 .1875 L
.65625 .1875 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001U0?oooeP00000H`3oool006D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0640oooo
001V0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1Q0?ooo`00IP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0HP3oool006H0oooo00<000000?ooo`3oool0:03oool2000002P0oooo00<000000?oo
o`3oool0HP3oool006H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0680oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1R0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0H`3oool006L0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06<0oooo001W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`00J03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H`3oool006P0oooo
00<000000?ooo`3oool09P3oool2000002H0oooo00<000000?ooo`3oool0I03oool006P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo001X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1T
0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0I03oool006T0oooo00<000000?ooo`3oool0703oool5000000@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1U0?ooo`00J@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U0?ooo`00J@3o
ool00`000000oooo0?ooo`020?ooodH00000103oool00`000000oooo0?ooo`1U0?ooo`00JP3oool0
1@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I@3oool006X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000006P0oooo001Z0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool2000000H0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo06H0oooo001Z0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0IP3oool006/0oooo00D000000?ooo`3oool0oooo0000000Q0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1V0?oo
o`00J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool07P3oool01@000000oooo0?ooo`3oool0000006T0oooo001[0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07P3oool2000001h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1W0?ooo`00J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06L0oooo
001/0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0I`3oool006`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo
0000001Z0?ooo`00K03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06P0oooo001/
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool006d0oooo00D000000?oo
o`3oool0oooo0000000O0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1X0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo0P00000M0?ooo`050000003oool0oooo0?ooo`000000J`3oool006d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1Y0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06T0oooo001^0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J@3oool006h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo
00D000000?ooo`3oool0oooo0000001/0?ooo`00KP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3o
ool006l0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`8000006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000K@3o
ool006l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1[0?ooo`00K`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo001`0?ooo`050000003oool0oooo0?oo
o`000000703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0J`3oool00700oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0000001^0?ooo`00L03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06`0oooo001`0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool2000001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1/0?ooo`00L@3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`050000003o
ool0oooo0?ooo`000000K`3oool00740oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1]0?ooo`00L@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06d0oooo001b0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`000000L03oool00780oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`030?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
06h0oooo001b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo000000070?ooo`8000001P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0KP3oool007<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool007<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000001a0?ooo`00L`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo06l0oooo001c0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0K`3oool007@0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`00M03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P00000F0?ooo`050000003oool0
oooo0?ooo`000000LP3oool007@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`
0?ooo`00M03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo001e0?ooo`05
0000003oool0oooo0?ooo`0000005`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0L03oool007D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000001c0?oo
o`00M@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0503oool01@000000oooo0?ooo`3oool0000007<0oooo001e0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0L@3oool007H0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`80
0000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0740oooo001f0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`000000M03oool007H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000001d0?ooo`00
MP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo001g0?ooo`050000003o
ool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0LP3oool007L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000001e0?ooo`00M`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0?ooo`3oool0000007D0oooo001g0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04P3oool200000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1c0?ooo`00N03oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo001h0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0
oooo0?ooo`000000MP3oool000L0oooo0`00000I0?ooo`D000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo1@00000K0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo1@00000H0?ooo`D00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0`0000030?ooo`001`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000703o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000L0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool00000
01`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool00`3oool00080oooo0`0000030?ooo`030000003oool0oooo01@0
oooo0`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool3000000<0
oooo00<000000?ooo`3oool05@3oool300000080oooo00<000000?ooo`0000002@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000090?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`060?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
000000L0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000
00070?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00
000M0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0000001/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool200000140oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo000000030?ooo`00203oool0
0`000000oooo0?ooo`0I0?ooo`800000203oool3000001/0oooo0P00000M0?ooo`030000003oool0
oooo00H0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`<000006`3oool2000001/0oooo0P0000080?ooo`<00000703oool0
0`000000oooo0?ooo`020?ooo`00NP3oool01@000000oooo0?ooo`3oool000000180oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo001j0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`050000003oool0oooo0?ooo`000000N03oool007X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000001h
0?ooo`00NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07H0oooo001k0?ooo`05
0000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0MP3oool000H0ooooo`00000H000000<0oooo00060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool000000080oooo0P0000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool00@3oool007`0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1g0?ooo`00O03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07L0
oooo001l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000NP3oool007d0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1h0?ooo`00O@3oool01@000000oooo0?ooo`3oool0000000l0oooo0P00000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool007d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1h0?ooo`00O@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000007/0oooo
001n0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool007h0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1i0?ooo`00OP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo001n
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`050000003oool0oooo0?ooo`000000O03oool007l0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07X0oooo001o
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0NP3oool007l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1j0?ooo`00O`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000007d0oooo00200?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0N`3oool00800oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07/0oooo00200?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool2000000X0oooo00D000000?ooo`3o
ool0oooo0000001n0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07`0oooo00210?ooo`05
0000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000007l0oooo00220?ooo`050000
003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`000000O`3oool00880oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1m0?ooo`00PP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0O@3oool00880oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000200?ooo`00
P`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3oool01@000000
oooo0?ooo`3oool000000800oooo00230?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool008<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`00P03oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000P@3oool007l0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool000000840oooo001o0?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool000000880oooo00200?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0`0000050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00220?ooo`00Q@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0800oooo00250?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0P03oool008D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000023
0?ooo`00QP3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000050?ooo`050000003oool0
oooo0?ooo`000000P`3oool008H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`00QP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000000Q03oool008L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000240?ooo`00Q`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0880oooo00270?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0PP3oool0
08L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool01@00
0000oooo0?ooo`3oool0000008D0oooo00280?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000Q@3oool008P0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08<0oooo00280?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000QP3oool008T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`240?ooo`00R@3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`240?ooo`00R@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080000000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`240?ooo`00R@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo000000270?ooo`00RP3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`250?ooo`00RP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`250?ooo`00RP3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`260?ooo`00R`3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo08H0oooo002;0?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000040?ooo`030000003oool0oooo08H0oooo002;0?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo08H0oooo002;0?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo08L0oooo002<0?ooo`040000003o
ool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`270?ooo`00R03oool5000000<0oooo0P00
00040?ooo`030000003oool0oooo08L0oooo002:0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00RP3oool00`000000oooo000000040?oo
o`8000000P3oool00`000000oooo0?ooo`280?ooo`00RP3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`000000RP3oool008X0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0?ooo`3oool0000008X0oooo00290?ooo`8000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo08T0oooo002>0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0R@3oool008h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`290?ooo`00SP3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo08X0oooo002>0?oo
o`060000003oool0oooo0000003oool00000S03oool008l0oooo00D000000?ooo`000000oooo0000
002<0?ooo`00S`3oool01@000000oooo0000003oool0000008`0oooo002?0?ooo`050000003oool0
00000?ooo`000000S03oool008l0oooo00@000000?ooo`0000000000S@3oool00900oooo0`00002=
0?ooo`00T03oool3000008d0oooo002@0?ooo`<00000S@3oool00900oooo0P00002>0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<
0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`80
0000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0
S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00R@3oool3000000D0oooo00<000000?ooo`3oool0S03oool0
08T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000
oooo0?ooo`040?ooo`800000S@3oool008X0oooo00<000000?ooo`3oool0T`3oool008T0oooo00<0
00000?ooo`000000U03oool008X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii)  Making a movie.", "Subsubsection"],

Cell["\<\
The following Mma accomplishes the movie effect in the MATLAB code.\
\>", "Text"],

Cell["\<\
Go to your two separate images above, beforePlot and afterPlot.  Select the \
two cell groups that contain these two plots (and only these two plots) -- \
click on the cell bracket and hold the button while you move until the two \
cell brackets are blackened.  Scroll the notebook until one of the image is \
in the center of the screen.  From the menu choose:  Cell, Animate Selected \
Graphics.  If you don't see the images flashing call for help.\
\>", "Text"],

Cell["\<\
Now let's create ten consecutive images (with scale 10), starting with t and \
repeatedly multiplying by d.  Rather than overwriting the original t, I \
prefer to call all of the transformed matrices c.\
\>", "Text"],

Cell["\<\
c = t;
view[c,10];
Do[
   c = d.c;
   view[c,10]
,{i,1,10}]\
\>", "Input"],

Cell["\<\
Now, Select the cell bracket containing all the plots (second from the \
inside) and animate the plots.
While the movie is playing, play with the \"play-back controls\" down on the \
lower bar.  Try the \"down v's\" first to slow down the action.  Describe \
what each does.\
\>", "Text"],

Cell["\<\
You should DELETE all of these multiple PLOTS before saving the notebook.  I \
suggest you scroll up to the top movie frame, Select the cell bracket \
containing all the plots (second from the inside) but not the program, then \
Cut (Ctrl-X).  If you are CAREFUL NOT TO DELETE YOUR PROGRAM, you (or I) can \
always recreate them.  Many graphics take up lots of space on the disk and in \
computer memory (RAM) while using the notebook.  If you encounter memory \
problems while saving or running Mma, delete movie frames.\
\>", "Text"]
}, Closed]],

Cell["(iii)  Make a contraction movie.", "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{

Cell["(c) Reflections", "Subsection"],

Cell[CellGroupData[{

Cell["(i) Find A, reflect t and r (from (a)(i)(ii)).", "Subsubsection"],

Cell[CellGroupData[{

Cell["A = {{1,0},{0,-1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0"},
            {"0", \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[A.t,1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66667 .83333 m
.5 .16667 L
.33333 .83333 L
.66667 .83333 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3
000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool00`3oool2000008h0
oooo00290?ooo`8000001@3oool3000008d0oooo002@0?ooo`<00000S@3oool00900oooo0`00002=
0?ooo`00S`3oool010000000oooo00000000002=0?ooo`00S`3oool01@000000oooo0000003oool0
000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03oool008l0oooo00D000000?oo
o`000000oooo0000002<0?ooo`00SP3oool01P000000oooo0?ooo`000000oooo000008`0oooo002>
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool008h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo08T0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`290?ooo`00S@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`280?ooo`00S03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000RP3o
ool008`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo08L0oooo002<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0Q`3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo08L0oooo002;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`00
RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
Q@3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`250?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo00290?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00R@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool008P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo00280?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?oo
o`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08<0oooo00270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`230?ooo`00Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00QP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0PP3oool00800oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0840oooo001o0?ooo`030000003oool0000000@0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
P@3oool007X0oooo0`0000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`210?ooo`00O`3oool0
0`000000oooo000000030?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0840oooo001o0?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03o
ool00800oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`200?ooo`00Q@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool008@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo00240?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00
Q03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
O`3oool008@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo07l0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1o0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`00PP3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0OP3oool00880oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?oo
o`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0O@3oool00840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo07d0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo07`0oooo00200?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N`3oool00800oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo0020
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k
0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0N`3oool007l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo07X0oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0NP3oool007h0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001n0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00OP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool007h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo
00070?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo1@00
000T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0S0?ooo`D000008P3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000002D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo000000070?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0000000V0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000040?ooo`000`3oool3000000<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0M0?ooo`<000000`3oool00`000000oooo0?ooo`0N0?oo
o`<000000P3oool00`000000oooo000000090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`0000002@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`060?ooo`80
00009P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000000L0oooo0P00000A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0000000L0oooo0P00000W0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool01P3oool2000000D0oooo00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`000000oooo000000070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00080?ooo`800000203o
ool3000002@0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo0`00000?0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00H0oooo0`00000U0?ooo`8000009@3oool2000000P0oooo0`0000040?ooo`00O03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool0
07`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
07L0oooo001k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1g0?ooo`00N`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0MP3oool007/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo07H0oooo000<0?ooool00000300000090?ooo`00303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo001j0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?ooo`00N@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3oool007T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo
001i0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1e0?ooo`00N@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0M03oool007P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo07@0oooo001h0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`1d0?ooo`00N03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0M03oool007P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001g0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00M`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool007L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0
oooo001g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1b0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0780oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3oool007D0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo001e0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1a0?ooo`00M@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3oool0
07D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0700oooo001d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1`0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0L03oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0700oooo001d0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K`3oool007<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001c0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00L`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0KP3o
ool00780oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06h0oooo001b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1^0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0KP3oool00780oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001a0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`00L@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00740oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001a0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00
L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
K03oool00700oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo06`0oooo001`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1/0?ooo`00L03oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000
00L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
06/0oooo001_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000002@3oool00`000000
oooo0?ooo`030?ooo`8000007`3oool00`000000oooo0?ooo`1[0?ooo`00K`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0J`3oool006l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1[0?ooo`00K`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo0`000005
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00
KP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
JP3oool006h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo06T0oooo001]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`1Y0?ooo`00K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0J@3oool006d0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo06T0oooo001]0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1X0?ooo`00K03oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool006`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001/0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1X0?oo
o`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0I`3oool006/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06L0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`1W0?ooo`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0I`3oool006/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001Z0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00JP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool006X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001Z
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U
0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0I@3oool006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo06D0oooo001Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1U0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0I03oool006P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo001X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1T0?ooo`00J03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03oool006P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06<0oooo
001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`1S0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0H`3oool006L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo06<0oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`1R0?ooo`00IP3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0HP3oool006H0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0680oooo001V0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1R0?ooo`00IP3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0H@3oool006D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0640
oooo001U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`1Q0?ooo`00I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0H@3oool006D0oooo00<000000?ooo`3oool0803oool5000000@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?oo
o`00I03ooomJ00000680oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2
000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00P03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool0
0800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800
oooo00<000000?ooo`3oool01P3oool2000009D0oooo00200?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0U03oool007l0oooo0P0000080?ooo`<00000U03oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[A.r,1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66667 .16667 m
.33333 .16667 L
.33333 .66667 L
.66667 .66667 L
.66667 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00I03ooomJ
00000680oooo001T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?ooo`030000003oool0oooo0280oooo0P0000060?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03o
ool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00
I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?oo
o`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo
001T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<00000
0?ooo`3oool04`3oool300000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`03
0?ooo`800000:P3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo000000070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00
I03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool0
06@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03o
ool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00
1`3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`D00000
903oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo
02<0oooo1@00000R0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000009@3oool00`000000
oooo0?ooo`0S0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0000000T0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`000000103oool01P000000oooo0?ooo`000000
oooo000002H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000@0oooo00030?ooo`<000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01d0oooo0`0000030?ooo`030000003oool0oooo01h0oooo0`0000020?ooo`050000003oool0
00000?ooo`0000001`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0009
0?ooo`030000003oool0oooo00H0oooo0P00000V0?ooo`030000003oool0oooo02<0oooo00D00000
0?ooo`000000oooo000000050?ooo`8000009@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P00000W0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool01P3oool2000000D0oooo00090?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`050000003oool000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000103o
ool010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`00203oool2000000P0oooo0`00000T0?ooo`8000009P3o
ool010000000oooo0?ooo`0000050?ooo`<00000903oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`00000U0?ooo`8000009@3oool2000000P0oooo
0`0000040?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo000<0?ooool000003000
00090?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?oo
o`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo
001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool0
06@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3o
ool0603oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03ooomJ00000680oooo001o0?ooo`030000003o
ool0000000L0oooo0P0000060?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`00
0000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo
0?ooo`040?ooo`800000S@3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo00290?oo
o`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo00200?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?oo
o`00P03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00
P03oool00`000000oooo0?ooo`060?ooo`800000U@3oool00800oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2D0?ooo`00O`3oool2000000P0oooo0`00002D0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(ii)  Up to the last sentence, do what the problem says as scratch work.  \
Report your result by defining 
A[w_] = the transformation matrix for reflection about a line of angle w.
For the last sentence, use A[Pi/3] to reflect t and r.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
Clear[A]
A[w_] = {{Cos[2w], Cos[2w-Pi/2]},{Sin[2w], Sin[2w-Pi/2]}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(cos(2\ w)\), \(sin(2\ w)\)},
            {\(sin(2\ w)\), \(-\(cos(2\ w)\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A[Pi/3]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\(1\/2\)\), \(\@3\/2\)},
            {\(\@3\/2\), \(1\/2\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[t,1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66667 .16667 m
.5 .83333 L
.33333 .16667 L
.66667 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00I03ooomJ
00000680oooo001T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001U0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001U0?ooo`030000003oool0oooo0240oooo0P0000060?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0H@3oool006D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0640oooo001U0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`1Q0?ooo`00IP3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0H@3oool006H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0680oooo001V0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1R0?ooo`00IP3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0HP3o
ool006L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0680oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1S0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0H`3oool006L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo06<0oooo001X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`00J03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03oool006P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo001X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1T0?ooo`00
J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
I03oool006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo06D0oooo001Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1U0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0I@3oool006X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo06D0oooo001Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00JP3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool006X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001[0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?oo
o`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0I`3oool006/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06L0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`1W0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0I`3oool006`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001/0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1X0?ooo`00K03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool006d0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0oooo001]
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Y
0?ooo`00K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0J@3oool006d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo06T0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`1Y0?ooo`00KP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006h0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001^0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00K`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06/0oooo
001_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool006l0oooo00<00000
0?ooo`3oool0203oool300000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`03
0?ooo`8000007`3oool00`000000oooo0?ooo`1[0?ooo`00L03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0J`3oool00700oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00
L03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00700oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00740
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0
oooo001a0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1]0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0K@3oool00780oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06h0oooo001b0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1^0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0KP3oool007<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo001c0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00L`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0K`3oool0
07<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
06l0oooo001d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1_0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0L03oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0700oooo001d0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1`0?ooo`00M@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo001e0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1a0?ooo`00M@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3o
ool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1b0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0LP3oool007H0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0780oooo001g0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool007L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo001g0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c0?ooo`00
1`3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`D00000
903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8`3oool500000280oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000U0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`000000103oool000<0oooo0`0000030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07@3oool3000000<0oooo00<000000?ooo`3oool07P3oool3
00000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool000T0oooo00<000000?ooo`3oool01P3oool20000
02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?ooo`800000303oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo000000070?ooo`8000009`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00H0oooo0P0000050?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00203oool2000000P0oooo
0`00000T0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`<00000303oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`<000009@3oool2000002D0oooo0P0000080?ooo`<00000103oool007T0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07D0oooo001i
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e
0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0M@3oool007X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo07H0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1f0?ooo`00303ooooo000000`000002@3oool000`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`00N`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07L0oooo001l0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00
O03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
M`3oool007`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo07P0oooo001m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1h0?ooo`00O@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0N03oool007d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo07P0oooo001m0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00OP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool007h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001n0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?oo
o`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0NP3oool007l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07X0oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0NP3oool007l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo00200?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`00P03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N`3oool00800oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo0020
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l
0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0O03oool00840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo07`0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00880oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00220?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`00PP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00880oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07h0oooo
00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1n0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0OP3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo07h0oooo00230?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool008@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07l0oooo00240?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool008D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800
oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`200?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo001o
0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00O`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000T0oooo00<0
00000?ooo`3oool0P@3oool007l0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00O`3oool00`00
0000oooo000000040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`210?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo00270?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00
Q`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
PP3oool008L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0880oooo00270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0P`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo00280?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?ooo`00R03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Q03oool008T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08@0oooo00290?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?oo
o`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0Q03oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0Q@3oool008X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08D0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`00R`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`26
0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0Q`3oool008`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`280?ooo`00S@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0R03oool008d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo08P0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`290?ooo`00SP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08T0oooo002>
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3oool008h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`290?ooo`00SP3oool01P000000oooo0?ooo`00
0000oooo000008`0oooo002?0?ooo`050000003oool000000?ooo`000000S03oool008l0oooo00D0
00000?ooo`000000oooo0000002<0?ooo`00S`3oool01@000000oooo0000003oool0000008`0oooo
002?0?ooo`040000003oool00000000008d0oooo002@0?ooo`<00000S@3oool00900oooo0`00002=
0?ooo`00T03oool3000008d0oooo00280?ooo`D000000`3oool2000008h0oooo002:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103o
ool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<0
00000?ooo`3oool01P3oool2000009D0oooo00200?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0U03oool007l0oooo0P0000080?ooo`<00000U03oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[A[Pi/3].t, 1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.12799 .47767 m
.78868 .66667 L
.29466 .189 L
.12799 .47767 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3
000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool005X0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`2<0?ooo`00F@3oool00`000000oooo0000000e0?ooo`03
0000003oool0oooo08`0oooo001I0?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`3o
ool0S03oool005P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo08`0oooo001H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`2<0?ooo`00E`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0S03oool005L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo08`0oooo001F0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2<0?ooo`00E@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0S03oool005D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08`0oooo001D
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2<
0?ooo`00E03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0S03oool005<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo08`0oooo001C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`2<0?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0S03oool00540oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo08`0oooo001A0?ooo`030000003oool0oooo
01H0oooo0P00000U0?ooo`030000003oool0oooo08`0oooo001@0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2<0?ooo`00D03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0S03oool004l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo08`0oooo001?
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2<
0?ooo`00CP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0S03oool004d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo08`0oooo001=0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`2<0?ooo`00C03oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0S03oool004`0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo08`0oooo001;0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2<0?ooo`00B`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0S03oool004X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo08`0oooo
00190?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`2<0?ooo`00B@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0S03oool004P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo08`0oooo00180?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`2<0?ooo`00A`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0S03oool004L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08`0oooo00160?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2<0?ooo`00A@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0S03oool004D0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00A03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`2<0?ooo`00A03oool00`000000oooo0?ooo`0c0?ooo`<000000P3oool010000000oooo0000
000000080?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00@`3oool00`000000oooo0?oo
o`0i0?ooo`050000003oool000000?ooo`0000001@3oool2000000H0oooo00<000000?ooo`3oool0
S03oool004<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00@P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`00
00050?ooo`030000003oool0oooo08`0oooo00110?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2<0?ooo`00@@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0S03oool00400oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08`0oooo00100?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00?`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03o
ool003l0oooo00<000000?ooo`3oool0B@3oool2000000@0oooo00<000000?ooo`3oool0S03oool0
03h0oooo00<000000?ooo`3oool0C03oool01@000000oooo0?ooo`3oool0000008h0oooo000m0?oo
o`030000003oool0oooo04h0oooo00@000000?ooo`3oool00000SP3oool003d0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0000002>0?ooo`00?03oool00`000000oooo0?ooo`1A0?ooo`80
0000SP3oool003`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2<0?ooo`00>`3o
ool00`000000oooo0?ooo`1C0?ooo`800000S@3oool003/0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0000002<0?ooo`00>P3oool00`000000oooo0?ooo`1D0?ooo`040000003oool0oooo
000008/0oooo000i0?ooo`030000003oool0oooo05D0oooo00D000000?ooo`3oool0oooo0000002:
0?ooo`00>@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0Q`3oool003P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08H0oooo000h0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`250?ooo`00=`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0Q03oool003L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo000f0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00=@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P@3oool003D0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo
000d0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1o0?ooo`00=03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0OP3oool003<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo07d0oooo000c0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1l0?ooo`00<P3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0N`3oool00340oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo00070?ooo`D000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool5
000002@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`D000008P3oool5
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000903oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo000000040?ooo`000`3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0I0?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`0N0?oo
o`<000000P3oool00`000000oooo000000090?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000T0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool000T0oooo00<000000?ooo`3oool01P3oool2000001/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000000L0oooo0P00000U0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`80
00009`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`00
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`00203oool2000000P0oooo0`00000I0?ooo`8000002@3o
ool2000002H0oooo00<000000?ooo`3oool01P3oool3000002@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0`00000U0?ooo`8000009@3o
ool2000000P0oooo0`0000040?ooo`00<03oool4000005d0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1c0?ooo`00=03oool3000005X0oooo00<000000?ooo`3oool05`3oool20000
07<0oooo000g0?ooo`@00000EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700
oooo000k0?ooo`<00000D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo
000n0?ooo`@00000C`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo000<
0?ooool00000300000090?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool4000000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00303oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo0`00000H0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`00C03oool40000
0440oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00D03oool3000003h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Y0?ooo`00D`3oool4000003X0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1X0?ooo`00E`3oool3000003L0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`00FP3oool4000003<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00GP3oool300000300oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1U0?ooo`00H@3oool4000002`0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`1T0?ooo`00I@3oool3000002T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1S0?ooo`00J03oool4000002D0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`1R0?ooo`00K03oool300000280oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1Q0?ooo`00K`3oool4000001h0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1P0?ooo`00L`3oool3000001/0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`1O0?ooo`00MP3oool4000001L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1N0?ooo`00NP3oool3000001@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`1M0?ooo`00O@3oool400000100oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1L
0?ooo`00P@3oool3000000d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1K0?oo
o`00Q03oool4000000T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1J0?ooo`00
R03oool3000000H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1I0?ooo`00R`3o
ool400000080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`00S`3oool3
000003@0oooo00<000000?ooo`3oool0E`3oool00940oooo1@00000a0?ooo`030000003oool0oooo
05H0oooo002A0?ooo`030000003oool0oooo0080oooo0`00000_0?ooo`030000003oool0oooo05D0
oooo002A0?ooo`030000003oool0oooo00D0oooo1000000/0?ooo`030000003oool0oooo05@0oooo
002A0?ooo`030000003oool0oooo00T0oooo0`00000Z0?ooo`030000003oool0oooo05<0oooo002A
0?ooo`030000003oool0oooo00`0oooo1000000W0?ooo`030000003oool0oooo0580oooo002A0?oo
o`030000003oool0oooo0100oooo0`00000U0?ooo`800000DP3oool00940oooo00<000000?ooo`3o
ool04`3oool4000002<0oooo00<000000?ooo`3oool0C`3oool00940oooo00<000000?ooo`3oool0
5`3oool300000240oooo00<000000?ooo`3oool0CP3oool00940oooo00<000000?ooo`3oool06P3o
ool4000001h0oooo00<000000?ooo`3oool0C@3oool00940oooo00<000000?ooo`3oool07P3oool3
000001`0oooo00<000000?ooo`3oool0C03oool00940oooo00<000000?ooo`3oool08@3oool40000
01T0oooo00<000000?ooo`3oool0B`3oool00940oooo00<000000?ooo`3oool09@3oool3000001L0
oooo00<000000?ooo`3oool0BP3oool00940oooo00<000000?ooo`3oool0:03oool4000001@0oooo
00<000000?ooo`3oool0B@3oool00940oooo00<000000?ooo`3oool0;03oool300000180oooo00<0
00000?ooo`3oool0B03oool00940oooo00<000000?ooo`3oool0;`3oool4000000l0oooo00<00000
0?ooo`3oool0A`3oool00940oooo00<000000?ooo`3oool0<`3oool3000000d0oooo00<000000?oo
o`3oool0AP3oool00940oooo00<000000?ooo`3oool0=P3oool4000000X0oooo00<000000?ooo`3o
ool0A@3oool00940oooo00<000000?ooo`3oool0>P3oool3000000P0oooo00<000000?ooo`3oool0
A03oool00940oooo00<000000?ooo`3oool0?@3oool4000000D0oooo00<000000?ooo`3oool0@`3o
ool00800oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0@@3oool3000000<0oooo00<000000?ooo`3oool0@P3oool0
07l0oooo00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003oool0oooo
04@0oooo1@0000130?ooo`00O`3oool00`000000oooo000000090?ooo`030000003oool0oooo00<0
oooo0P0000190?ooo`800000@P3oool007l0oooo00<000000?ooo`0000001`3oool2000000H0oooo
00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0oooo0`000005
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo0028
0?ooo`D00000103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00
RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo001n0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0oooo00H0
oooo0P00002E0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09@0oooo
001o0?ooo`800000203oool3000009@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
view[r, 1.5];
view[A[Pi/3].r, 1.5];\
\>", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66667 .83333 m
.33333 .83333 L
.33333 .33333 L
.66667 .33333 L
.66667 .83333 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3
000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool007l0oooo00<0
00000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo001T
0?oooeX00000HP3oool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo000000070?oo
o`8000001P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo
001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool000L0oooo1@0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08P3oool5000002@0oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0S0?ooo`D000008P3oool50000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000002D0oooo00<000000?ooo`3oool08`3oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0000000@0oooo00H000000?ooo`3oool000000?ooo`00000V0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?ooo`000`3oool3
000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`<000000`3oool0
0`000000oooo0?ooo`0N0?ooo`<000000P3oool01@000000oooo0000003oool0000000L0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`06
0?ooo`8000009P3oool00`000000oooo0?ooo`0S0?ooo`050000003oool000000?ooo`0000001@3o
ool2000002D0oooo00<000000?ooo`3oool08P3oool00`000000oooo000000040?ooo`030000003o
ool0oooo008000009`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0P00
00050?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool08`3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool000P0oooo0P0000080?ooo`<00000903oool2000002H0oooo00@000000?ooo`3oool00000
1@3oool3000002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<000009@3oool2000002D0oooo0P0000080?ooo`<00000103oool006@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1P0?ooo`00303ooooo000000`000002@3oool000`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool006@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03o
ool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00
I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?oo
o`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo
001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`00
00001`3oool00`000000oooo000000050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0H03oool006@0oooo00<000000?ooo`3oool0603oool00`000000oooo000000090?ooo`030000
003oool0oooo00<0oooo0P00000Z0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`0000001`3oool2000000H0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool30000
00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo
001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool0
06@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03o
ool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H03oool006@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00
I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
H03oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0600oooo001T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1P0?ooo`00I03oool00`000000oooo0?ooo`0Q0?ooo`D00000103oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001T0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600
oooo001T0?oooeX00000HP3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo00290?oo
o`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo00200?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?oo
o`00P03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00
P03oool00`000000oooo0?ooo`060?ooo`800000U@3oool00800oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2D0?ooo`00O`3oool2000000P0oooo0`00002D0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.70534 .811 m
.87201 .52233 L
.439 .27233 L
.27233 .561 L
.70534 .811 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3
000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool010000000oooo00000000000>0?ooo`030000
003oool0oooo08`0oooo001o0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo
0?ooo`2<0?ooo`00OP3oool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo0?oo
o`2<0?ooo`00OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0S03oool007d0oooo00<000000?ooo`3oool0203oool2000000L0oooo00<000000?oo
o`3oool0S03oool007d0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3o
ool0S03oool007`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo08`0oooo001k0?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`030000003o
ool0oooo08`0oooo001k0?ooo`030000003oool0oooo0140oooo0`00002>0?ooo`00NP3oool00`00
0000oooo0?ooo`0D0?ooo`800000S@3oool007X0oooo00<000000?ooo`3oool0503oool00`000000
oooo0000002<0?ooo`00N@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00800000
RP3oool007T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`800000R03o
ool007P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08D0oooo001g0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool20000
08D0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001`3oool00`000000
oooo000000050?ooo`030000003oool0oooo00L0oooo0P0000230?ooo`00MP3oool010000000oooo
0?ooo`3oool300000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`80
00002P3oool200000840oooo001f0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
1`3oool2000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n0?ooo`00M@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`800000OP3oool007D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`0>0?ooo`800000O03oool0
07@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
07T0oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool2000007T0
oooo001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool2000007L0oooo
001b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool2000007D0oooo001b
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b
0?ooo`00L@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo0P00001b0?oo
o`00L@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo0P00001`0?ooo`00
L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
K@3oool006l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0M0?ooo`800000K@3o
ool006l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`800000J`3oool0
06h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`800000J@3oool006h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0
oooo001]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0903oool2000006H0oooo
001]0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09P3oool2000006@0oooo001/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1Q
0?ooo`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02T0oooo0P00001Q0?oo
o`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02/0oooo0P00001O0?ooo`00
JP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo0P00001M0?ooo`00JP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0FP3o
ool006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0`0?ooo`800000FP3oool0
06T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0b0?ooo`800000F03oool006P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05D0
oooo001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0=@3oool2000005D0oooo
001W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0=`3oool2000005<0oooo001V
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>@3oool200000540oooo001V0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1>0?oo
o`00I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03`0oooo0P00001>0?ooo`00
I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03h0oooo0P00001<0?ooo`00I03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0B@3o
ool000L0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool5
000002@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool200000100oooo1@00000R0?ooo`D000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool00000
000000H0oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
000000L0oooo00<000000?ooo`000000503oool200000100oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00030?ooo`<000000`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo0`0000030?ooo`030000003oool0oooo
01h0oooo0`0000020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0503oool20000
00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00090?ooo`030000003oool0oooo00H0oooo0P00000V0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`0000001`3oool2000002D0oooo00<000000?ooo`3oool08P3oool00`000000
oooo000000070?ooo`8000006@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01P3oool2000000D0oooo00090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`<000001`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`0I0?ooo`8000002`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool000P0oooo0P0000080?ooo`<00000903oool2000002H0oooo00<0
00000?ooo`3oool01P3oool3000002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`060?ooo`<000006`3oool2000000P0oooo0P00000U0?ooo`800000203oool3000000@0oooo001P
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0m
0?ooo`00G`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04d0oooo0P00000m0?oo
o`00G`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04l0oooo0P00000k0?ooo`00
GP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0540oooo0P00000i0?ooo`00GP3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0=P3o
ool000`0ooooo`00000<000000T0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0`0000060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3o
ool00000:@3oool00`000000oooo0?ooo`070?ooo`00F`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo05T0oooo0P00000a0?ooo`00F`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo05/0oooo0P00000_0?ooo`00FP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo05d0oooo0P00000]0?ooo`00FP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool0:P3oool005T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02/0oooo001I0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0[0?ooo`00F03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;03oool005L0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02`0oooo001G
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0]
0?ooo`00EP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0;@3oool005H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo02h0oooo001E0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0_0?ooo`00E@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool0;`3oool005@0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0300oooo001E0?ooo`800000>P3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0300oooo001G0?ooo`800000>03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0340oooo001I0?ooo`800000=P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0340oooo001K0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0b0?ooo`00G03oool2000003<0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0c0?ooo`00GP3oool200000340oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0c0?ooo`00H03oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0=03oool00640oooo0P00000^0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000/0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0=@3oool006D0oooo0P00000Z0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0=@3oool006L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo03H0oooo001X0?ooo`8000009`3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo03L0oooo001Z0?ooo`8000009@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo03L0oooo001/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0h0?ooo`00K@3oool200000280oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0h0?ooo`00K`3oool200000200oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0i0?ooo`00L@3oool2000001h0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0i0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0>P3oool007@0oooo0P00000K0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0>`3oool007H0oooo0P00000I0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0>`3oool007P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo03`0oooo001i0?ooo`8000005P3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo03`0oooo001k0?ooo`800000503oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo03d0oooo001m0?ooo`8000004P3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo03d0oooo001o0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0n0?ooo`00P03oool2000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0?`3oool007l0oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0o0?ooo`00O`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000004X0oooo
00<000000?ooo`3oool0@03oool007l0oooo00<000000?ooo`0000000`3oool200000080oooo0P00
00060?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0@03oool007l0oooo00<00000
0?ooo`0000001@3oool3000000L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`11
0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0440oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`120?ooo`00S03oool2000000<0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`130?ooo`00SP3oool2000000030?ooo`000000oooo04L0oooo00<0
00000?ooo`3oool0@`3oool00900oooo0P0000170?ooo`030000003oool0oooo04@0oooo002A0?oo
o`800000AP3oool00`000000oooo0?ooo`140?ooo`00T@3oool010000000oooo0000000000130?oo
o`030000003oool0oooo04D0oooo002A0?ooo`040000003oool0oooo0?ooo`800000@@3oool00`00
0000oooo0?ooo`150?ooo`00T@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0AP3oool00940oooo00<000000?ooo`3oool0103oool2000003`0oooo
00<000000?ooo`3oool0A`3oool00940oooo00<000000?ooo`3oool01P3oool2000003X0oooo00<0
00000?ooo`3oool0A`3oool00940oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo04P0oooo002A0?ooo`030000003oool0oooo00T0oooo0P00000f0?oo
o`030000003oool0oooo04P0oooo002A0?ooo`030000003oool0oooo00/0oooo0P00000c0?ooo`03
0000003oool0oooo04T0oooo002A0?ooo`030000003oool0oooo00d0oooo0P00000a0?ooo`030000
003oool0oooo04T0oooo002A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`1:0?ooo`00T@3oool00`000000oooo0?ooo`0@0?ooo`800000;03oool0
0`000000oooo0?ooo`1;0?ooo`00T@3oool00`000000oooo0?ooo`0B0?ooo`800000:P3oool00`00
0000oooo0?ooo`1;0?ooo`00T@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0C03oool00940oooo00<000000?ooo`3oool05@3oool2000002H0oooo
00<000000?ooo`3oool0C03oool00940oooo00<000000?ooo`3oool05`3oool2000002<0oooo00<0
00000?ooo`3oool0C@3oool00940oooo00<000000?ooo`3oool06@3oool200000240oooo00<00000
0?ooo`3oool0C@3oool00940oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo04h0oooo002A0?ooo`030000003oool0oooo01`0oooo0P00000L0?ooo`03
0000003oool0oooo04l0oooo002A0?ooo`030000003oool0oooo01h0oooo0P00000J0?ooo`030000
003oool0oooo04l0oooo002A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1@0?ooo`00T@3oool00`000000oooo0?ooo`0Q0?ooo`8000005P3oool0
0`000000oooo0?ooo`1@0?ooo`00T@3oool00`000000oooo0?ooo`0S0?ooo`8000004`3oool00`00
0000oooo0?ooo`1A0?ooo`00T@3oool00`000000oooo0?ooo`0U0?ooo`8000004@3oool00`000000
oooo0?ooo`1A0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0DP3oool00940oooo00<000000?ooo`3oool0:03oool2000000`0oooo00<0
00000?ooo`3oool0D`3oool00940oooo00<000000?ooo`3oool0:P3oool2000000X0oooo00<00000
0?ooo`3oool0D`3oool00940oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo05@0oooo002A0?ooo`030000003oool0oooo02d0oooo0P0000060?ooo`03
0000003oool0oooo05@0oooo002A0?ooo`030000003oool0oooo02l0oooo0P0000030?ooo`030000
003oool0oooo05D0oooo002A0?ooo`030000003oool0oooo0340oooo0P0000000`3oool000000?oo
o`1F0?ooo`00T@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05H0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo00280?ooo`D00000103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo
00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo0P00
00060?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001n0?ooo`D000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00800oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo0020
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2000008d0oooo00200?oo
o`030000003oool0oooo00H0oooo0P00002E0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo09@0oooo001o0?ooo`800000203oool3000009@0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(d) Rotations", "Subsection"],

Cell[CellGroupData[{

Cell["t = Transpose[{{.5,-1},{0,1},{-.5,-1},{.5,-1}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "0", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {\(-1\), "1", \(-1\), \(-1\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(i)  Just define A[theta_] = matrix of rotation through angle theta\
\>", "Subsubsection"],

Cell["Clear[A]", "Input"],

Cell[CellGroupData[{

Cell["\<\
A[theta_] = {{Cos[theta], -Sin[theta]},{Sin[theta], Cos[theta]}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(cos(theta)\), \(-\(sin(theta)\)\)},
            {\(sin(theta)\), \(cos(theta)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii)  Find A[Pi/4], and use it to rotate t.", "Subsubsection"],

Cell[CellGroupData[{

Cell["A[Pi/4]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(1\/\@2\), \(-\(1\/\@2\)\)},
            {\(1\/\@2\), \(1\/\@2\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[A[Pi/4].t, 1.5];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.5 0.333333 [
[0 .4875 -12 -9 ]
[0 .4875 12 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -12 -9 ]
[.33333 .4875 12 0 ]
[.66667 .4875 -9 -9 ]
[.66667 .4875 9 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -9 -9 ]
[1 .4875 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -24 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -18 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -18 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-1.5)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-1)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-0.5)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(0.5)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(1)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1.5)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-0.5)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(0.5)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(1)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1.5)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.85355 .38215 m
.2643 .7357 L
.61785 .14645 L
.85355 .38215 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000009@0oooo001j0?ooo`<000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo002A0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`000000KP3oool00940oooo00<000000?ooo`3o
ool06`3oool010000000oooo0?ooo`00001]0?ooo`00R03oool5000000@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06X0oooo002:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo06T0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`8000006P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo002:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo06L0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo06H0oooo00290?ooo`8000001P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00940oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06@0oooo
002A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1S0?ooo`00T@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0640oooo002A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1P0?ooo`00T@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool00940oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05h0oooo002A0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1M0?ooo`00T@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0G03oool00940
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05/0
oooo002A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1J0?ooo`00T@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0F@3oool00940oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05P0oooo002A0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1G0?ooo`00T@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0EP3oool00940oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05D0oooo002A0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1D0?ooo`00T@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D`3oool0
0940oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0580oooo002A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`1A0?ooo`00T@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0D03oool00940oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo04l0oooo002A0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1>0?ooo`00T@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0C@3oool00940oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo04`0oooo002A0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1;0?ooo`00T@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0BP3o
ool00940oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo04T0oooo002A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`180?ooo`00T@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0A`3oool00940oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo04H0oooo002A0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`150?ooo`00T@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0A03oool00940oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo002A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`00
T@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
@@3oool00940oooo00D000000?ooo`3oool0oooo000000170?ooo`030000003oool0oooo0400oooo
002A0?ooo`040000003oool0oooo000004T0oooo00<000000?ooo`3oool0?`3oool00940oooo00@0
00000?ooo`3oool00000BP3oool00`000000oooo0?ooo`0n0?ooo`00P03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0000
001<0?ooo`030000003oool0oooo03d0oooo001o0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0000001=0?ooo`030000003oool0oooo03`0oooo001j0?oo
o`<000000P3oool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo0P00001?0?oo
o`030000003oool0oooo03/0oooo001o0?ooo`030000003oool0000000L0oooo0P0000060?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0>P3oool007l0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
>@3oool00800oooo00<000000?ooo`3oool01P3oool3000000@0oooo0P00001C0?ooo`030000003o
ool0oooo03P0oooo002@0?ooo`800000E03oool00`000000oooo0?ooo`0g0?ooo`00S`3oool00`00
0000oooo0000001E0?ooo`030000003oool0oooo03H0oooo002>0?ooo`040000003oool0oooo0000
05H0oooo00<000000?ooo`3oool0=@3oool008h0oooo00@000000?ooo`3oool00000E`3oool00`00
0000oooo0?ooo`0d0?ooo`00S@3oool01@000000oooo0?ooo`3oool0000005P0oooo00<000000?oo
o`3oool0<`3oool008d0oooo00D000000?ooo`3oool0oooo0000001I0?ooo`030000003oool0oooo
0380oooo002<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0a0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0<03oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02l0oooo002:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0^0?ooo`00RP3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05T0oooo0P00000a0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05L0oooo0P00000c0?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0<`3oool008P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1D0?ooo`800000=P3oool008L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1B0?ooo`800000>03oool008L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo03P0oooo00260?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0C`3oool2000003/0oooo00250?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0C@3oool2000003d0oooo00250?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0m0?ooo`00Q03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo04X0oooo0P0000100?ooo`00Q03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo04P0oooo0P0000120?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0@P3oool00880oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`150?ooo`800000A@3oool00880oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`130?ooo`800000A`3oool00840oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo04L0oooo00210?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0@03oool2000004X0oooo00200?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0?P3oool2000004`0oooo00200?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1<0?ooo`00O`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo03/0oooo0P00001?0?ooo`001`3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`D00000903oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo0P00000H0?ooo`D000008P3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000002D0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?oo
o`030000003oool000000140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0000000L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?oo
o`000`3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`<0
00000`3oool00`000000oooo0?ooo`0N0?ooo`<000000P3oool00`000000oooo000000090?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool01@3oool2000001d0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00090?ooo`030000
003oool0oooo00H0oooo0P00000V0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`000000
1`3oool200000140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0000000L0oooo0P0000060?ooo`8000007`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00H0oooo0P0000050?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00203oool2
000000P0oooo0`00000T0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`<000003P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool3
00000080oooo0P00000Q0?ooo`8000009@3oool2000000P0oooo0`0000040?ooo`00N`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02l0oooo0P00001K0?ooo`00NP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0F`3oool007X0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0/0?ooo`800000GP3oool007T0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0Z0?ooo`800000H03oool007P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo000<0?oo
ool00000300000090?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool2000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool200000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool007H0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`800000J03oool007D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0P0?ooo`800000JP3oool007D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo001d0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool2000006d0oooo001d0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool2000006l0oooo001c0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1_0?ooo`00LP3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo0P00001b0?ooo`00LP3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo0P00001d0?ooo`00L@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0M03oool00740oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`800000M`3oool00700oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`800000N@3oool006l0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001_0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool2000007`0oooo001^0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0303oool2000007h0oooo001^0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool02P3oool200000800oooo001]0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?ooo`00K03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0P0000230?ooo`00K03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo0P0000250?ooo`00J`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool006/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`800000R03oool006X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`02000008X0oooo001Y0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`000000S03oool006T0oooo00<000000?ooo`3oool09@3oool20000
08d0oooo001X0?ooo`030000003oool0oooo02@0oooo0`00002>0?ooo`00J03oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo000008h0oooo001W0?ooo`030000003oool0oooo0280oooo
0P0000030?ooo`030000003oool0oooo08`0oooo001V0?ooo`030000003oool0oooo0240oooo0P00
00050?ooo`030000003oool0oooo08`0oooo001V0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00I@3oool00`000000oooo0?ooo`0O0?oo
o`800000203oool00`000000oooo0?ooo`2<0?ooo`00I@3oool00`000000oooo0?ooo`0M0?ooo`80
00002P3oool00`000000oooo0?ooo`2<0?ooo`00I03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool006<0oooo00<000000?ooo`3oool0703o
ool2000000d0oooo00<000000?ooo`3oool0S03oool006<0oooo00<000000?ooo`3oool06P3oool2
000000l0oooo00<000000?ooo`3oool0S03oool00680oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo08`0oooo001R0?ooo`030000003oool0oooo01P0
oooo0P00000B0?ooo`030000003oool0oooo08`0oooo001Q0?ooo`030000003oool0oooo01L0oooo
0P00000D0?ooo`030000003oool0oooo08`0oooo001P0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`2<0?ooo`00H03oool00`000000oooo0?ooo`0E
0?ooo`8000005`3oool00`000000oooo0?ooo`2<0?ooo`00G`3oool00`000000oooo0?ooo`0D0?oo
o`8000006@3oool00`000000oooo0?ooo`2<0?ooo`00G`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool005h0oooo00<000000?ooo`3oool0
4P3oool2000000X0oooo00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000
003oool0oooo08`0oooo001M0?ooo`030000003oool0oooo0140oooo0P00000<0?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool00`3oool2000008d0oooo001M0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo000000070?ooo`8000001P3oool0
0`000000oooo0?ooo`2<0?ooo`00G03oool00`000000oooo0?ooo`0?0?ooo`8000003`3oool00`00
0000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool005`0
oooo00<000000?ooo`3oool03@3oool200000180oooo00<000000?ooo`3oool01P3oool3000000D0
oooo00<000000?ooo`3oool0S03oool005/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo08`0oooo001J0?ooo`030000003oool0oooo00`0oooo0P00
000V0?ooo`030000003oool0oooo08`0oooo001J0?ooo`030000003oool0oooo00X0oooo0P00000X
0?ooo`030000003oool0oooo08`0oooo001I0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`2<0?ooo`00F@3oool00`000000oooo0?ooo`080?ooo`80
0000:`3oool00`000000oooo0?ooo`2<0?ooo`00F03oool00`000000oooo0?ooo`070?ooo`800000
;@3oool00`000000oooo0?ooo`2<0?ooo`00E`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0S03oool005L0oooo00<000000?ooo`3oool01@3oool2
00000300oooo00<000000?ooo`3oool0S03oool005H0oooo00<000000?ooo`3oool0103oool20000
0380oooo00<000000?ooo`3oool0S03oool005H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo08`0oooo001E0?ooo`030000003oool0oooo0080oooo
0P00000e0?ooo`030000003oool0oooo08`0oooo001D0?ooo`040000003oool0oooo0?ooo`800000
=`3oool00`000000oooo0?ooo`2<0?ooo`00E03oool010000000oooo0?ooo`00000i0?ooo`030000
003oool0oooo08`0oooo001C0?ooo`040000003oool00000000003X0oooo00<000000?ooo`3oool0
S03oool005<0oooo0P00000l0?ooo`030000003oool0oooo08`0oooo001B0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008P0oooo1@00
00040?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool007h0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool20000
09D0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0U03oool007l0oooo
0P0000080?ooo`<00000U03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.63536, -1.61844, 0.0112783, 
  0.0112783}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(iii)  Make a movie as described.  Use transformation matrix defined below.\
\>", "Subsubsection"],

Cell["\<\
Use the following transformation matrix.  It is important to use N[ ] to get \
numerical (\"decimal\") values; otherwise, Mma will bog down (really slows to \
a halt) when it tries to compute many exact compostions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["a = N[A[Pi/20]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.987688340595137859`", \(-0.156434465040230863`\)},
            {"0.156434465040230863`", "0.987688340595137859`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
c = t;
view[c,1.5];
Do[
   c = a.c;
   view[c,1.5]
,{i,1,40}]\
\>", "Input"],

Cell["\<\
When you animate the resulting graphics, it will not stop at the last frame \
but the control buttons allow time and direction (order in which frames are \
displayed) control.\
\>", "Text"],

Cell["\<\
Remember to DELETE all of these PLOTS before saving the notebook.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(e) Combinations of Transformations (i).  (Omit (ii) since animation does \
it.)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["n = Transpose[{{-1,-2},{-1,2},{1,-2},{1,2}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), \(-1\), "1", "1"},
            {\(-2\), "2", \(-2\), "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[n,3];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-3)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-2)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-1)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(1)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(2)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(3)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.33333 .16667 m
.33333 .83333 L
.66667 .16667 L
.66667 .83333 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool2000009D0oooo002;0?ooo`030000003o
ool0oooo0980oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000
S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool3000000D0oooo00<0
00000?ooo`3oool0S03oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<
0?ooo`00HP3oool00`000000oooo0?ooo`0O0?ooo`<000000`3oool00`000000oooo0?ooo`040?oo
o`800000;03oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool200000600oooo001R0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0Z0?ooo`800000
H03oool00680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`000000H03oool00680oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool000000600oooo001R0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00001P0?ooo`00HP3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000H03oool0
0680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`050000003oool0oooo
0?ooo`000000H03oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?oo
o`050000003oool0oooo0?ooo`000000H03oool00680oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0GP3oool00680
oooo00<000000?ooo`3oool0;03oool2000002L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1N0?oo
o`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1N0?ooo`00HP3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`00
0000oooo0?ooo`0/0?ooo`8000008P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05h0oooo
001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05h0oooo001R0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0
oooo02`0oooo0P00000N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0GP3oool0
0680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0GP3oool00680oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0GP3oool00680oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03o
ool2000001T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1N0?ooo`00HP3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?oo
o`00HP3oool00`000000oooo0?ooo`0S0?ooo`D00000103oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0O0?ooo`<000000`3o
ool00`000000oooo0?ooo`040?ooo`800000503oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo05h0oooo001R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0GP3oool0
0680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`0T0?ooo`8000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0GP3oool00680oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0
;03oool200000100oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1N0?ooo`00HP3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1N
0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`80
00002`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05h0
oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05h0oooo001R
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo02`0oooo0P0000070?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0GP3o
ool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0GP3oool00680
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0GP3oool000L0oooo0P00
000/0?ooo`<00000:P3oool5000002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0S0?ooo`D00000:`3oool3000002/0oooo0P0000040?ooo`002@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`000000;03oool01@000000oooo0?ooo`3o
ool0000002P0oooo0P00000/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00@3o
ool00080oooo0`0000030?ooo`030000003oool0oooo02D0oooo0`0000030?ooo`030000003oool0
oooo02D0oooo0`000000103oool000000?ooo`00000/0?ooo`8000000P3oool00`000000oooo0?oo
o`0V0?ooo`800000;@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0009
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0000000/
0?ooo`040000003oool0oooo000002T0oooo0P00000]0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool00@3oool000L0oooo00<000000?ooo`000000:`3oool00`000000oooo0000000Z
0?ooo`030000003oool0000002`0oooo00@000000?ooo`3oool00000:@3oool2000002`0oooo00<0
00000?ooo`000000:`3oool00`000000oooo000000030?ooo`00203oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`030000003oool0000002T0oooo0`00000]
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00680oooo00<000000?oo
o`3oool0;03oool00`000000oooo0000000[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`03
0000003oool0oooo02`0oooo0P00000/0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000
003oool0oooo02`0oooo0P00000/0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool0
00H0ooooo`00000H000000<0oooo00060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`000000
;@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
0@3oool00680oooo00<000000?ooo`3oool0:P3oool00`000000oooo0000000]0?ooo`030000003o
ool0oooo05h0oooo001R0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000;@3o
ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0
oooo000002d0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0:03oool0
1@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0GP3oool00680oooo00<00000
0?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0GP3o
ool00680oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`020?ooo`800000;03oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?oo
o`00HP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0P00000/0?ooo`030000003oool0oooo
05h0oooo001R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo
001R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0303oool2000002`0oooo00<000000?ooo`3oool0GP3oool0
0680oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0GP3oool00680oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0@0?ooo`800000;03oool00`000000oooo0?ooo`1N0?ooo`00HP3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00/0oooo1@0000040?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0GP3oool00680oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00
HP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool2000002`0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo05h0oooo001R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool20000
00H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?oo
o`00HP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01X0oooo0P00000/0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo05h0oooo001R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
05h0oooo001R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo
001R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool07P3oool2000002`0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
GP3oool00680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool0
0680oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`800000;03oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00
HP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`1N0?ooo`00HP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo0P00000/
0?ooo`030000003oool0oooo05h0oooo001R0?ooo`050000003oool0oooo0?ooo`000000:P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?ooo`050000003oool0oooo
0?ooo`000000:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo001R0?oo
o`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N
0?ooo`00HP3oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0GP3oool00680oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo05h0oooo001R0?ooo`030000003oool0000002`0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool2000002d0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1N0?ooo`00HP3oool2000002D0oooo0`0000050?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0GP3oool00680oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool0
0680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`800000;03oool00`00
0000oooo0?ooo`1N0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0
oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2
000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo0029
0?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00
R`3oool00`000000oooo0?ooo`2B0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool0
0`000000oooo0?ooo`2C0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.12952, -3.09715, 0.0215829, 
  0.0215829}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A[theta_] = {{Cos[theta], -Sin[theta]},{Sin[theta], Cos[theta]}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(cos(theta)\), \(-\(sin(theta)\)\)},
            {\(sin(theta)\), \(cos(theta)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a = N[{{1.05,0},{0,1.05}}.A[2Pi/36]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.03404814066281836`", \(-0.182330586550276869`\)},
            {"0.182330586550276869`", "1.03404814066281836`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[a.n,3];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.5 0.166667 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-3)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-2)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-1)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(1)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(2)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(3)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-2)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-1)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(1)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(2)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(3)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.38844 .12493 m
.26688 .81429 L
.73312 .18571 L
.61156 .87507 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool2000009D0oooo002;0?ooo`030000003o
ool0oooo0980oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000
S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00740oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`2<0?ooo`00L@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo08`0oooo001a0?ooo`030000003oool0oooo01d0oooo0P00002=0?ooo`00
L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo08`0oooo001`0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0S03oool00700oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`2<0?ooo`00L03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
08`0oooo001`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0S03oool00700oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2<0?ooo`00K`3oool00`000000oooo0?oo
o`0G0?ooo`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00K`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool006l0oooo00<000000?oo
o`3oool04P3oool3000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo001_0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
K`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
S03oool006l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08`0oooo001^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0S03oool0
06h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2<0?ooo`00KP3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0C03oool006h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`800000CP3oool006h0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`800000CP3oool006h0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0k0?ooo`800000C`3oool006d0oooo00<000000?oo
o`3oool08@3oool2000003/0oooo00<000000?ooo`000000C`3oool006d0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0i0?ooo`040000003oool0oooo000004l0oooo001]0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0>@3oool010000000oooo0?ooo`00001?0?oo
o`00K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03P0oooo00D000000?ooo`3o
ool0oooo0000001?0?ooo`00K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00K@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1>0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1>0?ooo`00K03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>
0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1>0?ooo`00K03oool00`000000oooo0?ooo`0R0?ooo`80
0000=03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04h0oooo001/0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04h0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04l0oooo001[0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo04l0oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo001[0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0
oooo001[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo04l0oooo001[0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04l0oooo001Z
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0500oooo001Z0?ooo`030000003oool0oooo02@0oooo0P00000^0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0D03oool006X0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0D03oool006X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0D03oool006X0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0D03o
ool006X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0D03oool006T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0D@3oool006T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0D@3oool006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0D@3oool006T0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0D@3oool006T0oooo00<000000?ooo`3oool09@3oool2000002L0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1A0?ooo`00J@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1B0?oo
o`00J03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1B0?ooo`00J03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1B0?ooo`00J03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1B0?ooo`00J03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1B0?ooo`00J03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1B0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1C0?ooo`00I`3oool00`000000oooo
0?ooo`0N0?ooo`D00000103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0D`3oool006L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1C0?ooo`00I`3oool00`000000oooo0?ooo`0J0?ooo`<000000`3oool00`000000oooo0?ooo`04
0?ooo`800000803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05<0oooo001W0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D`3oool006L0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1C0?ooo`00IP3oool00`000000oooo0?ooo`0P0?ooo`800000
1P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
E03oool006H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0E03oool006H0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool0
06H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0E03oool006H0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool006H0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0E03oool006D0oooo00<000000?ooo`3oool0:@3oool2000001T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1E0?ooo`00I@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1E
0?ooo`00I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1E0?ooo`00I@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1E0?ooo`00
I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1E0?ooo`00I@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1F0?ooo`00I03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1F0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1F0?ooo`00I03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1F0?ooo`00I03oool00`000000oooo0?ooo`0Z0?ooo`8000004P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo05H0oooo001T0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05H0oooo001T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05L0oooo001S0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05L0oooo001S0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo05L0oooo001S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05L0oooo001S0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo05L0oooo001S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05L0oooo001R0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
05P0oooo001R0?ooo`030000003oool0oooo02`0oooo0P00000<0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0F03oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0F03oool00680oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0F03oool00680oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0F03oool00680oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0F03oool00640oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0F@3oool00640oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
F@3oool00640oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0F@3oool000L0oooo0P00000/0?ooo`<00000:@3oool6
000002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`D000000`3oool0
0`000000oooo0?ooo`0U0?ooo`<00000:`3oool2000000@0oooo00090?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`00000/0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`010?ooo`000P3oool30000
00<0oooo00<000000?ooo`3oool09@3oool3000000<0oooo00<000000?ooo`3oool09@3oool40000
0080oooo00<000000?ooo`3oool0:P3oool2000000@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0
oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`010?ooo`001`3oool00`000000oooo0000000[0?ooo`03
0000003oool0000002P0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`000000:`3oool00`000000oooo000000030?ooo`00203oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P00000/0?ooo`05
0000003oool0oooo0?ooo`0000009`3oool2000000@0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo001P0?ooo`030000003oool0oooo02h0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`1J0?ooo`00H03oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool0FP3oool00600oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0000000^0?ooo`030000003oool0oooo05/0oooo
001O0?ooo`030000003oool0oooo02l0oooo0P00000_0?ooo`030000003oool0oooo05/0oooo001O
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1K
0?ooo`001P3ooooo000001P000000`3oool000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`001P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000;03oool0
0`000000oooo0000000]0?ooo`040000003oool0oooo000002X0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`010?ooo`00G`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0
oooo000002l0oooo00<000000?ooo`3oool0G03oool005h0oooo00<000000?ooo`3oool0;@3oool0
10000000oooo0?ooo`00000_0?ooo`030000003oool0oooo05`0oooo001N0?ooo`030000003oool0
oooo02`0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo05`0oooo001N
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo05`0oooo001N0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05`0oooo001N0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo05`0oooo001M0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
103oool2000002d0oooo00<000000?ooo`3oool0G@3oool005d0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G@3o
ool005d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0G@3oool005d0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G@3oool005d0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0G@3oool005d0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G@3oool005`0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0GP3oool005`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool005`0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0GP3oool005`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool005`0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0<0?ooo`800000;03oool00`000000oooo0?ooo`1N0?ooo`00G03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1N0?ooo`00F`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1O0?ooo`00F`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`1O0?ooo`00F`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1O0?ooo`00F`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`1O0?ooo`00F`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`1O0?ooo`00F`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1P
0?ooo`00FP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1P0?ooo`00FP3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0180oooo0P00000Z0?ooo`030000003oool0oooo0600oooo001J0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0600oooo001J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0600oooo001J0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0600oooo001J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0640oooo001I0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0640
oooo001I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0640oooo001I0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0640oooo001I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0640oooo001I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool2000002T0oooo00<000000?ooo`3oool0H@3oool005P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0HP3oool005P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0HP3oool005P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0HP3o
ool005P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0HP3oool005P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0HP3oool005P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0HP3oool005L0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0E0?ooo`D00000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06<0oooo
001G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H`3oool005L0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0P00000W
0?ooo`030000003oool0oooo06<0oooo001G0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0H`3oool005L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`00
E`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo0P0000060?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0H`3oool005H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03o
ool005H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0I03oool005H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03oool005H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0I03oool005H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I03oool005H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0I@3oool005D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W
0?ooo`8000009@3oool00`000000oooo0?ooo`1U0?ooo`00E@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U0?oo
o`00E@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1U0?ooo`00E@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1U0?ooo`00E@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`1U0?ooo`00E03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00E03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1V0?ooo`00E03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1V0?ooo`00E03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1V0?ooo`00E03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02h0oooo0P00
000T0?ooo`030000003oool0oooo06H0oooo001D0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo001C0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo06L0oooo001C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06L0oooo001C0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06L0oooo001C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06L0oooo001C0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo06L0oooo001C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo06L0oooo001B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06P0
oooo001B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool200000280oooo
00<000000?ooo`3oool0J03oool00580oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool00580oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0J03oool00580oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0J03oool00580oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0J@3oool00540oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0J@3oool00540oooo00D000000?ooo`3oool0oooo
0000000k0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0J@3oool00540oooo00@0
00000?ooo`3oool00000?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06T0oooo
001A0?ooo`040000003oool0oooo000003`0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1Y0?ooo`00D@3oool00`000000oooo0000000m0?ooo`8000008@3oool00`000000oooo0?oo
o`1Y0?ooo`00D@3oool2000003h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z
0?ooo`00D03oool2000003l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?oo
o`00D03oool2000003l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00
D03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
JP3oool00940oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00T@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo002A0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0J`3oool008T0oooo0`0000050?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0J`3oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo06/0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00
000O0?ooo`030000003oool0oooo06/0oooo002:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1[0?ooo`00R@3oool00`000000oooo000000050?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool008X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo002A0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00940oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1/0?ooo`00T@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06`0oooo002A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0K03oool00940
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00T@3oool2000001d0oooo
00<000000?ooo`3oool0K@3oool00940oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1]0?ooo`00T@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool20000
08d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`800000
1P3oool00`000000oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`00
0000oooo0?ooo`2B0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo
0?ooo`2C0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.12952, -3.09715, 0.0215829, 
  0.0215829}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.05^36*2", "Input"],

Cell[BoxData[
    \(TraditionalForm\`11.5836322719437267`\)], "Output"]
}, Open  ]],

Cell["\<\
c = n;
view[c,12];
Do[
   c = a.c;
   view[c,12]
,{i,1,36}]\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(f) Translations (ii).  (Omit (i) since it was done in homework.)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["t = Transpose[{{1,0},{2,2},{3,0},{1,0}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "1"},
            {"0", "2", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Adding one number to a vector is not usually defined in mathematics but Mma \
and MATLAB just add it to every entry.\
\>", "Text"],

Cell[CellGroupData[{

Cell["t[[1]]+2", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, 4, 5, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["w = {t[[1]]+2, t[[2]]+3}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"3", "4", "5", "3"},
            {"3", "5", "3", "3"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Save a beforePlot and afterPlot (any scale) and use
Show[beforePlot, afterPlot, PlotRange->{{0,6},{0,6}}];\
\>", "Text"],

Cell[CellGroupData[{

Cell["beforePlot = view[t,4];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.625 .5 m
.75 .75 L
.875 .5 L
.625 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00RP3oool3000009<0oooo002;0?ooo`030000003o
ool0oooo0980oooo00240?ooo`<000000P3oool4000000@0oooo0P00002=0?ooo`00R@3oool00`00
0000oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`8000001@3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo
002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool008@0oooo0`000003
0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo08`0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<0
00001@3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo08`0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3o
ool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`00
0000oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool5000000@0
oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool000P0oooo0`00000N0?ooo`800000
8@3oool3000001l0oooo1@00000N0?ooo`030000003oool0oooo01d0oooo1@00000O0?ooo`<00000
7`3oool200000280oooo0`0000020?ooo`002@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool00@3oool00080oooo0`0000020?ooo`@000006@3oool3
000000<0oooo00<000000?ooo`3oool06P3oool3000000<0oooo00<000000?ooo`3oool06P3oool3
000000<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`@000000P3oool0
00L0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0N0?ooo`030000003oool00000
00<0oooo00080?ooo`8000007`3oool00`000000oooo0000000P0?ooo`030000003oool000000240
oooo00<000000?ooo`3oool07P3oool200000200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0000000O0?ooo`030000003oool000000240oooo0P0000030?ooo`002@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool200000200oooo
00<000000?ooo`3oool07P3oool200000280oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0040oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00060?ooool000006000
00030?ooo`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`001P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo0P00000Q0?ooo`030000003oool0oooo01l0oooo0P00000R0?oo
o`030000003oool0oooo0040oooo002A0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0V0?ooo`00T@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool09P3oool00940oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02L0oooo002A0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W0?ooo`00T@3oool20000
02@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0X0?ooo`00T@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03oool00940oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02T0oooo
002A0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0Y0?ooo`00T@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0:P3oool00940oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo02X0oooo002A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0[0?ooo`00T@3oool2000002L0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0[0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0;03oool00940oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02`0oooo002A0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`00T@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00940oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo
002A0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0^0?ooo`00T@3oool2000002/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0_
0?ooo`00T@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0;`3oool00940oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0300oooo002A0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0`0?ooo`00T@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0<@3oool00940oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0340oooo002A0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?ooo`00T@3oool2000002h0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?ooo`00T@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0<`3oool00940oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03<0oooo002A
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d
0?ooo`00T@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0=03oool008P0oooo1@0000040?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0e0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0e0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`800000<P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo03H0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03H0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03L0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0=`3oool00940oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo03P0oooo002A0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`00T@3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>@3oool00940oooo0P00000e0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>@3oool00940oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03X0oooo002A0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0j0?ooo`00T@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3o
ool00940oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo03/0oooo002A0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0l0?ooo`00T@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0?03oool00940oooo0P00000i0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0?@3oool00940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo03d0oooo002A0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0n0?ooo`00T@3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?P3oool00940oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03l0oooo002A0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0o0?ooo`00T@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@03o
ool00940oooo0P00000l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@03oool0
0940oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0440oooo002A0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`110?ooo`00T@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0@P3oool00940oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0480oooo002A0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`130?ooo`00T@3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@`3oool00940oooo0P0000100?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0A03oool00940oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04@0oooo002A0?ooo`030000003o
ool0oooo0400oooo00D000000?ooo`3oool0oooo000000170?ooo`00T@3oool00`000000oooo0?oo
o`100?ooo`050000003oool0oooo0?ooo`000000A`3oool008T0oooo0`0000050?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`000000B03oool008T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0000004P0oooo002:0?ooo`030000003oool0oooo
00@0oooo0P0000130?ooo`030000003oool0oooo04L0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo002;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?oo
o`3oool0103oool2000008d0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0S03oool008T0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool008X0oooo0`0000040?ooo`030000003oool0oooo08`0oooo002;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0S03oool008T0oooo100000040?ooo`800000S@3oool008T0
oooo00<000000?ooo`000000U03oool008X0oooo0P00002D0?ooo`00R`3oool00`000000oooo0?oo
o`2B0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.1727, -4.12954, 0.0287773, 
  0.0287773}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["afterPlot = view[w,6];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.75 .75 m
.83333 .91667 L
.91667 .75 L
.75 .75 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool2000009D0oooo00290?ooo`030000003o
ool0000009@0oooo00240?ooo`<000000P3oool00`000000oooo000000050?ooo`800000S@3oool0
08T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0S03oool008X0oooo0P0000050?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002:0?ooo`<00000103oool00`000000oooo0?oo
o`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo00240?oo
o`<000000P3oool4000000@0oooo0P00002=0?ooo`00R@3oool00`000000oooo000000050?ooo`03
0000003oool0oooo08`0oooo002:0?ooo`8000001@3oool00`000000oooo0?ooo`2<0?ooo`00R`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`00
0000oooo0?ooo`2<0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0
oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000oooo00000005
0?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool000L0oooo0P00000]0?ooo`<00000
:P3oool3000002/0oooo00<000000?ooo`3oool0:@3oool3000002d0oooo0`00000Z0?ooo`800000
103oool000L0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`0000000`3oool00080oooo0`0000020?ooo`030000003oool0
000002H0oooo0`0000020?ooo`@000009@3oool3000000<0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02/0oooo1000000Z0?ooo`030000003oool0
000000<0oooo00070?ooo`800000;03oool00`000000oooo0000000/0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool00000
02/0oooo0P0000040?ooo`001`3oool00`000000oooo0?ooo`0/0?ooo`800000:`3oool00`000000
oooo0000000[0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000;@3oool2000002/0
oooo00<000000?ooo`3oool00`3oool000P0oooo0P00000]0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0:P3oool2000000<0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00060?ooool000006000
00030?ooo`001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`001P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`010?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`80
0000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
R@3oool3000000D0oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000004<0oooo
;`00000K0?ooo`00T@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool06@3oool00940oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01X0oooo002A0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0J0?ooo`00T@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool06`3oool00940oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01/0oooo002A0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`00T@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703oool0
0940oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01d0oooo002A0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0M0?ooo`00T@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool07P3oool00940oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01h0oooo002A0?ooo`800000B@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo002A0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`00T@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool00940oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo002A0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`00T@3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08@3oool0
0940oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0280oooo002A0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0R0?ooo`00T@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool08`3oool00940oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02<0oooo002:0?ooo`<00000103oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0903oool008/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0903oool008T0oooo100000040?ooo`800000C`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo02D0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02D0oooo002:0?ooo`8000001@3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3o
ool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool09P3oool00940oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo002A0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`00T@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00940oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo002A
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y
0?ooo`00T@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0:@3oool00940oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02X0oooo002A0?ooo`800000E03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02X0oooo002A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0[0?ooo`00T@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0:`3oool00940oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo002A0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`00T@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00940oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo002A
0?ooo`030000003oool0oooo05L0oooo00D000000?ooo`3oool0oooo0000000`0?ooo`00T@3oool0
0`000000oooo0?ooo`1G0?ooo`050000003oool0oooo0?ooo`000000<03oool00940oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0000000a0?ooo`00T@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool000000340oooo002A0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0<03oool00940oooo0P00001J0?ooo`030000003oool0oooo0300oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003o
ool0oooo08`0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool0
08T0oooo00<000000?ooo`0000001@3oool2000008d0oooo00290?ooo`800000U@3oool008T0oooo
00<000000?ooo`3oool0U03oool008X0oooo0P00002D0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, 
  0.0431659}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[beforePlot,afterPlot,PlotRange->{{0,6},{0,6}}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.166667 0 0.166667 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(1)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(4)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(1)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(2)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(3)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(4)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(5)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(6)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.16667 0 m
.33333 .33333 L
.5 0 L
.16667 0 L
s
.5 .5 m
.66667 .83333 L
.83333 .5 L
.5 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00=P3oool5000002T0oooo0`00000Z0?ooo`800000;03oool3000002X0oooo00<000000?oo
o`3oool0:@3oool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`00
0000:P3oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool4000002/0oooo00<000000?ooo`3oool0
:03oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0000000Z0?ooo`800000:`3o
ool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000:P3oool0
0`000000oooo0000000[0?ooo`800000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00D0oooo000g0?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0:03oool3000002/0oooo0P0000050?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
2`3ooooo0000010000001P3oool000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`0Z
0?ooo`800000:`3oool00`000000oooo0?ooo`0Y0?ooo`800000;03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool000/0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo08d0oooo000;0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2=0?ooo`00
2`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
SP3oool000/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo08h0oooo000;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`2?0?ooo`002`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0S`3oool000/0oooo0P00000_0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0T03oool000/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0900oooo000;0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`2A0?ooo`002`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0T@3oool000/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0980oooo000;0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2B0?ooo`00
2`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
T`3oool000/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo09<0oooo000;0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`2D0?ooo`002`3oool2000003@0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`2D0?ooo`002`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0U@3oool000/0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo09D0oooo000;0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`2F0?ooo`002`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0UP3oool000/0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo09L0oooo000;0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2G0?ooo`00
2`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
V03oool000/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo09P0oooo000;0?ooo`800000>03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo09T0oooo000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`2I0?ooo`002`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0VP3oool000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo09X0oooo000;0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`2K0?ooo`002`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0V`3oool000/0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo09`0oooo000;0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2L0?ooo`00
2`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
W@3oool000/0oooo0P00000m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0W@3o
ool000/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo09h0oooo000;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`2N0?ooo`002`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0W`3oool000/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo09l0oooo000;0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2P0?ooo`002`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0X03oool000<0oooo1@0000030?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2Q0?oo
o`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`2Q0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`<00000
@03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:80oooo00050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0:80oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0:<0oooo00040?ooo`8000001@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0X`3oool000/0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:@0
oooo000;0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`2T0?ooo`002`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0Y@3oool000/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0:D0oooo000;0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`2V0?ooo`002`3oool2000004H0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`2V0?ooo`002`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0Y`3oool000/0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:L0oooo000;0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2X0?ooo`002`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0Z03oool000/0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:T0
oooo000;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`2Y0?ooo`002`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0ZP3oool000/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0:X0oooo000;0?ooo`800000BP3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0:/0oooo000;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`2[0?ooo`002`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0[03oool000/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0:`0oooo000;0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2]0?ooo`002`3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0[@3oool000/0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:h0
oooo000;0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`2^0?ooo`002`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0[`3oool000/0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0[`3oool000/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0;00oooo000;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2`0?ooo`002`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0/@3oool000/0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;40oooo000;0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2b0?ooo`002`3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/P3oool000/0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;<0
oooo000;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`2c0?ooo`002`3oool2000005<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2d0?ooo`002`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0]03oool000/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0;D0oooo000;0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2e0?ooo`002`3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0]P3oool000/0oooo00<000000?ooo`3oool0E@3o
ool01@000000oooo0?ooo`3oool000000;P0oooo000;0?ooo`030000003oool0oooo05D0oooo00@0
00000?ooo`3oool00000^@3oool000@0oooo0`0000040?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`000000^@3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F
0?ooo`800000^P3oool000D0oooo00<000000?ooo`3oool00`3oool3000005L0oooo00<000000?oo
o`3oool0^03oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool200000?l0oooo
503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103o
ool2000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo00<000000?ooo`3oool00`3oool30000
08@0ooooF`00000c0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0b0?ooo`00103oool00`000000oooo
000000040?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0b0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0c0?ooo`002`3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0<`3oool000/0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03@0oooo000;0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0d0?ooo`00
2`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
=@3oool000/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo03D0oooo000;0?ooo`800000R@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo03H0oooo000;0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0f0?ooo`002`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0=`3oool000/0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo03L0oooo000;0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0h0?ooo`002`3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0>03oool000/0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03T0oooo000;0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0i0?ooo`00
2`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
>P3oool000/0oooo0P00002>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0>P3o
ool000/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo03/0oooo000;0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0k0?ooo`002`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0?03oool000/0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo03`0oooo000;0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0m0?ooo`002`3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool000/0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo000;0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0n0?ooo`00
2`3oool200000980oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0o0?ooo`002`3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0?`3o
ool000/0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0400oooo000;0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`100?ooo`002`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0@@3oool000/0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0440oooo000;0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`120?ooo`002`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@P3oool000/0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04<0oooo000;0?ooo`80
0000U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo000;0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`140?ooo`002`3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0A03o
ool000/0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo04D0oooo000;0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`150?ooo`002`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0AP3oool000/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo04H0oooo00050?ooo`<000000`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A`3oool000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0A`3oool000@0oooo100000030?ooo`<00000VP3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo04P0oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04P0oooo00050?ooo`800000
103oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
B@3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0B@3oool000/0oooo00<000000?ooo`3oool0W03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04X0oooo000;0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1:0?ooo`002`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool000/0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo
000;0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1<0?ooo`002`3oool200000:00oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1<
0?ooo`002`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0C@3oool000/0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo04d0oooo000;0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`1>0?ooo`002`3oool00`000000oooo0?ooo`2Q0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0CP3oool000/0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04l0oooo000;0?ooo`030000003oool0oooo
0:80oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`002`3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool000/0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0500oooo
000;0?ooo`800000Y03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0540oooo000;
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1A
0?ooo`002`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0DP3oool000/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0580oooo000;0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1C0?ooo`002`3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0D`3oool000/0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo000;0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`002`3oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0E@3oool000/0oooo
0P00002Y0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool000/0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05H0oooo000;
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1F
0?ooo`002`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0E`3oool000/0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo05L0oooo000;0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1H0?ooo`002`3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0F03oool000/0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05T0oooo000;0?ooo`030000003oool0oooo
0:`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`002`3oool200000:d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1J0?ooo`002`3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool000/0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05/0oooo000;
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K
0?ooo`002`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0G03oool000/0oooo00<000000?ooo`3oool0[`3oool01@000000oooo0?ooo`3oool00000
05h0oooo000;0?ooo`030000003oool0oooo0:l0oooo00@000000?ooo`3oool00000G`3oool000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0000005l0
oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0/03oool200000600oooo
00060?ooo`030000003oool0oooo0080oooo0`00002a0?ooo`030000003oool0oooo05h0oooo0004
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooa<0oooo00040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103oool3000000@0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
0P00003o0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo0P00003o
0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo00040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooa<0
oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103o
ool00`000000oooo000000040?ooo`<00000o`3ooolC0?ooo`00103oool200000?l0oooo6`3oool0
00@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`001@3oool200000?l0oooo6P3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.258281, -0.27494, 0.0222122, 
  0.0222122}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(g) Homogeneous Coordinates -- defining function viewhomo
Dilation, Contraction, Reflection, Rotation redone\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["m = DiagonalMatrix[{1.25,1.25,1}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["1.25`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3], "0", "0"},
            {"0", 
              StyleBox["1.25`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3], "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["t = Transpose[{{1,0,1},{2,2,1},{3,0,1},{1,0,1}}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "1"},
            {"0", "2", "0", "0"},
            {"1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We need to change the view function to a viewhomo function that uses only the \
first two rows of the matrix.  This is easily done by using matrix[[{1,2}]].  \
Observe\
\>", "Text"],

Cell[CellGroupData[{

Cell["t[[{1,2}]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "1"},
            {"0", "2", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Now copy the view function and adapt it to define viewhomo that takes a \
3x(n+1) matrix.
While we're at it, let's allow any PlotRange for given {xmin, xmax, ymin, \
ymax} instead of just scale.\
\>", "Text"],

Cell["\<\
Clear[viewhomo]
viewhomo[matrix_, {xmin_,xmax_,ymin_,ymax_}] := 
ListPlot[Transpose[matrix[[{1,2}]]],
   PlotJoined->True,
   PlotRange->{{xmin,xmax},{ymin,ymax}},
   AspectRatio->Automatic];\
\>", "Input"],

Cell[CellGroupData[{

Cell["(i) Use m and viewhomo to plot the dialation of t.", "Subsubsection"],

Cell[CellGroupData[{

Cell["viewhomo[t,{0,6,0,6}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.166667 0 0.166667 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(1)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(4)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(1)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(2)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(3)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(4)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(5)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(6)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.16667 0 m
.33333 .33333 L
.5 0 L
.16667 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00=P3oool5000002T0oooo0`00000Z0?ooo`800000;03oool3000002X0oooo00<000000?oo
o`3oool0:@3oool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`00
0000:P3oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool4000002/0oooo00<000000?ooo`3oool0
:03oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0000000Z0?ooo`800000:`3o
ool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000:P3oool0
0`000000oooo0000000[0?ooo`800000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00D0oooo000g0?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0:03oool3000002/0oooo0P0000050?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
2`3ooooo0000010000001P3oool000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`002`3oool00`000000oooo0?ooo`0Z
0?ooo`800000:`3oool00`000000oooo0?ooo`0Y0?ooo`800000;03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool000/0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo08d0oooo000;0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2=0?ooo`00
2`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
SP3oool000/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo08h0oooo000;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`2?0?ooo`002`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0S`3oool000/0oooo0P00000_0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0T03oool000/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0900oooo000;0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`2A0?ooo`002`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0T@3oool000/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0980oooo000;0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2B0?ooo`00
2`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
T`3oool000/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo09<0oooo000;0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`2D0?ooo`002`3oool2000003@0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`2D0?ooo`002`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0U@3oool000/0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo09D0oooo000;0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`2F0?ooo`002`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0UP3oool000/0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo09L0oooo000;0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2G0?ooo`00
2`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
V03oool000/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo09P0oooo000;0?ooo`800000>03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo09T0oooo000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`2I0?ooo`002`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0VP3oool000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo09X0oooo000;0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`2K0?ooo`002`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0V`3oool000/0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo09`0oooo000;0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2L0?ooo`00
2`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
W@3oool000/0oooo0P00000m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0W@3o
ool000/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo09h0oooo000;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`2N0?ooo`002`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0W`3oool000/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo09l0oooo000;0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2P0?ooo`002`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0X03oool000<0oooo1@0000030?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2Q0?oo
o`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`2Q0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`<00000
@03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:80oooo00050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0:80oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0:<0oooo00040?ooo`8000001@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0X`3oool000/0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:@0
oooo000;0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`2T0?ooo`002`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0Y@3oool000/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0:D0oooo000;0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`2V0?ooo`002`3oool2000004H0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`2V0?ooo`002`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0Y`3oool000/0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:L0oooo000;0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2X0?ooo`002`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0Z03oool000/0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0:T0
oooo000;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`2Y0?ooo`002`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0ZP3oool000/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0:X0oooo000;0?ooo`800000BP3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0:/0oooo000;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`2[0?ooo`002`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0[03oool000/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0:`0oooo000;0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2]0?ooo`002`3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0[@3oool000/0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:h0
oooo000;0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`2^0?ooo`002`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0[`3oool000/0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0[`3oool000/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0;00oooo000;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2`0?ooo`002`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0/@3oool000/0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;40oooo000;0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2b0?ooo`002`3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/P3oool000/0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;<0
oooo000;0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`2c0?ooo`002`3oool2000005<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2d0?ooo`002`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0]03oool000/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0;D0oooo000;0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2e0?ooo`002`3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0]P3oool000/0oooo00<000000?ooo`3oool0E@3o
ool01@000000oooo0?ooo`3oool000000;P0oooo000;0?ooo`030000003oool0oooo05D0oooo00@0
00000?ooo`3oool00000^@3oool000@0oooo0`0000040?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`000000^@3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F
0?ooo`800000^P3oool000D0oooo00<000000?ooo`3oool00`3oool3000005L0oooo00<000000?oo
o`3oool0^03oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool200000?l0oooo
503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103o
ool2000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo00<000000?ooo`3oool00`3oool30000
0?l0oooo4`3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooa<0
oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool200000?l0oooo
503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001@3o
ool3000000<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo4`3oool000@0oooo100000030?ooo`<00000o`3ooolC0?oo
o`00103oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo
0P0000040?ooo`030000003oool0oooo0?l0oooo4`3oool000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3o
oolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo00040?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`<00000o`3ooolC0?oo
o`00103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0oooo4`3oool000@0oooo0`0000040?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo0P00003o0?oooa@0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`80
0000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`00103oool2000000D0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`00103oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo4`3oool0
00@0oooo00<000000?ooo`000000103oool300000?l0oooo4`3oool000@0oooo0P00003o0?oooa/0
oooo00040?ooo`030000003oool0oooo0?l0oooo6P3oool000D0oooo0P00003o0?oooaX0oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.258281, -0.27494, 0.0222122, 
  0.0222122}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[m.t,{0,6,0,6}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.166667 0 0.166667 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -6 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(1)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(4)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(1)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(2)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(3)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(4)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(5)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(6)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.20833 0 m
.41667 .41667 L
.625 0 L
.20833 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00=P3oool5000002T0oooo0`00000Z0?ooo`800000;03oool3000002X0oooo00<000000?oo
o`3oool0:@3oool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`00
0000:P3oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool4000002/0oooo00<000000?ooo`3oool0
:03oool00`000000oooo000000050?ooo`00>03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0000000Z0?ooo`800000:`3o
ool2000000H0oooo000h0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000:P3oool0
0`000000oooo0000000[0?ooo`800000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00D0oooo000g0?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0:03oool3000002/0oooo0P0000050?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
2`3ooooo0000010000001P3oool000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000/0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo
000;0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`1[0?ooo`002`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0J`3oool000/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo06`0oooo000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`1/0?ooo`002`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0K@3oool000/0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06d0oooo000;0?ooo`800000>`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06h0oooo000;0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1^0?ooo`002`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0K`3oool000/0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo06l0oooo
000;0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`1`0?ooo`002`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0L03oool000/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0740oooo000;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`1a0?ooo`002`3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0LP3oool000/0oooo0P00000o0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0LP3oool000/0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07<0oooo000;0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1c0?ooo`002`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0M03oool000/0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07@0oooo
000;0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`1e0?ooo`002`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0M@3oool000/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo07H0oooo000;0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`1f0?ooo`002`3oool2000004@0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`1g0?ooo`002`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0M`3oool000/0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo07P0oooo000;0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1h0?ooo`002`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0N@3oool000/0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo07T0oooo
000;0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1j0?ooo`002`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0NP3oool000/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo07/0oooo000;0?ooo`800000B03oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo07/0oooo000;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`1l0?ooo`002`3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0O03oool000/0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo07d0oooo000;0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1m0?ooo`002`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0OP3oool000/0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo07h0oooo
00030?ooo`D000000`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0O`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0O`3oool000D0oooo00<000000?oo
o`3oool00`3oool3000004`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`200?oo
o`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`200?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`210?ooo`00103o
ool2000000D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0840oooo000;0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`220?ooo`002`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0PP3oool000/0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo08<0oooo000;0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`230?ooo`002`3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0Q03oool000/0oooo0P00001A
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0Q03oool000/0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08D0oooo000;0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`250?ooo`00
2`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
QP3oool000/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo08H0oooo000;0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`270?ooo`002`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0Q`3oool000/0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo08P0oooo000;0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`280?ooo`002`3oool2000005H0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`290?ooo`002`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0R@3oool000/0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08X0oooo000;0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2:0?ooo`00
2`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
R`3oool000/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo08/0oooo000;0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`2<0?ooo`002`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0S03oool000/0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo08d0oooo000;0?ooo`800000F`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo08d0oooo000;0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`2>0?ooo`002`3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0SP3oool000/0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo08l0oooo000;0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2?0?ooo`00
2`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
T03oool000/0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0900oooo000;0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`2A0?ooo`002`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0T@3oool000/0oooo0P00001O0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0TP3oool000/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0980oooo000;0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`2C0?ooo`002`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0T`3oool000/0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo09@0oooo000;0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2D0?ooo`00
2`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
U@3oool000@0oooo0`0000040?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`2E0?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2F0?ooo`001@3oool00`00
0000oooo0?ooo`030?ooo`<00000H`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
09H0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo09L0oooo00040?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo09L0oooo
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo09P0oooo000;0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2H0?ooo`002`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0V@3oool000/0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09T0oooo000;0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2J0?ooo`002`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0VP3o
ool000/0oooo0P00001X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0V`3oool0
00/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
09/0oooo000;0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2L0?ooo`002`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0W03oool000/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo09d0oooo000;0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2M0?ooo`002`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0WP3oool000/0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09h0oooo000;0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2O0?ooo`002`3o
ool2000006d0oooo00D000000?ooo`3oool0oooo0000002Q0?ooo`002`3oool00`000000oooo0?oo
o`1/0?ooo`040000003oool0oooo00000:80oooo000;0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`000000XP3oool000/0oooo00<000000?ooo`3oool0K@3oool200000:<0oooo000;0?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0X@3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool20000
0?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`00103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo00<000000?ooo`3oool00`3o
ool300000?l0oooo4`3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?oooa<0oooo00040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool20000
0?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`001@3oool3000000<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo4`3oool000@0oooo100000030?ooo`<00000o`3o
oolC0?ooo`00103oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo4`3oool0
00D0oooo0P0000040?ooo`030000003oool0oooo0?l0oooo4`3oool000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`80
0000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo0P00003o0?oooa@0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?oooa<0oooo00040?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`<00000o`3o
oolC0?ooo`00103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo4`3oool000@0oooo0`0000040?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo000;0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo
4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo0P00003o0?oooa@0
oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo
0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`002`3oool200000?l0oooo503oool000/0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003o
ool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool000/0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;
0?ooo`800000o`3ooolD0?ooo`002`3oool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`03
0000003oool0oooo0?l0oooo4`3oool000/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo000;0?ooo`030000003oool0oooo0?l0oooo4`3oool0
00/0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00103oool2000000D0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`00103oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo
4`3oool000@0oooo00<000000?ooo`000000103oool300000?l0oooo4`3oool000@0oooo0P00003o
0?oooa/0oooo00040?ooo`030000003oool0oooo0?l0oooo6P3oool000D0oooo0P00003o0?oooaX0
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.258281, -0.27494, 0.0222122, 
  0.0222122}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii)  Rotate 45 degrees with a 3x3.", "Subsubsection"],

Cell[CellGroupData[{

Cell["A[Pi/4]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(1\/\@2\), \(-\(1\/\@2\)\)},
            {\(1\/\@2\), \(1\/\@2\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
m = {{1/Sqrt[2], -(1/Sqrt[2]), 0},
     {1/Sqrt[2],   1/Sqrt[2],  0},
     {0,           0,          1}}\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(1\/\@2\), \(-\(1\/\@2\)\), "0"},
            {\(1\/\@2\), \(1\/\@2\), "0"},
            {"0", "0", "1"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[m.t,{0,4,0,4}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.25 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .125 -18 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -6 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -18 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(0.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(1)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(1.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(2)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(3)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.17678 .17678 m
0 .70711 L
.53033 .53033 L
.17678 .17678 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool5
000001L0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool3
000001P0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool2
000001X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool3
00000080oooo000_0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000006P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000006`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000006`3oool00`00
0000oooo0?ooo`010?ooo`00;`3oool00`000000oooo000000090?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0
oooo100000020?ooo`00;`3oool00`000000oooo000000070?ooo`8000006`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0P00000K0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01P3oool2000001`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`050?ooo`8000006P3oool00`000000oooo000000030?ooo`00;`3oool00`000000oooo0000
00070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`000000603oool00`000000oooo0000
00070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`0000006@3oool00`000000oooo0000
00070?ooo`030000003oool0oooo01X0oooo0P0000030?ooo`00<03oool00`000000oooo0?ooo`06
0?ooo`<000006@3oool2000001X0oooo0P0000080?ooo`<000006P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo0`00000J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01P3oool3000001/0oooo00<000000?ooo`3oool00@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0
ooooo`000009000000<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o
0?ooo`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool20000
0?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003o
ool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool000@0oooo
00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo
2@3oool000@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`800000o`3o
ool:0?ooo`00103oool00`000000oooo000000070?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00050?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`03
0000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool0
01D0oooo0P00003o0?ooo`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?oo
o`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000;03oool00`000000oooo
0?ooo`3J0?ooo`005@3oool00`000000oooo0?ooo`0[0?ooo`800000f`3oool001D0oooo00<00000
0?ooo`3oool0:P3oool010000000oooo0?ooo`00003J0?ooo`005@3oool00`000000oooo0?ooo`0Z
0?ooo`050000003oool0oooo0?ooo`000000f@3oool001D0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0=H0oooo000E0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3E0?ooo`005@3oool2000002X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3D0?ooo`005@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0d`3oool001D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=80oooo000E
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3A
0?ooo`005@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0d03oool001D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0<l0oooo000E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3>0?ooo`005@3oool2000002P0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3=0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0c03oool001D0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0</0oooo000E0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3:0?ooo`003@3oool5000000<0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<T0oooo
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0<P0oooo000?0?ooo`030000003oool0oooo00<0oooo0P00000V
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0a`3oool000l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0aP3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0a@3oool000h0oooo0P0000050?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`340?ooo`005@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0``3o
ool001D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0<80oooo000E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`310?ooo`005@3oool2000002<0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`300?ooo`005@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0_`3oool001D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0;h0oooo000E0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`2m0?ooo`005@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0_03oool001D0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;/0oooo000E0?ooo`800000
8@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;X0oooo000E0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2i0?ooo`005@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0^03oool0
01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0;L0oooo000E0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`2f0?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0]@3oool001D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0;@0oooo000E0?ooo`8000007`3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0;<0oooo000E0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`2b0?ooo`005@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0/@3oool001D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0;00oooo000E0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2_0?ooo`005@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[P3oool0
01D0oooo0P00000M0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool001D0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:`0
oooo000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`2[0?ooo`005@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0ZP3oool001D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0:T0oooo00030?ooo`D000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0:P0oooo00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0Y`3oool000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`800000
6`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0:H0oooo00050?ooo`030000003o
ool0oooo00H0oooo0P0000050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`2U0?ooo`001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0:@0oooo00040?ooo`800000203oool3000000@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0:<0oooo000E0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2R0?ooo`005@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0X@3oool001D0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0:00oooo000E
0?ooo`800000603oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo09l0oooo000E0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2N0?oo
o`005@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0W@3oool001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo09`0oooo000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`2K0?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0VP3oool001D0oooo0P00000F0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0V@3oool001D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo09P0oooo000E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`2G0?ooo`005@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0UP3oool001D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo09D0oooo000E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2D0?oo
o`005@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0T`3oool001D0oooo0P00000D0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
TP3oool001D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0940oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`2@0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0S`3oool001D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo08h0oooo000E0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2=0?ooo`005@3oool200000180oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`2<0?ooo`005@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0R`3oool001D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo08X0oooo000E0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`290?ooo`00
5@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
R03oool000h0oooo0`0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`270?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`260?ooo`003`3oool00`00
0000oooo0?ooo`030?ooo`800000403oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
08D0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo08@0oooo000>0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08<0oooo
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0880oooo000E0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`210?ooo`005@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0P03oool001D0oooo0P00000>0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0O`3oool001D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07h0oooo000E0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0N03oool2000007l0oooo000E0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0M@3oool300000840oooo000E0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0LP3oool3000008@0oooo000E0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0L03oool3000008L0oooo000E0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0K@3oool3000008X0oooo000E0?ooo`800000303oool00`000000oooo0?oo
o`1Z0?ooo`<00000S@3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1X
0?ooo`<00000T03oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1U0?oo
o`<00000T`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`<0
0000UP3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1P0?ooo`<00000
V@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1M0?ooo`<00000W03o
ool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1J0?ooo`<00000W`3oool0
01D0oooo0P0000090?ooo`030000003oool0oooo05P0oooo0`00002R0?ooo`005@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo0`00002U0?ooo`005@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0580oooo0`00002X0?ooo`005@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0500oooo0`00002[0?ooo`005@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo04d0oooo0`00002^0?ooo`005@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04X0oooo0`00002a0?ooo`005@3oool2000000L0oooo00<000000?ooo`3o
ool0B03oool300000;@0oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
A@3oool300000;L0oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@P3o
ool300000;X0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool3
00000;d0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?@3oool30000
0<00oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`@00000``3oool000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo000000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0=`3oool300000<L0oooo00050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0=03oool300000<X0oooo0005
0?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0<@3oool300000<d0oooo00040?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo0`00003@0?oo
o`001@3oool00`000000oooo0?ooo`060?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02`0oooo0`00003C0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02T0oooo0`00003F0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02L0oooo0`00003I0?ooo`005@3oool2000000<0oooo00<000000?ooo`3oool0903oool3
00000=`0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool30000
0=l0oooo000E0?ooo`050000003oool0oooo0?ooo`0000008@3oool300000>80oooo000E0?ooo`05
0000003oool0oooo0?ooo`0000007P3oool300000>D0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000006`3oool300000>P0oooo000E0?ooo`040000003oool0oooo000001T0oooo0`00003[0?oo
o`005@3oool010000000oooo0?ooo`00000F0?ooo`<00000kP3oool001D0oooo0P0000000`3oool0
00000?ooo`0B0?ooo`<00000l@3oool001D0oooo00<000000?ooo`0000004@3oool300000?@0oooo
000E0?ooo`030000003oool0000000h0oooo0`00003g0?ooo`005@3oool00`000000oooo0000000;
0?ooo`<00000nP3oool001D0oooo0P0000090?ooo`<00000o@3oool001D0oooo0P0000060?ooo`<0
0000o`3oool10?ooo`005@3oool2000000<0oooo0`00003o0?ooo`@0oooo000E0?ooo`030000003o
ool0000000800000o`3oool70?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool2
00000?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`003P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2@3oool000l0
oooo00<000000?ooo`3oool00`3oool200000?l0oooo2P3oool00100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000>0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool2
00000?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool000@0oooo0P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool200000?l0oooo2P3o
ool000H0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00103oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3oool90?ooo`001@3oool00`000000oooo0?ooo`060?ooo`<00000103oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool000l0oooo0`0000030?ooo`030000003oool0oooo0?l0oooo2@3oool00100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000>0?ooo`@000000`3oool200000?l0
oooo2P3oool000h0oooo00<000000?ooo`000000o`3oool@0?ooo`003`3oool200000?l0oooo403o
ool00100oooo00<000000?ooo`3oool0o`3oool>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.324083, -0.244148, 0.0152257, 
  0.0152257}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
(iii)  Just READ and understand this part.  You don't have to turn in \
anything.\
\>", "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{

Cell["(h) Translation -- do it.", "Subsection"],

Cell[CellGroupData[{

Cell["m = {{1,0,2},{0,1,3},{0,0,1}}", "Input"],

Cell[OutputFormData["\<\
TableForm[{{1, 0, 2}, {0, 1, 3}, {0, 0, 1}}]





\
\>", "\<\
1   0   2

0   1   3

0   0   1\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[t,6];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-6)] 0 .5 0 2 Msboxa
[(-4)] .16667 .5 0 2 Msboxa
[(-2)] .33333 .5 0 2 Msboxa
[(2)] .66667 .5 0 2 Msboxa
[(4)] .83333 .5 0 2 Msboxa
[(6)] 1 .5 0 2 Msboxa
[(-6)] .4875 0 1 0 Msboxa
[(-4)] .4875 .16667 1 0 Msboxa
[(-2)] .4875 .33333 1 0 Msboxa
[(2)] .4875 .66667 1 0 Msboxa
[(4)] .4875 .83333 1 0 Msboxa
[(6)] .4875 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 .5 m
0 .50625 L
s
P
[(-6)] 0 .5 0 2 Mshowa
p
.002 w
.16667 .5 m
.16667 .50625 L
s
P
[(-4)] .16667 .5 0 2 Mshowa
p
.002 w
.33333 .5 m
.33333 .50625 L
s
P
[(-2)] .33333 .5 0 2 Mshowa
p
.002 w
.66667 .5 m
.66667 .50625 L
s
P
[(2)] .66667 .5 0 2 Mshowa
p
.002 w
.83333 .5 m
.83333 .50625 L
s
P
[(4)] .83333 .5 0 2 Mshowa
p
.002 w
1 .5 m
1 .50625 L
s
P
[(6)] 1 .5 0 2 Mshowa
p
.001 w
.03333 .5 m
.03333 .50375 L
s
P
p
.001 w
.06667 .5 m
.06667 .50375 L
s
P
p
.001 w
.1 .5 m
.1 .50375 L
s
P
p
.001 w
.13333 .5 m
.13333 .50375 L
s
P
p
.001 w
.2 .5 m
.2 .50375 L
s
P
p
.001 w
.23333 .5 m
.23333 .50375 L
s
P
p
.001 w
.26667 .5 m
.26667 .50375 L
s
P
p
.001 w
.3 .5 m
.3 .50375 L
s
P
p
.001 w
.36667 .5 m
.36667 .50375 L
s
P
p
.001 w
.4 .5 m
.4 .50375 L
s
P
p
.001 w
.43333 .5 m
.43333 .50375 L
s
P
p
.001 w
.46667 .5 m
.46667 .50375 L
s
P
p
.001 w
.53333 .5 m
.53333 .50375 L
s
P
p
.001 w
.56667 .5 m
.56667 .50375 L
s
P
p
.001 w
.6 .5 m
.6 .50375 L
s
P
p
.001 w
.63333 .5 m
.63333 .50375 L
s
P
p
.001 w
.7 .5 m
.7 .50375 L
s
P
p
.001 w
.73333 .5 m
.73333 .50375 L
s
P
p
.001 w
.76667 .5 m
.76667 .50375 L
s
P
p
.001 w
.8 .5 m
.8 .50375 L
s
P
p
.001 w
.86667 .5 m
.86667 .50375 L
s
P
p
.001 w
.9 .5 m
.9 .50375 L
s
P
p
.001 w
.93333 .5 m
.93333 .50375 L
s
P
p
.001 w
.96667 .5 m
.96667 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.5 0 m
.50625 0 L
s
P
[(-6)] .4875 0 1 0 Mshowa
p
.002 w
.5 .16667 m
.50625 .16667 L
s
P
[(-4)] .4875 .16667 1 0 Mshowa
p
.002 w
.5 .33333 m
.50625 .33333 L
s
P
[(-2)] .4875 .33333 1 0 Mshowa
p
.002 w
.5 .66667 m
.50625 .66667 L
s
P
[(2)] .4875 .66667 1 0 Mshowa
p
.002 w
.5 .83333 m
.50625 .83333 L
s
P
[(4)] .4875 .83333 1 0 Mshowa
p
.002 w
.5 1 m
.50625 1 L
s
P
[(6)] .4875 1 1 0 Mshowa
p
.001 w
.5 .03333 m
.50375 .03333 L
s
P
p
.001 w
.5 .06667 m
.50375 .06667 L
s
P
p
.001 w
.5 .1 m
.50375 .1 L
s
P
p
.001 w
.5 .13333 m
.50375 .13333 L
s
P
p
.001 w
.5 .2 m
.50375 .2 L
s
P
p
.001 w
.5 .23333 m
.50375 .23333 L
s
P
p
.001 w
.5 .26667 m
.50375 .26667 L
s
P
p
.001 w
.5 .3 m
.50375 .3 L
s
P
p
.001 w
.5 .36667 m
.50375 .36667 L
s
P
p
.001 w
.5 .4 m
.50375 .4 L
s
P
p
.001 w
.5 .43333 m
.50375 .43333 L
s
P
p
.001 w
.5 .46667 m
.50375 .46667 L
s
P
p
.001 w
.5 .53333 m
.50375 .53333 L
s
P
p
.001 w
.5 .56667 m
.50375 .56667 L
s
P
p
.001 w
.5 .6 m
.50375 .6 L
s
P
p
.001 w
.5 .63333 m
.50375 .63333 L
s
P
p
.001 w
.5 .7 m
.50375 .7 L
s
P
p
.001 w
.5 .73333 m
.50375 .73333 L
s
P
p
.001 w
.5 .76667 m
.50375 .76667 L
s
P
p
.001 w
.5 .8 m
.50375 .8 L
s
P
p
.001 w
.5 .86667 m
.50375 .86667 L
s
P
p
.001 w
.5 .9 m
.50375 .9 L
s
P
p
.001 w
.5 .93333 m
.50375 .93333 L
s
P
p
.001 w
.5 .96667 m
.50375 .96667 L
s
P
p
.002 w
.5 0 m
.5 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.004 w
.58333 .5 m
.66667 .66667 L
.75 .5 L
.58333 .5 L
s
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool2000009D0oooo0029
0?ooo`030000003oool0000009@0oooo00240?ooo`<000000P3oool00`000000oooo000000040?oo
o`<00000S@3oool008T0oooo0P0000050?ooo`030000003oool0oooo08d0oooo00290?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S@3oool008X0oooo0P0000040?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?oo
o`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool0
0900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo
00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool0
0`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000
oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool008X0oooo0`0000030?ooo`030000003oool0
oooo08d0oooo002;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S@3oool008@0
oooo0`0000020?ooo`@000000`3oool3000008d0oooo00290?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0S@3oool008X0oooo0P0000040?ooo`030000003oool0oooo08d0oooo002;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool0
0900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool0
0`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00R@3oool3000000@0oooo00<000000?ooo`3oool0S@3oool008T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2=0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0
0`3oool3000008d0oooo002:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S@3o
ool008T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`00RP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`80
0000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>0?oo
o`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000
003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo00080?ooo`800000;@3oool3
000002T0oooo0`00000Z0?ooo`030000003oool0oooo02X0oooo0`00000[0?ooo`<00000:P3oool2
000000H0oooo00080?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0000000D0oooo00030?ooo`<000000P3oool00`000000
oooo0000000V0?ooo`<000000P3oool4000002@0oooo0`0000030?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Y0?ooo`@00000:P3oool00`000000
oooo000000050?ooo`00203oool2000002`0oooo00<000000?ooo`000000:`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0000000[0?ooo`8000001P3oool000P0oooo00<000000?ooo`3oool0;03oool2000002X0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0000002/0oooo0P00
000[0?ooo`030000003oool0oooo00D0oooo00090?ooo`800000;@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo0P00000/0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool2000000D0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
00070?ooool000005@0000050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool000L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00<0oooo002@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1:0?ooo`00T03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0BP3oool00900oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo04/0oooo002@0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1;0?ooo`00T03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0C03oool00900oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04`0oooo002@0?oo
o`8000006@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04d0oooo002@0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1=0?ooo`00
T03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
CP3oool00900oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo04h0oooo002@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1?0?ooo`00T03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0C`3oool00900oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0500oooo002@0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1@0?ooo`00T03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D@3oool00900oooo0P00000N
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D@3oool00900oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0580oooo002@0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1B0?ooo`00
T03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
D`3oool00900oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo05<0oooo002@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1D0?ooo`00T03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0E03oool00900oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo05D0oooo002@0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1E0?ooo`00T03oool200000280oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1F0?ooo`00T03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0EP3oool00900oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05L0oooo002@0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1G0?ooo`00
T03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
F03oool00900oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo05P0oooo002@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1I0?ooo`00T03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0F@3oool00900oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo05X0oooo002@0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1J0?ooo`00T03oool2000002L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1K0?ooo`00T03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0F`3oool00900oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05`0oooo002@0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`00
T03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
G@3oool00900oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool0000005l0oooo
002@0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000H03oool008T0oooo0`00
00040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`000000H03oool008T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`800000H@3oool008X0oooo00<000000?oo
o`3oool00`3oool3000002/0oooo00<000000?ooo`3oool0G`3oool008X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2=0?ooo`00R@3oool00`000000oooo000000040?ooo`030000
003oool0oooo08d0oooo002:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?oo
o`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?oo
o`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000
003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0
oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<00000
0?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3o
ool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?oo
o`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?oo
o`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool00`000000oooo0?ooo`2=0?ooo`00RP3oool3000000<0oooo00<000000?ooo`3oool0S@3oool0
08/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2=0?ooo`00R@3oool4000000<0
oooo0`00002=0?ooo`00R@3oool00`000000oooo000000040?ooo`030000003oool0oooo08d0oooo
002:0?ooo`800000103oool00`000000oooo0?ooo`2=0?ooo`00R`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`800000SP3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0
oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool008T0oooo0P0000050?ooo`030000003oool0oooo08d0oooo00290?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool0S@3oool008T0oooo00<000000?ooo`00
0000103oool3000008d0oooo00290?ooo`800000U@3oool008T0oooo00<000000?ooo`3oool0U03o
ool008X0oooo0P00002D0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.31643, -6.26188, 0.0436368, 
  0.0436368}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[m.t,6];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-6)] 0 .5 0 2 Msboxa
[(-4)] .16667 .5 0 2 Msboxa
[(-2)] .33333 .5 0 2 Msboxa
[(2)] .66667 .5 0 2 Msboxa
[(4)] .83333 .5 0 2 Msboxa
[(6)] 1 .5 0 2 Msboxa
[(-6)] .4875 0 1 0 Msboxa
[(-4)] .4875 .16667 1 0 Msboxa
[(-2)] .4875 .33333 1 0 Msboxa
[(2)] .4875 .66667 1 0 Msboxa
[(4)] .4875 .83333 1 0 Msboxa
[(6)] .4875 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 .5 m
0 .50625 L
s
P
[(-6)] 0 .5 0 2 Mshowa
p
.002 w
.16667 .5 m
.16667 .50625 L
s
P
[(-4)] .16667 .5 0 2 Mshowa
p
.002 w
.33333 .5 m
.33333 .50625 L
s
P
[(-2)] .33333 .5 0 2 Mshowa
p
.002 w
.66667 .5 m
.66667 .50625 L
s
P
[(2)] .66667 .5 0 2 Mshowa
p
.002 w
.83333 .5 m
.83333 .50625 L
s
P
[(4)] .83333 .5 0 2 Mshowa
p
.002 w
1 .5 m
1 .50625 L
s
P
[(6)] 1 .5 0 2 Mshowa
p
.001 w
.03333 .5 m
.03333 .50375 L
s
P
p
.001 w
.06667 .5 m
.06667 .50375 L
s
P
p
.001 w
.1 .5 m
.1 .50375 L
s
P
p
.001 w
.13333 .5 m
.13333 .50375 L
s
P
p
.001 w
.2 .5 m
.2 .50375 L
s
P
p
.001 w
.23333 .5 m
.23333 .50375 L
s
P
p
.001 w
.26667 .5 m
.26667 .50375 L
s
P
p
.001 w
.3 .5 m
.3 .50375 L
s
P
p
.001 w
.36667 .5 m
.36667 .50375 L
s
P
p
.001 w
.4 .5 m
.4 .50375 L
s
P
p
.001 w
.43333 .5 m
.43333 .50375 L
s
P
p
.001 w
.46667 .5 m
.46667 .50375 L
s
P
p
.001 w
.53333 .5 m
.53333 .50375 L
s
P
p
.001 w
.56667 .5 m
.56667 .50375 L
s
P
p
.001 w
.6 .5 m
.6 .50375 L
s
P
p
.001 w
.63333 .5 m
.63333 .50375 L
s
P
p
.001 w
.7 .5 m
.7 .50375 L
s
P
p
.001 w
.73333 .5 m
.73333 .50375 L
s
P
p
.001 w
.76667 .5 m
.76667 .50375 L
s
P
p
.001 w
.8 .5 m
.8 .50375 L
s
P
p
.001 w
.86667 .5 m
.86667 .50375 L
s
P
p
.001 w
.9 .5 m
.9 .50375 L
s
P
p
.001 w
.93333 .5 m
.93333 .50375 L
s
P
p
.001 w
.96667 .5 m
.96667 .50375 L
s
P
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
.5 0 m
.50625 0 L
s
P
[(-6)] .4875 0 1 0 Mshowa
p
.002 w
.5 .16667 m
.50625 .16667 L
s
P
[(-4)] .4875 .16667 1 0 Mshowa
p
.002 w
.5 .33333 m
.50625 .33333 L
s
P
[(-2)] .4875 .33333 1 0 Mshowa
p
.002 w
.5 .66667 m
.50625 .66667 L
s
P
[(2)] .4875 .66667 1 0 Mshowa
p
.002 w
.5 .83333 m
.50625 .83333 L
s
P
[(4)] .4875 .83333 1 0 Mshowa
p
.002 w
.5 1 m
.50625 1 L
s
P
[(6)] .4875 1 1 0 Mshowa
p
.001 w
.5 .03333 m
.50375 .03333 L
s
P
p
.001 w
.5 .06667 m
.50375 .06667 L
s
P
p
.001 w
.5 .1 m
.50375 .1 L
s
P
p
.001 w
.5 .13333 m
.50375 .13333 L
s
P
p
.001 w
.5 .2 m
.50375 .2 L
s
P
p
.001 w
.5 .23333 m
.50375 .23333 L
s
P
p
.001 w
.5 .26667 m
.50375 .26667 L
s
P
p
.001 w
.5 .3 m
.50375 .3 L
s
P
p
.001 w
.5 .36667 m
.50375 .36667 L
s
P
p
.001 w
.5 .4 m
.50375 .4 L
s
P
p
.001 w
.5 .43333 m
.50375 .43333 L
s
P
p
.001 w
.5 .46667 m
.50375 .46667 L
s
P
p
.001 w
.5 .53333 m
.50375 .53333 L
s
P
p
.001 w
.5 .56667 m
.50375 .56667 L
s
P
p
.001 w
.5 .6 m
.50375 .6 L
s
P
p
.001 w
.5 .63333 m
.50375 .63333 L
s
P
p
.001 w
.5 .7 m
.50375 .7 L
s
P
p
.001 w
.5 .73333 m
.50375 .73333 L
s
P
p
.001 w
.5 .76667 m
.50375 .76667 L
s
P
p
.001 w
.5 .8 m
.50375 .8 L
s
P
p
.001 w
.5 .86667 m
.50375 .86667 L
s
P
p
.001 w
.5 .9 m
.50375 .9 L
s
P
p
.001 w
.5 .93333 m
.50375 .93333 L
s
P
p
.001 w
.5 .96667 m
.50375 .96667 L
s
P
p
.002 w
.5 0 m
.5 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.004 w
.75 .75 m
.83333 .91667 L
.91667 .75 L
.75 .75 L
s
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool2000009D0oooo0029
0?ooo`030000003oool0000009@0oooo00240?ooo`<000000P3oool00`000000oooo000000040?oo
o`<00000S@3oool008T0oooo0P0000050?ooo`030000003oool0oooo08d0oooo00290?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S@3oool008X0oooo0P0000040?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?oo
o`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool0
0900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo
00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool0
0`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000
oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool008X0oooo0`0000030?ooo`030000003oool0
oooo08d0oooo002;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S@3oool008@0
oooo0`0000020?ooo`@000000`3oool3000008d0oooo00290?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0S@3oool008X0oooo0P0000040?ooo`030000003oool0oooo08d0oooo002;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool0
0900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool0
0`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00R@3oool3000000@0oooo00<000000?ooo`3oool0S@3oool008T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2=0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0
0`3oool3000008d0oooo002:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S@3o
ool008T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`00RP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`80
0000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>0?oo
o`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000
003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo00080?ooo`800000;@3oool3
000002T0oooo0`00000Z0?ooo`030000003oool0oooo02X0oooo0`00000[0?ooo`<00000:P3oool2
000000H0oooo00080?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0000000D0oooo00030?ooo`<000000P3oool00`000000
oooo0000000V0?ooo`<000000P3oool4000002@0oooo0`0000030?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Y0?ooo`@00000:P3oool00`000000
oooo000000050?ooo`00203oool2000002`0oooo00<000000?ooo`000000:`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0000000[0?ooo`8000001P3oool000P0oooo00<000000?ooo`3oool0;03oool2000002X0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0000002/0oooo0P00
000[0?ooo`030000003oool0oooo00D0oooo00090?ooo`800000;@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo0P00000/0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool2000000D0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
00070?ooool000005@0000050?ooo`001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`001`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`030?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0
oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`80
0000SP3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3o
ool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo0P00002>0?oo
o`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03o
ool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`00
0000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool2000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000
003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0
oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo00290?ooo`<00000103oool00`000000oooo0?ooo`2=0?ooo`00R@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08d0oooo002:0?ooo`030000003oool0oooo00<0oooo0`00002=
0?ooo`00RP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08d0oooo00290?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool0S@3oool008X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool0
0`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000
oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool2000008h0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`03
0000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003o
ool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`800000SP3oool00900oooo00<0
00000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?oo
o`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0
@P3oool_000001`0oooo002@0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0K0?ooo`00T03oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool06`3oool00900oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo01`0oooo002@0?ooo`800000A@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo002@0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0M0?ooo`00T03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool00900oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo002@0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?oo
o`00T03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool07`3oool00900oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01l0oooo002@0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0P0?ooo`00T03oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0803oool00900oooo0P0000190?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08@3oool00900oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo002@0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0R0?ooo`00T03oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08P3oool00900oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo002@0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?oo
o`00T03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0903oool00900oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02@0oooo002:0?ooo`<000000`3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool09@3oool008/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09@3oool0
08T0oooo100000030?ooo`<00000C@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
02H0oooo00290?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo002:0?ooo`800000103oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09`3oool008/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool09`3oool00900oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02P0oooo002@0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`00T03oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0:@3oool00900oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo002@0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`00T03oool2
000005<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Z0?ooo`00T03oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00900
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0
oooo002@0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0/0?ooo`00T03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0;03oool00900oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02d0oooo002@0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`00T03oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool00900oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo002@0?ooo`800000E`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo002@0?ooo`030000003oool0
oooo05L0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`00T03oool00`000000oooo0?ooo`1G
0?ooo`040000003oool0oooo00000380oooo002@0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`000000<P3oool00900oooo00<000000?ooo`3oool0F03oool2000003<0oooo002@0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0<@3oool00900oooo00<000000?ooo`3oool0
S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool0
0900oooo0P00002>0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo
0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=
0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00
T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool00`000000oooo0?ooo`2=0?ooo`00T03oool2
000008h0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0
oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@
0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo00290?ooo`80
00001@3oool00`000000oooo0?ooo`2=0?ooo`00R@3oool00`000000oooo000000040?ooo`030000
003oool0oooo08d0oooo00290?ooo`030000003oool0000000@0oooo0`00002=0?ooo`00R@3oool2
000009D0oooo00290?ooo`030000003oool0oooo09@0oooo002:0?ooo`800000U03oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.31643, -6.26188, 0.0436368, 
  0.0436368}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Animations in homogeneous coordinates (i), (j), (k) -- movefig\
\>", "Subsection"],

Cell["\<\
The following definition of movefig uses viewhomo[matrix, {xmin, xmax, ymin, \
ymax}], so viewhomo must be working right first.  In range_:{-10,10,-10,10}, \
the colon indicates that what follows is a \"default value\" -- if the user \
doesn't put in any fourth argument, it will assume this value.  Do you \
understand the following program?\
\>", "Text"],

Cell["\<\
movefig[fig_, mat_, n_, range_:{-10,10,-10,10}] := 
Module[{tempfig},
   tempfig = fig;
   viewhomo[tempfig, range];
   Do[
      tempfig = mat.tempfig;
      viewhomo[tempfig, range]
   ,{i,1,n}]
]\
\>", "Input"],

Cell["\<\
The MATLAB movefig command in the book has one additional (fourth) argument \
for pause that we never need, so we don't include it.  Thus when the book \
says movefig(T,D,30,0,[-10,60,-10,40]), we would use \
movefig[t,d,30,{-10,60,-10,40}]  (assuming our matrices are given lowercase \
names).  Also, movefig(T,R,60,0) would simply be movefig[t,r,60].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["(i) Define translation matrix and use movefig as directed.", 
  "Subsection"],

Cell[CellGroupData[{

Cell["m = {{1,0,.2},{0,1,.1},{0,0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", 
              StyleBox["0.2`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {"0", "1", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["z = {0,10,0,10}", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 10, 0, 10}\)], "Output"]
}, Open  ]],

Cell["movefig[t,m,35,z]", "Input"],

Cell["\<\
Remember to delete the plots (but save the movefig command) after watching \
every movie.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["(j) Define matrices d, r, and s and use movefig as directed.", 
  "Subsection"],

Cell["\<\
For the r matrix, be sure to use N[ ] to define it with numerical entries.\
\>", "Text"],

Cell["\<\
For the s matrix, \"reflection of 180 degrees\" is ambiguous; assume that the \
book means reflection across the x-axis.\
\>", "Text"],

Cell[CellGroupData[{

Cell["d = DiagonalMatrix[{1.1,1.1,1}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["1.10000000000000008`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "0", "0"},
            {"0", 
              StyleBox["1.10000000000000008`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
r = N[{{Cos[Pi/30], -Sin[Pi/30], 0},
       {Sin[Pi/30], Cos[Pi/30],  0},
       {0,          0,           1}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.994521895368273334`", \(-0.104528463267653459`\), "0"},
            {"0.104528463267653459`", "0.994521895368273334`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["s = {{1,0,0},{0,-1,0},{0,0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", \(-1\), "0"},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["movefig[t,d,30,{-10,60,-10,40}]", "Input"],

Cell["movefig[t,r,60]", "Input"],

Cell["movefig[t,s,20]", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["(k)  Use movefig as directed.", "Subsection"],

Cell["movefig[t,s.m,60,{0,15,-10,10}]", "Input"],

Cell["movefig[t,d.r,41,{-100,100,-140,80}]", "Input"],

Cell["movefig[t,s.m.d,40,{-10,250,-100,100}]", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rising spinning pinwheel example (in spirit of (l)).", "Subsection"],

Cell[CellGroupData[{

Cell["p = N[1/Sqrt[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.707106781186547461`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
pinwheelpts = Transpose[{{0,0},{0,1},{p,p},{0,0},{1,0},
   {p,-p},{0,0},{0,-1},{-p,-p},{0,0},{-1,0},{-p,p},{0,0}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0", "0", "0.707106781186547461`", "0", "1", 
              "0.707106781186547461`", "0", "0", \(-0.707106781186547461`\), 
              "0", \(-1\), \(-0.707106781186547461`\), "0"},
           
             {"0", "1", "0.707106781186547461`", "0", "0", 
              \(-0.707106781186547461`\), "0", \(-1\), 
              \(-0.707106781186547461`\), "0", "0", "0.707106781186547461`", 
              "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
pinwheel = Append[pinwheelpts,
                  Table[1,{Length[pinwheelpts[[1]]]}]
           ]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0", "0", "0.707106781186547461`", "0", "1", 
              "0.707106781186547461`", "0", "0", \(-0.707106781186547461`\), 
              "0", \(-1\), \(-0.707106781186547461`\), "0"},
           
             {"0", "1", "0.707106781186547461`", "0", "0", 
              \(-0.707106781186547461`\), "0", \(-1\), 
              \(-0.707106781186547461`\), "0", "0", "0.707106781186547461`", 
              "0"},
            {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[pinwheel,{-2,2,-2,2}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .5 m
.5 .75 L
.67678 .67678 L
.5 .5 L
.75 .5 L
.67678 .32322 L
.5 .5 L
.5 .25 L
.32322 .32322 L
.5 .5 L
.25 .5 L
.32322 .67678 L
.5 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool00`3o
ool3000008d0oooo002:0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0S@3o
ool008X0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool3
000000D0oooo00<000000?ooo`3oool0S03oool008L0oooo0P0000080?ooo`030000003oool0oooo
08`0oooo00240?ooo`<000002P3oool00`000000oooo0?ooo`2<0?ooo`00PP3oool2000000d0oooo
00<000000?ooo`3oool0S03oool00800oooo0P00000?0?ooo`800000S@3oool007d0oooo0`00000A
0?ooo`030000003oool0oooo08`0oooo001k0?ooo`800000503oool00`000000oooo0?ooo`2<0?oo
o`00N@3oool2000001H0oooo00<000000?ooo`3oool0S03oool007H0oooo0`00000H0?ooo`030000
003oool0oooo08`0oooo001d0?ooo`8000006`3oool00`000000oooo0?ooo`2<0?ooo`00L@3oool3
000001d0oooo00<000000?ooo`3oool0S03oool006l0oooo0P00000P0?ooo`800000S@3oool006d0
oooo0P00000R0?ooo`030000003oool0oooo08`0oooo001Z0?ooo`<00000903oool00`000000oooo
0?ooo`2<0?ooo`00J03oool2000002L0oooo00<000000?ooo`3oool0S03oool006D0oooo0`00000Y
0?ooo`030000003oool0oooo08`0oooo001S0?ooo`800000;03oool00`000000oooo0?ooo`2<0?oo
o`00H@3oool2000002h0oooo00<000000?ooo`3oool0S03oool005l0oooo0P00000`0?ooo`800000
;`3oool00`000000oooo0?ooo`1K0?ooo`00H03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02d0oooo0P00001M0?ooo`00H@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02`0oooo00@000000?ooo`3oool00000G03oool00680oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`050000003oool0oooo0?ooo`000000G03oool006<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0F@3oool006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F@3oool006D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0F@3oool006H0oooo00<000000?ooo`3oool0:03oool2000002P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1H0?ooo`00I`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1H0?ooo`00J03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1G0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1G0?ooo`00JP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1G0?ooo`00J`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1F0?ooo`00K03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0EP3oool006d0oooo00<00000
0?ooo`3oool02P3oool300000080oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`03
0?ooo`8000008@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05D0oooo001^0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`0000001`3oool2000000H0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05D0oooo001_0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1D0?ooo`00
L03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1D0?ooo`00L@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1D0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1C0?ooo`00L`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1C0?ooo`00M03oool00`000000oooo0?ooo`0J0?ooo`8000006P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo001e0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0580oooo
001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0580oooo001g0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0540oooo001h0?oo
o`8000005`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0D@3oool007X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0D03oool007/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
D03oool007`0oooo00<000000?ooo`3oool04P3oool2000001<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`1@0?ooo`00O@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1?0?ooo`00OP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1?0?ooo`00O`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1>0?ooo`00P03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`1>0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`1>0?ooo`00PP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1=
0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`800000303oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo04d0oooo00240?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo00250?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo04`0oooo00070?ooo`<000006@3oool500000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0I0?ooo`D000006`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo00000004000001P0oooo1@00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool3000000<0oooo0007
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000L
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000@
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000603oool01@000000oooo0?ooo`3o
ool0000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000K0?ooo`030000003o
ool0oooo00<0oooo00020?ooo`<000000`3oool00`000000oooo0?ooo`0D0?ooo`<000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`030000003oool0
oooo01D0oooo0`0000020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo000000090?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000
000L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`020?ooo`00203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00000M
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool2000001<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`0000001`3oool2000001X0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?oo
o`060?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`001`3oool00`000000oooo0000000K
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`8000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool06@3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo000000030?ooo`00203oool00`000000oooo0?ooo`0I
0?ooo`800000203oool3000001/0oooo0P00000M0?ooo`030000003oool0oooo00H0oooo0`00000D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo0`00000J0?ooo`<000006`3oool2000000P0oooo0`00000L
0?ooo`030000003oool0oooo0080oooo002<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04T0oooo002=0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
04T0oooo002>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`180?ooo`00S`3oool01@000000oooo0000003oool000000440oooo00<000000?oo
o`3oool0B03oool00900oooo0`0000130?ooo`030000003oool0oooo04L0oooo00060?ooool00000
600000030?ooo`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0`00
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`8000008@3oool00`000000oooo0?ooo`0N
0?ooo`050000003oool000000?ooo`0000007`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`010?ooo`00C03oool0
0`000000oooo0?ooo`0o0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0R@3o
ool004d0oooo00<000000?ooo`3oool0?@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0R03oool004d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool004d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0QP3oool004h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`80
00001@3oool00`000000oooo0?ooo`250?ooo`00CP3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00C`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`230?ooo`00C`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`220?ooo`00C`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`210?ooo`00D03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`200?ooo`00D03oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1o0?ooo`00D@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00/0oooo0P00
000<0?ooo`030000003oool0oooo07h0oooo001A0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo001B0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo07`0oooo001B0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07/0oooo001B0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07X0oooo001C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07T0oooo001C0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo07P0oooo001D0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool20000
01<0oooo00<000000?ooo`3oool0M`3oool005@0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0MP3oool005@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0M@3oool005D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0M03oool005D0oooo00<00000
0?ooo`3oool07`3oool2000001P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1c
0?ooo`00EP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00EP3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1a0?ooo`00
EP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo0P00000J0?ooo`030000
003oool0oooo0700oooo001G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo06h0oooo001H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo06d0oooo001H0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0
oooo001H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo06/0oooo001I0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03P3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1Z0?ooo`00F@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`03
0?ooo`8000008@3oool00`000000oooo0?ooo`1Y0?ooo`00FP3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`0000001`3oool2000000H0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1X0?ooo`00FP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0I`3oool005/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool005/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0I@3o
ool005/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0I03oool005`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H`3oool005`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`800000:03oool00`000000
oooo0?ooo`1R0?ooo`00G@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1Q0?ooo`00G@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1P0?ooo`00G@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`1O0?ooo`00GP3oool01@000000oooo0?ooo`3oool0
000002h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00GP3oool01000
0000oooo0?ooo`00000_0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G@3oool0
05l0oooo0P00000`0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0G03oool005l0
oooo00<000000?ooo`3oool0;`3oool2000002h0oooo0P00001M0?ooo`00T@3oool00`000000oooo
0?ooo`0[0?ooo`800000G`3oool00940oooo00<000000?ooo`3oool0:03oool300000640oooo002A
0?ooo`030000003oool0oooo02H0oooo0P00001T0?ooo`00T@3oool00`000000oooo0?ooo`0S0?oo
o`<00000IP3oool00940oooo00<000000?ooo`3oool08@3oool2000006T0oooo002A0?ooo`030000
003oool0oooo01l0oooo0P00001[0?ooo`00T@3oool2000001d0oooo0`00001]0?ooo`00T@3oool0
0`000000oooo0?ooo`0J0?ooo`800000L03oool00940oooo00<000000?ooo`3oool05`3oool30000
0780oooo002A0?ooo`030000003oool0oooo01D0oooo0P00001e0?ooo`00T@3oool00`000000oooo
0?ooo`0B0?ooo`<00000M`3oool00940oooo00<000000?ooo`3oool0403oool2000007X0oooo002A
0?ooo`030000003oool0oooo00d0oooo0`00001l0?ooo`00T@3oool2000000`0oooo0P00001o0?oo
o`00T@3oool00`000000oooo0?ooo`090?ooo`800000P@3oool00940oooo00<000000?ooo`3oool0
1P3oool3000008<0oooo002A0?ooo`030000003oool0oooo00@0oooo0P0000260?ooo`00R03oool5
000000@0oooo00@000000?ooo`3oool0oooo0`0000280?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`040000003oool00000000008/0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=
0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00P03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03o
ool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool0
0800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool00800
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0
oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00R@3oool3000000D0oooo00<000000?ooo`3oool0S03oool008T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`800000S@3oool008X0oooo00<000000?ooo`3oool0T`3oool008T0oooo00<000000?ooo`00
0000U03oool008X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell["Let's rotate the pinwheel.", "Text"],

Cell[CellGroupData[{

Cell["\<\
rot = N[{{Cos[-Pi/10], -Sin[-Pi/10], 0},
         {Sin[-Pi/10], Cos[-Pi/10],  0},
         {0,           0,            1}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.951056516295153642`", "0.309016994374947451`", "0"},
            {\(-0.309016994374947451`\), "0.951056516295153642`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["movefig[pinwheel,rot,20,{-2,2,-2,2}]", "Input"],

Cell["Let's make it rise straight up.", "Text"],

Cell[CellGroupData[{

Cell["up = {{1,0,0},{0,1,.2},{0,0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", 
              StyleBox["0.2`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["movefig[pinwheel,up,20,{-2,2,-1,5}]", "Input"],

Cell["\<\
The real objective of this problem is to make the pinwheel do both \
simultaeously.  Your first idea might be to just multiply by both matrices, \
rot and up, on each step.  But you may be surprised what this does.\
\>", "Text"],

Cell["movefig[pinwheel,up.rot,20,{-2,2,-1,5}]", "Input"],

Cell["Explain why the pinwheel doesn't move straight up.", "Text"],

Cell["\<\
This really is a problem because matrix multiplication is not commutative.  \
Explain why the actaion of matrix up.rot is different than the action of \
matrix rot.up.\
\>", "Text"],

Cell["\<\
If we want to rise straight up, we really want to do all of the rotations \
first and then all of the ups.  In particular, after two steps the image \
should be accomplished by up.up.rot.rot and not by up.rot.up.rot.  The idea \
here is to never save a changed figure of points but to always start with the \
original figure and on each step find the new transformation matrix.  We will \
accumulate the net result of n rotations in rotmat and the net result of n \
shifts up in upmat.  These matrices are then alway applied to the original \
image pinwheel. This program will take no input but just use the variables \
pinwheel, up and rot defined above.\
\>", "Text"],

Cell["\<\
Clear[risespin]
risespin :=
Module[{rotmat,upmat},
   rotmat = IdentityMatrix[3];
   upmat = IdentityMatrix[3];
   viewhomo[pinwheel,{-2,2,-1,5}];
   Do[
      rotmat = rot.rotmat;
      upmat = up.upmat;
      viewhomo[upmat.rotmat.pinwheel,{-2,2,-1,5}]
   ,{i,1,20}]
]\
\>", "Input"],

Cell["risespin", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tumbling stickman problem (in spirit of (m)).", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
stickman = Transpose[{{-1,-3},{0,-1},{0,0},{-2,1},{0,0},
   {0,1},{-1,2},{0,3},{1,2},{0,1},{0,0},{2,1},{0,0},
   {0,-1},{1,-3}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-1\), "0", "0", \(-2\), "0", "0", \(-1\), "0", "1", "0", "0", 
              "2", "0", "0", "1"},
           
             {\(-3\), \(-1\), "0", "1", "0", "1", "2", "3", "2", "1", "0", 
              "1", "0", \(-1\), \(-3\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["stickman = Append[stickman,Table[1,{15}]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-1\), "0", "0", \(-2\), "0", "0", \(-1\), "0", "1", "0", "0", 
              "2", "0", "0", "1"},
           
             {\(-3\), \(-1\), "0", "1", "0", "1", "2", "3", "2", "1", "0", 
              "1", "0", \(-1\), \(-3\)},
           
             {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1",
               "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["viewhomo[stickman,{-4,4,-4,4}];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.375 .125 m
.5 .375 L
.5 .5 L
.25 .625 L
.5 .5 L
.5 .625 L
.375 .75 L
.5 .875 L
.625 .75 L
.5 .625 L
.5 .5 L
.75 .625 L
.5 .5 L
.5 .375 L
.625 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00RP3oool3000009<0oooo002;0?ooo`030000003o
ool0oooo0980oooo00240?ooo`<000000P3oool4000000@0oooo0P00002=0?ooo`00R@3oool00`00
0000oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`8000001@3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo
002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool006h0oooo00<00000
0?ooo`3oool04`3oool3000000<0oooo00<000000?ooo`3oool0103oool200000200oooo00<00000
0?ooo`3oool0JP3oool006l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0JP3oool006l0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo000000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0J`3oool00700oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0J`3oool00700oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/0?ooo`00L@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00780
oooo00<000000?ooo`3oool0703oool2000001d0oooo00<000000?ooo`3oool0K@3oool00780oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06h0oooo
001c0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`1^0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo06l0oooo001d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1`0?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool007D0oooo00<000000?ooo`3oool06@3o
ool2000001T0oooo00<000000?ooo`3oool0L@3oool007H0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo001f0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0LP3oool007L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07<0oooo
001h0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1c0?ooo`00N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0M03oool007T0oooo00<000000?ooo`3oool05@3oool2000001H0oooo00<000000?oo
o`3oool0M03oool007T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo07D0oooo001j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1e0?ooo`00NP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0MP3oool007/0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07H0oooo001k0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00O03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool007`0oooo
00<000000?ooo`3oool04P3oool200000180oooo00<000000?ooo`3oool0N03oool007d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0oooo001m
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i
0?ooo`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0N@3oool007h0oooo00<000000?ooo`3oool0203oool3000000D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00O`3o
ool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`8000003`3o
ool00`000000oooo0?ooo`1k0?ooo`00P03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`00P03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1l0?ooo`00P@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00880oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo0022
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1n
0?ooo`00P`3oool00`000000oooo0?ooo`0;0?ooo`800000303oool00`000000oooo0?ooo`1n0?oo
o`00P`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0O`3oool008@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo07l0oooo00240?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`200?ooo`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0P03oool008D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0840oooo00260?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`210?ooo`00QP3oool00`000000oooo
0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`220?ooo`00Q`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0PP3oool008L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo00280?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`230?oo
o`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0Q03oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo08@0oooo00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`8000001@3oool0
0`000000oooo0?ooo`250?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0QP3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002;0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008`0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000008X0oooo002=0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`280?ooo`00S@3oool010000000oooo0?ooo`3o
ool2000000030?ooo`000000oooo08X0oooo002>0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0R@3oool008h0oooo00H000000?ooo`3oool000000?ooo`00002<0?ooo`00S`3o
ool01@000000oooo0000003oool0000008`0oooo002?0?ooo`040000003oool00000000008d0oooo
00280?ooo`D000000`3oool3000008d0oooo002:0?ooo`030000003oool0oooo00<0oooo0P00002>
0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool000P0oooo0`00000N0?ooo`8000008@3oool3
000001l0oooo1@00000N0?ooo`030000003oool0oooo01d0oooo1@00000O0?ooo`<000007`3oool2
00000280oooo0`0000020?ooo`002@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool00@3oool00080oooo0`0000020?ooo`@000006@3oool3000000<0
oooo00<000000?ooo`3oool06P3oool3000000<0oooo00<000000?ooo`3oool06P3oool3000000<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`@000000P3oool000L0oooo
00<000000?ooo`0000008@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0N0?ooo`030000003oool0000000<0oooo
00080?ooo`8000007`3oool00`000000oooo0000000P0?ooo`030000003oool000000240oooo00<0
00000?ooo`3oool07P3oool200000200oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
000O0?ooo`030000003oool000000240oooo0P0000030?ooo`002@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool200000200oooo00<00000
0?ooo`3oool07P3oool200000280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0040oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00060?ooool00000600000030?oo
o`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo1@0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
703oool200000080oooo00<000000?ooo`3oool00P00000M0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0040oooo
002;0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000R03oool008T0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo0P0000260?ooo`00Q`3oool2000000P0oooo00<000000?oo
o`3oool01P3oool2000008@0oooo00250?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`80
0000PP3oool008<0oooo0P00000<0?ooo`8000002`3oool200000800oooo00210?ooo`8000003P3o
ool00`000000oooo0?ooo`0<0?ooo`800000OP3oool007l0oooo0P00000@0?ooo`030000003oool0
oooo00h0oooo0P00001l0?ooo`00O@3oool200000180oooo00<000000?ooo`3oool0403oool20000
07X0oooo001k0?ooo`800000503oool00`000000oooo0?ooo`0B0?ooo`800000N03oool007T0oooo
0P00000F0?ooo`030000003oool0oooo01@0oooo0P00001f0?ooo`00M`3oool2000001P0oooo00<0
00000?ooo`3oool05P3oool2000007@0oooo001e0?ooo`8000006P3oool2000001T0oooo0P00001b
0?ooo`00L`3oool2000001`0oooo00<000000?ooo`3oool06P3oool200000700oooo001a0?ooo`80
00007P3oool00`000000oooo0?ooo`0L0?ooo`800000KP3oool006l0oooo0P00000P0?ooo`030000
003oool0oooo01h0oooo0P00001/0?ooo`00K@3oool200000280oooo00<000000?ooo`3oool0803o
ool2000006X0oooo001[0?ooo`800000903oool00`000000oooo0?ooo`0R0?ooo`800000J03oool0
06T0oooo0P00000V0?ooo`030000003oool0oooo02@0oooo0P00001V0?ooo`00I`3oool2000002P0
oooo0P00000W0?ooo`800000I03oool006D0oooo0P00000Z0?ooo`030000003oool0oooo02P0oooo
0P00001R0?ooo`00H`3oool2000002`0oooo00<000000?ooo`3oool0:P3oool200000600oooo001Q
0?ooo`800000;P3oool00`000000oooo0?ooo`0/0?ooo`800000GP3oool005l0oooo0P00000`0?oo
o`030000003oool0oooo02h0oooo0P00001L0?ooo`00G@3oool200000380oooo00<000000?ooo`3o
ool0<03oool2000005X0oooo001K0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000
F03oool005T0oooo0P00000f0?ooo`800000=@3oool2000005H0oooo001G0?ooo`800000>03oool0
0`000000oooo0?ooo`0f0?ooo`800000E03oool005D0oooo0P00000j0?ooo`030000003oool0oooo
03P0oooo0P00001B0?ooo`00D`3oool2000003`0oooo00<000000?ooo`3oool0>P3oool200000500
oooo001A0?ooo`800000?P3oool00`000000oooo0?ooo`0l0?ooo`800000CP3oool004l0oooo0P00
000g0?ooo`D00000103oool00`000000oooo0?ooo`0n0?ooo`800000C03oool004d0oooo0P00000k
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@03oool2000004X0oooo001;0?oo
o`800000?@3oool00`000000oooo0?ooo`040?ooo`800000@`3oool00`000000oooo0?ooo`170?oo
o`00RP3oool00`000000oooo0?ooo`030?ooo`<00000S@3oool008X0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool0000008`0oooo00290?ooo`8000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo08T0oooo002=0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`280?ooo`00S03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08H0oooo002:0?ooo`030000003oool0
oooo00@0oooo0P0000050?ooo`030000003oool0oooo08D0oooo00290?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`240?ooo`00R03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0P`3oool008L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0880oooo
00260?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`210?ooo`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0P03oool008@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo07l0oooo00230?ooo`030000003oool0oooo00/0oooo0P00000<0?ooo`03
0000003oool0oooo07h0oooo00220?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1m0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0O03oool007l0oooo0P00000@0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0N`3oool007h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo001m0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00O03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0N03oool007/0oooo00<0
00000?ooo`3oool04`3oool2000001<0oooo00<000000?ooo`3oool0M`3oool007X0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07H0oooo001i0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?oo
o`00N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0M03oool007L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo07<0oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`1b0?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0L@3oool007@0oooo00<000000?ooo`3oool06P3oool20000
01X0oooo00<000000?ooo`3oool0L03oool007<0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo06l0oooo001b0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1^0?ooo`00L@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0K@3oool00700oooo00<00000
0?ooo`3oool05P3oool3000000D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1/
0?ooo`00K`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1[0?ooo`00KP3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00@0oooo0P00000P0?ooo`030000003oool0oooo06X0oooo001_0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo06/0oooo001`0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo001a0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo06d0oooo001b0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1^0?ooo`00L`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0K`3oool007@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0700oooo001e0?ooo`030000003oool0oooo01T0oooo0P00
000I0?ooo`030000003oool0oooo0740oooo001f0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1b0?ooo`00M`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool007P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07@0oooo001i0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e0?ooo`00NP3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0MP3o
ool007/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo07L0oooo001l0?ooo`030000003oool0oooo0180oooo0P00000B0?ooo`030000003oool0oooo
07P0oooo001m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1i0?ooo`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0NP3oool007l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo07/0oooo00200?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`00P@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool00880oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07d0oooo00230?ooo`030000
003oool0oooo00/0oooo0P00000<0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1o0?ooo`00Q@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool0
08H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0840oooo00270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`220?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0P`3oool008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo08@0oooo002:0?ooo`030000003oool0oooo00@0oooo0P000005
0?ooo`030000003oool0oooo08D0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`260?ooo`00S03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool008d0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo08P0oooo002>0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0R@3oool008T0oooo0P0000040?ooo`050000003oool000000?ooo`00
0000S03oool008/0oooo00<000000?ooo`3oool00P3oool3000008d0oooo002:0?ooo`030000003o
ool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo08`0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool008X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002:0?ooo`<00000103oool00`000000oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo08`0oooo00290?ooo`@00000103oool2000008d0oooo0029
0?ooo`030000003oool0000009@0oooo002:0?ooo`800000U03oool008/0oooo00<000000?ooo`3o
ool0TP3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.1727, -4.12954, 0.0287773, 
  0.0287773}}]
}, Open  ]],

Cell["\<\
Your mission is to adapt the risespin program to make this stickman do \
cartwheels across the screen.  The final result should show him starting by \
standing on the x-axis and tumbling across the x-axis floor for two total \
revolutions.\
\>", "Text"],

Cell["\<\
cartwheel := 
Module[{transMat,rotateMat,image},
   transMat = {{1,0,2},{0,1,3},{0,0,1}};
   rotateMat = N[{{Cos[-Pi/10], -Sin[-Pi/10], 0},
                 {Sin[-Pi/10], Cos[-Pi/10],  0},
                 {0,           0,            1}}];
   image = stickman;
   viewhomo[transMat.image,{0,20,0,6}];
   Do[
      transMat[[1,3]] = transMat[[1,3]]+.5;
      image = rotateMat.image;
      viewhomo[transMat.image, {0,24,0,6}]
   ,{i,1,40}]
]\
\>", "Input"],

Cell["\<\
For extra credit, make him bounce in the air and back down on his feet as he \
tumbles.  To do this realize that, since the original image stays at the \
origin, you can compute the new translation by any formula you want -- it \
doesn't have to be an accumulation of the same translation every time.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spirit of 5.2; 2 -- Graphics Transformations -- Tutorial & Instructions
(5.2; 2 alternative focused on compositions & homogeneous coordinates).\
\>", "Section"],

Cell[CellGroupData[{

Cell["\<\
Initializations -- view, rotMat, transMat, scaleMat, and flag.
(These functions are gathered from below)\
\>", "Subsection"],

Cell[BoxData[
    \(Needs["\<Graphics`Colors`\>"]\)], "Input",
  InitializationCell->True],

Cell["\<\
Clear[view]
view[homoMat2D_, xyRange_:Automatic] := 
\tListPlot[ Transpose[ homoMat2D[[{1,2}]] ],
\t\tPlotJoined->True,
\t\tPlotRange->xyRange,
\t\tAspectRatio->Automatic,
\t\tPlotStyle->Blue];
view[homoMat2D_, radius_?NumberQ] :=
   view[homoMat2D, {{-radius,radius},{-radius,radius}} ]\
\>", "Input",
  InitializationCell->True],

Cell[BoxData[
    \(rotMat[\[Theta]_]\  := \ 
      N[{{Cos[\[Theta]], \(-Sin[\[Theta]]\), 0}, {Sin[\[Theta]], 
            Cos[\[Theta]], 0}, {0, 0, 1}}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(transMat[h_, k_]\  := \ N[{{1, 0, h}, {0, 1, k}, {0, 0, 1}}]\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(scaleMat[s_, t_]\  := \ N[\ DiagonalMatrix[{s, t, 1}]\ ]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(flag\  = \ 
      Append[\n\t\tTranspose[{{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}], \n\t\t
        Table[1, {4}]\n\t]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting a matrix of points -- Start Here.", "Subsection"],

Cell[CellGroupData[{

Cell["Using ListPlot and options (including color).", "Subsubsection"],

Cell["\<\
For use in Mma's ListPlot command, points are given by a list of ordered \
pairs.\
\>", "Text"],

Cell[BoxData[
    \(pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}\)], "Input"],

Cell["ListPlot[pts, PlotJoined->True];", "Input"],

Cell[TextData[{
  "This image is distorted since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " fits the image into a wide rectangle.  The ratio of width to height is \
called the AspectRatio (with default value around 1.6).  The following option \
requests that box have side lengths proportional to the numerical ranges, so \
the axes end up with the same scale."
}], "Text"],

Cell["\<\
ListPlot[pts, PlotJoined->True,
   AspectRatio->Automatic];\
\>", "Input"],

Cell["We may also want to \"manually\" specify the PlotRange.", "Text"],

Cell["\<\
ListPlot[pts, PlotJoined->True,
   PlotRange->{{-3,3},{0,3}}, AspectRatio->Automatic];\
\>", "Input"],

Cell["\<\
Finally, Let's plot in Blue.  WARNING: Before you ever use a color name, you \
must first execute the following Needs command.  If you forget and use the \
name Blue first, then you have to Remove[Blue] before the Needs command to \
correctly define it.  If you are curious of what color names are defined, \
enter AllColors after the Needs command.\
\>", "Text"],

Cell[BoxData[
    \(Needs["\<Graphics`Colors`\>"]\)], "Input"],

Cell["\<\
ListPlot[pts, PlotJoined->True,
   PlotRange->{{-3,3},{0,3}}, AspectRatio->Automatic, PlotStyle->Blue];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous 2D coordinates and a view function.", "Subsubsection"],

Cell["\<\
For use in matrix transformations it is best to store the points in a 3\
\[Times]n matrix, where each point (x, y) is stored in a column with entries \
(x, y, 1).\
\>", "Text"],

Cell[BoxData[
    \(flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)], "Input"],

Cell["\<\
For reference, I'll call any such matrix of points a \"homoMat2D.\"  To plot \
a homoMat2D, we need to ListPlot the Transpose of the first two rows and use \
all of the options developed above.  We can define such a function once and \
for all.\
\>", "Text"],

Cell["\<\
Clear[view]
view[homoMat2D_, xyRange_:Automatic] := 
\tListPlot[ Transpose[ homoMat2D[[{1,2}]] ],
\t\tPlotJoined->True,
\t\tPlotRange->xyRange,
\t\tAspectRatio->Automatic,
\t\tPlotStyle->Blue
\t];
\t\t
view[homoMat2D_, radius_?NumberQ] :=
   view[homoMat2D, {{-radius,radius},{-radius,radius}} ]\
\>", "Input"],

Cell["\<\
view has three options for the second argument as displayed below.  Usually, \
you want to pick some xyRange, as in the first example, and stick with it \
throughout transformations so that you can correctly compare before and after \
transformation.\
\>", "Text"],

Cell[BoxData[
    \(\(view[flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[BoxData[
    \(\(view[flag, \ 2]; \)\)], "Input"],

Cell[BoxData[
    \(\(view[flag]; \)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Transformations", "Subsection"],

Cell["\<\
To perform any linear transformation T on all the points in a homoMat2D, use \
a 3\[Times]3 matrix that includes the standard 2\[Times]2 matrix of the \
transformation in the upper left and a one in the lower right (zeros \
elsewhere).  Here is a function that returns the rotation matrix.  The N \
makes computation with such a matrix more efficient.\
\>", "Text"],

Cell[BoxData[
    \(rotMat[\[Theta]_]\  := \ 
      N[{{Cos[\[Theta]], \(-Sin[\[Theta]]\), 0}, {Sin[\[Theta]], 
            Cos[\[Theta]], 0}, {0, 0, 1}}]\)], "Input"],

Cell[BoxData[
    \(Ar\  = \ rotMat[Pi/4]\)], "Input"],

Cell[BoxData[
    \(\( (*\ review\ of\ homoMat2D\ construction\ *) \n
    pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}; \n
    flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)\)], "Input"],

Cell[BoxData[
    \(Ar.flag\)], "Input"],

Cell["\<\
Notice how Ar multiples the x,y coordinates by the upper left 2\[Times]2 and \
leaves the \"3rd coordinate\" as one.  This 3rd coordinate has no purpose \
yet.\
\>", "Text"],

Cell[BoxData[
    \(\(view[Ar.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell["\<\
The extra 1 enables translations (not a linear transformation in 2D) to be \
performed by matrix multiplication (a 3 coordinate linear transformation!) as \
shown in Lay, p. 157.  \
\>", "Text"],

Cell[BoxData[
    \(transMat[h_, k_]\  := \ N[{{1, 0, h}, {0, 1, k}, {0, 0, 1}}]\)], "Input"],

Cell[BoxData[
    \(At\  = \ transMat[1, .5]\)], "Input"],

Cell[BoxData[
    \(flag\)], "Input"],

Cell[BoxData[
    \(At.flag\)], "Input"],

Cell[BoxData[
    \(\(view[At.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell["Let's save this shifted flag.", "Text"],

Cell[BoxData[
    \(flag1\  = \ At.flag\)], "Input"],

Cell["\<\
We also need a scaling transformation that will multiply x coordinates by one \
factor s and y coordinates by another factor t.  If 0 < s = t < 1, then the \
transformation just shrinks the image toward the origin.  With negatives, you \
can perform reflections.  Let's try s=-0.5 and t=0.5 on the shifted flag1.\
\>", "Text"],

Cell[BoxData[
    \(scaleMat[s_, t_]\  := \ N[\ DiagonalMatrix[{s, t, 1}]\ ]\)], "Input"],

Cell[BoxData[
    \(As = \ scaleMat[\(-.5\), .5]\)], "Input"],

Cell[BoxData[
    \(flag1\)], "Input"],

Cell[BoxData[
    \(As.flag1\)], "Input"],

Cell[BoxData[
    \(\(view[As.flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell["\<\
Here is how you can superimpose any two (or more) plots.  We use it to see \
before and after together.  You can ignore the \"friendly\" possible spelling \
errors, they indicate that Before already has a definition.\
\>", "Text"],

Cell[BoxData[
    \(\(before\  = \ view[flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[BoxData[
    \(\(after\  = \ view[As.flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Show[before, after]; \)\)], "Input"],

Cell["\<\
Later, we will see that any linear transformation can be performed by a \
rotation, followed by a scaling (any s and t), followed by another rotation \
(this follows from the Singular Value Decomposition).  An affine \
transformation is defined to be a linear transformation together with a \
translation.  Thus, combinations of rotMat, scaleMat, and transMat are enough \
to produce any affine transformation.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assignment  -- Part I.", "Subsection"],

Cell["Names?", "Text"],

Cell[BoxData[
    \(\( (*\ review\ of\ homoMat2D\ construction\ *) \n
    pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}; \n
    flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)\)], "Input"],

Cell[BoxData[
    \(\(view[flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[TextData[{
  "1.  ",
  StyleBox[
  "Find the transformation matrix A that maps the original flag to the \
\"after\" image defined in the above section and view A.flag.  (If you get \
stuck with something wrong, study Lay p. 101.)", "Text"]
}], "Subsubsection"],

Cell["\<\
2.  Your matrix A should have been a product of two matrices.  Form B by \
multiplying them in the opposite order and view B.flag.  What's going on \
here?  Explain the algebraic problem as well as the geometry.\
\>", "Subsubsection"],

Cell[TextData[{
  "3.  To vertically smash a figure, we use ",
  StyleBox["scaleMat[1,.3]", "Input"],
  " (understand?).  To smash it along the line y=x, we could first rotate it \
by -Pi/4, then vertically smash, then rotate back Pi/4.  Find the matrix A \
that accomplishes this and view A.flag."
}], "Subsubsection"],

Cell[TextData[{
  "4.  Often, rather than rotating twice, a shear transformation is added to \
the mix.  Any linear transformation is a combination one rotation, one \
scaling and one shear.  Define a ",
  StyleBox["shearMat[t_]", "Input"],
  " function that produces the 3\[Times]3 matrix that leaves the x-axis fixed \
but leans the y-axis to the right by an angle of t radians.  This should be a \
horizontal (only) shear that leaves all y coordinates unchanged by the \
transformation.  Hint: first find the standard 2\[Times]2 matrix for this \
transformation.  Test it by shearing flag by Pi/6 and viewing the result."
}], "Subsubsection"],

Cell["\<\
5.  Rotation about a point other than the origin can be accomplished using \
translations (note plural).  Find a matrix that rotates an image thru -Pi/4 \
about the point (0,1).  Test on flag and view the result.  Hint:  Change to \
rotation about the origin.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
6.  Design any interesting stick image and transformation.  Specifically, \
define a homoMat2D, find one matrix that performs more than one of the \
geometric transformations, and plot both the before and after images \
together.\
\>", "Subsubsection"],

Cell["\<\
In class, you may want to skip to the next idea and come back to this after \
you have time to think about your design.  SAVE YOUR WORK before you go on, \
to protect in case of a \"crash.\"\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Making movies", "Subsection"],

Cell[CellGroupData[{

Cell["Flag waving", "Subsubsection"],

Cell[BoxData[
    \(initA\  = \ rotMat[\(-Pi\)/5]\)], "Input"],

Cell[BoxData[
    \(rotStep\  = \ rotMat[Pi/20]\)], "Input"],

Cell[BoxData[
    \(view[initA.flag, {{\(-3\), 3}, {0, 3}}]; \n
    view[rotStep.initA.flag, {{\(-3\), 3}, {0, 3}}]; \n
    view[rotStep.rotStep.initA.flag, {{\(-3\), 3}, {0, 3}}]; \)], "Input"],

Cell[TextData[{
  "The above output should make sense.  We need a loop to produce many such \
pictures.  The command \nDo[ ",
  StyleBox["lines separated by semicolons",
    FontSlant->"Italic"],
  " , {i,1,6}] will execute the lines repeatedly.  The list {i,1,6} is called \
an iterator and directs Do in exactly the same way as it directs Table."
}], "Text"],

Cell[BoxData[
    \(Do[\n\ttemp\  = \ i^2; \n\tPrint[temp]\n, {i, 1, 6}]\)], "Input"],

Cell["\<\
Now, let's use Do to wave the flag by viewing each step and producing the \
matrix for the next step in the sequence.  We use the matrix name A to denote \
the constantly changing matrix that will transform the homoMat2D.  It is just \
a variable, the matrices we designed are initA, the initial value of A, and \
stepA (called rotStep here) that is the change on each step.\
\>", "Text"],

Cell[BoxData[
    \(A\  = \ initA; \n
    Do[\n\tview[A.flag, {{\(-3\), 3}, {0, 3}}]; \n\t
      A\  = \ rotStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["\<\
Now, Select the cell bracket containing all the plots (second from the \
inside) and animate the plots by Ctrl+Y (or from the Cell menu).  While the \
movie is playing, play with the \"play-back controls\" down on the lower bar. \
 Try the \"down v's\" first.  Verbally describe what each button does to your \
instructor.\
\>", "Text"],

Cell["\<\
You should DELETE all of these multiple PLOTS before saving the notebook.  I \
suggest you scroll up to the top movie frame, Select the cell bracket \
containing all the plots (second from the inside) but not the program, then \
Cut (Ctrl-X).  If you are CAREFUL NOT TO DELETE YOUR PROGRAM, you (or I) can \
always recreate them.  Many graphics take up lots of space on the disk and in \
computer memory (RAM) while using the notebook.  If you encounter memory \
problems while saving or running Mma, delete movie frames.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rising spinning pinwheel.", "Subsubsection"],

Cell["p = N[1/Sqrt[2]]", "Input"],

Cell[BoxData[{
    \(\(pinwheelpts
       = {{0, 0}, {0, 1}, {p, p}, {0, 0}, {1, 0}, {p, \(-p\)}, {0, 0}, {0, 
          \(-1\)}, {\(-p\), \(-p\)}, {0, 0}, {\(-1\), 0}, {\(-p\), p}, {0, 
          0}}; \)\), 
    \(pinwheel = 
      Append[\n\t\tTranspose[pinwheelpts], \n\t\t
        Table[1, {Length[pinwheelpts]}]\n\t]\)}], "Input"],

Cell["view[pinwheel,2];", "Input"],

Cell["\<\
Let's rotate the pinwheel.  Of course, you'll want to animate (Ctrl-Y) the \
result of all of these movie frames.\
\>", "Text"],

Cell["rotStep = rotMat[Pi/10]", "Input"],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, 2]; \n\tA\  = \ rotStep.A\n, {i, 1, 10}]; \)], 
  "Input"],

Cell["Let's make it rise straight up.", "Text"],

Cell["upStep = {{1,0,0},{0,1,.2},{0,0,1}}", "Input"],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      A\  = \ upStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["\<\
The real objective of this problem is to make the pinwheel do both \
simultaeously.  Your first idea might be to just multiply by both matrices, \
rot and up, on each step.  But you may be surprised what this does.\
\>", "Text"],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      A\  = \ rotStep.upStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["Why doesn't the pinwheel move straight up?", "Text"],

Cell["\<\
This really is a problem because matrix multiplication is not commutative.  \
Why is the action of matrix upStep.rotStep different than the action of \
matrix rotStep.upStep?\
\>", "Text"],

Cell["\<\
If we want to rise straight up, we really want to do all of the rotations \
first and then all of the ups.  In particular, after two steps the image \
should be accomplished by upStep.upStep.rotStep.rotStep and not by \
upStep.rotStep.upStep.rotStep.  The idea here is to accumulate the net result \
of n rotations in Ar and the net result of n shifts up in Au.  These are both \
variable matrices that have initial values and a change on each step.\
\>", "Text"],

Cell[BoxData[
    \(Ar\  = \ IdentityMatrix[3]; \nAu\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[Au.Ar.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      Ar\  = \ rotStep.Ar; \n\t\(Au\  = \ upStep.Au; \)\n, {i, 1, 10}]; \)], 
  "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assignment -- Part II.", "Subsection"],

Cell["Names?", "Text"],

Cell[CellGroupData[{

Cell["7.  Iteration of one transformation.", "Subsubsection"],

Cell["\<\
Form one transformation matrix that (in one combination move) rotates by \
Pi/6, shrinks the image by 0.8 and then translates the origin to (1,2).  Use \
a Do loop to repeatedly apply (iterate) this transformation 20 times to flag. \
 A good xyRange is {{-5,5},{0,7}}.  Hint:  decide if the one transformation \
matrix described above is the variable A, initA, or stepA.\
\>", "Text"],

Cell["\<\
Repeating this transformation attracts to a fixed point (one that doesn't \
move under the transformation) in very much the same way that the Markov \
chains attracted to a steady-state.\
\>", "Text"]
}, Open  ]],

Cell["\<\
7.  Extra credit:  Use NullSpace to find the fixed point (as in the Markov \
chain project).\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["8.  Tumbling stickman problem", "Subsubsection"],

Cell["\<\
stickmanPts = {{-1,-3},{0,-1},{0,0},{-2,1},{0,0},
   {0,1},{-1,2},{0,3},{1,2},{0,1},{0,0},{2,1},{0,0},
   {0,-1},{1,-3}};
stickman = Append[Transpose[stickmanPts],Table[1,{15}]]\
\>", "Input"],

Cell["view[stickman,4];", "Input"],

Cell["\<\
Your mission is to make this stickman do cartwheels across the screen.  The \
final result should show him starting by standing on the x-axis and tumbling \
across the x-axis floor for two total revolutions.\
\>", "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spirit of 5.2; 2 -- Graphics Transformations -- Solutions
(5.2; 2 alternative focused on compositions & homogeneous coordinates).\
\>", "Section"],

Cell[CellGroupData[{

Cell["\<\
Initializations -- view, rotMat, transMat, scaleMat, and flag.
(These functions are gathered from below)\
\>", "Subsection"],

Cell[BoxData[
    \(Needs["\<Graphics`Colors`\>"]\)], "Input",
  InitializationCell->True],

Cell["\<\
Clear[view]
view[homoMat2D_, xyRange_:Automatic] := 
\tListPlot[ Transpose[ homoMat2D[[{1,2}]] ],
\t\tPlotJoined->True,
\t\tPlotRange->xyRange,
\t\tAspectRatio->Automatic,
\t\tPlotStyle->Blue];
view[homoMat2D_, radius_?NumberQ] :=
   view[homoMat2D, {{-radius,radius},{-radius,radius}} ]\
\>", "Input",
  InitializationCell->True],

Cell[BoxData[
    \(rotMat[\[Theta]_]\  := \ 
      N[{{Cos[\[Theta]], \(-Sin[\[Theta]]\), 0}, {Sin[\[Theta]], 
            Cos[\[Theta]], 0}, {0, 0, 1}}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(transMat[h_, k_]\  := \ N[{{1, 0, h}, {0, 1, k}, {0, 0, 1}}]\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(scaleMat[s_, t_]\  := \ N[\ DiagonalMatrix[{s, t, 1}]\ ]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(flag\  = \ 
      Append[\n\t\tTranspose[{{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}], \n\t\t
        Table[1, {4}]\n\t]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting a matrix of points. -- Start Here", "Subsection"],

Cell[CellGroupData[{

Cell["Using ListPlot and options (including color).", "Subsubsection"],

Cell["\<\
For use in Mma's ListPlot command, points are given by a list of ordered \
pairs.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0"},
            {"0", "2"},
            {"2", 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2]},
            {"0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ListPlot[pts, PlotJoined->True];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.294302 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(1.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02381 .60332 L
.97619 .45617 L
.02381 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=`3oool5000003L0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=`3oool3000000L0oooo001?0?ooo`030000003oool0000000L0oooo00<000000?ooo`00
0000>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000>03oool00`000000oooo0?ooo`070?ooo`00C`3oool00`000000oooo000000090?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool01P3oool004l0oooo00<000000?ooo`0000001`3o
ool2000003/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`800000>P3o
ool00`000000oooo0?ooo`060?ooo`00C`3oool00`000000oooo000000070?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`0000001`3oool00500oooo00<000000?ooo`3oool01P3oool30000
03T0oooo0P00000j0?ooo`800000203oool3000003T0oooo00<000000?ooo`3oool01P3oool00?l0
oooo8@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`003`3ooooo0000014000000@3oool001D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00103oool00`000000oooo000000070?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool0o`3oool90?ooo`00103oool00`000000oooo000000090?ooo`030000003oool0oooo0080
oooo0`00003o0?ooo`T0oooo00040?ooo`030000003oool0000000L0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo2@3oool000@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo2@3oool000D0oooo00<000000?ooo`3oool01P3oool3
000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000
o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool000d0oooo1@0000030?ooo`030000003oool0oooo0?l0oooo2@3oool000l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000?0?ooo`030000003oool0oooo00<0
oooo1000003o0?ooo`P0oooo000?0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo1P00003o0?ooo`80oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool700000?X0oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`0>0?ooo`H00000m03o
ool001D0oooo00<000000?ooo`3oool0503oool700000>d0oooo000E0?ooo`030000003oool0oooo
01/0oooo1P00003W0?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`L00000h03oool001D0oooo
00<000000?ooo`3oool0:03oool600000=X0oooo000E0?ooo`800000;`3oool700000=<0oooo000E
0?ooo`030000003oool0oooo03D0oooo1P00003=0?ooo`005@3oool00`000000oooo0?ooo`0k0?oo
o`H00000a`3oool001D0oooo00<000000?ooo`3oool0@@3oool700000<00oooo000E0?ooo`030000
003oool0oooo04P0oooo1P00002j0?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`L00000/`3o
ool001D0oooo00<000000?ooo`3oool0E@3oool600000:d0oooo000E0?ooo`030000003oool0oooo
05/0oooo1`00002V0?ooo`005@3oool2000006<0oooo1P00002P0?ooo`005@3oool00`000000oooo
0?ooo`1X0?ooo`L00000V@3oool001D0oooo00<000000?ooo`3oool0K`3oool6000009<0oooo000E
0?ooo`030000003oool0oooo07D0oooo1`00002<0?ooo`005@3oool00`000000oooo0?ooo`1l0?oo
o`H00000QP3oool001D0oooo00<000000?ooo`3oool0PP3oool7000007l0oooo000E0?ooo`030000
003oool0oooo08T0oooo1P00001i0?ooo`005@3oool00`000000oooo0?ooo`2?0?ooo`L00000LP3o
ool001D0oooo0P00002G0?ooo`H00000K03oool001D0oooo00<000000?ooo`3oool0W03oool70000
06D0oooo000E0?ooo`030000003oool0oooo0:<0oooo1P00001O0?ooo`005@3oool00`000000oooo
0?ooo`2Y0?ooo`L00000F03oool001D0oooo00<000000?ooo`3oool0/03oool600000580oooo000E
0?ooo`030000003oool0oooo0;H0oooo1`00001;0?ooo`005@3oool00`000000oooo0?ooo`2m0?oo
o`H00000A@3oool001D0oooo00<000000?ooo`3oool0``3oool6000003l0oooo000E0?ooo`800000
bP3oool7000003P0oooo000E0?ooo`030000003oool0oooo0=00oooo1P00000b0?ooo`005@3oool0
0`000000oooo0?ooo`3F0?ooo`L00000:`3oool001D0oooo00<000000?ooo`3oool0g@3oool60000
02D0oooo000E0?ooo`030000003oool0oooo0><0oooo1`00000N0?ooo`005@3oool00`000000oooo
0?ooo`3Z0?ooo`H00000603oool000<0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3`0?ooo`L000004@3oool000D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000040?ooo`030000003oool0oooo0?L0oooo1P00000;
0?ooo`001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0`00003m0?oo
o`@000001`3oool000D0oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3o
ool0m`3oool6000000/0oooo00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3`0?ooo`L000004@3oool000@0oooo0P0000080?ooo`<00000103o
ool00`000000oooo0?ooo`3Z0?ooo`H00000603oool001D0oooo00<000000?ooo`3oool0h`3oool7
000001h0oooo000E0?ooo`030000003oool0oooo0=d0oooo1P00000U0?ooo`005@3oool00`000000
oooo0?ooo`3F0?ooo`L00000:`3oool001D0oooo00<000000?ooo`3oool0d03oool600000380oooo
000E0?ooo`800000bP3oool7000003P0oooo000E0?ooo`030000003oool0oooo0<<0oooo1P00000o
0?ooo`005@3oool00`000000oooo0?ooo`2m0?ooo`H00000A@3oool001D0oooo00<000000?ooo`3o
ool0]P3oool7000004/0oooo000E0?ooo`030000003oool0oooo0;00oooo1P00001B0?ooo`005@3o
ool00`000000oooo0?ooo`2Y0?ooo`L00000F03oool001D0oooo00<000000?ooo`3oool0X`3oool6
000005l0oooo000E0?ooo`030000003oool0oooo09`0oooo1`00001U0?ooo`005@3oool2000009L0
oooo1P00001/0?ooo`005@3oool00`000000oooo0?ooo`2?0?ooo`L00000LP3oool001D0oooo00<0
00000?ooo`3oool0R@3oool6000007T0oooo000E0?ooo`030000003oool0oooo0880oooo1`00001o
0?ooo`005@3oool00`000000oooo0?ooo`1l0?ooo`H00000QP3oool001D0oooo00<000000?ooo`3o
ool0M@3oool7000008`0oooo000E0?ooo`030000003oool0oooo06l0oooo1P00002C0?ooo`005@3o
ool00`000000oooo0?ooo`1X0?ooo`L00000V@3oool001D0oooo0P00001S0?ooo`H00000X03oool0
01D0oooo00<000000?ooo`3oool0F`3oool700000:H0oooo000E0?ooo`030000003oool0oooo05D0
oooo1P00002]0?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`L00000/`3oool001D0oooo00<0
00000?ooo`3oool0B03oool600000;X0oooo000E0?ooo`030000003oool0oooo0440oooo1`000030
0?ooo`005@3oool00`000000oooo0?ooo`0k0?ooo`H00000a`3oool001D0oooo00<000000?ooo`3o
ool0=@3oool600000<d0oooo000E0?ooo`800000;`3oool700000=<0oooo000E0?ooo`030000003o
ool0oooo02P0oooo1P00003J0?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`L00000h03oool0
01D0oooo00<000000?ooo`3oool06`3oool600000>L0oooo000E0?ooo`030000003oool0oooo01@0
oooo1`00003]0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`H00000m03oool000h0oooo0`00
00040?ooo`030000003oool0oooo00L0oooo1`00003j0?ooo`003P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`H00000o`3oool20?ooo`003`3oool00`000000oooo0?ooo`03
0?ooo`@00000o`3oool80?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?l0oooo2@3oool000h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.165971, -0.15494, 
  0.00772359, 0.012497}}]
}, Open  ]],

Cell[TextData[{
  "This image is distorted since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " fits the image into a wide rectangle.  The ratio of width to height is \
called the AspectRatio (with default value around 1.6).  The following option \
requests that box have side lengths proportional to the numerical ranges, so \
the axes end up with the same scale."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[pts, PlotJoined->True,
   AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.2619 .01131 -9 -9 ]
[.2619 .01131 9 0 ]
[.5 .01131 -3 -9 ]
[.5 .01131 3 0 ]
[.7381 .01131 -9 -9 ]
[.7381 .01131 9 0 ]
[.97619 .01131 -3 -9 ]
[.97619 .01131 3 0 ]
[.01131 .2619 -18 -4.5 ]
[.01131 .2619 0 4.5 ]
[.01131 .5 -6 -4.5 ]
[.01131 .5 0 4.5 ]
[.01131 .7381 -18 -4.5 ]
[.01131 .7381 0 4.5 ]
[.01131 .97619 -6 -4.5 ]
[.01131 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .02381 m
.2619 .03006 L
s
[(0.5)] .2619 .01131 0 1 Mshowa
.5 .02381 m
.5 .03006 L
s
[(1)] .5 .01131 0 1 Mshowa
.7381 .02381 m
.7381 .03006 L
s
[(1.5)] .7381 .01131 0 1 Mshowa
.97619 .02381 m
.97619 .03006 L
s
[(2)] .97619 .01131 0 1 Mshowa
.125 Mabswid
.07143 .02381 m
.07143 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.16667 .02381 m
.16667 .02756 L
s
.21429 .02381 m
.21429 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.35714 .02381 m
.35714 .02756 L
s
.40476 .02381 m
.40476 .02756 L
s
.45238 .02381 m
.45238 .02756 L
s
.54762 .02381 m
.54762 .02756 L
s
.59524 .02381 m
.59524 .02756 L
s
.64286 .02381 m
.64286 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.78571 .02381 m
.78571 .02756 L
s
.83333 .02381 m
.83333 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.92857 .02381 m
.92857 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .2619 m
.03006 .2619 L
s
[(0.5)] .01131 .2619 1 0 Mshowa
.02381 .5 m
.03006 .5 L
s
[(1)] .01131 .5 1 0 Mshowa
.02381 .7381 m
.03006 .7381 L
s
[(1.5)] .01131 .7381 1 0 Mshowa
.02381 .97619 m
.03006 .97619 L
s
[(2)] .01131 .97619 1 0 Mshowa
.125 Mabswid
.02381 .07143 m
.02756 .07143 L
s
.02381 .11905 m
.02756 .11905 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .21429 m
.02756 .21429 L
s
.02381 .30952 m
.02756 .30952 L
s
.02381 .35714 m
.02756 .35714 L
s
.02381 .40476 m
.02756 .40476 L
s
.02381 .45238 m
.02756 .45238 L
s
.02381 .54762 m
.02756 .54762 L
s
.02381 .59524 m
.02756 .59524 L
s
.02381 .64286 m
.02756 .64286 L
s
.02381 .69048 m
.02756 .69048 L
s
.02381 .78571 m
.02756 .78571 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .88095 m
.02756 .88095 L
s
.02381 .92857 m
.02756 .92857 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .02381 m
.02381 .97619 L
.97619 .7381 L
.02381 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.375, 249.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000nB000`400?l00000o`00003on@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00AP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool5000002d0oooo1@0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool3000000D0oooo00150?ooo`03
0000003oool0000000L0oooo00<000000?ooo`000000<@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`050?ooo`00
A@3oool00`000000oooo000000090?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
103oool004D0oooo00<000000?ooo`0000001`3oool200000380oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`060?ooo`800000<P3oool00`000000oooo0?ooo`040?ooo`00A@3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`0000001@3oool0
01@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`060?ooo`<00000<03oool20000
0300oooo0P0000080?ooo`<00000<@3oool00`000000oooo0?ooo`040?ooo`00503oool00`000000
oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?oo
o`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?oo
o`003`3ooooZ00000000503oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00@0oooo
000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?oo
o`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000
003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0
oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80
oooo000D0?ooo`800000h`3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<00000
0?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3o
ool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3o
ool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0
oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo0P00
003S0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?oo
o`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503o
ool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`00
0000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo
0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool200000><0oooo000D0?oo
o`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000
003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0
oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80
oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D
0?ooo`030000003oool0oooo0>80oooo000D0?ooo`800000h`3oool001@0oooo00<000000?ooo`3o
ool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3o
ool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0
oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<0
00000?ooo`3oool0hP3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0hP3oool000@0oooo00<000000?oo
o`0000001`3oool00`000000oooo000000030?ooo`030000003oool0oooo0>80oooo00040?ooo`03
0000003oool0000000T0oooo00@000000?ooo`3oool0oooo0`00003R0?ooo`00103oool00`000000
oooo000000070?ooo`800000103oool00`000000oooo0?ooo`3R0?ooo`00103oool00`000000oooo
000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0hP3oool000D0oooo00<0
00000?ooo`3oool01P3oool3000000<0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<00000
0?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3o
ool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3o
ool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0
oooo0P00003S0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?oo
o`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?oo
o`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503o
ool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`00
0000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool200000><0oooo
000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?oo
o`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000
003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0
oooo0>80oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`030000003oool0oooo0>80
oooo000D0?ooo`030000003oool0oooo0>80oooo000D0?ooo`800000h`3oool001@0oooo00<00000
0?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3o
ool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3o
ool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0
oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<0
00000?ooo`3oool0hP3oool001@0oooo0P00003S0?ooo`00503oool00`000000oooo0?ooo`3R0?oo
o`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503o
ool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`00
0000oooo0?ooo`3R0?ooo`00503oool00`000000oooo0?ooo`3R0?ooo`00503oool00`000000oooo
0?ooo`3R0?ooo`003@3oool500000080oooo00<000000?ooo`3oool0hP3oool000l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3R0?ooo`003`3oool00`000000oooo0?ooo`020?oo
o`<00000hP3oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000300000=l0
oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool400000=/0oooo
000>0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`@00000e`3oool001@0oooo00<00000
0?ooo`3oool02`3oool400000=<0oooo000D0?ooo`030000003oool0oooo00l0oooo1000003?0?oo
o`00503oool00`000000oooo0?ooo`0C0?ooo`@00000b`3oool001@0oooo00<000000?ooo`3oool0
5`3oool400000<L0oooo000D0?ooo`030000003oool0oooo01/0oooo100000330?ooo`00503oool0
0`000000oooo0?ooo`0O0?ooo`@00000_`3oool001@0oooo00<000000?ooo`3oool08`3oool40000
0;/0oooo000D0?ooo`030000003oool0oooo02L0oooo1000002g0?ooo`00503oool2000002`0oooo
1000002c0?ooo`00503oool00`000000oooo0?ooo`0_0?ooo`@00000[`3oool001@0oooo00<00000
0?ooo`3oool0<`3oool400000:/0oooo000D0?ooo`030000003oool0oooo03L0oooo1000002W0?oo
o`00503oool00`000000oooo0?ooo`0k0?ooo`@00000X`3oool001@0oooo00<000000?ooo`3oool0
?`3oool4000009l0oooo000D0?ooo`030000003oool0oooo04<0oooo1000002K0?ooo`00503oool0
0`000000oooo0?ooo`170?ooo`@00000U`3oool001@0oooo00<000000?ooo`3oool0B`3oool40000
09<0oooo000D0?ooo`030000003oool0oooo04l0oooo1000002?0?ooo`00503oool00`000000oooo
0?ooo`1C0?ooo`@00000R`3oool001@0oooo0P00001H0?ooo`@00000Q`3oool001@0oooo00<00000
0?ooo`3oool0F`3oool4000008<0oooo000D0?ooo`030000003oool0oooo05l0oooo1000001o0?oo
o`00503oool00`000000oooo0?ooo`1S0?ooo`@00000N`3oool001@0oooo00<000000?ooo`3oool0
I`3oool4000007L0oooo000D0?ooo`030000003oool0oooo06/0oooo0`00001d0?ooo`00503oool0
0`000000oooo0?ooo`1^0?ooo`@00000L03oool001@0oooo00<000000?ooo`3oool0LP3oool40000
06`0oooo000D0?ooo`030000003oool0oooo07H0oooo1000001X0?ooo`00503oool00`000000oooo
0?ooo`1j0?ooo`@00000I03oool001@0oooo00<000000?ooo`3oool0OP3oool400000600oooo000D
0?ooo`800000P`3oool4000005`0oooo000D0?ooo`030000003oool0oooo08H0oooo1000001H0?oo
o`00503oool00`000000oooo0?ooo`2:0?ooo`@00000E03oool001@0oooo00<000000?ooo`3oool0
SP3oool400000500oooo000D0?ooo`030000003oool0oooo0980oooo1000001<0?ooo`00503oool0
0`000000oooo0?ooo`2F0?ooo`@00000B03oool001@0oooo00<000000?ooo`3oool0VP3oool40000
04@0oooo000D0?ooo`030000003oool0oooo09h0oooo100000100?ooo`00503oool00`000000oooo
0?ooo`2R0?ooo`@00000?03oool001@0oooo00<000000?ooo`3oool0YP3oool4000003P0oooo000D
0?ooo`030000003oool0oooo0:X0oooo1000000d0?ooo`00503oool200000:l0oooo1000000`0?oo
o`00503oool00`000000oooo0?ooo`2b0?ooo`@00000;03oool001@0oooo00<000000?ooo`3oool0
]P3oool4000002P0oooo000D0?ooo`030000003oool0oooo0;X0oooo1000000T0?ooo`00503oool0
0`000000oooo0?ooo`2n0?ooo`@00000803oool001@0oooo00<000000?ooo`3oool0`P3oool40000
01`0oooo000D0?ooo`030000003oool0oooo0<H0oooo1000000H0?ooo`00503oool00`000000oooo
0?ooo`3:0?ooo`@00000503oool001@0oooo00<000000?ooo`3oool0cP3oool400000100oooo0003
0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0dP3oool4000000`0oooo00050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`3F0?ooo`@00000203oool000D0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`3oool300000=T0oooo0`0000060?ooo`001@3oool00`000000
oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`3E0?ooo`@000002@3oool000D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=40oooo
1000000=0?ooo`00103oool2000000P0oooo0`0000030?ooo`030000003oool0oooo0<d0oooo1000
000A0?ooo`00503oool00`000000oooo0?ooo`390?ooo`@000005@3oool001@0oooo00<000000?oo
o`3oool0a@3oool4000001T0oooo000D0?ooo`030000003oool0oooo0<40oooo1000000M0?ooo`00
503oool00`000000oooo0?ooo`2m0?ooo`@000008@3oool001@0oooo00<000000?ooo`3oool0^@3o
ool4000002D0oooo000D0?ooo`030000003oool0oooo0;D0oooo1000000Y0?ooo`00503oool00`00
0000oooo0?ooo`2a0?ooo`@00000;@3oool001@0oooo0P00002^0?ooo`@00000<@3oool001@0oooo
00<000000?ooo`3oool0Z@3oool4000003D0oooo000D0?ooo`030000003oool0oooo0:D0oooo1000
000i0?ooo`00503oool00`000000oooo0?ooo`2Q0?ooo`@00000?@3oool001@0oooo00<000000?oo
o`3oool0W@3oool400000440oooo000D0?ooo`030000003oool0oooo09T0oooo100000150?ooo`00
503oool00`000000oooo0?ooo`2E0?ooo`@00000B@3oool001@0oooo00<000000?ooo`3oool0T@3o
ool4000004d0oooo000D0?ooo`030000003oool0oooo08d0oooo1000001A0?ooo`00503oool00`00
0000oooo0?ooo`290?ooo`@00000E@3oool001@0oooo00<000000?ooo`3oool0Q@3oool4000005T0
oooo000D0?ooo`800000PP3oool4000005d0oooo000D0?ooo`030000003oool0oooo07d0oooo1000
001Q0?ooo`00503oool00`000000oooo0?ooo`1i0?ooo`@00000I@3oool001@0oooo00<000000?oo
o`3oool0M@3oool4000006T0oooo000D0?ooo`030000003oool0oooo0740oooo1000001]0?ooo`00
503oool00`000000oooo0?ooo`1]0?ooo`@00000L@3oool001@0oooo00<000000?ooo`3oool0J03o
ool5000007D0oooo000D0?ooo`030000003oool0oooo06@0oooo1000001j0?ooo`00503oool00`00
0000oooo0?ooo`1P0?ooo`@00000OP3oool001@0oooo00<000000?ooo`3oool0G03oool400000880
oooo000D0?ooo`030000003oool0oooo05P0oooo100000260?ooo`00503oool2000005D0oooo1000
002:0?ooo`00503oool00`000000oooo0?ooo`1@0?ooo`@00000SP3oool001@0oooo00<000000?oo
o`3oool0C03oool400000980oooo000D0?ooo`030000003oool0oooo04P0oooo1000002F0?ooo`00
503oool00`000000oooo0?ooo`140?ooo`@00000VP3oool001@0oooo00<000000?ooo`3oool0@03o
ool4000009h0oooo000D0?ooo`030000003oool0oooo03`0oooo1000002R0?ooo`00503oool00`00
0000oooo0?ooo`0h0?ooo`@00000YP3oool001@0oooo00<000000?ooo`3oool0=03oool400000:X0
oooo000D0?ooo`030000003oool0oooo0300oooo1000002^0?ooo`00503oool00`000000oooo0?oo
o`0/0?ooo`@00000/P3oool001@0oooo0P00000Y0?ooo`@00000]P3oool001@0oooo00<000000?oo
o`3oool0903oool400000;X0oooo000D0?ooo`030000003oool0oooo0200oooo1000002n0?ooo`00
503oool00`000000oooo0?ooo`0L0?ooo`@00000`P3oool001@0oooo00<000000?ooo`3oool0603o
ool400000<H0oooo000D0?ooo`030000003oool0oooo01@0oooo1000003:0?ooo`00503oool00`00
0000oooo0?ooo`0@0?ooo`@00000cP3oool001@0oooo00<000000?ooo`3oool0303oool400000=80
oooo000D0?ooo`030000003oool0oooo00P0oooo1000003F0?ooo`003P3oool3000000<0oooo00<0
00000?ooo`3oool0103oool400000=X0oooo000>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01000003N0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<00000hP3oool000l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3R0?ooo`003P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0>80oooo000?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool001@0oooo00<000000?oo
o`3oool0hP3oool001@0oooo00<000000?ooo`3oool0hP3oool00?T0oooo003i0?ooo`00n@3oool0
0?T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 248.375}, {248.375, 0}} -> {-0.188486, -0.147929, 
  0.00901257, 0.00901257}}]
}, Open  ]],

Cell["We may also want to \"manually\" specify the PlotRange.", "Text"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[pts, PlotJoined->True,
   PlotRange->{{-3,3},{0,3}}, AspectRatio->Automatic];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.5 0 m
.5 .33333 L
.83333 .25 L
.5 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`800000S@3o
ool007l0oooo00<000000?ooo`0000001`3oool2000000H0oooo00<000000?ooo`3oool0S03oool0
07l0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08`0oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00280?ooo`D00000
103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<00000R@3oool008X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`@00000Q@3oool008T0oooo0P0000060?ooo`030000
003oool0oooo00L0oooo100000210?ooo`00T@3oool00`000000oooo0?ooo`0;0?ooo`@00000O@3o
ool00940oooo00<000000?ooo`3oool03`3oool4000007T0oooo002A0?ooo`030000003oool0oooo
01<0oooo1000001e0?ooo`00T@3oool00`000000oooo0?ooo`0G0?ooo`@00000L@3oool00940oooo
00<000000?ooo`3oool06`3oool4000006d0oooo002A0?ooo`030000003oool0oooo01l0oooo1000
001Y0?ooo`00T@3oool00`000000oooo0?ooo`0S0?ooo`@00000I@3oool00940oooo00<000000?oo
o`3oool09`3oool400000640oooo002A0?ooo`030000003oool0oooo02/0oooo1000001M0?ooo`00
T@3oool00`000000oooo0?ooo`0_0?ooo`@00000F@3oool00940oooo00<000000?ooo`3oool0<`3o
ool4000005D0oooo002A0?ooo`030000003oool0oooo03L0oooo1000001A0?ooo`00T@3oool00`00
0000oooo0?ooo`0k0?ooo`@00000C@3oool00940oooo00<000000?ooo`3oool0?`3oool4000004T0
oooo002A0?ooo`030000003oool0oooo04<0oooo100000150?ooo`00OP3oool500000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo1000
00110?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0B`3oool4000003d0oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool200000500oooo0`00000j0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`80
00001P3oool00`000000oooo0?ooo`1<0?ooo`@00000?03oool00800oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0oooo100000100?ooo`00O`3o
ool2000000P0oooo0`0000050?ooo`030000003oool0oooo04@0oooo100000140?ooo`00T@3oool0
0`000000oooo0?ooo`100?ooo`@00000B03oool00940oooo00<000000?ooo`3oool0?03oool40000
04`0oooo002A0?ooo`030000003oool0oooo03P0oooo1000001@0?ooo`00T@3oool00`000000oooo
0?ooo`0d0?ooo`@00000E03oool00940oooo00<000000?ooo`3oool0<03oool4000005P0oooo002A
0?ooo`030000003oool0oooo02`0oooo1000001L0?ooo`00T@3oool00`000000oooo0?ooo`0X0?oo
o`@00000H03oool00940oooo00<000000?ooo`3oool0903oool4000006@0oooo002A0?ooo`030000
003oool0oooo0200oooo1000001X0?ooo`00T@3oool00`000000oooo0?ooo`0L0?ooo`@00000K03o
ool00940oooo00<000000?ooo`3oool0603oool400000700oooo002A0?ooo`030000003oool0oooo
01@0oooo1000001d0?ooo`00T@3oool00`000000oooo0?ooo`0@0?ooo`@00000N03oool00940oooo
00<000000?ooo`3oool0303oool4000007`0oooo002A0?ooo`030000003oool0oooo00P0oooo1000
00200?ooo`00R@3oool3000000D0oooo00<000000?ooo`3oool0103oool4000008@0oooo00290?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0100000280?ooo`00RP3oool00`000000
oooo0?ooo`040?ooo`<00000S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2<0?ooo`00R@3oool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool007l0oooo0`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00O`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<0
00000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool007l0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00200?oo
o`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`2B
0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["\<\
Finally, Let's plot in Blue.  WARNING: Before you ever use a color name, you \
must first execute the following Needs command.  If you forget and use the \
name Blue first, then you have to Remove[Blue] before the Needs command to \
correctly define it.  If you are curious of what color names are defined, \
enter AllColors after the Needs command.\
\>", "Text"],

Cell[BoxData[
    \(Needs["\<Graphics`Colors`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[pts, PlotJoined->True,
   PlotRange->{{-3,3},{0,3}}, AspectRatio->Automatic, PlotStyle->Blue];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.5 .33333 L
.83333 .25 L
.5 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo
08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo00200?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
1@3oool00`000?l0oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000090?ooo`030000003o
ool0oooo00<0oooo00<0003o0000003oool0S03oool007l0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<0003o0?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`050?ooo`030000o`3oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0
oooo0`0000050?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`03
0000o`3oool0oooo08`0oooo00280?ooo`D00000103oool00`000?l0oooo0?ooo`2<0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08`0oooo002:0?ooo`030000003oool0
oooo00@0oooo0P000?n=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0003o
00<0003oR@3oool008X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`@0
003oQ@3oool008T0oooo0P0000060?ooo`030000o`3oool0oooo00L0oooo10000?n10?ooo`00T@3o
ool00`000?l0oooo0?ooo`0;0?ooo`@0003oO@3oool00940oooo00<0003o0?ooo`3oool03`3oool4
0000ogT0oooo002A0?ooo`030000o`3oool0oooo01<0oooo10000?me0?ooo`00T@3oool00`000?l0
oooo0?ooo`0G0?ooo`@0003oL@3oool00940oooo00<0003o0?ooo`3oool06`3oool40000ofd0oooo
002A0?ooo`030000o`3oool0oooo01l0oooo10000?mY0?ooo`00T@3oool00`000?l0oooo0?ooo`0S
0?ooo`@0003oI@3oool00940oooo00<0003o0?ooo`3oool09`3oool40000of40oooo002A0?ooo`03
0000o`3oool0oooo02/0oooo10000?mM0?ooo`00T@3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o
F@3oool00940oooo00<0003o0?ooo`3oool0<`3oool40000oeD0oooo002A0?ooo`030000o`3oool0
oooo03L0oooo10000?mA0?ooo`00T@3oool00`000?l0oooo0?ooo`0k0?ooo`@0003oC@3oool00940
oooo00<0003o0?ooo`3oool0?`3oool40000odT0oooo002A0?ooo`030000o`3oool0oooo04<0oooo
10000?m50?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000o`3oool0oooo04L0oooo10000?m10?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000D0oooo00<0003o0?ooo`3oool0B`3oool40000ocd0oooo00200?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000?l000000?ooo`1?0?oo
o`<0003o>P3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<0003o0?ooo`3o
ool0C03oool40000oc`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`180?ooo`@0003o@03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000?l0oooo0?ooo`140?ooo`@0003oA03oool00940oooo00<0003o0?ooo`3oool0@03oool4
0000odP0oooo002A0?ooo`030000o`3oool0oooo03`0oooo10000?m<0?ooo`00T@3oool00`000?l0
oooo0?ooo`0h0?ooo`@0003oD03oool00940oooo00<0003o0?ooo`3oool0=03oool40000oe@0oooo
002A0?ooo`030000o`3oool0oooo0300oooo10000?mH0?ooo`00T@3oool00`000?l0oooo0?ooo`0/
0?ooo`@0003oG03oool00940oooo00<0003o0?ooo`3oool0:03oool40000of00oooo002A0?ooo`03
0000o`3oool0oooo02@0oooo10000?mT0?ooo`00T@3oool00`000?l0oooo0?ooo`0P0?ooo`@0003o
J03oool00940oooo00<0003o0?ooo`3oool0703oool40000of`0oooo002A0?ooo`030000o`3oool0
oooo01P0oooo10000?m`0?ooo`00T@3oool00`000?l0oooo0?ooo`0D0?ooo`@0003oM03oool00940
oooo00<0003o0?ooo`3oool0403oool40000ogP0oooo002A0?ooo`030000o`3oool0oooo00`0oooo
10000?ml0?ooo`00T@3oool00`000?l0oooo0?ooo`080?ooo`@0003oP03oool008T0oooo0`000005
0?ooo`030000o`3oool0oooo00@0oooo10000?n40?ooo`00R@3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0003oR03oool008X0oooo00<000000?ooo`3oool0103oool30000oh`0
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo001o0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0oooo00H0oooo0P00
00060?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?oo
o`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool008/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`800000S@3oool008/0oooo00<000000?ooo`3oool0TP3oool008T0oooo00<000000?oo
o`000000U03oool008X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homogeneous 2D coordinates and a view function.", "Subsubsection"],

Cell["\<\
For use in matrix transformations it is best to store the points in a 3\
\[Times]n matrix, where each point (x, y) is stored in a column with entries \
(x, y, 1).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "2", "0"},
            {"0", "2", 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "1"},
            {"1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
For reference, I'll call any such matrix of points a \"homoMat2D.\"  To plot \
a homoMat2D, we need to ListPlot the Transpose of the first two rows and use \
all of the options developed above.  We can define such a function once and \
for all.\
\>", "Text"],

Cell["\<\
Clear[view]
view[homoMat2D_, xyRange_:Automatic] := 
\tListPlot[ Transpose[ homoMat2D[[{1,2}]] ],
\t\tPlotJoined->True,
\t\tPlotRange->xyRange,
\t\tAspectRatio->Automatic,
\t\tPlotStyle->Blue
\t];
\t\t
view[homoMat2D_, radius_?NumberQ] :=
   view[homoMat2D, {{-radius,radius},{-radius,radius}} ]\
\>", "Input"],

Cell["\<\
view has three options for the second argument as displayed below.  Usually, \
you want to pick some xyRange, as in the first example, and stick with it \
throughout transformations so that you can correctly compare before and after \
transformation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.5 .33333 L
.83333 .25 L
.5 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo
08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo00200?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
1@3oool00`000?l0oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000090?ooo`030000003o
ool0oooo00<0oooo00<0003o0000003oool0S03oool007l0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<0003o0?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`050?ooo`030000o`3oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0
oooo0`0000050?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`03
0000o`3oool0oooo08`0oooo00280?ooo`D00000103oool00`000?l0oooo0?ooo`2<0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08`0oooo002:0?ooo`030000003oool0
oooo00@0oooo0P000?n=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0003o
00<0003oR@3oool008X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`@0
003oQ@3oool008T0oooo0P0000060?ooo`030000o`3oool0oooo00L0oooo10000?n10?ooo`00T@3o
ool00`000?l0oooo0?ooo`0;0?ooo`@0003oO@3oool00940oooo00<0003o0?ooo`3oool03`3oool4
0000ogT0oooo002A0?ooo`030000o`3oool0oooo01<0oooo10000?me0?ooo`00T@3oool00`000?l0
oooo0?ooo`0G0?ooo`@0003oL@3oool00940oooo00<0003o0?ooo`3oool06`3oool40000ofd0oooo
002A0?ooo`030000o`3oool0oooo01l0oooo10000?mY0?ooo`00T@3oool00`000?l0oooo0?ooo`0S
0?ooo`@0003oI@3oool00940oooo00<0003o0?ooo`3oool09`3oool40000of40oooo002A0?ooo`03
0000o`3oool0oooo02/0oooo10000?mM0?ooo`00T@3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o
F@3oool00940oooo00<0003o0?ooo`3oool0<`3oool40000oeD0oooo002A0?ooo`030000o`3oool0
oooo03L0oooo10000?mA0?ooo`00T@3oool00`000?l0oooo0?ooo`0k0?ooo`@0003oC@3oool00940
oooo00<0003o0?ooo`3oool0?`3oool40000odT0oooo002A0?ooo`030000o`3oool0oooo04<0oooo
10000?m50?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000o`3oool0oooo04L0oooo10000?m10?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000D0oooo00<0003o0?ooo`3oool0B`3oool40000ocd0oooo00200?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000?l000000?ooo`1?0?oo
o`<0003o>P3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<0003o0?ooo`3o
ool0C03oool40000oc`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`180?ooo`@0003o@03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000?l0oooo0?ooo`140?ooo`@0003oA03oool00940oooo00<0003o0?ooo`3oool0@03oool4
0000odP0oooo002A0?ooo`030000o`3oool0oooo03`0oooo10000?m<0?ooo`00T@3oool00`000?l0
oooo0?ooo`0h0?ooo`@0003oD03oool00940oooo00<0003o0?ooo`3oool0=03oool40000oe@0oooo
002A0?ooo`030000o`3oool0oooo0300oooo10000?mH0?ooo`00T@3oool00`000?l0oooo0?ooo`0/
0?ooo`@0003oG03oool00940oooo00<0003o0?ooo`3oool0:03oool40000of00oooo002A0?ooo`03
0000o`3oool0oooo02@0oooo10000?mT0?ooo`00T@3oool00`000?l0oooo0?ooo`0P0?ooo`@0003o
J03oool00940oooo00<0003o0?ooo`3oool0703oool40000of`0oooo002A0?ooo`030000o`3oool0
oooo01P0oooo10000?m`0?ooo`00T@3oool00`000?l0oooo0?ooo`0D0?ooo`@0003oM03oool00940
oooo00<0003o0?ooo`3oool0403oool40000ogP0oooo002A0?ooo`030000o`3oool0oooo00`0oooo
10000?ml0?ooo`00T@3oool00`000?l0oooo0?ooo`080?ooo`@0003oP03oool008T0oooo0`000005
0?ooo`030000o`3oool0oooo00@0oooo10000?n40?ooo`00R@3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0003oR03oool008X0oooo00<000000?ooo`3oool0103oool30000oh`0
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo001o0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0oooo00H0oooo0P00
00060?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?oo
o`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool008/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`800000S@3oool008/0oooo00<000000?ooo`3oool0TP3oool008T0oooo00<000000?oo
o`000000U03oool008X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[flag, \ 2]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 .5 m
.5 1 L
1 .875 L
.5 .75 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool0103o
ool2000008d0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool0S03oool007X0oooo0`0000020?ooo`030000003oool0000000T0oooo00<0
00000?ooo`3oool00`3oool2000008d0oooo001o0?ooo`030000003oool0000000L0oooo0P000006
0?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`<0
00001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool20000
08d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000
S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
1`3oool3000001T0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6@3oool5000001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06@3oool5000001P0oooo1@0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06P3oool3000000<0oooo00070?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000L0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000L0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000K0?ooo`030000003o
ool0oooo00<0oooo00020?ooo`<000000`3oool00`000000oooo0?ooo`0D0?ooo`<000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`030000003oool0
oooo01D0oooo0`0000020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo0P00000M0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool20000
01/0oooo00<000000?ooo`3oool06@3oool00`000000oooo000000070?ooo`8000007@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003oool0oooo
0080oooo00070?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`0J0?ooo`8000006P3oool00`000000oooo000000070?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`0000000`3oool000P0oooo00<000000?ooo`3oool06@3oool2000000P0oooo
0`00000K0?ooo`8000007@3oool00`000000oooo0?ooo`060?ooo`<000006P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0`00000K0?ooo`8000006`3oool2000000P0oooo
0`00000L0?ooo`030000003oool0oooo0080oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00060?oooh/0000000<0
003o000000000000R@0000030?ooo`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0040oooo00060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`010?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo
0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<
0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00
T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool0
0`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0
oooo0?ooo`2<0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?oo
o`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?oo
o`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3o
ool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`00
0?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo
0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<
0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00
T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool0
0`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00P03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo
00<0003o0?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?oo
o`030?ooo`030000o`000000oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo0P000006
0?ooo`030000o`3oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`<0
00001@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3o
ool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`00
0?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo
0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<
0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00
T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool0
0`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0
oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?oo
o`2<0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?oo
o`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3o
ool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`00
0?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo
0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<
0?ooo`00R03oool5000000@0oooo00<0003o0?ooo`3oool0S03oool008X0oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`80003o
S@3oool008X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0000o`030000ohT0oooo002:
0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool40000ohD0oooo00290?oo
o`8000001P3oool00`000?l0oooo0?ooo`070?ooo`@0003oP@3oool00940oooo00<0003o0?ooo`3o
ool02`3oool40000ogd0oooo002A0?ooo`030000o`3oool0oooo00l0oooo10000?mi0?ooo`00T@3o
ool00`000?l0oooo0?ooo`0C0?ooo`@0003oM@3oool00940oooo00<0003o0000003oool05`3oool4
0000og40oooo002A0?ooo`030000o`3oool0oooo01/0oooo10000?m]0?ooo`00T@3oool00`000?l0
oooo0?ooo`0O0?ooo`@0003oJ@3oool00940oooo00<0003o0?ooo`3oool08`3oool40000ofD0oooo
002A0?ooo`030000o`3oool0oooo02L0oooo10000?mQ0?ooo`00T@3oool00`000?l0oooo0?ooo`0[
0?ooo`@0003oG@3oool00940oooo00<0003o0?ooo`3oool0;`3oool40000oeT0oooo002A0?ooo`03
0000o`000000oooo03<0oooo10000?mE0?ooo`00T@3oool00`000?l0oooo0?ooo`0g0?ooo`@0003o
D@3oool00940oooo00<0003o0?ooo`3oool0>`3oool40000odd0oooo002A0?ooo`030000o`3oool0
oooo03l0oooo10000?m90?ooo`00T@3oool00`000?l0oooo0?ooo`130?ooo`@0003oA@3oool00940
oooo00<0003o0?ooo`3oool0A`3oool40000od40oooo002A0?ooo`030000o`3oool0oooo04/0oooo
10000?lm0?ooo`00T@3oool00`000?l000000?ooo`1?0?ooo`@0003o>@3oool00940oooo00<0003o
0?ooo`3oool0D`3oool40000ocD0oooo002A0?ooo`030000o`3oool0oooo05L0oooo10000?la0?oo
o`00T@3oool00`000?l0oooo0?ooo`1K0?ooo`@0003o;@3oool00940oooo00<0003o0?ooo`3oool0
G`3oool40000obT0oooo002A0?ooo`030000o`3oool0oooo06<0oooo10000?lU0?ooo`00T@3oool0
0`000?l0oooo0?ooo`1W0?ooo`@0003o8@3oool00940oooo00<0003o0000003oool0J`3oool40000
oad0oooo002A0?ooo`030000o`3oool0oooo06l0oooo10000?lI0?ooo`00T@3oool00`000?l0oooo
0?ooo`1c0?ooo`@0003o5@3oool00940oooo00<0003o0?ooo`3oool0M`3oool40000oa40oooo002A
0?ooo`030000o`3oool0oooo07/0oooo10000?l=0?ooo`00OP3oool500000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo07l0oooo10000?l90?oo
o`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<0003o0?ooo`3o
ool0P`3oool40000o`D0oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000?l000000?ooo`270?ooo`80003o0`3oool00800oooo00<000000?ooo`3oool01P3o
ool2000000H0oooo00<0003o0?ooo`3oool0P`3oool40000o`D0oooo00200?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1o0?ooo`@0003o2@3oool0
07l0oooo0P0000080?ooo`<000001@3oool00`000?l0oooo0?ooo`1k0?ooo`@0003o3@3oool00940
oooo00<0003o0?ooo`3oool0M`3oool40000oa40oooo002A0?ooo`030000o`3oool0oooo07<0oooo
10000?lE0?ooo`00T@3oool00`000?l0oooo0?ooo`1_0?ooo`@0003o6@3oool00940oooo00<0003o
0000003oool0J`3oool40000oad0oooo002A0?ooo`030000o`3oool0oooo06L0oooo10000?lQ0?oo
o`00T@3oool00`000?l0oooo0?ooo`1S0?ooo`@0003o9@3oool00940oooo00<0003o0?ooo`3oool0
G`3oool40000obT0oooo002A0?ooo`030000o`3oool0oooo05/0oooo10000?l]0?ooo`00T@3oool0
0`000?l0oooo0?ooo`1G0?ooo`@0003o<@3oool00940oooo00<0003o0?ooo`3oool0D`3oool40000
ocD0oooo002A0?ooo`030000o`000000oooo04l0oooo10000?li0?ooo`00T@3oool00`000?l0oooo
0?ooo`1;0?ooo`@0003o?@3oool00940oooo00<0003o0?ooo`3oool0A`3oool40000od40oooo002A
0?ooo`030000o`3oool0oooo04<0oooo10000?m50?ooo`00T@3oool00`000?l0oooo0?ooo`0o0?oo
o`@0003oB@3oool00940oooo00<0003o0?ooo`3oool0>`3oool40000odd0oooo002A0?ooo`030000
o`3oool0oooo03L0oooo10000?mA0?ooo`00T@3oool00`000?l000000?ooo`0c0?ooo`@0003oE@3o
ool00940oooo00<0003o0?ooo`3oool0;`3oool40000oeT0oooo002A0?ooo`030000o`3oool0oooo
02/0oooo10000?mM0?ooo`00T@3oool00`000?l0oooo0?ooo`0W0?ooo`@0003oH@3oool00940oooo
00<0003o0?ooo`3oool08`3oool40000ofD0oooo002A0?ooo`030000o`3oool0oooo01l0oooo1000
0?mY0?ooo`00T@3oool00`000?l0oooo0?ooo`0K0?ooo`@0003oK@3oool00940oooo00<0003o0000
003oool05`3oool40000og40oooo002A0?ooo`030000o`3oool0oooo01<0oooo10000?me0?ooo`00
T@3oool00`000?l0oooo0?ooo`0?0?ooo`@0003oN@3oool00940oooo00<0003o0?ooo`3oool02`3o
ool40000ogd0oooo002A0?ooo`030000o`3oool0oooo00L0oooo10000?n10?ooo`00R@3oool30000
00D0oooo00<0003o0?ooo`3oool00`3oool40000ohD0oooo00290?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`000?l00`000?n90?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`80003o
S@3oool008X0oooo00<000000?ooo`3oool0T`3oool008T0oooo00<000000?ooo`000000U03oool0
08X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[flag]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.2619 .01131 -9 -9 ]
[.2619 .01131 9 0 ]
[.5 .01131 -3 -9 ]
[.5 .01131 3 0 ]
[.7381 .01131 -9 -9 ]
[.7381 .01131 9 0 ]
[.97619 .01131 -3 -9 ]
[.97619 .01131 3 0 ]
[.01131 .2619 -18 -4.5 ]
[.01131 .2619 0 4.5 ]
[.01131 .5 -6 -4.5 ]
[.01131 .5 0 4.5 ]
[.01131 .7381 -18 -4.5 ]
[.01131 .7381 0 4.5 ]
[.01131 .97619 -6 -4.5 ]
[.01131 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .02381 m
.2619 .03006 L
s
[(0.5)] .2619 .01131 0 1 Mshowa
.5 .02381 m
.5 .03006 L
s
[(1)] .5 .01131 0 1 Mshowa
.7381 .02381 m
.7381 .03006 L
s
[(1.5)] .7381 .01131 0 1 Mshowa
.97619 .02381 m
.97619 .03006 L
s
[(2)] .97619 .01131 0 1 Mshowa
.125 Mabswid
.07143 .02381 m
.07143 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.16667 .02381 m
.16667 .02756 L
s
.21429 .02381 m
.21429 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.35714 .02381 m
.35714 .02756 L
s
.40476 .02381 m
.40476 .02756 L
s
.45238 .02381 m
.45238 .02756 L
s
.54762 .02381 m
.54762 .02756 L
s
.59524 .02381 m
.59524 .02756 L
s
.64286 .02381 m
.64286 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.78571 .02381 m
.78571 .02756 L
s
.83333 .02381 m
.83333 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.92857 .02381 m
.92857 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .2619 m
.03006 .2619 L
s
[(0.5)] .01131 .2619 1 0 Mshowa
.02381 .5 m
.03006 .5 L
s
[(1)] .01131 .5 1 0 Mshowa
.02381 .7381 m
.03006 .7381 L
s
[(1.5)] .01131 .7381 1 0 Mshowa
.02381 .97619 m
.03006 .97619 L
s
[(2)] .01131 .97619 1 0 Mshowa
.125 Mabswid
.02381 .07143 m
.02756 .07143 L
s
.02381 .11905 m
.02756 .11905 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .21429 m
.02756 .21429 L
s
.02381 .30952 m
.02756 .30952 L
s
.02381 .35714 m
.02756 .35714 L
s
.02381 .40476 m
.02756 .40476 L
s
.02381 .45238 m
.02756 .45238 L
s
.02381 .54762 m
.02756 .54762 L
s
.02381 .59524 m
.02756 .59524 L
s
.02381 .64286 m
.02756 .64286 L
s
.02381 .69048 m
.02756 .69048 L
s
.02381 .78571 m
.02756 .78571 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .88095 m
.02756 .88095 L
s
.02381 .92857 m
.02756 .92857 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .02381 m
.02381 .97619 L
.97619 .7381 L
.02381 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=`3oool5000003L0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>03oool3000000H0oooo001?0?ooo`030000003oool0000000L0oooo00<000000?ooo`00
0000>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000>@3oool00`000000oooo0?ooo`060?ooo`00C`3oool00`000000oooo000000090?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool004l0oooo00<000000?ooo`0000001`3o
ool2000003/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`800000>`3o
ool00`000000oooo0?ooo`050?ooo`00C`3oool00`000000oooo000000070?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`0000001P3oool001D0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`060?ooo`<00000>@3oool2000003X0oooo0P0000080?ooo`<00000>P3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000h0
oooo1`0000000`000?l000000000003o000000T00000000E0?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000?l0oooo0?oo
o`0n0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0000003oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l00000
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`000000oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0000003oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo00050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
00@0oooo00<000000?ooo`0000001`3oool00`000000oooo000000040?ooo`030000o`3oool0oooo
0?l0oooo2@3oool000@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`03
0000o`00000000000?l0oooo2@3oool000@0oooo00<000000?ooo`0000001`3oool2000000D0oooo
00<0003o0?ooo`3oool0o`3oool90?ooo`00103oool00`000000oooo000000070?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`001@3oool00`000000oooo0?ooo`06
0?ooo`<00000103oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`000000oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0000003oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l000000?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo
0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`000000oooo0?l0oooo2@3oool001D0oooo00<0003o
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`03
0000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000?l0oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool0
01D0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`005@3oool00`000?l0oooo0?ooo`3o0?ooo`T0
oooo000E0?ooo`030000o`3oool0oooo0?l0oooo2@3oool001D0oooo00<0003o0?ooo`3oool0o`3o
ool90?ooo`003@3oool5000000<0oooo00<0003o0?ooo`3oool0o`3oool90?ooo`003`3oool00`00
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0?l0oooo2@3oool000l0oooo00<000000?ooo`3o
ool00`3oool20000o`030000003oool0oooo0?l0oooo1`3oool000l0oooo00<000000?ooo`3oool0
0`3oool00`000?l0oooo0000o`030000ool0oooo1P3oool000l0oooo00<000000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`@0003oo`3oool20?ooo`003P3oool2000000D0oooo00<0003o
0?ooo`3oool01`3oool40000ood0oooo000E0?ooo`030000o`3oool0oooo00/0oooo10000?oi0?oo
o`005@3oool00`000?l0oooo0?ooo`0?0?ooo`@0003om@3oool001D0oooo00<0003o0?ooo`3oool0
4`3oool40000oo40oooo000E0?ooo`030000o`3oool0oooo01L0oooo10000?o]0?ooo`005@3oool0
0`000?l0oooo0?ooo`0K0?ooo`@0003oj@3oool001D0oooo00<0003o0?ooo`3oool07`3oool40000
onD0oooo000E0?ooo`030000o`3oool0oooo02<0oooo10000?oQ0?ooo`005@3oool00`000?l0oooo
0?ooo`0W0?ooo`@0003og@3oool001D0oooo00<0003o0?ooo`3oool0:`3oool40000omT0oooo000E
0?ooo`030000o`000000oooo02l0oooo10000?oE0?ooo`005@3oool00`000?l0oooo0?ooo`0c0?oo
o`@0003od@3oool001D0oooo00<0003o0?ooo`3oool0=`3oool40000old0oooo000E0?ooo`030000
o`3oool0oooo03/0oooo10000?o90?ooo`005@3oool00`000?l0oooo0?ooo`0o0?ooo`@0003oa@3o
ool001D0oooo00<0003o0?ooo`3oool0@`3oool40000ol40oooo000E0?ooo`030000o`3oool0oooo
04L0oooo10000?nm0?ooo`005@3oool00`000?l0oooo0?ooo`1;0?ooo`@0003o^@3oool001D0oooo
00<0003o0?ooo`3oool0C`3oool40000okD0oooo000E0?ooo`030000o`3oool0oooo05<0oooo1000
0?na0?ooo`005@3oool00`000?l0oooo0?ooo`1G0?ooo`@0003o[@3oool001D0oooo00<0003o0?oo
o`3oool0F`3oool40000ojT0oooo000E0?ooo`030000o`3oool0oooo05l0oooo10000?nU0?ooo`00
5@3oool00`000?l000000?ooo`1S0?ooo`@0003oX@3oool001D0oooo00<0003o0?ooo`3oool0I`3o
ool40000oid0oooo000E0?ooo`030000o`3oool0oooo06/0oooo10000?nI0?ooo`005@3oool00`00
0?l0oooo0?ooo`1_0?ooo`@0003oU@3oool001D0oooo00<0003o0?ooo`3oool0L`3oool40000oi40
oooo000E0?ooo`030000o`3oool0oooo07L0oooo10000?n=0?ooo`005@3oool00`000?l0oooo0?oo
o`1k0?ooo`@0003oR@3oool001D0oooo00<0003o0?ooo`3oool0O`3oool40000ohD0oooo000E0?oo
o`030000o`3oool0oooo08<0oooo10000?n10?ooo`005@3oool00`000?l0oooo0?ooo`270?ooo`@0
003oO@3oool001D0oooo00<0003o0?ooo`3oool0R`3oool40000ogT0oooo000E0?ooo`030000o`3o
ool0oooo08l0oooo10000?me0?ooo`005@3oool00`000?l0oooo0?ooo`2C0?ooo`@0003oL@3oool0
01D0oooo00<0003o0000003oool0U`3oool40000ofd0oooo000E0?ooo`030000o`3oool0oooo09/0
oooo10000?mY0?ooo`005@3oool00`000?l0oooo0?ooo`2O0?ooo`@0003oI@3oool001D0oooo00<0
003o0?ooo`3oool0X`3oool40000of40oooo000E0?ooo`030000o`3oool0oooo0:L0oooo10000?mM
0?ooo`005@3oool00`000?l0oooo0?ooo`2[0?ooo`@0003oF@3oool001D0oooo00<0003o0?ooo`3o
ool0[`3oool40000oeD0oooo000E0?ooo`030000o`3oool0oooo0;<0oooo10000?mA0?ooo`005@3o
ool00`000?l0oooo0?ooo`2g0?ooo`@0003oC@3oool001D0oooo00<0003o0?ooo`3oool0^`3oool4
0000odT0oooo000E0?ooo`030000o`3oool0oooo0;l0oooo10000?m50?ooo`005@3oool00`000?l0
oooo0?ooo`330?ooo`@0003o@@3oool001D0oooo00<0003o0?ooo`3oool0a`3oool40000ocd0oooo
000E0?ooo`030000o`000000oooo0</0oooo10000?li0?ooo`005@3oool00`000?l0oooo0?ooo`3?
0?ooo`@0003o=@3oool001D0oooo00<0003o0?ooo`3oool0d`3oool40000oc40oooo000E0?ooo`03
0000o`3oool0oooo0=L0oooo10000?l]0?ooo`005@3oool00`000?l0oooo0?ooo`3K0?ooo`@0003o
:@3oool001D0oooo00<0003o0?ooo`3oool0g`3oool40000obD0oooo000E0?ooo`030000o`3oool0
oooo0><0oooo10000?lQ0?ooo`005@3oool00`000?l0oooo0?ooo`3W0?ooo`@0003o7@3oool001D0
oooo00<0003o0?ooo`3oool0j`3oool40000oaT0oooo000E0?ooo`030000o`3oool0oooo0>l0oooo
10000?lE0?ooo`005@3oool00`000?l0oooo0?ooo`3c0?ooo`@0003o4@3oool000<0oooo1@000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`3g
0?ooo`@0003o3@3oool000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?oo
o`030000o`3oool0oooo0?/0oooo10000?l90?ooo`001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<0003o000000000000o`3oool20000o`L0oooo00050?ooo`030000
003oool0oooo00H0oooo0P0000050?ooo`030000o`3oool0oooo0?/0oooo10000?l90?ooo`001@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0m`3o
ool40000o`d0oooo00040?ooo`800000203oool3000000@0oooo00<0003o0?ooo`3oool0l`3oool4
0000oa40oooo000E0?ooo`030000o`3oool0oooo0>l0oooo10000?lE0?ooo`005@3oool00`000?l0
oooo0?ooo`3[0?ooo`@0003o6@3oool001D0oooo00<0003o0?ooo`3oool0i`3oool40000oad0oooo
000E0?ooo`030000o`3oool0oooo0><0oooo10000?lQ0?ooo`005@3oool00`000?l0oooo0?ooo`3O
0?ooo`@0003o9@3oool001D0oooo00<0003o0?ooo`3oool0f`3oool40000obT0oooo000E0?ooo`03
0000o`3oool0oooo0=L0oooo10000?l]0?ooo`005@3oool00`000?l0oooo0?ooo`3C0?ooo`@0003o
<@3oool001D0oooo00<0003o0?ooo`3oool0c`3oool40000ocD0oooo000E0?ooo`030000o`000000
oooo0</0oooo10000?li0?ooo`005@3oool00`000?l0oooo0?ooo`370?ooo`@0003o?@3oool001D0
oooo00<0003o0?ooo`3oool0``3oool40000od40oooo000E0?ooo`030000o`3oool0oooo0;l0oooo
10000?m50?ooo`005@3oool00`000?l0oooo0?ooo`2k0?ooo`@0003oB@3oool001D0oooo00<0003o
0?ooo`3oool0]`3oool40000odd0oooo000E0?ooo`030000o`3oool0oooo0;<0oooo10000?mA0?oo
o`005@3oool00`000?l0oooo0?ooo`2_0?ooo`@0003oE@3oool001D0oooo00<0003o0?ooo`3oool0
Z`3oool40000oeT0oooo000E0?ooo`030000o`3oool0oooo0:L0oooo10000?mM0?ooo`005@3oool0
0`000?l0oooo0?ooo`2S0?ooo`@0003oH@3oool001D0oooo00<0003o0?ooo`3oool0W`3oool40000
ofD0oooo000E0?ooo`030000o`3oool0oooo09/0oooo10000?mY0?ooo`005@3oool00`000?l00000
0?ooo`2G0?ooo`@0003oK@3oool001D0oooo00<0003o0?ooo`3oool0T`3oool40000og40oooo000E
0?ooo`030000o`3oool0oooo08l0oooo10000?me0?ooo`005@3oool00`000?l0oooo0?ooo`2;0?oo
o`@0003oN@3oool001D0oooo00<0003o0?ooo`3oool0Q`3oool40000ogd0oooo000E0?ooo`030000
o`3oool0oooo08<0oooo10000?n10?ooo`005@3oool00`000?l0oooo0?ooo`1o0?ooo`@0003oQ@3o
ool001D0oooo00<0003o0?ooo`3oool0N`3oool40000ohT0oooo000E0?ooo`030000o`3oool0oooo
07L0oooo10000?n=0?ooo`005@3oool00`000?l0oooo0?ooo`1c0?ooo`@0003oT@3oool001D0oooo
00<0003o0?ooo`3oool0K`3oool40000oiD0oooo000E0?ooo`030000o`3oool0oooo06/0oooo1000
0?nI0?ooo`005@3oool00`000?l0oooo0?ooo`1W0?ooo`@0003oW@3oool001D0oooo00<0003o0000
003oool0H`3oool40000oj40oooo000E0?ooo`030000o`3oool0oooo05l0oooo10000?nU0?ooo`00
5@3oool00`000?l0oooo0?ooo`1K0?ooo`@0003oZ@3oool001D0oooo00<0003o0?ooo`3oool0E`3o
ool40000ojd0oooo000E0?ooo`030000o`3oool0oooo05<0oooo10000?na0?ooo`005@3oool00`00
0?l0oooo0?ooo`1?0?ooo`@0003o]@3oool001D0oooo00<0003o0?ooo`3oool0B`3oool40000okT0
oooo000E0?ooo`030000o`3oool0oooo04L0oooo10000?nm0?ooo`005@3oool00`000?l0oooo0?oo
o`130?ooo`@0003o`@3oool001D0oooo00<0003o0?ooo`3oool0?`3oool40000olD0oooo000E0?oo
o`030000o`3oool0oooo03/0oooo10000?o90?ooo`005@3oool00`000?l0oooo0?ooo`0g0?ooo`@0
003oc@3oool001D0oooo00<0003o0?ooo`3oool0<`3oool40000om40oooo000E0?ooo`030000o`00
0000oooo02l0oooo10000?oE0?ooo`005@3oool00`000?l0oooo0?ooo`0[0?ooo`@0003of@3oool0
01D0oooo00<0003o0?ooo`3oool09`3oool40000omd0oooo000E0?ooo`030000o`3oool0oooo02<0
oooo10000?oQ0?ooo`005@3oool00`000?l0oooo0?ooo`0O0?ooo`@0003oi@3oool001D0oooo00<0
003o0?ooo`3oool06`3oool40000onT0oooo000E0?ooo`030000o`3oool0oooo01L0oooo10000?o]
0?ooo`005@3oool00`000?l0oooo0?ooo`0C0?ooo`@0003ol@3oool001D0oooo00<0003o0?ooo`3o
ool03`3oool40000ooD0oooo000E0?ooo`030000o`3oool0oooo00/0oooo10000?oi0?ooo`005@3o
ool00`000?l0oooo0?ooo`070?ooo`@0003oo@3oool000h0oooo0`0000040?ooo`030000o`3oool0
oooo00<0oooo10000?oo0?ooo`80oooo000>0?ooo`030000003oool0oooo00@0oooo00<0003o0?oo
o`000?l00`000?oo0?ooo`H0oooo000?0?ooo`030000003oool0oooo00<0oooo0P000?l00`000000
oooo0?ooo`3o0?ooo`L0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3oool90?ooo`003P3oool00`000000oooo000000040?ooo`030000003oool0oooo0?l0oooo2@3o
ool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.165192, -0.130459, 0.00771848,
   0.00771848}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Transformations", "Subsection"],

Cell["\<\
To perform any linear transformation T on all the points in a homoMat2D, use \
a 3\[Times]3 matrix that includes the standard 2\[Times]2 matrix of the \
transformation in the upper left and a one in the lower right (zeros \
elsewhere).  Here is a function that returns the rotation matrix.  The N \
makes computation with such a matrix more efficient.\
\>", "Text"],

Cell[BoxData[
    \(rotMat[\[Theta]_]\  := \ 
      N[{{Cos[\[Theta]], \(-Sin[\[Theta]]\), 0}, {Sin[\[Theta]], 
            Cos[\[Theta]], 0}, {0, 0, 1}}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ar\  = \ rotMat[Pi/4]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.707106781186547461`", \(-0.707106781186547461`\), "0"},
            {"0.707106781186547461`", "0.707106781186547461`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ review\ of\ homoMat2D\ construction\ *) \n
    pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}; \n
    flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "2", "0"},
            {"0", "2", 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "1"},
            {"1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ar.flag\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.`", \(-1.41421356237309492`\), "0.35355339059327373`", 
              \(-0.707106781186547461`\)},
           
             {"0.`", "1.41421356237309492`", "2.47487373415291589`", 
              "0.707106781186547461`"},
            {"1.`", "1.`", "1.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Notice how Ar multiples the x,y coordinates by the upper left 2\[Times]2 and \
leaves the \"3rd coordinate\" as one.  This 3rd coordinate has no purpose \
yet.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[Ar.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.2643 .2357 L
.55893 .41248 L
.38215 .11785 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000o`00
0000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002?0?ooo`030000o`3oool0000008h0oooo002>0?ooo`040000o`3oool0oooo
000008h0oooo002=0?ooo`050000o`3oool0oooo0?ooo`000000SP3oool008`0oooo00<0003o0?oo
o`3oool00P3oool00`000000oooo0?ooo`2<0?ooo`00R`3oool00`000?l0oooo0?ooo`030?ooo`03
0000003oool0oooo08`0oooo002:0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0
S03oool008T0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool0
0`000?l0oooo0?ooo`060?ooo`030000003oool0oooo08`0oooo00270?ooo`030000o`3oool0oooo
00L0oooo00<000000?ooo`3oool0S03oool008H0oooo00<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`2<0?ooo`00Q@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo08`0oooo
00240?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0S03oool008<0oooo00<0003o
0?ooo`3oool02`3oool00`000000oooo0?ooo`2<0?ooo`00PP3oool00`000?l0oooo0?ooo`0<0?oo
o`030000003oool0oooo08`0oooo00210?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3o
ool0S03oool00800oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`2<0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo08`0oooo001n0?ooo`030000o`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08`0oooo001m0?ooo`050000o`3oool000000?ooo`0000001`3oool00`000000oooo00000005
0?ooo`030000003oool0oooo08`0oooo001l0?ooo`060000o`3oool0oooo0000003oool000002@3o
ool00`000000oooo0?ooo`030?ooo`800000S@3oool007/0oooo00L0003o0?ooo`3oool0oooo0000
003oool0000000L0oooo0P0000060?ooo`030000003oool0oooo08`0oooo001j0?ooo`030000o`3o
ool0oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo08`0oooo001i0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool01P3oool3
000000D0oooo00<000000?ooo`3oool0S03oool007P0oooo00<0003o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`2<0?ooo`00M`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo08`0
oooo001f0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0S03oool007D0oooo00<0
003o0?ooo`3oool06@3oool00`000000oooo0?ooo`2<0?ooo`00L`3oool20000oa`0oooo00<00000
0?ooo`3oool0S03oool00780oooo0`000?lL0?ooo`030000003oool0oooo08`0oooo001a0?ooo`04
0000o`3oool0oooo0000oa`0oooo00<000000?ooo`3oool0S03oool00700oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo08`0oooo001_0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`2<0?ooo`00KP3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0S03o
ool006d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0
oooo08`0oooo001/0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool05`3oool00`00
0000oooo0?ooo`2<0?ooo`00J`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01H0
oooo00<000000?ooo`3oool0S03oool006X0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0F0?ooo`030000003oool0oooo08`0oooo001Y0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool05@3oool00`000000oooo0?ooo`2<0?ooo`00J03oool00`000?l0oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00`0oooo1@0000040?ooo`030000003oool0oooo08`0oooo001W0?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08`0oooo001V0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`800000S@3oool006D0oooo00<0003o0?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S03oool006@0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0S03oool006<0oooo00<0003o0?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0:0?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00HP3oool00`00
0?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0S03oool00640
oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo08`0
oooo001P0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0403oool00`000000oooo
0?ooo`2<0?ooo`00G`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00l0oooo00<0
00000?ooo`3oool0S03oool005h0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0?
0?ooo`030000003oool0oooo08`0oooo001M0?ooo`030000o`3oool0oooo0200oooo00<0003o0?oo
o`3oool03P3oool00`000000oooo0?ooo`2<0?ooo`00G03oool00`000?l0oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo00h0oooo00<000000?ooo`3oool0S03oool005/0oooo00<0003o0?ooo`3oool0
8`3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo08`0oooo001J0?ooo`030000o`3o
ool0oooo02D0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`2<0?ooo`00F@3oool0
0`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0S03oool0
05P0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo
08`0oooo001G0?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool02`3oool00`000000
oooo0?ooo`2<0?ooo`00EP3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool0S03oool005D0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo08`0oooo001F0?ooo`80003o;@3oool00`000?l0oooo0?ooo`09
0?ooo`030000003oool0oooo08`0oooo001H0?ooo`80003o903oool500000080oooo00<000000000
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001J0?ooo`03
0000o`3oool0oooo02<0oooo00<000000?ooo`3oool00`3oool01P000?l0oooo0?ooo`000000oooo
000000D0oooo00<000000?ooo`3oool0S03oool005/0oooo0P000?lS0?ooo`030000003oool0oooo
00@0oooo00D0003o0?ooo`3oool0oooo000000050?ooo`800000S@3oool005d0oooo0P000?lQ0?oo
o`030000003oool0oooo00D0oooo00<0003o0000000000001P3oool00`000000oooo0?ooo`2<0?oo
o`00G`3oool00`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<0003o0000003o
ool01P3oool00`000000oooo0?ooo`2<0?ooo`00H03oool20000oad0oooo0P0000080?ooo`030000
o`000000000000D0oooo00<000000?ooo`3oool0S03oool00680oooo00<0003o0?ooo`3oool0903o
ool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo001S0?ooo`80003o9@3oool0
0`000?l0oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001U0?ooo`80003o8`3oool00`00
0?l0oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001W0?ooo`030000o`3oool0oooo0240
oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00J03oool20000ob80oooo
00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`2<0?ooo`00JP3oool20000ob00oooo00<0
003o0?ooo`3oool00P3oool00`000000oooo0?ooo`2<0?ooo`00K03oool00`000?l0oooo0?ooo`0N
0?ooo`050000o`3oool0oooo0?ooo`000000SP3oool006d0oooo0P000?lN0?ooo`050000o`3oool0
oooo0?ooo`000000SP3oool006l0oooo0P000?lM0?ooo`040000o`3oool0oooo000008h0oooo001a
0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`000000SP3oool00780oooo0P000?lK0?oo
o`030000o`3oool0000008h0oooo001d0?ooo`80003o6P3oool00`000?l000000?ooo`2=0?ooo`00
MP3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`000000oooo08d0oooo001g0?ooo`80003o603o
ool00`000?l0oooo0?ooo`2<0?ooo`00N@3oool00`000?l0oooo0?ooo`0E0?ooo`03000000000?l0
oooo08`0oooo001j0?ooo`80003o3@3oool3000000D0oooo00<000000000o`3oool0S03oool007`0
oooo0P000?l;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000?l0S03oool007h0oooo
00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`80000000<0003o0?ooo`3oool0
RP3oool007l0oooo0P000?l90?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0003o
R`3oool00840oooo0P000?l60?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0003o
R`3oool008<0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`000?l0RP3oool008@0oooo0P000?l;0?ooo`030000003oool0oooo0080oooo00<0
003o0?ooo`3oool0Q`3oool008H0oooo0P000?l90?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool0Q`3oool008P0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000o`3oool0oooo08H0oooo00290?ooo`80003o1P3oool00`000000oooo0?ooo`030?ooo`03
0000o`3oool0oooo08H0oooo002;0?ooo`80003o103oool00`000000oooo0?ooo`040?ooo`030000
o`3oool0oooo08D0oooo002=0?ooo`050000o`3oool0oooo0?ooo`0000001`3oool00`000?l0oooo
0?ooo`240?ooo`00SP3oool20000o`030?ooo`000000oooo00H0oooo00<0003o0?ooo`3oool0Q03o
ool00900oooo0P000?l80?ooo`030000o`3oool0oooo08<0oooo002A0?ooo`03000000000?l0oooo
00H0oooo00<0003o0?ooo`3oool0P`3oool00940oooo00@000000?ooo`000?l0003o1P3oool00`00
0?l0oooo0?ooo`220?ooo`00T@3oool01@000000oooo0?ooo`3oool0003o00D0oooo00<0003o0?oo
o`3oool0PP3oool00940oooo00<000000?ooo`3oool00P3oool20000o`@0oooo00<0003o0?ooo`3o
ool0P@3oool00940oooo00<000000?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool0
P03oool00940oooo00<000000?ooo`3oool01P3oool010000?l0oooo0?ooo`000?n20?ooo`00T@3o
ool00`000000oooo0?ooo`070?ooo`80003o00<0oooo0000o`3oool0P03oool007l0oooo0`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`80003oP@3oool007l0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000050?oo
o`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0OP3oool00800oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<000000?ooo`3oool0
1P3oool2000000H0oooo00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0
oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`2<0?oo
o`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000
003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`2B0?ooo`00R@3oool0
0`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["\<\
The extra 1 enables translations (not a linear transformation in 2D) to be \
performed by matrix multiplication (a 3 coordinate linear transformation!) as \
shown in Lay, p. 157.  \
\>", "Text"],

Cell[BoxData[
    \(transMat[h_, k_]\  := \ N[{{1, 0, h}, {0, 1, k}, {0, 0, 1}}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(At\  = \ transMat[1, .5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0", "1.`"},
            {"0", "1.`", "0.5`"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(flag\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "2", "0"},
            {"0", "2", 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "1"},
            {"1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(At.flag\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "1.`", "3.`", "1.`"},
            {"0.5`", "2.5`", "2.`", "1.5`"},
            {"1.`", "1.`", "1.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[At.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.66667 .08333 m
.66667 .41667 L
1 .33333 L
.66667 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`800000:03o
ool00`000?l0oooo0?ooo`1R0?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001o0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
0680oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo
002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<00000
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0HP3oool008P0oooo1@0000040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo0680oooo002:0?ooo`030000003oool0oooo00@0oooo0P00000X0?ooo`030000o`3oool0
oooo0680oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`1R0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool008T0oooo0P0000060?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3o
ool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool007h0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo00200?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo0680oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool20000
02P0oooo0P000?mS0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000
oooo0?ooo`0W0?ooo`030000o`3oool0003o00<0003oG`3oool00800oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
0`3oool40000oe/0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`070?ooo`@0003oE`3oool00940oooo00<000000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`0;0?ooo`@0003oD`3oool00940oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`0?0?ooo`@0003oC`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`0C0?ooo`@0003oB`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0G0?ooo`@0003oA`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0K0?ooo`@0003o@`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0O
0?ooo`@0003o?`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0S0?oo
o`@0003o>`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0W0?ooo`@0
003o=`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0[0?ooo`@0003o
<`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o;`3o
ool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0c0?ooo`@0003o:`3oool0
0940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0g0?ooo`@0003o9`3oool00940
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0k0?ooo`@0003o8`3oool00940oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0o0?ooo`@0003o7`3oool00940oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`130?ooo`@0003o6`3oool008T0oooo0`000005
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0A`3oool40000oaL0oooo00290?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1;0?oo
o`@0003o4`3oool008X0oooo00<000000?ooo`3oool0103oool2000002P0oooo00<0003o0?ooo`3o
ool0C`3oool30000oa00oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`1<0?ooo`@0003o4P3oool008T0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04P0oooo10000?lF0?ooo`00RP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0A03oool4
0000oaX0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0@03oool40000
oah0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0?03oool40000ob80
oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0>03oool40000obH0oooo
002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0=03oool40000obX0oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0<03oool40000obh0oooo002A0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0;03oool40000oc80oooo002A0?ooo`03
0000003oool0oooo02L0oooo00<0003o0?ooo`3oool0:03oool40000ocH0oooo002A0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0903oool40000ocX0oooo002A0?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0803oool40000och0oooo002A0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`3oool0703oool40000od80oooo002A0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0603oool40000odH0oooo002A0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0503oool40000odX0oooo002A0?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0403oool40000odh0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0303oool40000oe80oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o
0?ooo`3oool0203oool40000oeH0oooo001o0?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`040?oo
o`@0003oFP3oool007l0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000050?ooo`03
0000003oool0oooo02L0oooo00<0003o0?ooo`3oool010000?mN0?ooo`00P03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00000X0?ooo`<0003oHP3oool00800oooo00<0
00000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool007l0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00200?oo
o`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`2B
0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["Let's save this shifted flag.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(flag1\  = \ At.flag\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "1.`", "3.`", "1.`"},
            {"0.5`", "2.5`", "2.`", "1.5`"},
            {"1.`", "1.`", "1.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We also need a scaling transformation that will multiply x coordinates by one \
factor s and y coordinates by another factor t.  If 0 < s = t < 1, then the \
transformation just shrinks the image.  With negatives, you can perform \
reflections.  Let's try s=-0.5 and t=0.5 on the shifted flag1.\
\>", "Text"],

Cell[BoxData[
    \(scaleMat[s_, t_]\  := \ N[\ DiagonalMatrix[{s, t, 1}]\ ]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(As = \ scaleMat[\(-.5\), .5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), "0", "0"},
            {"0", "0.5`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(flag1\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "1.`", "3.`", "1.`"},
            {"0.5`", "2.5`", "2.`", "1.5`"},
            {"1.`", "1.`", "1.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(As.flag1\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), \(-0.5`\), \(-1.5`\), \(-0.5`\)},
            {"0.25`", "1.25`", "1.`", "0.75`"},
            {"1.`", "1.`", "1.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[As.flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.41667 .04167 m
.41667 .20833 L
.25 .16667 L
.41667 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03o
ool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo
0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k
0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo001k0?ooo`070000o`3oool0oooo0?ooo`000000oooo000000070?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00L0003o0?ooo`3o
ool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool00`3oool2000008d0oooo001k0?oo
o`070000o`3oool0oooo0?ooo`000000oooo000000070?ooo`8000001P3oool00`000000oooo0?oo
o`2<0?ooo`00N`3oool01`000?l0oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?oo
o`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3o
ool0S03oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0
oooo01<0oooo00<000000?ooo`3oool0S03oool007X0oooo0P000?lE0?ooo`030000003oool0oooo
08`0oooo001f0?ooo`@0003o00<0oooo0000o`3oool0503oool00`000000oooo0?ooo`2<0?ooo`00
LP3oool40000o`D0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00KP3o
ool40000o`T0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00JP3oool4
0000o`d0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00I`3oool30000
oa40oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00H`3oool40000oa@0
oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00G`3oool40000oaP0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00F`3oool40000oa`0oooo00<0
003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00E`3oool40000ob00oooo00<0003o
0?ooo`3oool02P3oool5000000@0oooo00<000000?ooo`3oool0S03oool005<0oooo10000?lT0?oo
o`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?oo
o`00D@3oool30000obL0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`80
0000S@3oool005@0oooo10000?lS0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00F03oool40000oal0oooo00<0003o0?ooo`3oool0303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001L0?ooo`@0003o6`3oool0
0`000?l0oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00H03oool40000
oaL0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00I03oool50000oa80
oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00J@3oool40000o`h0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00K@3oool40000o`X0oooo00<0
003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00L@3oool40000o`H0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00M@3oool40000o`80oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N@3oool30000oaD0oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?oo
o`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0S03oool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000
S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03o
ool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0`0000050?ooo`03
0000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001o0?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000050?ooo`030000003o
ool0oooo08`0oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2
000008d0oooo00200?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo
08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R@3o
ool2000000H0oooo00<000000?ooo`3oool0S03oool008/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008/0
oooo00<000000?ooo`3oool0TP3oool008T0oooo00<000000?ooo`000000U03oool008X0oooo00<0
00000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["\<\
Here is how you can superimpose any two (or more) plots.  We use it to see \
before and after together.  You can ignore the \"friendly\" possible spelling \
errors, they indicate that Before already has a definition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(before\  = \ view[flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`before\\)\\\" is similar to existing symbol \
\\\"\\!\\(TraditionalForm\\`Before\\)\\\".\"\>"}], TraditionalForm]], 
  "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.66667 .08333 m
.66667 .41667 L
1 .33333 L
.66667 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`800000:03o
ool00`000?l0oooo0?ooo`1R0?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001o0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
0680oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo
002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<00000
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0HP3oool008P0oooo1@0000040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo0680oooo002:0?ooo`030000003oool0oooo00@0oooo0P00000X0?ooo`030000o`3oool0
oooo0680oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`1R0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool008T0oooo0P0000060?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3o
ool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool007h0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo00200?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo0680oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool20000
02P0oooo0P000?mS0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000
oooo0?ooo`0W0?ooo`030000o`3oool0003o00<0003oG`3oool00800oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
0`3oool40000oe/0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`070?ooo`@0003oE`3oool00940oooo00<000000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`0;0?ooo`@0003oD`3oool00940oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`0?0?ooo`@0003oC`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`0C0?ooo`@0003oB`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0G0?ooo`@0003oA`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0K0?ooo`@0003o@`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0O
0?ooo`@0003o?`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0S0?oo
o`@0003o>`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0W0?ooo`@0
003o=`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0[0?ooo`@0003o
<`3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o;`3o
ool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0c0?ooo`@0003o:`3oool0
0940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0g0?ooo`@0003o9`3oool00940
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0k0?ooo`@0003o8`3oool00940oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0o0?ooo`@0003o7`3oool00940oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`130?ooo`@0003o6`3oool008T0oooo0`000005
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0A`3oool40000oaL0oooo00290?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1;0?oo
o`@0003o4`3oool008X0oooo00<000000?ooo`3oool0103oool2000002P0oooo00<0003o0?ooo`3o
ool0C`3oool30000oa00oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`1<0?ooo`@0003o4P3oool008T0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04P0oooo10000?lF0?ooo`00RP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0A03oool4
0000oaX0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0@03oool40000
oah0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0?03oool40000ob80
oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0>03oool40000obH0oooo
002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0=03oool40000obX0oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0<03oool40000obh0oooo002A0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0;03oool40000oc80oooo002A0?ooo`03
0000003oool0oooo02L0oooo00<0003o0?ooo`3oool0:03oool40000ocH0oooo002A0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0903oool40000ocX0oooo002A0?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0803oool40000och0oooo002A0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`3oool0703oool40000od80oooo002A0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0603oool40000odH0oooo002A0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0503oool40000odX0oooo002A0?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0403oool40000odh0oooo002A0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0303oool40000oe80oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o
0?ooo`3oool0203oool40000oeH0oooo001o0?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`040?oo
o`@0003oFP3oool007l0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000050?ooo`03
0000003oool0oooo02L0oooo00<0003o0?ooo`3oool010000?mN0?ooo`00P03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00000X0?ooo`<0003oHP3oool00800oooo00<0
00000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool007l0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00200?oo
o`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002:0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`2B
0?ooo`00R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(after\  = \ view[As.flag1, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`after\\)\\\" is similar to existing symbol \
\\\"\\!\\(TraditionalForm\\`After\\)\\\".\"\>"}], TraditionalForm]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.41667 .04167 m
.41667 .20833 L
.25 .16667 L
.41667 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03o
ool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo
0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k
0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo001k0?ooo`070000o`3oool0oooo0?ooo`000000oooo000000070?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00L0003o0?ooo`3o
ool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool00`3oool2000008d0oooo001k0?oo
o`070000o`3oool0oooo0?ooo`000000oooo000000070?ooo`8000001P3oool00`000000oooo0?oo
o`2<0?ooo`00N`3oool01`000?l0oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?oo
o`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3o
ool0S03oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0
oooo01<0oooo00<000000?ooo`3oool0S03oool007X0oooo0P000?lE0?ooo`030000003oool0oooo
08`0oooo001f0?ooo`@0003o00<0oooo0000o`3oool0503oool00`000000oooo0?ooo`2<0?ooo`00
LP3oool40000o`D0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00KP3o
ool40000o`T0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00JP3oool4
0000o`d0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00I`3oool30000
oa40oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00H`3oool40000oa@0
oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00G`3oool40000oaP0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00F`3oool40000oa`0oooo00<0
003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00E`3oool40000ob00oooo00<0003o
0?ooo`3oool02P3oool5000000@0oooo00<000000?ooo`3oool0S03oool005<0oooo10000?lT0?oo
o`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?oo
o`00D@3oool30000obL0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`80
0000S@3oool005@0oooo10000?lS0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00F03oool40000oal0oooo00<0003o0?ooo`3oool0303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001L0?ooo`@0003o6`3oool0
0`000?l0oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00H03oool40000
oaL0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00I03oool50000oa80
oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00J@3oool40000o`h0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00K@3oool40000o`X0oooo00<0
003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00L@3oool40000o`H0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00M@3oool40000o`80oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N@3oool30000oaD0oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool007h0oooo1@0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?oo
o`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0S03oool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000
S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03o
ool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0`0000050?ooo`03
0000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001o0?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000050?ooo`030000003o
ool0oooo08`0oooo00200?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2
000008d0oooo00200?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo
08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R@3o
ool2000000H0oooo00<000000?ooo`3oool0S03oool008/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008/0
oooo00<000000?ooo`3oool0TP3oool008T0oooo00<000000?ooo`000000U03oool008X0oooo00<0
00000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[before, after]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.66667 .08333 m
.66667 .41667 L
1 .33333 L
.66667 .25 L
s
.41667 .04167 m
.41667 .20833 L
.25 .16667 L
.41667 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03o
ool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo
0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo08`0oooo001k
0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0S03oool007/0oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`2<0?ooo`00N`3oool00`000?l0oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo001k0?ooo`070000o`3oool0oooo0?ooo`000000oooo000000070?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00L0003o0?ooo`3o
ool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool00`3oool2000002P0oooo00<0003o
0?ooo`3oool0HP3oool007/0oooo00L0003o0?ooo`3oool0oooo0000003oool0000000L0oooo0P00
00060?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool007/0oooo00L0003o
0?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001k0?ooo`030000o`3oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`1R0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo00<0003o
0?ooo`3oool0HP3oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo0680oooo001k0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool007/0oooo00<0003o0?ooo`3oool04`3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001k0?ooo`030000o`3oool0
oooo01<0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00NP3oool20000
oaD0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00MP3oool40000o`03
0?ooo`000?l0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00
LP3oool40000o`D0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo0680oooo001^0?ooo`@0003o2@3oool00`000?l0oooo0?ooo`0C0?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool006X0oooo10000?l=0?ooo`030000o`3oool0
oooo01<0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00I`3oool30000
oa40oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
0680oooo001S0?ooo`@0003o503oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool005l0oooo10000?lH0?ooo`030000o`3oool0oooo01<0oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00F`3oool40000oa`0oooo00<0
003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001G
0?ooo`@0003o803oool00`000?l0oooo0?ooo`0:0?ooo`D00000103oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo0680oooo001C0?ooo`@0003o903oool00`000?l0oooo0?ooo`0<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?oo
o`00D@3oool30000obL0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`80
0000:03oool00`000?l0oooo0?ooo`1R0?ooo`00E03oool40000ob<0oooo00<0003o0?ooo`3oool0
303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool005P0oooo10000?lO0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001L0?ooo`@0003o6`3oool0
0`000?l0oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo0680oooo001P0?ooo`@0003o5`3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0HP3oool006@0oooo1@000?lB0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00J@3oool40000o`h0oooo
00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo
001]0?ooo`@0003o2P3oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0HP3oool00740oooo10000?l60?ooo`030000o`3oool0oooo01<0oooo00<00000
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00M@3oool40000o`80oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001i0?ooo`<0
003o5@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R
0?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00800oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000050?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0HP3oool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000
:03oool20000of<0oooo00200?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`000?l00`000?mO0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`03
0?ooo`@0003oF`3oool007l0oooo0P0000080?ooo`<000001@3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo00L0oooo10000?mG0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo00/0oooo10000?mC0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo00l0oooo10000?m?0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo01<0oooo10000?m;0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo01L0oooo10000?m70?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
01/0oooo10000?m30?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo01l0
oooo10000?lo0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02<0oooo
10000?lk0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02L0oooo1000
0?lg0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02/0oooo10000?lc
0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02l0oooo10000?l_0?oo
o`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03<0oooo10000?l[0?ooo`00
T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03L0oooo10000?lW0?ooo`00T@3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03/0oooo10000?lS0?ooo`00T@3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03l0oooo10000?lO0?ooo`00T@3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04<0oooo10000?lK0?ooo`00R@3oool3000000D0
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`170?ooo`@0003o5`3oool008T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04/0oooo
10000?lC0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000:03oool00`000?l0oooo0?oo
o`1?0?ooo`<0003o403oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo04`0oooo10000?lB0?ooo`00R@3oool00`000000oooo000000050?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0B03oool40000oaH0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`140?ooo`@0
003o6P3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`100?ooo`@0003o
7P3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0l0?ooo`@0003o8P3o
ool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0h0?ooo`@0003o9P3oool0
0940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0d0?ooo`@0003o:P3oool00940
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0`0?ooo`@0003o;P3oool00940oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0/0?ooo`@0003o<P3oool00940oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0X0?ooo`@0003o=P3oool00940oooo00<00000
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0T0?ooo`@0003o>P3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`0P0?ooo`@0003o?P3oool00940oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`0L0?ooo`@0003o@P3oool00940oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0H0?ooo`@0003oAP3oool00940oooo00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`0D0?ooo`@0003oBP3oool00940oooo00<000000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`0@0?ooo`@0003oCP3oool00940oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`0<0?ooo`@0003oDP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`080?ooo`@0003oEP3oool007l0oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00@0oooo
10000?mJ0?ooo`00O`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`040000oeh0oooo00200?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool2000002P0oooo0`000?mR0?ooo`00P03oool00`00
0000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool00`000000
oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool00800oooo
00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003o
ool0oooo08`0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002;0?ooo`030000003oool0oooo0980
oooo00290?ooo`030000003oool0000009@0oooo002:0?ooo`030000003oool0oooo09<0oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["\<\
Later, we will see that any linear transformation can be performed by a \
rotation, followed by a scaling (any s and t), followed by another rotation \
(this is the Singular Value Decomposition).  An affine transformation is \
defined to be a linear transformation together with a translation.  Thus, \
combinations of rotMat, scaleMat, and transMat are enough to produce any \
affine transformation.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assignment  -- Part I.", "Subsection"],

Cell["Names?", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ review\ of\ homoMat2D\ construction\ *) \n
    pts\  = \ {{0, 0}, {0, 2}, {2, 1.5}, {0, 1}}; \n
    flag\  = \ Append[Transpose[pts], Table[1, {4}]]\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "2", "0"},
            {"0", "2", 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], "1"},
            {"1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.5 .33333 L
.83333 .25 L
.5 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo
08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo00200?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
1@3oool00`000?l0oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo000000090?ooo`030000003o
ool0oooo00<0oooo00<0003o0000003oool0S03oool007l0oooo00<000000?ooo`0000001`3oool2
000000H0oooo00<0003o0?ooo`3oool0S03oool007l0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`050?ooo`030000o`3oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0
oooo0`0000050?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo
002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?oo
o`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000
o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0
oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0
oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A
0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`03
0000o`3oool0oooo08`0oooo00280?ooo`D00000103oool00`000?l0oooo0?ooo`2<0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08`0oooo002:0?ooo`030000003oool0
oooo00@0oooo0P000?n=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0003o
00<0003oR@3oool008X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`@0
003oQ@3oool008T0oooo0P0000060?ooo`030000o`3oool0oooo00L0oooo10000?n10?ooo`00T@3o
ool00`000?l0oooo0?ooo`0;0?ooo`@0003oO@3oool00940oooo00<0003o0?ooo`3oool03`3oool4
0000ogT0oooo002A0?ooo`030000o`3oool0oooo01<0oooo10000?me0?ooo`00T@3oool00`000?l0
oooo0?ooo`0G0?ooo`@0003oL@3oool00940oooo00<0003o0?ooo`3oool06`3oool40000ofd0oooo
002A0?ooo`030000o`3oool0oooo01l0oooo10000?mY0?ooo`00T@3oool00`000?l0oooo0?ooo`0S
0?ooo`@0003oI@3oool00940oooo00<0003o0?ooo`3oool09`3oool40000of40oooo002A0?ooo`03
0000o`3oool0oooo02/0oooo10000?mM0?ooo`00T@3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o
F@3oool00940oooo00<0003o0?ooo`3oool0<`3oool40000oeD0oooo002A0?ooo`030000o`3oool0
oooo03L0oooo10000?mA0?ooo`00T@3oool00`000?l0oooo0?ooo`0k0?ooo`@0003oC@3oool00940
oooo00<0003o0?ooo`3oool0?`3oool40000odT0oooo002A0?ooo`030000o`3oool0oooo04<0oooo
10000?m50?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000o`3oool0oooo04L0oooo10000?m10?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000D0oooo00<0003o0?ooo`3oool0B`3oool40000ocd0oooo00200?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000?l000000?ooo`1?0?oo
o`<0003o>P3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<0003o0?ooo`3o
ool0C03oool40000oc`0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`180?ooo`@0003o@03oool007l0oooo0P0000080?ooo`<000001@3o
ool00`000?l0oooo0?ooo`140?ooo`@0003oA03oool00940oooo00<0003o0?ooo`3oool0@03oool4
0000odP0oooo002A0?ooo`030000o`3oool0oooo03`0oooo10000?m<0?ooo`00T@3oool00`000?l0
oooo0?ooo`0h0?ooo`@0003oD03oool00940oooo00<0003o0?ooo`3oool0=03oool40000oe@0oooo
002A0?ooo`030000o`3oool0oooo0300oooo10000?mH0?ooo`00T@3oool00`000?l0oooo0?ooo`0/
0?ooo`@0003oG03oool00940oooo00<0003o0?ooo`3oool0:03oool40000of00oooo002A0?ooo`03
0000o`3oool0oooo02@0oooo10000?mT0?ooo`00T@3oool00`000?l0oooo0?ooo`0P0?ooo`@0003o
J03oool00940oooo00<0003o0?ooo`3oool0703oool40000of`0oooo002A0?ooo`030000o`3oool0
oooo01P0oooo10000?m`0?ooo`00T@3oool00`000?l0oooo0?ooo`0D0?ooo`@0003oM03oool00940
oooo00<0003o0?ooo`3oool0403oool40000ogP0oooo002A0?ooo`030000o`3oool0oooo00`0oooo
10000?ml0?ooo`00T@3oool00`000?l0oooo0?ooo`080?ooo`@0003oP03oool008T0oooo0`000005
0?ooo`030000o`3oool0oooo00@0oooo10000?n40?ooo`00R@3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0003oR03oool008X0oooo00<000000?ooo`3oool0103oool30000oh`0
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008T0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo001o0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0oooo00H0oooo0P00
00060?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`060?oo
o`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool008/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`800000S@3oool008/0oooo00<000000?ooo`3oool0TP3oool008T0oooo00<000000?oo
o`000000U03oool008X0oooo00<000000?ooo`3oool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "1.  ",
  StyleBox[
  "Find the transformation matrix A that maps the original flag to the \
\"after\" image defined in the above section and view A.flag.", "Text"]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(At\  = \ transMat[1, .5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0", "1.`"},
            {"0", "1.`", "0.5`"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(As = \ scaleMat[\(-.5\), .5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), "0", "0"},
            {"0", "0.5`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ As.At\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), "0.`", \(-0.5`\)},
            {"0.`", "0.5`", "0.25`"},
            {"0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[A.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.41667 .04167 m
.41667 .20833 L
.25 .16667 L
.41667 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{407.25, 203.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006G0000bb000`400?l00000o`00003oo`3ooonH
0?ooo`005@3oool2000003/0oooo0`00000j0?ooo`D00000L`3oool5000003X0oooo0`00000j0?oo
o`8000004P3oool001L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00l0oooo000@0?ooo`<000000`3oool00`000000oooo0?ooo`0d0?ooo`<00000
0`3oool00`000000oooo0?ooo`0e0?ooo`<000000`3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0@0?ooo`005`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03`3o
ool001D0oooo00<000000?ooo`000000>P3oool00`000000oooo0000000l0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0000000j0?ooo`030000003oool0
00000140oooo000F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool20000
07H0oooo0P00000m0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0403oool00?l0
ooooV03oool00?l0ooooV03oool00?l0ooooV03oool00?l0ooooV03oool00?l0ooooV03oool00?l0
ooooV03oool001@0ooooo`00001c00000140oooo000D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000D
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo000D0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo003<0?ooo`03
0000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003o
ool0oooo0<P0oooo003<0?ooo`<00000b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0
oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<0
00000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo0`0000380?oo
o`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00[@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0<P0oooo002]0?ooo`030000o`3oool0
oooo01`0oooo00<000000?ooo`3oool0b03oool00:d0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`380?ooo`00[@3oool00`000?l0oooo0?ooo`0L0?ooo`<00000b03oool00:d0oooo
00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00[@3oool00`000?l0oooo0?oo
o`0L0?ooo`030000003oool0oooo0<P0oooo002]0?ooo`030000o`3oool0oooo01`0oooo00<00000
0?ooo`3oool0b03oool00:d0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?oo
o`00[@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0<P0oooo002]0?ooo`030000
o`3oool0oooo01`0oooo0`0000380?ooo`00[@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<P0oooo002]0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool0
0:d0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00[@3oool00`000?l0
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0<P0oooo002]0?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003oool0oooo0<P0oooo
002]0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`0000002@3oool00`000000oooo0?oo
o`030?ooo`<00000b03oool00:d0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo00000007
0?ooo`8000001P3oool00`000000oooo0?ooo`380?ooo`00[@3oool00`000?l0oooo0?ooo`0:0?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`380?oo
o`00[@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`03
0000003oool0oooo0<P0oooo002]0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0
b03oool00:d0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00[@3oool0
0`000?l0oooo0?ooo`0L0?ooo`<00000b03oool00:d0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`380?ooo`00[@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0<P0
oooo002]0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool00:d0oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00[@3oool00`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo0<P0oooo002]0?ooo`030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool0b03oool00:d0oooo00<0003o0?ooo`3oool0703oool300000<P0oooo002]0?ooo`030000
o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool00:d0oooo00<0003o0?ooo`3oool0703o
ool00`000000oooo0?ooo`380?ooo`00Z`3oool30000oah0oooo00<000000?ooo`3oool0b03oool0
0:L0oooo10000?l20?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool00:<0
oooo10000?l60?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool009l0oooo
10000?l:0?ooo`030000o`3oool0oooo01`0oooo0`0000380?ooo`00V`3oool40000o`h0oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00U`3oool40000oa80oooo00<0003o
0?ooo`3oool0703oool00`000000oooo0?ooo`380?ooo`00T`3oool40000oaH0oooo00<0003o0?oo
o`3oool0703oool00`000000oooo0?ooo`380?ooo`00S`3oool40000oaX0oooo00<0003o0?ooo`3o
ool0703oool00`000000oooo0?ooo`380?ooo`00R`3oool40000oah0oooo00<0003o0?ooo`3oool0
703oool00`000000oooo0?ooo`380?ooo`00Q`3oool40000ob80oooo00<0003o0?ooo`3oool0703o
ool300000<P0oooo00230?ooo`@0003o9P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0
oooo0<P0oooo001o0?ooo`@0003o:P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo
0<P0oooo001k0?ooo`@0003o;P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0<P0
oooo001g0?ooo`@0003o<P3oool00`000?l0oooo0?ooo`0C0?ooo`D00000103oool00`000000oooo
0?ooo`380?ooo`00L`3oool40000ocH0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0<P0oooo001`0?ooo`<0003o>P3oool00`000?l0oooo0?ooo`0E
0?ooo`030000003oool0oooo00@0oooo0`0000380?ooo`00L`3oool40000ocH0oooo00<0003o0?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<P0oooo001g0?ooo`@0
003o<P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0b03oool007/0oooo10000?l^0?ooo`030000o`3oool0oooo01@0oooo0P0000060?ooo`030000
003oool0oooo0<P0oooo001o0?ooo`@0003o:P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<P0oooo00230?ooo`@0003o9P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0
oooo0<P0oooo00270?ooo`@0003o8P3oool00`000?l0oooo0?ooo`0L0?ooo`<00000b03oool008/0
oooo10000?lN0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool008l0oooo
10000?lJ0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool009<0oooo1000
0?lF0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool009L0oooo10000?lB
0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool009/0oooo10000?l>0?oo
o`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0b03oool009l0oooo10000?l:0?ooo`03
0000o`3oool0oooo01`0oooo0`0000380?ooo`00X`3oool40000o`H0oooo00<0003o0?ooo`3oool0
703oool00`000000oooo0?ooo`380?ooo`00Y`3oool40000o`80oooo00<0003o0?ooo`3oool0703o
ool00`000000oooo0?ooo`380?ooo`00Z`3oool30000oah0oooo00<000000?ooo`3oool0b03oool0
0<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo
0`0000380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`38
0?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00
c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool3
00000<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0
oooo003<0?ooo`030000003oool0oooo0<P0oooo002i0?ooo`D000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0b03oool00;/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000050?ooo`030000003oool0oooo0<P0oooo002k0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool300000<P0oooo002k0?ooo`03
0000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo0<P0oooo002k0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`380?ooo`00^P3o
ool2000000P0oooo0`0000050?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0
oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`<00000b03oool00<`0oooo
00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<00000
0?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3o
ool0b03oool00<`0oooo0`0000380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool0
0`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000
oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool300000<P0oooo003<
0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`03
0000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003o
ool0oooo0<P0oooo003<0?ooo`<00000b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0
oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<@0oooo0`00
00050?ooo`030000003oool0oooo0<P0oooo00340?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0b03oool00<D0oooo00<000000?ooo`3oool0103oool300000<P0oooo00350?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0b03oool00<@0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`380?ooo`00a@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo
0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`<00000b03oool00<`0oooo00<0
00000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?oo
o`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0
b03oool00<`0oooo0`0000380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`00
0000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo
0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool300000<P0oooo003<0?oo
o`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000
003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0
oooo0<P0oooo003<0?ooo`<00000b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo
00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00;X0oooo0`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`38
0?ooo`00^P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0b03oool00;/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<0
0000b03oool00;/0oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0
b03oool00;X0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0<P0oooo002k0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0
oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0
oooo003<0?ooo`<00000b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<00000
0?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3o
ool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03o
ool00<`0oooo0`0000380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000
oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?oo
o`380?ooo`00c03oool00`000000oooo0?ooo`380?ooo`00c03oool300000<P0oooo003<0?ooo`03
0000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003o
ool0oooo0<P0oooo003<0?ooo`030000003oool0oooo0<P0oooo003<0?ooo`030000003oool0oooo
0<P0oooo003<0?ooo`<00000b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<`0oooo00<0
00000?ooo`3oool0b03oool00<`0oooo00<000000?ooo`3oool0b03oool00<@0oooo0P0000060?oo
o`030000003oool0oooo0<P0oooo00360?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0b03oool00<D0oooo00<000000?ooo`3oool0103oool300000<P0oooo00360?ooo`030000003o
ool0oooo0<h0oooo00340?ooo`030000003oool000000=00oooo00350?ooo`030000003oool0oooo
0<l0oooo003o0?oooiP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 406.25}, {202.625, 0}} -> {-3.32704, -0.221348, 
  0.0162592, 0.0162592}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.  Your matrix A should have been a product of two matrices.  Form B by \
multiplying them in the opposite order and view B.flag.  What's going on \
here?  Explain the algebraic problem as well as the geometry.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\  = \ At.As\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), "0.`", "1.`"},
            {"0.`", "0.5`", "0.5`"},
            {"0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[B.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.66667 .08333 m
.66667 .25 L
.5 .20833 L
.66667 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
O`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
S03oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`800000:03o
ool00`000?l0oooo0?ooo`1R0?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo001o0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
0680oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0680oooo
002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0HP3oool00940oooo00<00000
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo0680oooo002A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0HP3oool008P0oooo1@0000040?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
HP3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo0680oooo002:0?ooo`030000003oool0oooo00@0oooo0P00000V0?ooo`<0003oI03oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`@0003o0P3oool00`00
0?l0oooo0?ooo`1R0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0
oooo10000?l60?ooo`030000o`3oool0oooo0680oooo00290?ooo`8000001P3oool00`000000oooo
0?ooo`0I0?ooo`@0003o2P3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?oo
o`0E0?ooo`@0003o3P3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0@
0?ooo`D0003o4P3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0<0?oo
o`@0003o5`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`080?ooo`@0
003o6`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`040?ooo`@0003o
7`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`040000ob<0oooo00<0
003o0?ooo`3oool0HP3oool00940oooo0`000?lW0?ooo`030000o`3oool0oooo0680oooo002A0?oo
o`030000003oool0003o00<0003o903oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000
oooo0?ooo`030?ooo`@0003o803oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo
0?ooo`070?ooo`@0003o703oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?oo
o`0;0?ooo`@0003o603oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0?
0?ooo`<0003o5@3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0B0?oo
o`@0003o4@3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0F0?ooo`@0
003o3@3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0J0?ooo`@0003o
2@3oool00`000?l0oooo0?ooo`1R0?ooo`00OP3oool500000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo10000?l50?ooo`030000o`3o
ool0oooo0680oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`0R0?ooo`@0003o00<0oooo0000o`3oool0H`3oool00800oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`8000009`3oool20000of@0oooo00200?ooo`03
0000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo08`0oooo00200?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00O`3o
ool2000000P0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`000000oooo0?ooo`2<
0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo002:0?ooo`03
0000003oool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08`0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03o
ool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool3000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001o0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00
P03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03o
ool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool0
0800oooo00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`03
0000003oool0oooo08`0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002;0?ooo`030000003oool0
oooo0980oooo00290?ooo`030000003oool0000009@0oooo002:0?ooo`030000003oool0oooo09<0
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]],

Cell["\<\
Matrix mult is not commutative, so they give different results.  A first \
translates then shrinks and reflects.  B first shrinks and reflects, then \
translates.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.  To vertically smash a figure, we use ",
  StyleBox["scaleMat[1,.3]", "Input"],
  " (understand?).  To smash it along the line y=x, we could first rotate it \
by -Pi/4, then vertically smash, then rotate back Pi/4.  Find the matrix A \
that accomplishes this and view A.flag."
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ rotMat[Pi/4].scaleMat[1, .3].rotMat[\(-Pi\)/4]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.649999999999999911`", "0.349999999999999911`", "0.`"},
            {"0.349999999999999911`", "0.649999999999999911`", "0.`"},
            {"0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[A.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.61667 .21667 L
.80417 .27917 L
.55833 .10833 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`0300000000
0?l0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002A0?ooo`03000000000?l0oooo08`0oooo002A0?ooo`030000003oool0003o
08`0oooo002A0?ooo`030000003oool0003o08`0oooo002A0?ooo`040000003oool0oooo0000oh/0
oooo002A0?ooo`040000003oool0oooo0000oh/0oooo002A0?ooo`050000003oool0oooo0?ooo`00
0?l0RP3oool00940oooo00D000000?ooo`3oool0oooo0000o`2:0?ooo`00T@3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo08L0oooo002A0?ooo`030000003oool0oooo0080oooo00<0
003o0?ooo`3oool0Q`3oool00940oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`26
0?ooo`00T@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08H0oooo002A0?ooo`03
0000003oool0oooo00@0oooo00<0003o0?ooo`3oool0Q@3oool00940oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`240?ooo`00T@3oool00`000000oooo0?ooo`050?ooo`030000o`3o
ool0oooo08@0oooo002A0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0P`3oool0
0940oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`230?ooo`00T@3oool00`000000
oooo0?ooo`070?ooo`030000o`3oool0oooo0880oooo00200?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<0003o0?ooo`3oool0PP3oool007l0oooo00<000000?ooo`0000001`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0P@3oool007l0oooo00<00000
0?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000?l0oooo0?ooo`21
0?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool00`000000oooo0?ooo`090?oo
o`030000o`3oool0oooo0800oooo001o0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo0800oooo00200?ooo`030000
003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool0
O`3oool00940oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1o0?ooo`00T@3oool0
0`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07h0oooo002A0?ooo`030000003oool0oooo
00/0oooo00<0003o0?ooo`3oool0OP3oool00940oooo00<000000?ooo`3oool0303oool20000ogh0
oooo002A0?ooo`030000003oool0oooo00d0oooo0P000?mm0?ooo`00T@3oool00`000000oooo0?oo
o`0=0?ooo`040000o`3oool0003o0000og/0oooo002A0?ooo`030000003oool0oooo00h0oooo00@0
003o0?ooo`3oool0003oNP3oool00940oooo00<000000?ooo`3oool03P3oool01@000?l0oooo0?oo
o`3oool0003o07T0oooo002A0?ooo`030000003oool0oooo00l0oooo00@0003o0?ooo`3oool0oooo
0P000?mg0?ooo`00T@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0M03oool00940oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`03
0?ooo`80003oM03oool00940oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0740oooo002A0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3o
ool01@3oool20000og40oooo002A0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`1^0?ooo`00T@3oool00`000000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00L0oooo0P000?m^0?ooo`00R03oool5000000@0oooo00<000000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo06/0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
06X0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00000E0?ooo`030000o`3oool0oooo00T0
oooo0P000?mZ0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1W0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool02`3oool20000ofL0oooo0029
0?ooo`8000001P3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3oool0I03oool00940oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0=0?oo
o`80003oI03oool00940oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo0640oooo002A0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`1P0?ooo`00T@3oool00`000000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo0100oooo0P000?mP0?ooo`00T@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo0140oooo00<0003o0?ooo`3oool0G@3oool00940oooo00<000000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0B0?ooo`80003oG@3oool00940oooo00<000000?ooo`3oool06@3oool00`000?l0
oooo0?ooo`0C0?ooo`030000o`3oool0oooo05X0oooo002A0?ooo`030000003oool0oooo01T0oooo
00<0003o0?ooo`3oool0503oool20000oeX0oooo002A0?ooo`030000003oool0oooo01X0oooo0P00
0?lF0?ooo`030000o`3oool0oooo05L0oooo002A0?ooo`030000003oool0oooo01`0oooo0`000?lD
0?ooo`80003oE`3oool00940oooo00<000000?ooo`3oool07`3oool30000oa<0oooo00<0003o0?oo
o`3oool0E03oool00940oooo00<000000?ooo`3oool08P3oool30000oa40oooo00<0003o0?ooo`3o
ool0D`3oool00940oooo00<000000?ooo`3oool09@3oool30000o`l0oooo0P000?mC0?ooo`00T@3o
ool00`000000oooo0?ooo`0X0?ooo`<0003o3P3oool00`000?l0oooo0?ooo`1@0?ooo`00T@3oool0
0`000000oooo0?ooo`0[0?ooo`<0003o303oool20000oe00oooo001n0?ooo`D000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool30000
o`/0oooo00<0003o0?ooo`3oool0C@3oool00800oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000050?ooo`030000003oool0oooo0340oooo0P000?l:0?ooo`80003oC@3oool00800oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000=03oool30000o`T0oooo
00<0003o0?ooo`3oool0BP3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<0
00000?ooo`3oool0=P3oool30000o`L0oooo0P000?m:0?ooo`00P03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool30000o`H0oooo00<0003o
0?ooo`3oool0A`3oool007l0oooo0P0000080?ooo`<000001@3oool00`000000oooo0?ooo`0l0?oo
o`<0003o103oool00`000?l0oooo0?ooo`160?ooo`00T@3oool00`000000oooo0?ooo`0o0?ooo`<0
003o0P3oool20000odH0oooo002A0?ooo`030000003oool0oooo0480oooo0`000?l00`3oool0003o
0?ooo`140?ooo`00T@3oool00`000000oooo0?ooo`150?ooo`@0003o@`3oool00940oooo00<00000
0?ooo`3oool0B03oool20000od80oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo00290?ooo`<000001@3oool00`000000oooo0?ooo`2<0?ooo`00
R@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003o
ool0oooo00@0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08`0oooo00290?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool008X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool3000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo001o0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00P03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00P03oool00`00
0000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool00`000000
oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool00800oooo
00<000000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003o
ool0oooo08`0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool0
08X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002;0?ooo`030000003oool0oooo0980
oooo00290?ooo`030000003oool0000009@0oooo002:0?ooo`030000003oool0oooo09<0oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.  Often, rather than rotating twice, a shear transformation is added to \
the mix.  Any linear transformation is a combination of rotation, scaling and \
shear.  Define a ",
  StyleBox["shearMat[t_]", "Input"],
  " function that produces the 3\[Times]3 matrix that leaves the x-axis fixed \
but leans the y-axis to the right by an angle of t radians.  Hint: first find \
the standard 2\[Times]2 matrix for this transformation.  Test it by shearing \
flag by Pi/6 and viewing the result."
}], "Subsubsection"],

Cell[BoxData[
    \(shearMat[t_]\  := \ N[{{1, Tan[t], 0}, {0, 1, 0}, {0, 0, 1}}]\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ shearMat[Pi/6]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.577350269189625819`", "0"},
            {"0", "1.`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[A.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 0 m
.69245 .33333 L
.97767 .25 L
.59623 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180ooooO`0000000`000?l000000000001l00000100oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`0300000000
0?l0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo002A0?ooo`03000000000?l0oooo08`0oooo002A0?ooo`030000003oool0003o
08`0oooo002A0?ooo`030000003oool0003o08`0oooo002A0?ooo`040000003oool0oooo0000oh/0
oooo002A0?ooo`040000003oool0oooo0000oh/0oooo002A0?ooo`050000003oool0oooo0?ooo`00
0?l0RP3oool00940oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`00T@3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo08L0oooo002A0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0QP3oool00940oooo00<000000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`260?ooo`00T@3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08D0
oooo002A0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0Q@3oool00940oooo00<0
00000?ooo`3oool01@3oool00`000?l0oooo0?ooo`240?ooo`00T@3oool00`000000oooo0?ooo`06
0?ooo`030000o`3oool0oooo08<0oooo002A0?ooo`030000003oool0oooo00H0oooo00<0003o0?oo
o`3oool0P`3oool00940oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`220?ooo`00
T@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo0880oooo00200?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0P@3oool007l0oooo00<000000?ooo`0000001`3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0P@3oool0
07l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`8000002P3oool00`00
0?l0oooo0?ooo`200?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo07l0oooo001o0?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo07l0oooo
00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo00/0oooo00<0
003o0?ooo`3oool0OP3oool00940oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1n
0?ooo`00T@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07d0oooo002A0?ooo`03
0000003oool0oooo00`0oooo00<0003o0?ooo`3oool0O@3oool00940oooo00<000000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`1l0?ooo`00T@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo07/0oooo002A0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0N`3oool0
0940oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1j0?ooo`00T@3oool00`000000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo002A0?ooo`030000003oool0oooo0100oooo
00<0003o0?ooo`3oool0N@3oool00940oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`1i0?ooo`00T@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo07P0oooo002A0?oo
o`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0M`3oool00940oooo00<000000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`1g0?ooo`00T@3oool00`000000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo07H0oooo002A0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0MP3o
ool008P0oooo1@0000040?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0M@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
07D0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00000F0?ooo`<0003oM03oool008X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0003o00<0003o
L03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo00<0oooo1@000?m[0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`070?ooo`@0003oI`3oool00940oooo00<000000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0;0?ooo`D0003oHP3oool00940oooo00<000000?ooo`3oool0603oool00`000?l0
oooo0?ooo`0?0?ooo`D0003oG@3oool00940oooo00<000000?ooo`3oool0603oool00`000?l0oooo
0?ooo`0D0?ooo`@0003oF@3oool00940oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0G0?ooo`D0003oE03oool00940oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0K
0?ooo`@0003oD03oool00940oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0O0?oo
o`D0003oB`3oool00940oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0S0?ooo`@0
003oA`3oool00940oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0W0?ooo`D0003o
@P3oool00940oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0[0?ooo`D0003o?@3o
ool00940oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0`0?ooo`@0003o>@3oool0
0940oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0c0?ooo`D0003o=03oool00940
oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0g0?ooo`@0003o<03oool00940oooo
00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0k0?ooo`D0003o:`3oool00940oooo00<0
00000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0o0?ooo`@0003o9`3oool00940oooo00<00000
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`130?ooo`D0003o8P3oool007h0oooo1@0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo04L0oooo1@000?lM0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`1<0?ooo`@0
003o6@3oool00800oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000
8P3oool00`000?l0oooo0?ooo`1?0?ooo`<0003o5P3oool00800oooo00<000000?ooo`3oool01P3o
ool2000000H0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`1;0?ooo`@0003o603o
ool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0280oooo00<0003o0?ooo`3oool0B03oool30000oa`0oooo001o0?ooo`800000203oool30000
00D0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`140?ooo`<0003o7`3oool00940
oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`100?ooo`@0003o8P3oool00940oooo
00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`0l0?ooo`<0003o9P3oool00940oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0?ooo`0h0?ooo`@0003o:@3oool00940oooo00<00000
0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0d0?ooo`<0003o;@3oool00940oooo00<000000?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0_0?ooo`@0003o<03oool00940oooo00<000000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`0/0?ooo`<0003o=03oool00940oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0X0?ooo`<0003o=`3oool00940oooo00<000000?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`0T0?ooo`@0003o>P3oool00940oooo00<000000?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`0P0?ooo`<0003o?P3oool00940oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`0L0?ooo`@0003o@@3oool00940oooo00<000000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0H0?ooo`<0003oA@3oool00940oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0C0?ooo`@0003oB03oool00940oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?oo
o`0@0?ooo`<0003oC03oool00940oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0<
0?ooo`<0003oC`3oool00940oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`080?oo
o`@0003oDP3oool008T0oooo0`0000050?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3o
ool0103oool30000oeH0oooo00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`040000oeT0oooo002:0?ooo`030000003oool0oooo00@0oooo0P00
000^0?ooo`80003oG@3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<
0?ooo`00R@3oool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool007l0oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00O`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0S03oool00800oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`800000S@3oool00800oooo00<000000?oo
o`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0S03oool007l0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000
003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000oooo0?oo
o`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo002:0?oo
o`030000003oool0oooo00@0oooo0P00002=0?ooo`00R`3oool00`000000oooo0?ooo`2B0?ooo`00
R@3oool00`000000oooo0000002D0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
5.  Rotation about a point other than the origin can be accomplished using \
translations.  Find a matrix that rotates an image thru -Pi/4 about the point \
(0,1).  Test on flag and view the result.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ transMat[0, 1].rotMat[Pi/4].transMat[0, \(-1\)]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.707106781186547461`", \(-0.707106781186547461`\), 
              "0.707106781186547461`"},
           
             {"0.707106781186547461`", "0.707106781186547461`", 
              "0.292893218813452538`"},
            {"0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(view[A.flag, {{\(-3\), 3}, {0, 3}}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .08333 -18 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .41667 -18 -4.5 ]
[.4875 .41667 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .08333 m
.50625 .08333 L
s
[(0.5)] .4875 .08333 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(1.5)] .4875 .25 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .41667 m
.50625 .41667 L
s
[(2.5)] .4875 .41667 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.125 Mabswid
.5 .01667 m
.50375 .01667 L
s
.5 .03333 m
.50375 .03333 L
s
.5 .05 m
.50375 .05 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .11667 m
.50375 .11667 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .15 m
.50375 .15 L
s
.5 .18333 m
.50375 .18333 L
s
.5 .2 m
.50375 .2 L
s
.5 .21667 m
.50375 .21667 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .28333 m
.50375 .28333 L
s
.5 .3 m
.50375 .3 L
s
.5 .31667 m
.50375 .31667 L
s
.5 .35 m
.50375 .35 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .38333 m
.50375 .38333 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .45 m
.50375 .45 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .48333 m
.50375 .48333 L
s
.25 Mabswid
.5 0 m
.5 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.61785 .04882 m
.38215 .28452 L
.67678 .46129 L
.5 .16667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`004`3oool2000002P0oooo0`00000V0?ooo`D00000C@3oool5000002H0oooo0`00000W0?oo
o`8000004@3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00h0oooo000>0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`<00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`005@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3o
ool001<0oooo00<000000?ooo`0000009`3oool00`000000oooo0000000X0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000000W0?ooo`030000003oool0
00000100oooo000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000
0500oooo0P00000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00180oooooP00000@0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo06l0oooo002A0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0L03oool00940
oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`1a0?ooo`00T@3oool00`000000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo0780oooo002A0?ooo`030000003oool0oooo01H0oooo00<0
003o0?ooo`3oool0L`3oool00940oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`1d
0?ooo`00T@3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo07D0oooo00200?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01<0oooo00<0003o0?ooo`3oool0MP3oool007l0oooo00<000000?ooo`000000
1`3oool00`000000oooo000000050?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0
M`3oool007l0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`8000004P3o
ool00`000?l0oooo0?ooo`1h0?ooo`00O`3oool00`000000oooo000000070?ooo`8000001P3oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo07T0oooo001o0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
07X0oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo00h0
oooo00<0003o0?ooo`3oool0N`3oool00940oooo00<000000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`1l0?ooo`00T@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07d0oooo002A
0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0OP3oool00940oooo00<000000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`1o0?ooo`00T@3oool00`000000oooo0?ooo`090?ooo`03
0000o`3oool0oooo0800oooo002A0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
P@3oool00940oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`220?ooo`00T@3oool0
0`000000oooo0?ooo`060?ooo`030000o`3oool0oooo08<0oooo002A0?ooo`030000003oool0oooo
00D0oooo00<0003o0?ooo`3oool0Q03oool00940oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`250?ooo`00T@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08H0oooo
002A0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool00940oooo00D00000
0?ooo`3oool0oooo0000o`2:0?ooo`00T@3oool010000000oooo0?ooo`000?n;0?ooo`00T@3oool0
0`000000oooo0000o`2<0?ooo`00R03oool5000000@0oooo00<000000000o`3oool0S03oool008X0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo
0?ooo`030?ooo`80003o00<000000?ooo`3oool0R`3oool008X0oooo00<000000?ooo`3oool00`3o
ool00`000?l000000000o`2=0?ooo`00RP3oool00`000000oooo0?ooo`020?ooo`040000o`3oool0
00000000ohd0oooo00290?ooo`8000000`3oool01P000?l0oooo0?ooo`000000oooo0000oh`0oooo
002=0?ooo`070000o`3oool0oooo0?ooo`000000oooo0000o`2<0?ooo`00S03oool00`000?l0oooo
0?ooo`020?ooo`040000003oool0oooo0000oh/0oooo002;0?ooo`030000o`3oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000o`2:0?ooo`00RP3oool00`000?l0oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000?l0RP3oool008T0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo08L0oooo00280?ooo`030000o`3oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`00Q`3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0QP3oool008H0oooo00<0003o0?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08D0oooo00250?ooo`03
0000o`3oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`250?ooo`00
Q03oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
Q03oool008<0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000o`3o
ool0oooo08@0oooo00220?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`230?ooo`00P@3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<0003o0?ooo`3oool0PP3oool00800oooo00<0003o0?ooo`3oool03P3oool00`000000
oooo0?ooo`070?ooo`030000o`3oool0oooo0880oooo001o0?ooo`030000o`3oool0oooo00l0oooo
00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`210?ooo`00OP3oool00`000?l000000000
000200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0P@3oool007d0oooo00@0003o0?ooo`3oool00000203o
ool00`000000oooo000000050?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0P03o
ool007`0oooo00D0003o0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo0P00
000:0?ooo`030000o`3oool0oooo0800oooo001k0?ooo`030000o`3oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1o
0?ooo`00NP3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07h0oooo001i0?ooo`03
0000o`3oool0oooo00<0oooo0P0000080?ooo`<000001@3oool00`000000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo07h0oooo001h0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0
303oool00`000?l0oooo0?ooo`1m0?ooo`00M`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0O@3oool007H0oooo00<0003o0?ooo`3oool0603oool0
0`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo07`0oooo001e0?ooo`030000o`3oool0oooo
01T0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1k0?ooo`00M03oool00`000?l0
oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0N`3oool007<0oooo
00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo
001d0?ooo`80003o6`3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo001f
0?ooo`80003o6@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo07T0oooo001h0?oo
o`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1h0?oo
o`00N@3oool20000oaH0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1h0?ooo`00
N`3oool20000oa@0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`1g0?ooo`00O@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0M`3o
ool007h0oooo0P000?lA0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0MP3oool0
0800oooo0P000?l?0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0M@3oool00880
oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo07D0
oooo00230?ooo`80003o103oool3000000D0oooo00<000000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`1d0?ooo`00Q@3oool20000o`80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo07@0oooo00270?ooo`80003o00<0oooo0000003oool01@3oool2
000001L0oooo00<0003o0?ooo`3oool0L`3oool008T0oooo00<0003o0000003oool01@3oool00`00
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0780oooo00290?ooo`03000000000?l0003o00D0
oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1b0?ooo`00RP3oool010000000oooo
0000o`000?l30?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0L@3oool008h0oooo
00@0003o0?ooo`3oool000006P3oool00`000?l0oooo0?ooo`1a0?ooo`00S`3oool20000o`030000
003oool0oooo01T0oooo00<0003o0?ooo`3oool0L03oool00940oooo0P000?lK0?ooo`030000o`3o
ool0oooo06l0oooo002A0?ooo`030000003oool0003o01X0oooo00<0003o0?ooo`3oool0K`3oool0
0940oooo00<000000?ooo`3oool00P000?lI0?ooo`030000o`3oool0oooo06h0oooo002A0?ooo`03
0000003oool0oooo0080oooo0P000?lG0?ooo`030000o`3oool0oooo06h0oooo002A0?ooo`030000
003oool0oooo00@0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`1]0?ooo`00T@3o
ool00`000000oooo0?ooo`050?ooo`80003o5P3oool00`000?l0oooo0?ooo`1/0?ooo`00T@3oool0
0`000000oooo0?ooo`070?ooo`80003o503oool00`000?l0oooo0?ooo`1/0?ooo`00T@3oool00`00
0000oooo0?ooo`090?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0J`3oool00940
oooo00<000000?ooo`3oool02P3oool20000oa80oooo00<0003o0?ooo`3oool0J`3oool00940oooo
00<000000?ooo`3oool0303oool20000oa40oooo00<0003o0?ooo`3oool0JP3oool00940oooo00<0
00000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo06X0oooo002A
0?ooo`030000003oool0oooo00l0oooo0P000?l?0?ooo`030000o`3oool0oooo06T0oooo002A0?oo
o`030000003oool0oooo0140oooo0P000?l>0?ooo`030000o`3oool0oooo06P0oooo001o0?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo06P0oooo001o0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0D0?ooo`80003o
303oool00`000?l0oooo0?ooo`1W0?ooo`00P03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo0P00000G0?ooo`80003o2P3oool00`000?l0oooo0?ooo`1W0?ooo`00P03oool0
0`000000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`0H0?ooo`80003o2@3oool0
0`000?l0oooo0?ooo`1V0?ooo`00O`3oool00`000000oooo000000070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
06D0oooo00200?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo01/0
oooo0P000?l70?ooo`030000o`3oool0oooo06D0oooo002A0?ooo`030000003oool0oooo01d0oooo
0P000?l60?ooo`030000o`3oool0oooo06@0oooo002A0?ooo`030000003oool0oooo01l0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1T0?ooo`00T@3oool00`000000oooo0?ooo`0P
0?ooo`80003o103oool00`000?l0oooo0?ooo`1S0?ooo`00T@3oool00`000000oooo0?ooo`0R0?oo
o`80003o0`3oool00`000?l0oooo0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0T0?ooo`04
0000o`3oool0oooo0000of@0oooo002A0?ooo`030000003oool0oooo02D0oooo0P000?l00`3oool0
003o0?ooo`1R0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`80003oH`3oool00940oooo00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`1P0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0S03oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008/0oooo00<00000
0?ooo`3oool0TP3oool008T0oooo00<000000?ooo`000000U03oool008X0oooo00<000000?ooo`3o
ool0T`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3.44308, -0.288723, 0.0237454, 
  0.0237454}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
6.  Design any interesting stick image and transformation.  Specifically, \
define a homoMat2D, find one matrix that performs more than one of the \
geometric transformations, and plot both the before and after images \
together.\
\>", "Subsubsection"],

Cell["\<\
In class, you may want to skip to the next idea and come back to this after \
you have time to think about your design.  SAVE YOUR WORK before you go on, \
to protect in case of a \"crash.\"\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Making movies", "Subsection"],

Cell[CellGroupData[{

Cell["Flag waving", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(initA\  = \ rotMat[\(-Pi\)/5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.809016994374947451`", "0.587785252292473181`", "0"},
            {\(-0.587785252292473181`\), "0.809016994374947451`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rotStep\  = \ rotMat[Pi/20]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.987688340595137859`", \(-0.156434465040230863`\), "0"},
            {"0.156434465040230863`", "0.987688340595137859`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(view[initA.flag, {{\(-3\), 3}, {0, 3}}]; \n
    view[rotStep.initA.flag, {{\(-3\), 3}, {0, 3}}]; \n
    view[rotStep.rotStep.initA.flag, {{\(-3\), 3}, {0, 3}}]; \n\)\)], "Input"],

Cell[TextData[{
  "The above output should make sense.  We need a loop to produce many such \
pictures.  The command \nDo[ ",
  StyleBox["lines separated by semicolons",
    FontSlant->"Italic"],
  " , {i,1,6}] will execute the lines repeatedly.  The list {i,1,6} is called \
an iterator and directs Do in exactly the same way as it directs Table."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[\n\ttemp\  = \ i^2; \n\tPrint[temp]\n, {i, 1, 6}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\)], "Print"],

Cell[BoxData[
    \(TraditionalForm\`4\)], "Print"],

Cell[BoxData[
    \(TraditionalForm\`9\)], "Print"],

Cell[BoxData[
    \(TraditionalForm\`16\)], "Print"],

Cell[BoxData[
    \(TraditionalForm\`25\)], "Print"],

Cell[BoxData[
    \(TraditionalForm\`36\)], "Print"]
}, Open  ]],

Cell["\<\
Now, let's use Do to wave the flag by viewing each step and producing the \
matrix for the next step in the sequence.\
\>", "Text"],

Cell[BoxData[
    \(A\  = \ initA; \n
    Do[\n\tview[A.flag, {{\(-3\), 3}, {0, 3}}]; \n\t
      A\  = \ rotStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["\<\
Now, Select the cell bracket containing all the plots (second from the \
inside) and animate the plots by Ctrl+Y (or from the Cell menu).  While the \
movie is playing, play with the \"play-back controls\" down on the lower bar. \
 Try the \"down v's\" first.  Verbally describe what each button does to your \
instructor.\
\>", "Text"],

Cell["\<\
You should DELETE all of these multiple PLOTS before saving the notebook.  I \
suggest you scroll up to the top movie frame, Select the cell bracket \
containing all the plots (second from the inside) but not the program, then \
Cut (Ctrl-X).  If you are CAREFUL NOT TO DELETE YOUR PROGRAM, you (or I) can \
always recreate them.  Many graphics take up lots of space on the disk and in \
computer memory (RAM) while using the notebook.  If you encounter memory \
problems while saving or running Mma, delete movie frames.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rising spinning pinwheel.", "Subsubsection"],

Cell[CellGroupData[{

Cell["p = N[1/Sqrt[2]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.707106781186547461`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pinwheelpts
       = {{0, 0}, {0, 1}, {p, p}, {0, 0}, {1, 0}, {p, \(-p\)}, {0, 0}, {0, 
          \(-1\)}, {\(-p\), \(-p\)}, {0, 0}, {\(-1\), 0}, {\(-p\), p}, {0, 
          0}}; \)\), 
    \(pinwheel = 
      Append[\n\t\tTranspose[pinwheelpts], \n\t\t
        Table[1, {Length[pinwheelpts]}]\n\t]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0", "0", "0.707106781186547461`", "0", "1", 
              "0.707106781186547461`", "0", "0", \(-0.707106781186547461`\), 
              "0", \(-1\), \(-0.707106781186547461`\), "0"},
           
             {"0", "1", "0.707106781186547461`", "0", "0", 
              \(-0.707106781186547461`\), "0", \(-1\), 
              \(-0.707106781186547461`\), "0", "0", "0.707106781186547461`", 
              "0"},
            {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[pinwheel,2];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-2)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-1.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-1)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(1)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(1.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(2)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-2)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-1.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-1)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(1.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.5 .5 m
.5 .75 L
.67678 .67678 L
.5 .5 L
.75 .5 L
.67678 .32322 L
.5 .5 L
.5 .25 L
.32322 .32322 L
.5 .5 L
.25 .5 L
.32322 .67678 L
.5 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00R@3oool3000009@0oooo00290?ooo`030000003o
ool0oooo09@0oooo00240?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`800000S@3oool0
08X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R@3oool00`000000
oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool500000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo
00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`2<0?ooo`00NP3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool00800oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?oo
o`3oool0S03oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001o0?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00R03oool5000000@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00Q03oool3000000<0oooo00<000000?ooo`3oool00`3o
ool20000o`030000003oool0oooo08/0oooo002:0?ooo`040000003oool0oooo0?ooo`80003o00<0
oooo0000o`3oool0S@3oool008X0oooo00@000000?ooo`000?l0003o0`3oool00`000?l0oooo0?oo
o`2<0?ooo`00R@3oool30000o`D0oooo00<0003o0?ooo`3oool0S03oool008L0oooo0P000?l80?oo
o`030000o`3oool0oooo08`0oooo00240?ooo`<0003o2P3oool00`000?l0oooo0?ooo`2<0?ooo`00
PP3oool20000o`d0oooo00<0003o0?ooo`3oool0S03oool00800oooo0P000?l?0?ooo`030000o`00
0000oooo08`0oooo001m0?ooo`<0003o4@3oool00`000?l0oooo0?ooo`2<0?ooo`00N`3oool20000
oa@0oooo00<0003o0?ooo`3oool0S03oool007T0oooo0P000?lF0?ooo`030000o`3oool0oooo08`0
oooo001f0?ooo`<0003o603oool00`000?l0oooo0?ooo`2<0?ooo`00M03oool20000oa/0oooo00<0
003o0?ooo`3oool0S03oool00740oooo0`000?lM0?ooo`030000o`3oool0oooo08`0oooo001_0?oo
o`80003o803oool00`000?l000000?ooo`2<0?ooo`00K@3oool20000ob80oooo00<0003o0?ooo`3o
ool0S03oool006X0oooo0`000?lT0?ooo`030000o`3oool0oooo08`0oooo001X0?ooo`80003o9`3o
ool00`000?l0oooo0?ooo`2<0?ooo`00I@3oool30000obT0oooo00<0003o0?ooo`3oool0S03oool0
06<0oooo0P000?l/0?ooo`030000o`3oool0oooo08`0oooo001Q0?ooo`80003o;P3oool00`000?l0
oooo0?ooo`2<0?ooo`00G`3oool20000oc00oooo00<0003o0000003oool0;P3oool00`000?l0oooo
0?ooo`1K0?ooo`00H03oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo02d0oooo0P00
0?mM0?ooo`00H@3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo02`0oooo00@0003o
0?ooo`3oool0003oG03oool00680oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0[
0?ooo`050000o`3oool0oooo0?ooo`000?l0G03oool006<0oooo00<0003o0?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0F@3oool0
06@0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0F@3oool006D0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0X0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0F@3oool006H0oooo
00<0003o0?ooo`3oool0:03oool00`000?l000000?ooo`0W0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0F03oool006L0oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0V0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0F03oool006P0oooo00<0003o
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool0E`3oool006T0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0T0?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0E`3oool006X0oooo00<0003o0?ooo`3o
ool0903oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o
ool0E`3oool006/0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0R0?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0EP3oool006`0oooo00<0003o0?ooo`3oool0403o
ool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<0003o0?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo05H0oooo001]0?ooo`030000o`3oool0
oooo00X0oooo0`0000020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool00`3oool0
0`000?l000000?ooo`0P0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0E@3oool0
06h0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo000000070?ooo`8000001P3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0E@3oool006l0
oooo00<0003o0?ooo`3oool03@3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo05@0
oooo001`0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool01P3oool3000000D0oooo
00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo05@0oooo
001a0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0?oo
o`0F0?ooo`030000o`3oool0oooo05@0oooo001b0?ooo`030000o`3oool0oooo01`0oooo00<0003o
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo05<0oooo001c0?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0I0?oo
o`030000o`3oool0oooo05<0oooo001d0?ooo`030000o`3oool0oooo01X0oooo00<0003o0000003o
ool06@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0580oooo001e0?ooo`030000
o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0L0?ooo`030000
o`3oool0oooo0580oooo001f0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo0580oooo001g0?ooo`030000o`3oool0
oooo01L0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0
oooo0540oooo001h0?ooo`80003o5`3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo
0200oooo00<0003o0?ooo`3oool0D@3oool007X0oooo00<0003o0?ooo`3oool0503oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0D03oool007/0oooo
00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo02<0oooo
00<0003o0?ooo`3oool0D03oool007`0oooo00<0003o0?ooo`3oool04P3oool00`000?l000000?oo
o`0B0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0D03oool007d0oooo00<0003o
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo02H0oooo00<0003o
0?ooo`3oool0C`3oool007h0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0@0?oo
o`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0C`3oool007l0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3o
ool0CP3oool00800oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0CP3oool00840oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0CP3o
ool00880oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo02d0oooo00<0003o0?ooo`3oool0C@3oool008<0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l000000?ooo`0;0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0C@3oool008@0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0300
oooo00<0003o0?ooo`3oool0C03oool008D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool0C03oool000L0oooo0`00
000I0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo1@00
000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`030000o`3oool0000000@00000603oool500000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0J0?ooo`<000000`3oool000L0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000001`0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo000000070?ooo`030000003oool000000100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0000000H0?ooo`050000o`3oool0oooo0?ooo`000000703oool00`000000oooo0?oo
o`060?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool00`3oool00080oooo0`000003
0?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo00<000000?ooo`3oool05@3oool300000080oooo00<00000
0?ooo`0000002@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0000001`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool2000001d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo000000070?ooo`8000004`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo000000070?ooo`8000006P3oool0
10000?l0oooo0?ooo`00000L0?ooo`030000003oool0oooo00H0oooo0P00000M0?ooo`030000003o
ool0oooo0080oooo00070?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0000003oool0103oool0
0`000?l0oooo0?ooo`0B0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool06@3oool0
10000?l0oooo0?ooo`00000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo000000030?ooo`00203oool00`000000oooo0?ooo`0I0?ooo`800000203oool3
000001/0oooo0P00000M0?ooo`030000003oool0oooo00H0oooo0`00000D0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo0`00000J0?ooo`030000o`000000000001/0oooo0P0000080?ooo`<00000703oool0
0`000000oooo0?ooo`020?ooo`00S03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`190?ooo`00S@3oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`190?oo
o`00SP3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo03h0oooo00<0003o0?oo
o`3oool0B03oool008l0oooo00D0003o0?ooo`000?l0oooo0000o`110?ooo`030000o`3oool0oooo
04P0oooo002@0?ooo`<0003o@`3oool00`000?l0oooo0?ooo`170?ooo`001P3ooom5000008`0003o
AP0000030?ooo`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0`00
0?l40?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`03000000000?l0oooo0200oooo00<00000
0?ooo`3oool07P3oool01@000?l0oooo0000o`3oool0003o01l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00@3o
ool004`0oooo00<0003o0?ooo`3oool0?`3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo08T0oooo001=0?ooo`030000o`3oool0oooo03d0oooo00D0003o0?ooo`3oool0oooo0000
o`030?ooo`030000o`3oool0oooo08P0oooo001=0?ooo`030000o`3oool0oooo03`0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo08L0oooo001=0?oo
o`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo08H0oooo001>0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3o
ool0103oool00`000?l000000?ooo`040?ooo`030000o`3oool0oooo08D0oooo001>0?ooo`030000
o`3oool0oooo03P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo08@0oooo001?0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo08<0oooo001?0?ooo`030000o`3oool0
oooo03D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0880oooo001?0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0840oooo001@0?ooo`030000o`3oool0oooo0380
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0800
oooo001@0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo07l0oooo001A0?ooo`030000o`3oool0oooo02l0oooo00<0
003o0?ooo`3oool02`3oool00`000?l000000?ooo`0;0?ooo`030000o`3oool0oooo07h0oooo001A
0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030000o`3oool0oooo07d0oooo001B0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo07`0oooo001B0?ooo`03
0000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo07/0oooo001B0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo001C0?ooo`030000o`3o
ool0oooo02P0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo07T0oooo001C0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo07P0oooo001D0?ooo`030000o`3oool0oooo
02D0oooo00<0003o0?ooo`3oool04P3oool00`000?l000000?ooo`0B0?ooo`030000o`3oool0oooo
07L0oooo001D0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0C0?ooo`030000o`3oool0oooo07H0oooo001D0?ooo`030000o`3oool0oooo02<0oooo
00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo07D0oooo
001E0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0E0?ooo`030000o`3oool0oooo07@0oooo001E0?ooo`030000o`3oool0oooo01l0oooo0P000?lH
0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0L`3oool005H0oooo00<0003o0?oo
o`3oool07@3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?oo
o`3oool0LP3oool005H0oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`0I0?ooo`03
0000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0L@3oool005H0oooo00<0003o0?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`000000oooo01T0oooo00<0003o0?ooo`3oool0
L03oool005L0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo01X0oooo00<0003o0?ooo`3oool0K`3oool005L0oooo00<0003o0?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0KP3oool0
05P0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo
01`0oooo00<0003o0?ooo`3oool0K@3oool005P0oooo00<0003o0?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0N0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0K03oool005P0oooo
00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo01h0oooo
00<0003o0?ooo`3oool0J`3oool005T0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0>0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`000?l0oooo0?oo
o`0O0?ooo`030000o`3oool0oooo06X0oooo001I0?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool03`3oool00`000000oooo000000090?ooo`030000003oool0oooo00<0oooo00<0003o
0000003oool0803oool00`000?l0oooo0?ooo`1Y0?ooo`00FP3oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0100oooo00<000000?ooo`0000001`3oool2000000H0oooo00<0003o0?oo
o`3oool08@3oool00`000?l0oooo0?ooo`1X0?ooo`00FP3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0I`3oool005/0oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000
o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0IP3oool005/0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0I@3o
ool005/0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool0I03oool005`0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0H`3oool005`0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`000000oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool005d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0Y0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool0H@3oool005d0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo02T0oooo00<0
003o0?ooo`3oool0H03oool005d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0[
0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0G`3oool005h0oooo00D0003o0?oo
o`3oool0oooo0000o`0^0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0GP3oool0
05h0oooo00@0003o0?ooo`3oool0003o;`3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0
oooo05d0oooo001O0?ooo`80003o<03oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo
05`0oooo001O0?ooo`030000o`3oool0oooo02l0oooo00<0003o0000003oool0;@3oool20000oed0
oooo002A0?ooo`030000o`3oool0oooo02/0oooo0P000?mO0?ooo`00T@3oool00`000?l0oooo0?oo
o`0X0?ooo`<0003oH@3oool00940oooo00<0003o0?ooo`3oool09P3oool20000of@0oooo002A0?oo
o`030000o`3oool0oooo02<0oooo0`000?mV0?ooo`00T@3oool00`000?l0oooo0?ooo`0Q0?ooo`80
003oJ@3oool00940oooo00<0003o0?ooo`3oool07`3oool20000of/0oooo002A0?ooo`030000o`00
0000oooo01`0oooo0`000?m]0?ooo`00T@3oool00`000?l0oooo0?ooo`0J0?ooo`80003oL03oool0
0940oooo00<0003o0?ooo`3oool05`3oool30000og80oooo002A0?ooo`030000o`3oool0oooo01D0
oooo0P000?me0?ooo`00T@3oool00`000?l0oooo0?ooo`0B0?ooo`<0003oM`3oool00940oooo00<0
003o0?ooo`3oool0403oool20000ogX0oooo002A0?ooo`030000o`3oool0oooo00d0oooo0`000?ml
0?ooo`00T@3oool00`000?l000000?ooo`0;0?ooo`80003oO`3oool00940oooo00<0003o0?ooo`3o
ool02@3oool20000oh40oooo002A0?ooo`030000o`3oool0oooo00H0oooo0`000?n30?ooo`00T@3o
ool00`000?l0oooo0?ooo`040?ooo`80003oQP3oool008P0oooo1@0000040?ooo`040000o`3oool0
oooo0?ooo`<0003oR03oool008X0oooo00<000000?ooo`3oool0103oool010000?l0oooo0000o`00
0?n;0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`80003oS@3oool008X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo001n0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00800oooo00<000000?ooo`3oool01P3o
ool00`000000oooo000000050?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool2000008d0oooo00200?ooo`030000003oool0oooo
00H0oooo0P0000060?ooo`030000003oool0oooo08`0oooo00200?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?ooo`00O`3oool2000000P0oooo
0`0000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`80
0000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00
002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool20000
08d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000
S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008T0oooo
0`0000050?ooo`030000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool2000008d0oooo002:0?oo
o`030000003oool0oooo09<0oooo00290?ooo`030000003oool0000009@0oooo002:0?ooo`030000
003oool0oooo09<0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.08635, -2.06477, 0.0143886, 
  0.0143886}}]
}, Open  ]],

Cell["\<\
Let's rotate the pinwheel.  Of course, you'll want to animate (Ctrl-Y) the \
result of all of these movie frames.\
\>", "Text"],

Cell[CellGroupData[{

Cell["rotStep = rotMat[Pi/10]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.951056516295153642`", \(-0.309016994374947451`\), "0"},
            {"0.309016994374947451`", "0.951056516295153642`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, 2]; \n\tA\  = \ rotStep.A\n, {i, 1, 10}]; \)], 
  "Input"],

Cell["Let's make it rise straight up.", "Text"],

Cell[CellGroupData[{

Cell["upStep = {{1,0,0},{0,1,.2},{0,0,1}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {"0", "1", 
              StyleBox["0.2`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]},
            {"0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      A\  = \ upStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["\<\
The real objective of this problem is to make the pinwheel do both \
simultaeously.  Your first idea might be to just multiply by both matrices, \
rot and up, on each step.  But you may be surprised what this does.\
\>", "Text"],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      A\  = \ rotStep.upStep.A\n, {i, 1, 10}]; \)], "Input"],

Cell["Why the pinwheel doesn't move straight up?", "Text"],

Cell["\<\
This really is a problem because matrix multiplication is not commutative.  \
Why the action of matrix upStep.rotStep is different than the action of \
matrix rotStep.upStep?\
\>", "Text"],

Cell["\<\
If we want to rise straight up, we really want to do all of the rotations \
first and then all of the ups.  In particular, after two steps the image \
should be accomplished by upStep.upStep.rotStep.rotStep and not by \
upStep.rotStep.upStep.rotStep.  The idea here is to accumulate the net result \
of n rotations in Ar and the net result of n shifts up in Au.\
\>", "Text"],

Cell[BoxData[
    \(Ar\  = \ IdentityMatrix[3]; \nAu\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[Au.Ar.pinwheel, {{\(-2\), 2}, {\(-1\), 3}}]; \n\t
      Ar\  = \ rotStep.Ar; \n\t\(Au\  = \ upStep.Au; \)\n, {i, 1, 10}]; \)], 
  "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assignment -- Part II.", "Subsection"],

Cell["Names?", "Text"],

Cell[CellGroupData[{

Cell["7.  Iteration of one transformation.", "Subsubsection"],

Cell["\<\
Form the transformation matrix that rotates by Pi/6, shrinks the image by 0.8 \
and then translates the origin to (1,2).  Use a Do loop to repeatedly apply \
(iterate) this transformation 20 times to flag.  A good xyRange is \
{{-5,5},{0,7}}.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(step\  = \ transMat[1, 2].scaleMat[.8, .8].rotMat[Pi/6]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.692820323027550788`", \(-0.4`\), "1.`"},
            {"0.4`", "0.692820323027550788`", "2.`"},
            {"0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(A\  = \ IdentityMatrix[3]; \n
    Do[\n\tview[A.flag, \ {{\(-5\), 5}, {0, 7}}]; \n\t
      A\  = \ step.A\n, {i, 1, 20}]\)], "Input"],

Cell["\<\
Repeating this transformation attracts to a fixed point (one that doesn't \
move under the transformation) in very much the same way that the Markov \
chains attracted to a steady-state.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
7.  Extra credit:  Use NullSpace to find the fixed point (as in the Markov \
chain project).\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[step - IdentityMatrix[3]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.42628972679299375`", \(-0.877421144498772775`\), 
              \(-0.220020917226563561`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%/%[\([1, 3]\)]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1.93749636246642698`\), "3.98789876689433206`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.  Tumbling stickman problem", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
stickmanPts = {{-1,-3},{0,-1},{0,0},{-2,1},{0,0},
   {0,1},{-1,2},{0,3},{1,2},{0,1},{0,0},{2,1},{0,0},
   {0,-1},{1,-3}};
stickman = Append[Transpose[stickmanPts],Table[1,{15}]]
   \
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-1\), "0", "0", \(-2\), "0", "0", \(-1\), "0", "1", "0", "0", 
              "2", "0", "0", "1"},
           
             {\(-3\), \(-1\), "0", "1", "0", "1", "2", "3", "2", "1", "0", 
              "1", "0", \(-1\), \(-3\)},
           
             {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1",
               "1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["view[stickman,4];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.375 .125 m
.5 .375 L
.5 .5 L
.25 .625 L
.5 .5 L
.5 .625 L
.375 .75 L
.5 .875 L
.625 .75 L
.5 .625 L
.5 .5 L
.75 .625 L
.5 .5 L
.5 .375 L
.625 .125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00RP3oool3000009<0oooo002;0?ooo`030000003o
ool0oooo0980oooo00240?ooo`<000000P3oool4000000@0oooo0P00002=0?ooo`00R@3oool00`00
0000oooo000000050?ooo`030000003oool0oooo08`0oooo002:0?ooo`8000001@3oool00`000000
oooo0?ooo`2<0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool008T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo
002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool006h0oooo00<0003o
0?ooo`3oool04`3oool3000000<0oooo00<000000?ooo`3oool0103oool200000200oooo00<0003o
0?ooo`3oool0JP3oool006l0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0JP3oool006l0oooo00<0003o0?ooo`3o
ool05`3oool00`000000oooo000000050?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3o
ool0J`3oool00700oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01h0oooo00<0003o0?ooo`3oool0J`3oool00700oooo00<0003o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo06`0oooo001a0?ooo`030000o`3oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`1/0?ooo`00L@3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0K@3oool00780
oooo00<0003o0?ooo`3oool0703oool2000001d0oooo00<0003o0?ooo`3oool0K@3oool00780oooo
00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo06h0oooo
001c0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`1^0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<0003o
0?ooo`3oool0K`3oool007@0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo06l0oooo001d0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`1`0?ooo`00M@3oool00`000?l0oooo0?ooo`0I0?ooo`030000
003oool0oooo01T0oooo00<0003o0?ooo`3oool0L03oool007D0oooo00<0003o0?ooo`3oool06@3o
ool2000001T0oooo00<0003o0?ooo`3oool0L@3oool007H0oooo00<0003o0?ooo`3oool0603oool0
0`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0740oooo001f0?ooo`030000o`3oool0oooo
01P0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1b0?ooo`00M`3oool00`000?l0
oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0LP3oool007L0oooo
00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo07<0oooo
001h0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?oo
o`1c0?ooo`00N03oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool0M03oool007T0oooo00<0003o0?ooo`3oool05@3oool2000001H0oooo00<0003o0?oo
o`3oool0M03oool007T0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo07D0oooo001j0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0
503oool00`000?l0oooo0?ooo`1e0?ooo`00NP3oool00`000?l0oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<0003o0?ooo`3oool0MP3oool007/0oooo00<0003o0?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo07H0oooo001k0?ooo`030000o`3oool0oooo
01<0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`1g0?ooo`00O03oool00`000?l0
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0M`3oool007`0oooo
00<0003o0?ooo`3oool04P3oool200000180oooo00<0003o0?ooo`3oool0N03oool007d0oooo00<0
003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo07P0oooo001m
0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`1i
0?ooo`00OP3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0003o0?oo
o`3oool0N@3oool007h0oooo00<0003o0?ooo`3oool0203oool3000000D0oooo00<000000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`1j0?ooo`00O`3oool00`000?l0oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1j0?ooo`00O`3o
ool00`000?l0oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`8000003`3o
ool00`000?l0oooo0?ooo`1k0?ooo`00P03oool00`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1k0?ooo`00P03oool00`00
0?l0oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`1l0?ooo`00P@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1l0?ooo`00P@3oool00`000?l0oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0O@3oool00880oooo00<0
003o0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07d0oooo0022
0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1n
0?ooo`00P`3oool00`000?l0oooo0?ooo`0;0?ooo`800000303oool00`000?l0oooo0?ooo`1n0?oo
o`00P`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0O`3oool008@0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo07l0oooo00240?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`200?ooo`00Q@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<0003o0?ooo`3oool0P03oool008D0oooo00<0003o0?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000o`3oool0oooo0840oooo00260?ooo`030000o`3oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`210?ooo`00QP3oool00`000?l0oooo
0?ooo`080?ooo`800000203oool00`000?l0oooo0?ooo`220?ooo`00Q`3oool00`000?l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0PP3oool008L0oooo00<0003o
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo08<0oooo00280?oo
o`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`230?oo
o`00R03oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0Q03oool008T0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
o`3oool0oooo08@0oooo00290?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`250?ooo`00RP3oool00`000?l0oooo0?ooo`040?ooo`8000001@3oool0
0`000?l0oooo0?ooo`250?ooo`00RP3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool0QP3oool008/0oooo00<0003o0?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000o`3oool0oooo08H0oooo002;0?ooo`030000o`3oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`00S03oool00`000?l0oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool008`0oooo00<0003o
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0003o08X0oooo002=0?ooo`050000o`3oool0
oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`280?ooo`00S@3oool010000?l0oooo0?ooo`3o
ool2000000030?ooo`000?l0oooo08X0oooo002>0?ooo`040000o`3oool0oooo00000080oooo00<0
003o0?ooo`3oool0R@3oool008h0oooo00H0003o0?ooo`3oool000000?ooo`000?n<0?ooo`00S`3o
ool01@000?l0oooo0000003oool0003o08`0oooo002?0?ooo`040000o`3oool000000000ohd0oooo
00280?ooo`D000000`3oool00`000?l000000000o`2=0?ooo`00RP3oool00`000000oooo0?ooo`03
0?ooo`80003oSP3oool008@0oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<0003o0000
003oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`2<0?ooo`00
RP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08`0oooo00290?ooo`8000001P3o
ool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`00
0?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l00000
0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<
0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00
T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool0
0`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0
oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?oo
o`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?oo
o`00T@3oool00`000?l000000?ooo`2<0?ooo`00T@3oool00`000?l0oooo0?ooo`2<0?ooo`00T@3o
ool00`000?l0oooo0?ooo`2<0?ooo`00203oool3000001h0oooo0P00000Q0?ooo`<000007`3oool5
000001h0oooo00<0003o0?ooo`3oool07@3oool5000001l0oooo0`00000O0?ooo`8000008P3oool3
00000080oooo00090?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`010?ooo`000P3oool300000080oooo1000000I0?ooo`<000000`3oool00`000000
oooo0?ooo`0J0?ooo`<000000`3oool00`000000oooo0?ooo`0J0?ooo`<000000`3oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo100000020?ooo`001`3oool00`000000oooo
0000000Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`0000000`3oool000P0oooo0P00
000O0?ooo`030000003oool000000200oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`0N0?ooo`030000o`000000oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
000O0?ooo`030000003oool000000240oooo0P0000030?ooo`002@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool200000200oooo00<0003o
0?ooo`3oool07P3oool200000280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0040oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`03
0000o`3oool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo002A0?ooo`030000o`3o
ool0oooo08`0oooo002A0?ooo`030000o`3oool0oooo08`0oooo00060?oooh/0000000<0003o0000
00000000R@0000030?ooo`001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo1@000?l30?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000H0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0703oool20000o`80oooo00<0003o0?ooo`3oool00P000?lM0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0040oooo002;0?ooo`80003o103oool00`000?l0oooo0?ooo`020?ooo`80003oR03o
ool008T0oooo0P000?l60?ooo`030000o`3oool0oooo00@0oooo0P000?n60?ooo`00Q`3oool20000
o`P0oooo00<0003o0?ooo`3oool01P3oool20000oh@0oooo00250?ooo`80003o2P3oool00`000?l0
oooo0?ooo`080?ooo`80003oPP3oool008<0oooo0P000?l<0?ooo`030000o`000000oooo00X0oooo
0P000?n00?ooo`00P@3oool20000o`h0oooo00<0003o0?ooo`3oool0303oool20000ogh0oooo001o
0?ooo`80003o403oool00`000?l0oooo0?ooo`0>0?ooo`80003oO03oool007d0oooo0P000?lB0?oo
o`030000o`3oool0oooo0100oooo0P000?mj0?ooo`00N`3oool20000oa@0oooo00<0003o0?ooo`3o
ool04P3oool20000ogP0oooo001i0?ooo`80003o5P3oool00`000?l0oooo0?ooo`0D0?ooo`80003o
MP3oool007L0oooo0P000?lH0?ooo`030000o`3oool0oooo01H0oooo0P000?md0?ooo`00M@3oool2
0000oaX0oooo00<0003o0000003oool0603oool20000og80oooo001c0?ooo`80003o703oool00`00
0?l0oooo0?ooo`0J0?ooo`80003oL03oool00740oooo0P000?lN0?ooo`030000o`3oool0oooo01`0
oooo0P000?m^0?ooo`00K`3oool20000ob00oooo00<0003o0?ooo`3oool07P3oool20000of`0oooo
001]0?ooo`80003o8P3oool00`000?l0oooo0?ooo`0P0?ooo`80003oJP3oool006/0oooo0P000?lT
0?ooo`030000o`3oool0oooo0280oooo0P000?mX0?ooo`00J@3oool20000obH0oooo00<0003o0?oo
o`3oool0903oool20000ofH0oooo001W0?ooo`80003o:03oool00`000?l000000?ooo`0V0?ooo`80
003oI03oool006D0oooo0P000?lZ0?ooo`030000o`3oool0oooo02P0oooo0P000?mR0?ooo`00H`3o
ool20000ob`0oooo00<0003o0?ooo`3oool0:P3oool20000of00oooo001Q0?ooo`80003o;P3oool0
0`000?l0oooo0?ooo`0/0?ooo`80003oGP3oool005l0oooo0P000?l`0?ooo`030000o`3oool0oooo
02h0oooo0P000?mL0?ooo`00G@3oool20000oc80oooo00<0003o0?ooo`3oool0<03oool20000oeX0
oooo001K0?ooo`80003o=03oool00`000?l0oooo0?ooo`0b0?ooo`80003oF03oool005T0oooo0P00
0?lf0?ooo`030000o`000000oooo03@0oooo0P000?mF0?ooo`00E`3oool20000ocP0oooo00<0003o
0?ooo`3oool0=P3oool20000oe@0oooo001E0?ooo`80003o>P3oool00`000?l0oooo0?ooo`0h0?oo
o`80003oDP3oool005<0oooo0P000?ll0?ooo`030000o`3oool0oooo03X0oooo0P000?m@0?ooo`00
D@3oool20000och0oooo00<0003o0?ooo`3oool0?03oool20000odh0oooo001?0?ooo`80003o=`3o
ool5000000@0oooo00<0003o0?ooo`3oool0?P3oool20000od`0oooo001=0?ooo`80003o>`3oool0
0`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0400oooo0P000?m:0?ooo`00B`3oool20000
ocd0oooo00<000000?ooo`3oool0103oool00`000?l000000?ooo`120?ooo`030000o`3oool0oooo
04L0oooo002:0?ooo`030000003oool0oooo00<0oooo00<0003o000000000?l0S@3oool008X0oooo
00<000000?ooo`3oool00P3oool01@000?l0oooo0000003oool0003o08`0oooo00290?ooo`800000
0`3oool010000?l0oooo0?ooo`0000020?ooo`030000o`3oool0oooo08T0oooo002=0?ooo`050000
o`3oool0oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`280?ooo`00S03oool00`000?l0oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool008/0oooo00<0
003o0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08H0oooo002:
0?ooo`030000o`3oool0oooo00@0oooo0P0000050?ooo`030000o`3oool0oooo08D0oooo00290?oo
o`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`240?oo
o`00R03oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0P`3oool008L0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
o`3oool0oooo0880oooo00260?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`210?ooo`00Q@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<0003o0?ooo`3oool0P03oool008@0oooo00<0003o0?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo07l0oooo00230?ooo`030000o`3oool0oooo00/0
oooo0P00000<0?ooo`030000o`3oool0oooo07h0oooo00220?ooo`030000o`3oool0oooo00`0oooo
00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`1m0?ooo`00P@3oool00`000?l0oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0O03oool007l0oooo0P000?l@
0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0N`3oool007h0oooo00<0003o0?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo001m0?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`1i0?ooo`00
O03oool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0
N03oool007/0oooo00<0003o0?ooo`3oool04`3oool2000001<0oooo00<0003o0?ooo`3oool0M`3o
ool007X0oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo07H0oooo001i0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`1e0?ooo`00N03oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0
oooo00<0003o0?ooo`3oool0M03oool007L0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo07<0oooo001f0?ooo`030000o`3oool0oooo01P0oooo00<0
00000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1b0?ooo`00M@3oool00`000?l0oooo0?ooo`0I
0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0L@3oool007@0oooo00<0003o0?oo
o`3oool06P3oool2000001X0oooo00<0003o0?ooo`3oool0L03oool007<0oooo00<0003o0?ooo`3o
ool06`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo06l0oooo001b0?ooo`030000
o`3oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`1^0?ooo`00L@3o
ool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0K@3o
ool00700oooo00<0003o0?ooo`3oool05P3oool3000000D0oooo00<000000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`1/0?ooo`00K`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`1[0?ooo`00KP3oool00`000?l0
oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0P00000P0?ooo`030000o`3oool0oooo06X0
oooo001_0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo06/0oooo001`0?ooo`030000o`3oool0oooo01H0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo06`0oooo001a
0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo06d0oooo001b0?ooo`030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`1^0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01X0oooo00<0003o0?ooo`3oool0K`3oool007@0oooo00<0003o0?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0700oooo001e0?ooo`030000o`3o
ool0oooo01T0oooo0P00000I0?ooo`030000o`3oool0oooo0740oooo001f0?ooo`030000o`3oool0
oooo01P0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1b0?ooo`00M`3oool00`00
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0L`3oool007P0
oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo07@0
oooo001i0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000?l0oooo
0?ooo`1e0?ooo`00NP3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<0
003o0?ooo`3oool0MP3oool007/0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo07L0oooo001l0?ooo`030000o`3oool0oooo0180oooo0P00000B0?oo
o`030000o`3oool0oooo07P0oooo001m0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`1i0?ooo`00OP3oool00`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<0003o0?ooo`3oool0NP3oool007l0oooo00<0003o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo07/0oooo00200?ooo`030000o`3oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1k0?ooo`00P@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0O03oool00880
oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo07d0
oooo00230?ooo`030000o`3oool0oooo00/0oooo0P00000<0?ooo`030000o`3oool0oooo07h0oooo
00240?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`1o0?ooo`00Q@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0003o
0?ooo`3oool0P03oool008H0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000o`3oool0oooo0840oooo00270?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`220?ooo`00R03oool00`000?l0oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<0003o0?ooo`3oool0P`3oool008T0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo08@0oooo002:0?ooo`030000o`3oool0
oooo00@0oooo0P0000050?ooo`030000o`3oool0oooo08D0oooo002;0?ooo`030000o`3oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`260?ooo`00S03oool00`000?l0
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool008d0oooo
00D0003o0?ooo`3oool0oooo000000030?ooo`030000o`3oool0oooo08P0oooo002>0?ooo`040000
o`3oool0oooo00000080oooo00<0003o0?ooo`3oool0R@3oool008T0oooo0P0000040?ooo`050000
o`3oool000000?ooo`000?l0S03oool008/0oooo00<000000?ooo`3oool00P3oool00`000?l00000
0000o`2=0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000o`000000oooo08`0oooo002;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool008T0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool008X0oooo0`0000040?ooo`03
0000003oool0oooo08`0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
S03oool008T0oooo100000040?ooo`800000S@3oool008T0oooo00<000000?ooo`000000U03oool0
08X0oooo0P00002D0?ooo`00R`3oool00`000000oooo0?ooo`2B0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.1727, -4.12954, 0.0287773, 
  0.0287773}}]
}, Open  ]],

Cell["\<\
Your mission is to make this stickman do cartwheels across the screen.  The \
final result should show him starting by standing on the x-axis and tumbling \
across the x-axis floor for two total revolutions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rotStep\  = \ rotMat[\(-Pi\)/8]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.923879532511286782`", "0.382683432365089792`", "0"},
            {\(-0.382683432365089792`\), "0.923879532511286782`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(overStep\  = \ transMat[.5, 0]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0", "0.5`"},
            {"0", "1.`", "0"},
            {"0", "0", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Ar\  = \ IdentityMatrix[3]; \nAt\  = \ transMat[\(-4\), 3]; \n
    Do[\n\tview[At.Ar.stickman, {{\(-6\), 14}, {0, 6}}]; \n\t
      Ar\  = \ rotStep.Ar; \n\t\(At\  = \ overStep.At; \)\n, {i, 1, 33}]; \)],
   "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{580, 399},
WindowMargins->{{0, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 162, 4, 66, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1896, 57, 75, 3, 83, "Subtitle"],
Cell[1974, 62, 153, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[2152, 70, 88, 2, 53, "Section"],
Cell[2243, 74, 55, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2323, 78, 57, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[2405, 82, 43, 0, 43, "Subsubsection"],
Cell[2451, 84, 157, 3, 33, "Text"],
Cell[2611, 89, 55, 0, 30, "Input"],
Cell[2669, 91, 48, 0, 30, "Input"],
Cell[2720, 93, 110, 3, 48, "Input"],
Cell[2833, 98, 504, 8, 90, "Text"],
Cell[3340, 108, 35, 0, 30, "Input"],
Cell[3378, 110, 119, 3, 48, "Input"]
}, Open  ]],
Cell[3512, 116, 119, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3656, 123, 159, 4, 60, "Subsubsection"],
Cell[3818, 129, 64, 0, 30, "Input"],
Cell[3885, 131, 129, 3, 48, "Input"],
Cell[4017, 136, 72, 0, 33, "Text"],
Cell[4092, 138, 37, 0, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4178, 144, 91, 2, 31, "Subsection"],
Cell[4272, 148, 352, 8, 109, "Text"],
Cell[4627, 158, 29, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4693, 163, 68, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[4786, 167, 46, 0, 43, "Subsubsection"],
Cell[4835, 169, 64, 0, 30, "Input"],
Cell[4902, 171, 46, 0, 33, "Text"],
Cell[4951, 173, 241, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5229, 182, 46, 0, 43, "Subsubsection"],
Cell[5278, 184, 91, 2, 33, "Text"],
Cell[5372, 188, 474, 7, 71, "Text"],
Cell[5849, 197, 226, 4, 52, "Text"],
Cell[6078, 203, 84, 7, 120, "Input"],
Cell[6165, 212, 243, 5, 52, "Text"],
Cell[6411, 219, 579, 9, 90, "Text"]
}, Open  ]],
Cell[7005, 231, 57, 0, 43, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[7099, 236, 37, 0, 31, "Subsection"],
Cell[7139, 238, 71, 0, 43, "Subsubsection"],
Cell[7213, 240, 269, 5, 77, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[7519, 250, 35, 0, 31, "Subsection"],
Cell[7557, 252, 64, 0, 30, "Input"],
Cell[7624, 254, 100, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7749, 260, 68, 0, 43, "Subsubsection"],
Cell[7820, 262, 24, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7881, 267, 108, 2, 43, "Subsubsection"],
Cell[7992, 271, 239, 4, 52, "Text"],
Cell[8234, 277, 32, 0, 30, "Input"],
Cell[8269, 279, 86, 7, 120, "Input"],
Cell[8358, 288, 199, 4, 52, "Text"],
Cell[8560, 294, 89, 2, 33, "Text"]
}, Open  ]]
}, Closed]],
Cell[8676, 300, 110, 3, 31, "Subsection"],

Cell[CellGroupData[{
Cell[8811, 307, 95, 2, 47, "Subsection"],
Cell[8909, 311, 57, 0, 30, "Input"],
Cell[8969, 313, 140, 3, 33, "Text"],
Cell[9112, 318, 25, 0, 30, "Input"],
Cell[9140, 320, 41, 0, 30, "Input"],
Cell[9184, 322, 130, 3, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9351, 330, 138, 3, 50, "Subsection"],
Cell[9492, 335, 50, 0, 30, "Input"],
Cell[9545, 337, 65, 0, 30, "Input"],
Cell[9613, 339, 191, 4, 52, "Text"],
Cell[9807, 345, 27, 0, 30, "Input"],
Cell[9837, 347, 218, 5, 52, "Text"],
Cell[10058, 354, 90, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[10173, 362, 75, 0, 43, "Subsubsection"],
Cell[10251, 364, 39, 0, 30, "Input"]
}, Open  ]],
Cell[10305, 367, 60, 0, 43, "Subsubsection"],
Cell[10368, 369, 114, 3, 43, "Subsubsection"]
}, Closed]],
Cell[10497, 375, 47, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[10569, 379, 92, 2, 47, "Subsection"],
Cell[10664, 383, 366, 6, 71, "Text"],
Cell[11033, 391, 223, 10, 174, "Input"],
Cell[11259, 403, 376, 6, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11672, 414, 83, 1, 31, "Subsection"],
Cell[11758, 417, 113, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11908, 425, 85, 1, 31, "Subsection"],
Cell[11996, 428, 98, 2, 33, "Text"],
Cell[12097, 432, 144, 3, 33, "Text"]
}, Closed]],
Cell[12256, 438, 51, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[12332, 442, 74, 0, 47, "Subsection"],
Cell[12409, 444, 33, 0, 30, "Input"],
Cell[12445, 446, 139, 3, 48, "Input"],
Cell[12587, 451, 122, 4, 66, "Input"],
Cell[12712, 457, 48, 0, 30, "Input"],
Cell[12763, 459, 42, 0, 33, "Text"],
Cell[12808, 461, 148, 4, 66, "Input"],
Cell[12959, 467, 53, 0, 30, "Input"],
Cell[13015, 469, 47, 0, 33, "Text"],
Cell[13065, 471, 48, 0, 30, "Input"],
Cell[13116, 473, 52, 0, 30, "Input"],
Cell[13171, 475, 238, 4, 52, "Text"],
Cell[13412, 481, 56, 0, 30, "Input"],
Cell[13471, 483, 66, 0, 33, "Text"],
Cell[13540, 485, 190, 4, 52, "Text"],
Cell[13733, 491, 679, 10, 109, "Text"],
Cell[14415, 503, 295, 13, 228, "Input"],
Cell[14713, 518, 25, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14775, 523, 67, 0, 31, "Subsection"],
Cell[14845, 525, 153, 4, 66, "Input"],
Cell[15001, 531, 58, 0, 30, "Input"],
Cell[15062, 533, 48, 0, 30, "Input"],
Cell[15113, 535, 263, 5, 52, "Text"],
Cell[15379, 542, 324, 5, 52, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15752, 553, 66, 0, 33, "Section"],
Cell[15821, 555, 55, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[15901, 559, 57, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[15983, 563, 44, 0, 43, "Subsubsection"],
Cell[16030, 565, 157, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[16212, 572, 55, 0, 30, "Input"],
Cell[16270, 574, 601, 18, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16908, 597, 48, 0, 30, "Input"],
Cell[16959, 599, 20671, 423, 186, 2619, 196, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37667, 1027, 110, 3, 48, "Input"],
Cell[37780, 1032, 25232, 611, 296, 3682, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[63027, 1646, 504, 8, 90, "Text"],

Cell[CellGroupData[{
Cell[63556, 1658, 35, 0, 30, "Input"],
Cell[63594, 1660, 573, 16, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64204, 1681, 119, 3, 48, "Input"],
Cell[64326, 1686, 25232, 611, 296, 3682, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[89607, 2303, 119, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[89751, 2310, 74, 0, 30, "Input"],
Cell[89828, 2312, 1102, 31, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90967, 2348, 119, 3, 48, "Input"],
Cell[91089, 2353, 23886, 595, 296, 3697, 341, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[115024, 2954, 160, 4, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[115209, 2962, 64, 0, 30, "Input"],
Cell[115276, 2964, 537, 15, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115850, 2984, 129, 3, 48, "Input"],
Cell[115982, 2989, 19647, 542, 235, 3682, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[135644, 3534, 67, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[135736, 3538, 55, 0, 30, "Input"],
Cell[135794, 3540, 670, 20, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136501, 3565, 56, 0, 30, "Input"],
Cell[136560, 3567, 21799, 470, 186, 3134, 235, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158396, 4042, 37, 0, 30, "Input"],
Cell[158436, 4044, 28548, 656, 296, 3726, 345, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[187045, 4707, 91, 2, 31, "Subsection"],
Cell[187139, 4711, 352, 8, 109, "Text"],
Cell[187494, 4721, 158, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[187677, 4729, 29, 0, 30, "Input"],
Cell[187709, 4731, 26181, 557, 296, 3173, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[213939, 5294, 68, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[214032, 5298, 46, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[214103, 5302, 64, 0, 30, "Input"],
Cell[214170, 5304, 573, 16, 44, "Output"]
}, Open  ]],
Cell[214758, 5323, 46, 0, 33, "Text"],
Cell[214807, 5325, 241, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[215073, 5333, 40, 0, 30, "Input"],
Cell[215116, 5335, 405, 12, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215558, 5352, 24, 0, 30, "Input"],
Cell[215585, 5354, 258, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215880, 5365, 140, 3, 30, "Input"],
Cell[216023, 5370, 25325, 614, 296, 3682, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241385, 5989, 132, 3, 30, "Input"],
Cell[241520, 5994, 27161, 636, 296, 3696, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268718, 6635, 44, 0, 30, "Input"],
Cell[268765, 6637, 32163, 701, 296, 3740, 345, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[300977, 7344, 46, 0, 29, "Subsubsection"],
Cell[301026, 7346, 91, 2, 33, "Text"],
Cell[301120, 7350, 474, 7, 71, "Text"],
Cell[301597, 7359, 226, 4, 52, "Text"],
Cell[301826, 7365, 84, 7, 120, "Input"],
Cell[301913, 7374, 298, 6, 71, "Text"],
Cell[302214, 7382, 545, 8, 90, "Text"]
}, Closed]],
Cell[302774, 7393, 57, 0, 29, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[302868, 7398, 37, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[302930, 7402, 71, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[303026, 7406, 35, 0, 30, "Input"],
Cell[303064, 7408, 196, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303297, 7419, 31, 0, 30, "Input"],
Cell[303331, 7421, 26189, 557, 296, 3173, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[329557, 7983, 31, 0, 30, "Input"],
Cell[329591, 7985, 24184, 533, 296, 3193, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[353824, 8524, 269, 5, 77, "Subsubsection"],

Cell[CellGroupData[{
Cell[354118, 8533, 91, 3, 48, "Input"],
Cell[354212, 8538, 199, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[354448, 8548, 24, 0, 30, "Input"],
Cell[354475, 8550, 183, 5, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[354695, 8560, 29, 0, 30, "Input"],
Cell[354727, 8562, 26181, 557, 296, 3173, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380945, 9124, 38, 0, 30, "Input"],
Cell[380986, 9126, 23084, 518, 296, 3175, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[404107, 9649, 60, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[404192, 9656, 24184, 533, 296, 3193, 269, "GraphicsData", 
"PostScript", "Graphics"],
Cell[428379, 10191, 23443, 524, 296, 3185, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[451895, 10723, 35, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[451955, 10727, 64, 0, 30, "Input"],
Cell[452022, 10729, 573, 16, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452632, 10750, 100, 2, 43, "Subsubsection"],
Cell[452735, 10754, 25, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[452785, 10758, 89, 2, 30, "Input"],
Cell[452877, 10762, 203, 5, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[453129, 10773, 68, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[453222, 10777, 24, 0, 30, "Input"],
Cell[453249, 10779, 187, 5, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453473, 10789, 38, 0, 30, "Input"],
Cell[453514, 10791, 24453, 535, 296, 3175, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[478016, 11332, 108, 2, 43, "Subsubsection"],
Cell[478127, 11336, 239, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[478391, 11344, 32, 0, 30, "Input"],
Cell[478426, 11346, 276, 6, 44, "Output"]
}, Open  ]],
Cell[478717, 11355, 86, 7, 120, "Input"],
Cell[478806, 11364, 199, 4, 52, "Text"],
Cell[479008, 11370, 89, 2, 33, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[479146, 11378, 110, 3, 31, "Subsection"],

Cell[CellGroupData[{
Cell[479281, 11385, 61, 0, 30, "Input"],
Cell[479345, 11387, 225, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[479607, 11398, 27, 0, 30, "Input"],
Cell[479637, 11400, 29759, 601, 296, 3155, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509433, 12006, 89, 2, 30, "Input"],
Cell[509525, 12010, 203, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509765, 12020, 53, 0, 30, "Input"],
Cell[509821, 12022, 274, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[510132, 12033, 29, 0, 30, "Input"],
Cell[510164, 12035, 30152, 606, 296, 3155, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[540353, 12646, 26, 0, 30, "Input"],
Cell[540382, 12648, 71, 1, 29, "Output"]
}, Open  ]],
Cell[540468, 12652, 84, 7, 120, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[540589, 12664, 95, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[540709, 12670, 57, 0, 30, "Input"],
Cell[540769, 12672, 213, 6, 44, "Output"]
}, Open  ]],
Cell[540997, 12681, 140, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[541162, 12688, 25, 0, 30, "Input"],
Cell[541190, 12690, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[541290, 12696, 41, 0, 30, "Input"],
Cell[541334, 12698, 213, 6, 44, "Output"]
}, Open  ]],
Cell[541562, 12707, 130, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[541717, 12714, 40, 0, 30, "Input"],
Cell[541760, 12716, 20770, 556, 296, 3660, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[562567, 13277, 39, 0, 30, "Input"],
Cell[562609, 13279, 17980, 423, 296, 2854, 232, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580626, 13707, 69, 0, 30, "Input"],
Cell[580698, 13709, 25710, 556, 296, 3187, 273, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[606457, 14271, 138, 3, 50, "Subsection"],

Cell[CellGroupData[{
Cell[606620, 14278, 50, 0, 30, "Input"],
Cell[606673, 14280, 444, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607154, 14298, 65, 0, 30, "Input"],
Cell[607222, 14300, 247, 7, 62, "Output"]
}, Open  ]],
Cell[607484, 14310, 191, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[607700, 14318, 27, 0, 30, "Input"],
Cell[607730, 14320, 213, 6, 44, "Output"]
}, Open  ]],
Cell[607958, 14329, 218, 5, 52, "Text"],
Cell[608179, 14336, 216, 7, 120, "Input"],

Cell[CellGroupData[{
Cell[608420, 14347, 75, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[608520, 14351, 39, 0, 30, "Input"],
Cell[608562, 14353, 21537, 500, 296, 3141, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[630136, 14858, 41, 0, 30, "Input"],
Cell[630180, 14860, 22681, 514, 296, 3143, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[652910, 15380, 60, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[652995, 15384, 24, 0, 30, "Input"],
Cell[653022, 15386, 187, 5, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[653246, 15396, 129, 4, 66, "Input"],
Cell[653378, 15402, 226, 6, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[653641, 15413, 41, 0, 30, "Input"],
Cell[653685, 15415, 25372, 612, 296, 3703, 340, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[679084, 16031, 114, 3, 43, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[679235, 16039, 47, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[679307, 16043, 46, 0, 30, "Input"],
Cell[679356, 16045, 135, 14, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[679528, 16064, 31, 0, 30, "Input"],
Cell[679562, 16066, 18546, 621, 296, 3493, 431, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[698145, 16692, 33, 0, 30, "Input"],
Cell[698181, 16694, 18595, 622, 296, 3493, 431, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[716825, 17322, 92, 2, 31, "Subsection"],
Cell[716920, 17326, 366, 6, 71, "Text"],
Cell[717289, 17334, 223, 10, 174, "Input"],
Cell[717515, 17346, 376, 6, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[717928, 17357, 83, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[718036, 17362, 48, 0, 30, "Input"],
Cell[718087, 17364, 442, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[718566, 17382, 32, 0, 30, "Input"],
Cell[718601, 17384, 65, 1, 29, "Output"]
}, Open  ]],
Cell[718681, 17388, 34, 0, 30, "Input"],
Cell[718718, 17390, 113, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[718868, 17398, 85, 1, 31, "Subsection"],
Cell[718956, 17401, 98, 2, 33, "Text"],
Cell[719057, 17405, 144, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[719226, 17412, 48, 0, 30, "Input"],
Cell[719277, 17414, 474, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[719788, 17432, 136, 4, 66, "Input"],
Cell[719927, 17438, 317, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[720281, 17450, 47, 0, 30, "Input"],
Cell[720331, 17452, 235, 7, 62, "Output"]
}, Open  ]],
Cell[720581, 17462, 48, 0, 30, "Input"],
Cell[720632, 17464, 32, 0, 30, "Input"],
Cell[720667, 17466, 32, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[720736, 17471, 51, 0, 31, "Subsection"],
Cell[720790, 17473, 48, 0, 30, "Input"],
Cell[720841, 17475, 53, 0, 30, "Input"],
Cell[720897, 17477, 55, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[720989, 17482, 74, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[721088, 17486, 33, 0, 30, "Input"],
Cell[721124, 17488, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[721233, 17494, 139, 3, 48, "Input"],
Cell[721375, 17499, 582, 13, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[721994, 17517, 122, 4, 66, "Input"],
Cell[722119, 17523, 661, 14, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[722817, 17542, 48, 0, 30, "Input"],
Cell[722868, 17544, 26520, 634, 296, 3780, 349, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[749403, 18181, 42, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[749470, 18185, 148, 4, 66, "Input"],
Cell[749621, 18191, 317, 7, 62, "Output"]
}, Open  ]],
Cell[749953, 18201, 53, 0, 30, "Input"],
Cell[750009, 18203, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[750081, 18207, 48, 0, 30, "Input"],
Cell[750132, 18209, 337, 10, 62, "Output"]
}, Open  ]],
Cell[750484, 18222, 52, 0, 30, "Input"],
Cell[750539, 18224, 238, 4, 71, "Text"],
Cell[750780, 18230, 56, 0, 30, "Input"],
Cell[750839, 18232, 66, 0, 33, "Text"],
Cell[750908, 18234, 191, 4, 52, "Text"],
Cell[751102, 18240, 679, 10, 147, "Text"],
Cell[751784, 18252, 295, 13, 228, "Input"],
Cell[752082, 18267, 25, 0, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[752144, 18272, 67, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[752236, 18276, 153, 4, 66, "Input"],
Cell[752392, 18282, 400, 10, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[752829, 18297, 58, 0, 30, "Input"],
Cell[752890, 18299, 517, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[753444, 18317, 48, 0, 30, "Input"],
Cell[753495, 18319, 25096, 619, 296, 3770, 351, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[778606, 18941, 263, 5, 52, "Text"],
Cell[778872, 18948, 466, 15, 264, "Input"],
Cell[779341, 18965, 324, 5, 52, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[779714, 18976, 170, 3, 75, "Section"],

Cell[CellGroupData[{
Cell[779909, 18983, 134, 3, 66, "Subsection"],
Cell[780046, 18988, 90, 2, 30, "Input",
  InitializationCell->True],
Cell[780139, 18992, 340, 11, 174, "Input",
  InitializationCell->True],
Cell[780482, 19005, 195, 4, 30, "Input",
  InitializationCell->True],
Cell[780680, 19011, 123, 3, 30, "Input",
  InitializationCell->True],
Cell[780806, 19016, 117, 2, 30, "Input",
  InitializationCell->True],
Cell[780926, 19020, 178, 4, 90, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[781141, 19029, 64, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[781230, 19033, 70, 0, 43, "Subsubsection"],
Cell[781303, 19035, 105, 3, 33, "Text"],
Cell[781411, 19040, 77, 1, 30, "Input"],
Cell[781491, 19043, 49, 0, 30, "Input"],
Cell[781543, 19045, 389, 8, 71, "Text"],
Cell[781935, 19055, 84, 3, 48, "Input"],
Cell[782022, 19060, 71, 0, 33, "Text"],
Cell[782096, 19062, 111, 3, 48, "Input"],
Cell[782210, 19067, 373, 6, 71, "Text"],
Cell[782586, 19075, 62, 1, 30, "Input"],
Cell[782651, 19078, 128, 3, 48, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[782816, 19086, 72, 0, 29, "Subsubsection"],
Cell[782891, 19088, 186, 4, 33, "Text"],
Cell[783080, 19094, 81, 1, 30, "Input"],
Cell[783164, 19097, 268, 5, 52, "Text"],
Cell[783435, 19104, 320, 12, 210, "Input"],
Cell[783758, 19118, 274, 5, 52, "Text"],
Cell[784035, 19125, 72, 1, 30, "Input"],
Cell[784110, 19128, 54, 1, 30, "Input"],
Cell[784167, 19131, 49, 1, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[784265, 19138, 37, 0, 31, "Subsection"],
Cell[784305, 19140, 375, 6, 71, "Text"],
Cell[784683, 19148, 167, 3, 30, "Input"],
Cell[784853, 19153, 54, 1, 30, "Input"],
Cell[784910, 19156, 190, 3, 70, "Input"],
Cell[785103, 19161, 40, 1, 30, "Input"],
Cell[785146, 19164, 183, 4, 33, "Text"],
Cell[785332, 19170, 75, 1, 30, "Input"],
Cell[785410, 19173, 204, 4, 52, "Text"],
Cell[785617, 19179, 93, 1, 30, "Input"],
Cell[785713, 19182, 57, 1, 30, "Input"],
Cell[785773, 19185, 37, 1, 30, "Input"],
Cell[785813, 19188, 40, 1, 30, "Input"],
Cell[785856, 19191, 75, 1, 30, "Input"],
Cell[785934, 19194, 45, 0, 33, "Text"],
Cell[785982, 19196, 52, 1, 30, "Input"],
Cell[786037, 19199, 336, 5, 52, "Text"],
Cell[786376, 19206, 89, 1, 30, "Input"],
Cell[786468, 19209, 61, 1, 30, "Input"],
Cell[786532, 19212, 38, 1, 30, "Input"],
Cell[786573, 19215, 41, 1, 30, "Input"],
Cell[786617, 19218, 76, 1, 30, "Input"],
Cell[786696, 19221, 240, 4, 52, "Text"],
Cell[786939, 19227, 86, 1, 30, "Input"],
Cell[787028, 19230, 88, 1, 30, "Input"],
Cell[787119, 19233, 58, 1, 30, "Input"],
Cell[787180, 19236, 434, 7, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[787651, 19248, 44, 0, 31, "Subsection"],
Cell[787698, 19250, 22, 0, 33, "Text"],
Cell[787723, 19252, 190, 3, 70, "Input"],
Cell[787916, 19257, 72, 1, 30, "Input"],
Cell[787991, 19260, 265, 6, 64, "Subsubsection"],
Cell[788259, 19268, 244, 4, 60, "Subsubsection"],
Cell[788506, 19274, 319, 6, 61, "Subsubsection"],
Cell[788828, 19282, 645, 10, 95, "Subsubsection"],
Cell[789476, 19294, 292, 5, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[789793, 19303, 262, 5, 60, "Subsubsection"],
Cell[790058, 19310, 214, 4, 52, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[790321, 19320, 35, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[790381, 19324, 36, 0, 43, "Subsubsection"],
Cell[790420, 19326, 62, 1, 30, "Input"],
Cell[790485, 19329, 60, 1, 30, "Input"],
Cell[790548, 19332, 194, 3, 70, "Input"],
Cell[790745, 19337, 360, 7, 90, "Text"],
Cell[791108, 19346, 85, 1, 90, "Input"],
Cell[791196, 19349, 398, 6, 90, "Text"],
Cell[791597, 19357, 144, 3, 110, "Input"],
Cell[791744, 19362, 346, 6, 90, "Text"],
Cell[792093, 19370, 545, 8, 128, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[792675, 19383, 50, 0, 29, "Subsubsection"],
Cell[792728, 19385, 33, 0, 30, "Input"],
Cell[792764, 19387, 335, 7, 130, "Input"],
Cell[793102, 19396, 34, 0, 30, "Input"],
Cell[793139, 19398, 137, 3, 33, "Text"],
Cell[793279, 19403, 40, 0, 30, "Input"],
Cell[793322, 19405, 136, 3, 110, "Input"],
Cell[793461, 19410, 47, 0, 33, "Text"],
Cell[793511, 19412, 52, 0, 30, "Input"],
Cell[793566, 19414, 164, 3, 110, "Input"],
Cell[793733, 19419, 238, 4, 52, "Text"],
Cell[793974, 19425, 172, 3, 110, "Input"],
Cell[794149, 19430, 58, 0, 33, "Text"],
Cell[794210, 19432, 198, 4, 52, "Text"],
Cell[794411, 19438, 473, 7, 71, "Text"],
Cell[794887, 19447, 235, 4, 150, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[795171, 19457, 44, 0, 31, "Subsection"],
Cell[795218, 19459, 22, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[795265, 19463, 61, 0, 43, "Subsubsection"],
Cell[795329, 19465, 394, 6, 71, "Text"],
Cell[795726, 19473, 210, 4, 52, "Text"]
}, Open  ]],
Cell[795951, 19480, 125, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[796101, 19487, 54, 0, 43, "Subsubsection"],
Cell[796158, 19489, 202, 5, 84, "Input"],
Cell[796363, 19496, 34, 0, 30, "Input"],
Cell[796400, 19498, 231, 4, 52, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[796692, 19509, 156, 3, 75, "Section"],

Cell[CellGroupData[{
Cell[796873, 19516, 134, 3, 66, "Subsection"],
Cell[797010, 19521, 90, 2, 30, "Input",
  InitializationCell->True],
Cell[797103, 19525, 340, 11, 174, "Input",
  InitializationCell->True],
Cell[797446, 19538, 195, 4, 30, "Input",
  InitializationCell->True],
Cell[797644, 19544, 123, 3, 30, "Input",
  InitializationCell->True],
Cell[797770, 19549, 117, 2, 30, "Input",
  InitializationCell->True],
Cell[797890, 19553, 178, 4, 90, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[798105, 19562, 64, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[798194, 19566, 70, 0, 43, "Subsubsection"],
Cell[798267, 19568, 105, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[798397, 19575, 77, 1, 30, "Input"],
Cell[798477, 19578, 346, 11, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[798860, 19594, 49, 0, 30, "Input"],
Cell[798912, 19596, 13099, 329, 186, 2690, 196, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[812026, 19928, 389, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[812440, 19940, 84, 3, 48, "Input"],
Cell[812527, 19945, 14726, 350, 258, 2633, 196, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[827268, 20298, 71, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[827364, 20302, 111, 3, 48, "Input"],
Cell[827478, 20307, 11844, 380, 152, 3168, 268, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[839337, 20690, 373, 6, 71, "Text"],
Cell[839713, 20698, 62, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[839800, 20703, 128, 3, 48, "Input"],
Cell[839931, 20708, 11908, 381, 152, 3176, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[851888, 21095, 72, 0, 29, "Subsubsection"],
Cell[851963, 21097, 186, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[852174, 21105, 81, 1, 30, "Input"],
Cell[852258, 21108, 352, 10, 62, "Output"]
}, Open  ]],
Cell[852625, 21121, 268, 5, 52, "Text"],
Cell[852896, 21128, 320, 12, 210, "Input"],
Cell[853219, 21142, 274, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[853518, 21151, 72, 1, 30, "Input"],
Cell[853593, 21154, 11908, 381, 152, 3176, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[865538, 21540, 54, 1, 30, "Input"],
Cell[865595, 21543, 19929, 546, 296, 3681, 341, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[885561, 22094, 49, 1, 30, "Input"],
Cell[885613, 22097, 18298, 395, 296, 2641, 197, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[903972, 22499, 37, 0, 31, "Subsection"],
Cell[904012, 22501, 375, 6, 71, "Text"],
Cell[904390, 22509, 167, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[904582, 22516, 54, 1, 30, "Input"],
Cell[904639, 22519, 317, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[904993, 22531, 190, 3, 70, "Input"],
Cell[905186, 22536, 352, 10, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[905575, 22551, 40, 1, 30, "Input"],
Cell[905618, 22554, 437, 11, 62, "Output"]
}, Open  ]],
Cell[906070, 22568, 183, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[906278, 22576, 75, 1, 30, "Input"],
Cell[906356, 22579, 14923, 419, 152, 3185, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[921294, 23001, 204, 4, 52, "Text"],
Cell[921501, 23007, 93, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[921619, 23012, 57, 1, 30, "Input"],
Cell[921679, 23015, 243, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[921959, 23027, 37, 1, 30, "Input"],
Cell[921999, 23030, 352, 10, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[922388, 23045, 40, 1, 30, "Input"],
Cell[922431, 23048, 274, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[922742, 23060, 75, 1, 30, "Input"],
Cell[922820, 23063, 14132, 409, 152, 3188, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[936967, 23475, 45, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[937037, 23479, 52, 1, 30, "Input"],
Cell[937092, 23482, 274, 7, 62, "Output"]
}, Open  ]],
Cell[937381, 23492, 318, 5, 52, "Text"],
Cell[937702, 23499, 89, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[937816, 23504, 61, 1, 30, "Input"],
Cell[937880, 23507, 243, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[938160, 23519, 38, 1, 30, "Input"],
Cell[938201, 23522, 274, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[938512, 23534, 41, 1, 30, "Input"],
Cell[938556, 23537, 293, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[938886, 23549, 76, 1, 30, "Input"],
Cell[938965, 23552, 12705, 391, 152, 3191, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[951685, 23946, 240, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[951950, 23954, 86, 1, 30, "Input"],
Cell[952039, 23957, 296, 7, 25, "Message"],
Cell[952338, 23966, 14132, 409, 152, 3188, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[966507, 24380, 88, 1, 30, "Input"],
Cell[966598, 24383, 291, 6, 25, "Message"],
Cell[966892, 24391, 12705, 391, 152, 3191, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[979634, 24787, 58, 1, 30, "Input"],
Cell[979695, 24790, 15570, 431, 152, 3249, 274, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[995280, 25224, 424, 7, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[995741, 25236, 44, 0, 31, "Subsection"],
Cell[995788, 25238, 22, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[995835, 25242, 190, 3, 70, "Input"],
Cell[996028, 25247, 352, 10, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[996417, 25262, 72, 1, 30, "Input"],
Cell[996492, 25265, 11908, 381, 152, 3176, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1008437, 25651, 203, 5, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[1008665, 25660, 57, 1, 30, "Input"],
Cell[1008725, 25663, 243, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009005, 25675, 61, 1, 30, "Input"],
Cell[1009069, 25678, 243, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009349, 25690, 46, 1, 30, "Input"],
Cell[1009398, 25693, 261, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009696, 25705, 74, 1, 30, "Input"],
Cell[1009773, 25708, 16186, 434, 212, 3191, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1026008, 26148, 244, 4, 46, "Subsubsection"],

Cell[CellGroupData[{
Cell[1026277, 26156, 46, 1, 30, "Input"],
Cell[1026326, 26159, 256, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1026619, 26171, 74, 1, 30, "Input"],
Cell[1026696, 26174, 12683, 391, 152, 3189, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1039394, 26568, 186, 4, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1039617, 26577, 319, 6, 47, "Subsubsection"],

Cell[CellGroupData[{
Cell[1039961, 26587, 87, 1, 30, "Input"],
Cell[1040051, 26590, 322, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1040410, 26602, 74, 1, 30, "Input"],
Cell[1040487, 26605, 13564, 402, 152, 3187, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1054100, 27013, 529, 9, 81, "Subsubsection"],
Cell[1054632, 27024, 97, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[1054754, 27030, 55, 1, 30, "Input"],
Cell[1054812, 27033, 258, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1055107, 27045, 74, 1, 30, "Input"],
Cell[1055184, 27048, 13958, 407, 152, 3184, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1069191, 27461, 231, 4, 46, "Subsubsection"],

Cell[CellGroupData[{
Cell[1069447, 27469, 88, 1, 30, "Input"],
Cell[1069538, 27472, 417, 11, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1069992, 27488, 74, 1, 30, "Input"],
Cell[1070069, 27491, 15124, 421, 152, 3192, 269, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1085242, 27918, 262, 5, 46, "Subsubsection"],
Cell[1085507, 27925, 214, 4, 52, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1085770, 27935, 35, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[1085830, 27939, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1085891, 27943, 62, 1, 30, "Input"],
Cell[1085956, 27946, 317, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1086310, 27958, 60, 1, 30, "Input"],
Cell[1086373, 27961, 317, 7, 62, "Output"]
}, Open  ]],
Cell[1086705, 27971, 200, 3, 90, "Input"],
Cell[1086908, 27976, 360, 7, 71, "Text"],

Cell[CellGroupData[{
Cell[1087293, 27987, 85, 1, 90, "Input"],
Cell[1087381, 27990, 51, 1, 25, "Print"],
Cell[1087435, 27993, 51, 1, 25, "Print"],
Cell[1087489, 27996, 51, 1, 25, "Print"],
Cell[1087543, 27999, 52, 1, 25, "Print"],
Cell[1087598, 28002, 52, 1, 25, "Print"],
Cell[1087653, 28005, 52, 1, 25, "Print"]
}, Open  ]],
Cell[1087720, 28009, 141, 3, 33, "Text"],
Cell[1087864, 28014, 144, 3, 110, "Input"],
Cell[1088011, 28019, 346, 6, 71, "Text"],
Cell[1088360, 28027, 545, 8, 90, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1088942, 28040, 50, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[1089017, 28044, 33, 0, 30, "Input"],
Cell[1089053, 28046, 72, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1089162, 28052, 335, 7, 130, "Input"],
Cell[1089500, 28061, 661, 14, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1090198, 28080, 34, 0, 30, "Input"],
Cell[1090235, 28082, 26824, 639, 296, 3788, 350, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1117074, 28724, 137, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1117236, 28731, 40, 0, 30, "Input"],
Cell[1117279, 28733, 317, 7, 62, "Output"]
}, Open  ]],
Cell[1117611, 28743, 136, 3, 110, "Input"],
Cell[1117750, 28748, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[1117822, 28752, 52, 0, 30, "Input"],
Cell[1117877, 28754, 337, 10, 62, "Output"]
}, Open  ]],
Cell[1118229, 28767, 164, 3, 110, "Input"],
Cell[1118396, 28772, 238, 4, 52, "Text"],
Cell[1118637, 28778, 172, 3, 110, "Input"],
Cell[1118812, 28783, 58, 0, 33, "Text"],
Cell[1118873, 28785, 198, 4, 52, "Text"],
Cell[1119074, 28791, 385, 6, 71, "Text"],
Cell[1119462, 28799, 235, 4, 150, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1119746, 28809, 44, 0, 31, "Subsection"],
Cell[1119793, 28811, 22, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[1119840, 28815, 61, 0, 43, "Subsubsection"],
Cell[1119904, 28817, 266, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[1120195, 28826, 88, 1, 30, "Input"],
Cell[1120286, 28829, 291, 7, 62, "Output"]
}, Open  ]],
Cell[1120592, 28839, 153, 3, 110, "Input"],
Cell[1120748, 28844, 210, 4, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1120995, 28853, 125, 3, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[1121145, 28860, 68, 1, 30, "Input"],
Cell[1121216, 28863, 267, 7, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1121520, 28875, 48, 1, 30, "Input"],
Cell[1121571, 28878, 217, 5, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1121837, 28889, 54, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[1121916, 28893, 206, 6, 102, "Input"],
Cell[1122125, 28901, 517, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1122679, 28919, 34, 0, 30, "Input"],
Cell[1122716, 28921, 25310, 622, 296, 3778, 352, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1148041, 29546, 231, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[1148297, 29554, 64, 1, 30, "Input"],
Cell[1148364, 29557, 317, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1148718, 29569, 63, 1, 30, "Input"],
Cell[1148784, 29572, 241, 7, 62, "Output"]
}, Open  ]],
Cell[1149040, 29582, 235, 4, 150, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

