(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18936,        737]*)
(*NotebookOutlinePosition[     19612,        761]*)
(*  CellTagsIndexPosition[     19568,        757]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College, 6/1/98."
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["ATLAST 6.1  Exercises on Orthogonality", "Subtitle"],

Cell[CellGroupData[{

Cell["ATLAST 6.1; 1 -- Orthogonal Matrices -- Instructions", "Section"],

Cell["\<\
randint[m_,n_,k_:9] :=
   Table[ Random[Integer,{-k,k}], {m},{n}]\
\>", "Input"],

Cell["a = IdentityMatrix[4] - (1/2) * Table[1,{4},{4}]", "Input"],

Cell["b = IdentityMatrix[4][[{2,3,4,1}]]", "Input"],

Cell["\<\
c = {{54,-82,18,6},{54,18,-82,6},{18,6,6,-98},{62,54,54,18}}/100\
\>", "Input"],

Cell["\<\
Let's also define cn to be the same as c but with numerical (decimal) values, \
just to observe roundoff error.\
\>", "Text"],

Cell["cn = N[c]", "Input"],

Cell["(a)  verify all \"four\" are orthogonal matrices", "Subsection"],

Cell["(b)  (for the rest of the problem using cn is optional)", "Subsection"],

Cell["(c)", "Subsection"],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell["\<\
The following defintion of norm works when x is an nx1 (one-column) matrix.\
\>", "Text"],

Cell["norm[x_] := N[Sqrt[Transpose[x].x]]", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ATLAST 6.1; 1 -- Orthogonal Matrices -- Solutions", "Section"],

Cell["\<\
randint[m_,n_,k_:9] :=
   Table[ Random[Integer,{-k,k}], {m},{n}]\
\>", "Input"],

Cell[CellGroupData[{

Cell["a = IdentityMatrix[4] - .5 * Table[1,{4},{4}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.5`", \(-0.5`\), \(-0.5`\), \(-0.5`\)},
            {\(-0.5`\), "0.5`", \(-0.5`\), \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), "0.5`", \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), \(-0.5`\), "0.5`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b = IdentityMatrix[4][[{2,3,4,1}]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"},
            {"1", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
c = {{54,-82,18,6},{54,18,-82,6},{18,6,6,-98},{62,54,54,18}}/100\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(27\/50\), \(-\(41\/50\)\), \(9\/50\), \(3\/50\)},
            {\(27\/50\), \(9\/50\), \(-\(41\/50\)\), \(3\/50\)},
            {\(9\/50\), \(3\/50\), \(3\/50\), \(-\(49\/50\)\)},
            {\(31\/50\), \(27\/50\), \(27\/50\), \(9\/50\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["cn = N[c]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.540000000000000035`", \(-0.819999999999999928`\), 
              "0.179999999999999982`", "0.06`"},
           
             {"0.540000000000000035`", "0.179999999999999982`", 
              \(-0.819999999999999928`\), "0.06`"},
           
             {"0.179999999999999982`", "0.06`", "0.06`", 
              \(-0.980000000000000071`\)},
           
             {"0.620000000000000017`", "0.540000000000000035`", 
              "0.540000000000000035`", "0.179999999999999982`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(a)", "Subsection"],

Cell[CellGroupData[{

Cell["Transpose[a].a", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.`", "0.`"},
            {"0.`", "1.`", "0.`", "0.`"},
            {"0.`", "0.`", "1.`", "0.`"},
            {"0.`", "0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[b].b", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[c].c", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[cn].cn", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.`", \(-1.38777878078144567`*^-17\)},
           
             {"0.`", "1.`", "5.5511151231257827`*^-17", 
              "1.38777878078144567`*^-17"},
           
             {"0.`", "5.5511151231257827`*^-17", "1.`", 
              "1.38777878078144567`*^-17"},
           
             {\(-1.38777878078144567`*^-17\), "1.38777878078144567`*^-17", 
              "1.38777878078144567`*^-17", "0.999999999999999822`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(b)", "Subsection"],

Cell[CellGroupData[{

Cell["Inverse[a]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.5`", \(-0.5`\), \(-0.5`\), \(-0.5`\)},
            {\(-0.5`\), "0.5`", \(-0.5`\), \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), "0.5`", \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), \(-0.5`\), "0.5`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse[b]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "1"},
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse[c]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(27\/50\), \(27\/50\), \(9\/50\), \(31\/50\)},
            {\(-\(41\/50\)\), \(9\/50\), \(3\/50\), \(27\/50\)},
            {\(9\/50\), \(-\(41\/50\)\), \(3\/50\), \(27\/50\)},
            {\(3\/50\), \(3\/50\), \(-\(49\/50\)\), \(9\/50\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(c)", "Subsection"],

Cell[CellGroupData[{

Cell["a.b", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.5`\), "0.5`", \(-0.5`\), \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), "0.5`", \(-0.5`\)},
            {\(-0.5`\), \(-0.5`\), \(-0.5`\), "0.5`"},
            {"0.5`", \(-0.5`\), \(-0.5`\), \(-0.5`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[a.b].a.b", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.`", "0.`"},
            {"0.`", "1.`", "0.`", "0.`"},
            {"0.`", "0.`", "1.`", "0.`"},
            {"0.`", "0.`", "0.`", "1.`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["b.c", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(27\/50\), \(9\/50\), \(-\(41\/50\)\), \(3\/50\)},
            {\(9\/50\), \(3\/50\), \(3\/50\), \(-\(49\/50\)\)},
            {\(31\/50\), \(27\/50\), \(27\/50\), \(9\/50\)},
            {\(27\/50\), \(-\(41\/50\)\), \(9\/50\), \(3\/50\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[b.c].b.c", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a.c", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.4`\), \(-0.8`\), "0.199999999999999964`", "0.4`"},
            {\(-0.4`\), "0.199999999999999964`", \(-0.8`\), "0.4`"},
           
             {\(-0.759999999999999964`\), "0.0799999999999999644`", 
              "0.0799999999999999644`", \(-0.640000000000000035`\)},
           
             {\(-0.320000000000000017`\), "0.559999999999999964`", 
              "0.559999999999999964`", "0.520000000000000017`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transpose[a.c].a.c", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.`", \(-4.16333634234433702`*^-17\)},
           
             {"5.5511151231257827`*^-17", "1.`", "0.`", 
              \(-4.16333634234433702`*^-17\)},
           
             {"5.5511151231257827`*^-17", "0.`", "1.`", 
              \(-4.16333634234433702`*^-17\)},
           
             {\(-1.38777878078144567`*^-17\), "1.38777878078144567`*^-17", 
              "1.38777878078144567`*^-17", "0.999999999999999822`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(d)", "Subsection"],

Cell[CellGroupData[{

Cell["x = randint[4,1]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-3\)},
            {"5"},
            {\(-2\)},
            {\(-9\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["norm[x_] := N[Sqrt[Transpose[x].x]]", "Input"],

Cell[CellGroupData[{

Cell["norm[x]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((10.9087121146357146`)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["norm[a.x]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((10.9087121146357146`)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["norm[b.x]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((10.9087121146357146`)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["norm[c.x]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((10.9087121146357146`)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spirit of 6.1; 2  -- Gram-Schmidt and alternatives", "Section"],

Cell[CellGroupData[{

Cell["Intializations -- LAMaster, norm, project", "Subsection",
  InitializationCell->True],

Cell["\<\
Needs[\"LinearAlgebra`Master`\"]
(* MUST EXECUTE ONCE BEFORE TRYING GramSchmidt *)\
\>", "Input",
  InitializationCell->True],

Cell["\<\
Actually, GramSchmidt is in the LinearAlgebra`Orthogonalization` package and \
`Master` loads all of the LinearAlgebra packages.\
\>", "Text"],

Cell["norm[x_] := Sqrt[x.x]", "Input",
  InitializationCell->True],

Cell["project[y_,u_] := ((y.u)/(u.u))u", "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Find an orthonormal basis for the span of the columns of A.", 
  "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ A\  = 
      \ {{1, 2, 5}, {\(-1\), 1, \(-4\)}, {\(-1\), 4, \(-3\)}, {1, \(-4\), 
          7}, {1, 2, 1}}\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "5"},
            {\(-1\), "1", \(-4\)},
            {\(-1\), "4", \(-3\)},
            {"1", \(-4\), "7"},
            {"1", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{x1,x2,x3} = Transpose[A]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-1\), \(-1\), "1", "1"},
            {"2", "1", "4", \(-4\), "2"},
            {"5", \(-4\), \(-3\), "7", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Detailed proj, perp... procedure.", "Subsection"],

Cell[CellGroupData[{

Cell["v1 = x1", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-1\), \(-1\), 1, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x2hat\  = \ project[x2, v1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-1\), 1, 1, \(-1\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["v2 = x2 - x2hat", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, 0, 3, \(-3\), 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x3hat\  = \ project[x3, v1]\  + \ project[x3, v2]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{3, \(-4\), \(-5\), 5, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["v3 = x3 - x3hat", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2, 0, 2, 2, \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{v1,v2,v3}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-1\), \(-1\), "1", "1"},
            {"3", "0", "3", \(-3\), "3"},
            {"2", "0", "2", "2", \(-2\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({v1/norm[v1], \ v2/norm[v2], \ v3/norm[v3]}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(1\/\@5\), \(-\(1\/\@5\)\), \(-\(1\/\@5\)\), \(1\/\@5\), 
              \(1\/\@5\)},
            {\(1\/2\), "0", \(1\/2\), \(-\(1\/2\)\), \(1\/2\)},
            {\(1\/2\), "0", \(1\/2\), \(1\/2\), \(-\(1\/2\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["GramSchmidt function (provided in LinearAlgebra`Master`) ", "Subsection"],

Cell[CellGroupData[{

Cell["QT = GramSchmidt[{x1,x2,x3}]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(1\/\@5\), \(-\(1\/\@5\)\), \(-\(1\/\@5\)\), \(1\/\@5\), 
              \(1\/\@5\)},
            {\(1\/2\), "0", \(1\/2\), \(-\(1\/2\)\), \(1\/2\)},
            {\(1\/2\), "0", \(1\/2\), \(1\/2\), \(-\(1\/2\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["QR factorization", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q\  = \ Transpose[QT]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(1\/\@5\), \(1\/2\), \(1\/2\)},
            {\(-\(1\/\@5\)\), "0", "0"},
            {\(-\(1\/\@5\)\), \(1\/2\), \(1\/2\)},
            {\(1\/\@5\), \(-\(1\/2\)\), \(1\/2\)},
            {\(1\/\@5\), \(1\/2\), \(-\(1\/2\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\  = \ QT.A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(\@5\), \(-\@5\), \(4\ \@5\)},
            {"0", "6", \(-2\)},
            {"0", "0", "4"}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q.R\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "5"},
            {\(-1\), "1", \(-4\)},
            {\(-1\), "4", \(-3\)},
            {"1", \(-4\), "7"},
            {"1", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "5"},
            {\(-1\), "1", \(-4\)},
            {\(-1\), "4", \(-3\)},
            {"1", \(-4\), "7"},
            {"1", "2", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical QRDecomposition function", "Subsection"],

Cell["{QT,R} = QRDecomposition[N[A]];", "Input"],

Cell[CellGroupData[{

Cell["QT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-0.447213595499957872`\), "0.447213595499957961`", 
              "0.447213595499957961`", \(-0.447213595499957961`\), 
              \(-0.447213595499957961`\)},
            {\(-0.5`\), "0.`", \(-0.5`\), "0.5`", \(-0.5`\)},
           
             {\(-0.5`\), \(-2.77555756156289135`*^-17\), \(-0.5`\), \(-0.5`\),
               "0.5`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["R", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-2.2360679774997898`\), "2.2360679774997898`", 
              \(-8.94427190999915744`\)},
            {"0", \(-6.`\), "2.`"},
            {"0", "0", \(-4.`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{573, 380},
WindowMargins->{{0, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 161, 4, 66, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1895, 57, 58, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[1978, 61, 71, 0, 53, "Section"],
Cell[2052, 63, 90, 3, 48, "Input"],
Cell[2145, 68, 65, 0, 30, "Input"],
Cell[2213, 70, 51, 0, 30, "Input"],
Cell[2267, 72, 89, 2, 30, "Input"],
Cell[2359, 76, 135, 3, 33, "Text"],
Cell[2497, 81, 26, 0, 30, "Input"],
Cell[2526, 83, 70, 0, 47, "Subsection"],
Cell[2599, 85, 77, 0, 47, "Subsection"],
Cell[2679, 87, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[2729, 91, 25, 0, 47, "Subsection"],
Cell[2757, 93, 99, 2, 33, "Text"],
Cell[2859, 97, 52, 0, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2960, 103, 68, 0, 33, "Section"],
Cell[3031, 105, 90, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[3146, 112, 62, 0, 30, "Input"],
Cell[3211, 114, 365, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3613, 127, 51, 0, 30, "Input"],
Cell[3667, 129, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3985, 142, 89, 2, 30, "Input"],
Cell[4077, 146, 400, 8, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4514, 159, 26, 0, 30, "Input"],
Cell[4543, 161, 658, 16, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5238, 182, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5288, 186, 31, 0, 30, "Input"],
Cell[5322, 188, 313, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5672, 201, 31, 0, 30, "Input"],
Cell[5706, 203, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6024, 216, 31, 0, 30, "Input"],
Cell[6058, 218, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6376, 231, 33, 0, 30, "Input"],
Cell[6412, 233, 595, 14, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7056, 253, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[7106, 257, 27, 0, 30, "Input"],
Cell[7136, 259, 365, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7538, 272, 27, 0, 30, "Input"],
Cell[7568, 274, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7886, 287, 27, 0, 30, "Input"],
Cell[7916, 289, 400, 8, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8365, 303, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[8415, 307, 20, 0, 30, "Input"],
Cell[8438, 309, 365, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8840, 322, 35, 0, 30, "Input"],
Cell[8878, 324, 313, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9228, 337, 20, 0, 30, "Input"],
Cell[9251, 339, 400, 8, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9688, 352, 35, 0, 30, "Input"],
Cell[9726, 354, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10044, 367, 20, 0, 30, "Input"],
Cell[10067, 369, 578, 12, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10682, 386, 35, 0, 30, "Input"],
Cell[10720, 388, 601, 14, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11370, 408, 25, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[11420, 412, 33, 0, 30, "Input"],
Cell[11456, 414, 230, 8, 80, "Output"]
}, Open  ]],
Cell[11701, 425, 52, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[11778, 429, 24, 0, 30, "Input"],
Cell[11805, 431, 77, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11919, 437, 26, 0, 30, "Input"],
Cell[11948, 439, 77, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12062, 445, 26, 0, 30, "Input"],
Cell[12091, 447, 77, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12205, 453, 26, 0, 30, "Input"],
Cell[12234, 455, 77, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12372, 463, 69, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[12466, 467, 91, 1, 47, "Subsection",
  InitializationCell->True],
Cell[12560, 470, 135, 4, 48, "Input",
  InitializationCell->True],
Cell[12698, 476, 152, 3, 52, "Text"],
Cell[12853, 481, 66, 1, 30, "Input",
  InitializationCell->True],
Cell[12922, 484, 77, 1, 30, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13036, 490, 84, 1, 31, "Subsection"],

Cell[CellGroupData[{
Cell[13145, 495, 145, 3, 50, "Input"],
Cell[13293, 500, 305, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13635, 514, 42, 0, 30, "Input"],
Cell[13680, 516, 277, 7, 62, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14006, 529, 56, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[14087, 533, 24, 0, 30, "Input"],
Cell[14114, 535, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14227, 541, 60, 1, 30, "Input"],
Cell[14290, 544, 81, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14408, 550, 32, 0, 30, "Input"],
Cell[14443, 552, 71, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14551, 558, 82, 1, 30, "Input"],
Cell[14636, 561, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14749, 567, 32, 0, 30, "Input"],
Cell[14784, 569, 71, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14892, 575, 27, 0, 30, "Input"],
Cell[14922, 577, 274, 7, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15233, 589, 76, 1, 30, "Input"],
Cell[15312, 592, 346, 8, 95, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15707, 606, 79, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[15811, 610, 45, 0, 30, "Input"],
Cell[15859, 612, 346, 8, 95, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16254, 626, 38, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[16317, 630, 54, 1, 30, "Input"],
Cell[16374, 633, 346, 8, 173, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16757, 646, 45, 1, 30, "Input"],
Cell[16805, 649, 212, 6, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17054, 660, 36, 1, 30, "Input"],
Cell[17093, 663, 305, 9, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17435, 677, 34, 1, 30, "Input"],
Cell[17472, 680, 305, 9, 98, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17826, 695, 56, 0, 31, "Subsection"],
Cell[17885, 697, 48, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[17958, 701, 19, 0, 30, "Input"],
Cell[17980, 703, 513, 12, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18530, 720, 18, 0, 30, "Input"],
Cell[18551, 722, 333, 9, 62, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

