(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    108189,       2472]*)
(*NotebookOutlinePosition[    108867,       2496]*)
(*  CellTagsIndexPosition[    108823,       2492]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College, 6/1/98."
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["ATLAST 7.1  Exercises on Eigenvalues", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
ATLAST 7.1; 1 -- eigshow -- Tutorial
A Geometric View of Eigenvalues and Eigenvectors\
\>", "Section"],

Cell[CellGroupData[{

Cell["Initializations -- unitImage, eigshow, svdshow", "Subsection"],

Cell["\<\
These three programs are stand-alone, except that before any is defined the \
following cell MUST be evaluated once to load the packages.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Arrow`; \n<< Graphics`Colors`; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(unitImage::usage\), " ", "=", " ", 
        StyleBox[
          \("\<unitImage[mat, {x1,x2}] displays the unit circle and the unit \
vector in the direction of {x1,x2}, dashed before and solid after \
transformation by the 2\[Times]2 matrix mat.
		\nunitImage[mat, {{x1,x2},{y1,y2}}] will display two unit vectors and their \
images.
		\nGraphics options such as Axes->True may be included as a last \
argument.\>"\),
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["\n",
        FontColor->RGBColor[0, 0, 1]], 
      \(unitImage[A_?MatrixQ, {v_, w_}, \ opts___Rule]\  := \ \n
        Module[{unitCircle, normalize, unitVec1, \ unitVec2}, \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tnormalize[u_]\  := \ 
            If[u \[NotEqual] {0, 0}\  && \ \ Im[u] == {0, 0}, \ u/Sqrt[u.u], 
              \ {0, 0}]; \n\t\t
          If[VectorQ[v]\ 
             (*\ v\ and\ w\ should\ be\ plane\ vectors; \ 
              complex\ are\ set\ to\ {0, 0}\ *) , \ \n\t\t\t\t\t
            unitVec1\  = \ normalize[v]; \ unitVec2\  = \ normalize[w], \n\t\t
             (*\ else\ v\ and\ w\ should\ be\ numbers\ *) \ \n\t\t\t\t\t
            unitVec1\  = \ normalize[{v, w}]; \ unitVec2\  = \ {0, 0}\n\t\t]; 
          \n\t\tShow[
            Graphics[{\n
                \t\t\t\t{Line[Transpose[A.unitCircle]], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], 
                    Line[Transpose[unitCircle]]}}, \n\t\t\t\tRed, 
                \ {Arrow[{0, 0}, A.unitVec1], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], 
                    Arrow[{0, 0}, unitVec1]}}, \n\t\t\t\tBlue, 
                \ {Arrow[{0, 0}, A.unitVec2], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, unitVec2]}}
                  \n\t\t}], AspectRatio -> Automatic, \ opts]\n]\), ";"}]], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(eigshow::usage\), " ", "=", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[
          \("\<eigshow[mat] creates movie frames for animation as a unit \
vector rotates from 0\[Degree] to 180\[Degree].  Each frame displays the unit \
vector and the unit circle, dashed before and solid after transformation by \
the 2\[Times]2 matrix mat.
		\neigshow[mat, tmin, tmax, dt] varies the unit vector
		from tmin\[Degree] to tmax\[Degree] by steps of dt\[Degree].\>"\),
          FontColor->RGBColor[0, 0, 1]]}], ";", "\n", 
      \(eigshow[A_?MatrixQ, \ degMin_:  0., degMax_:  180., degStep_:  5.]\ 
         := \nModule[{num, unitCircle, circleGraphic, rotMat, R, v, t}, \n\t\t
          num[x_, {t_, b_}]\  := \ 
            ToString[PaddedForm[Chop[x, .005], {t, b}]]; \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tcircleGraphic\  = 
            \ {Line[Transpose[A.unitCircle]], {Dashing[{0.01, .02}], 
                Line[Transpose[unitCircle]]}}; \n\t\t
          rotMat[\[Theta]_]\  := 
            \ {{Cos[\[Theta]], \(-Sin[\[Theta]]\)}, {Sin[\[Theta]], 
                Cos[\[Theta]]}}; \n\t\tR\  = \ rotMat[degStep*Pi/180.]; \n\t\t
          v\  = \ rotMat[degMin*Pi/180.].{1., 0.}; \n\t\t
          Do[\n\t\t\t\t
            Show[Graphics[{\n\t\t\t\t\t\tcircleGraphic, \n\t\t\t\t\t\tRed, 
                  \ {Arrow[{0, 0}, A.v], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, v]}}
                    \n\t\t\t\t}], \n\t\t\t\t\t\tAspectRatio -> Automatic, \n
              \t\t\t\t\t\t
              PlotLabel -> 
                StringJoin[\n\t\t\t\t\t\t\t\tnum[v, {3, 2}], "\< at\>", 
                  num[t, {4, 1}], "\<\[Degree]\n\>", \n\t\t\t\t\t\t\t\t
                  "\<to image length: \>", 
                  num[Sqrt[\((A.v)\).\((A.v)\)], {4, 2}]]\n\t\t\t\t]; \n
            \t\t\t\t\(v\  = \ R.v; \)\n\t\t, {t, degMin, \ degMax, \ degStep}]
            \n]\), ";"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(svdshow::usage\), " ", "=", " ", 
        StyleBox[
          \("\<svdshow[mat] creates movie frames for animation as a pair of \
orthonormal vectors rotate through 90\[Degree].  Each frame displays the \
orthonormal vectors and the unit circle, dashed before and solid after \
transformation by the 2\[Times]2 matrix mat.
		\nsvdshow[mat, tmin, tmax, dt] varies the first vector
		from tmin\[Degree] to tmax\[Degree] by steps of dt\[Degree].\>"\),
          FontColor->RGBColor[0, 0, 1]]}], ";", "\n", 
      \(svdshow[A_?MatrixQ, \ degMin_:  0., degMax_:  90., degStep_:  5.]\ 
         := \nModule[{num, unitCircle, circleGraphic, rotMat, R, v, w, t}, \n
          \t\tnum[x_, {t_, b_}]\  := \ 
            ToString[PaddedForm[Chop[x, .005], {t, b}]]; \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tcircleGraphic\  = 
            \ {Line[Transpose[A.unitCircle]], {Dashing[{0.01, .02}], 
                Line[Transpose[unitCircle]]}}; \n\t\t
          rotMat[\[Theta]_]\  := 
            \ {{Cos[\[Theta]], \(-Sin[\[Theta]]\)}, {Sin[\[Theta]], 
                Cos[\[Theta]]}}; \n\t\tR\  = \ rotMat[degStep*Pi/180.]; \n\t\t
          v\  = \ rotMat[degMin*Pi/180.].{1., 0.}; \n\t\t
          w\  = \ rotMat[degMin*Pi/180.].{0., 1.}; \n\t\t
          Do[\n\t\t\t\t
            Show[Graphics[{\n\t\t\t\t\t\tcircleGraphic, \n\t\t\t\t\t\tRed, 
                  \ {Arrow[{0, 0}, A.v], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], 
                      Arrow[{0, 0}, v]}}, \n\t\t\t\t\t\tBlue, 
                  \ {Arrow[{0, 0}, A.w], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, w]}}
                    \n\t\t\t\t}], \n\t\t\t\t\t\tAspectRatio -> Automatic, \n
              \t\t\t\t\t\t
              PlotLabel -> 
                StringJoin[\n\t\t\t\t\t\t\t\t"\<From angles:\>", 
                  num[t, {4, 1}], \ num[t + 90, {4, 1}], "\<\n\>", \n
                  \t\t\t\t\t\t\t\t"\<to lengths: \>", \ 
                  num[Sqrt[\((A.v)\).\((A.v)\)], {4, 2}], \n\t\t\t\t\t\t\t\t
                  num[Sqrt[\((A.w)\).\((A.w)\)], {4, 2}]]\n\t\t\t\t]; \n
            \t\t\t\tv\  = \ R.v; \n\t\t\t\t\(w\  = \ R.w; \)\n
            \t\t, {t, degMin, \ degMax, \ degStep}]\n]\), ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["1. (a) through (e) -- Student Tutorial START HERE", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{2, 0}, {1.5, 0.5}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "0"},
            {
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Let's look at the image of one unit vector {1,0} under transformation by A \
along with the image of the entire unit circle.  The function unitImage shows \
dashed before and solid after transformation.  (In this context, image means \
after transformation.)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, {1, 0}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79027 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.395137 0.238095 [
[ 0 0 0 0 ]
[ 1 .79027 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .79027 L
0 .79027 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.97619 .75228 m
.97438 .7613 L
.96896 .76753 L
.95996 .77092 L
.94747 .77146 L
.93158 .76913 L
.91239 .76396 L
.89007 .75597 L
.86478 .74525 L
.83672 .73185 L
.80609 .7159 L
.77313 .6975 L
.7381 .67681 L
.70125 .65397 L
.66287 .62916 L
.62325 .60256 L
.58269 .57439 L
.5415 .54486 L
.5 .51418 L
.4585 .4826 L
.41731 .45036 L
.37675 .41769 L
.33713 .38486 L
.29875 .3521 L
.2619 .31966 L
.22687 .28781 L
.19391 .25677 L
.16328 .22678 L
.13522 .19807 L
.10993 .17087 L
.08761 .14537 L
.06842 .12177 L
.05253 .10025 L
.04004 .08098 L
.03104 .06409 L
.02562 .04973 L
.02381 .03799 L
.02562 .02898 L
.03104 .02275 L
.04004 .01935 L
.05253 .01882 L
.06842 .02114 L
.08761 .02632 L
.10993 .0343 L
.13522 .04503 L
.16328 .05842 L
.19391 .07437 L
.22687 .09277 L
.2619 .11347 L
.29875 .13631 L
Mistroke
.33713 .16112 L
.37675 .18771 L
.41731 .21588 L
.4585 .24542 L
.5 .27609 L
.5415 .30767 L
.58269 .33992 L
.62325 .37258 L
.66287 .40542 L
.70125 .43818 L
.7381 .47061 L
.77313 .50247 L
.80609 .53351 L
.83672 .5635 L
.86478 .5922 L
.89007 .61941 L
.91239 .64491 L
.93158 .66851 L
.94747 .69003 L
.95996 .7093 L
.96896 .72618 L
.97438 .74055 L
.97619 .75228 L
Mfstroke
[ .01 .02 ] 0 setdash
.7381 .39514 m
.73719 .41589 L
.73448 .43648 L
.72998 .45676 L
.72374 .47657 L
.71579 .49576 L
.7062 .51418 L
.69504 .5317 L
.68239 .54818 L
.66836 .5635 L
.65304 .57753 L
.63657 .59017 L
.61905 .60133 L
.60062 .61092 L
.58143 .61887 L
.56162 .62512 L
.54134 .62962 L
.52075 .63233 L
.5 .63323 L
.47925 .63233 L
.45866 .62962 L
.43838 .62512 L
.41857 .61887 L
.39938 .61092 L
.38095 .60133 L
.36343 .59017 L
.34696 .57753 L
.33164 .5635 L
.31761 .54818 L
.30496 .5317 L
.2938 .51418 L
.28421 .49576 L
.27626 .47657 L
.27002 .45676 L
.26552 .43648 L
.26281 .41589 L
.2619 .39514 L
.26281 .37439 L
.26552 .35379 L
.27002 .33351 L
.27626 .3137 L
.28421 .29451 L
.2938 .27609 L
.30496 .25857 L
.31761 .24209 L
.33164 .22678 L
.34696 .21275 L
.36343 .2001 L
.38095 .18894 L
.39938 .17935 L
Mistroke
.41857 .1714 L
.43838 .16515 L
.45866 .16066 L
.47925 .15795 L
.5 .15704 L
.52075 .15795 L
.54134 .16066 L
.56162 .16515 L
.58143 .1714 L
.60062 .17935 L
.61905 .18894 L
.63657 .2001 L
.65304 .21275 L
.66836 .22678 L
.68239 .24209 L
.69504 .25857 L
.7062 .27609 L
.71579 .29451 L
.72374 .3137 L
.72998 .33351 L
.73448 .35379 L
.73719 .37439 L
.7381 .39514 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .39514 m
.97619 .75228 L
s
% Start of user PostScript
0 0 2. 1.5 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .39514 m
.7381 .39514 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .39514 m
.5 .39514 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .39514 m
.5 .39514 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{323.938, 255.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000530000ob000`400?l00000o`00003oo`3ooom4
0?ooo`00o`3ooom40?ooo`00o`3ooom40?ooo`00o`3ooom40?ooo`00o`3ooom40?ooo`00o`3ooom4
0?ooo`00303oool<00000?l0oooo;03oool000X0oooo0P00000<0?ooo`<00000o`3ooolY0?ooo`00
2@3oool00`000000oooo0?ooo`0?0?ooo`<00000o`3ooolV0?ooo`00203oool00`000000oooo0?oo
o`0C0?ooo`800000o`3ooolT0?ooo`00203oool00`000000oooo0?ooo`0E0?ooo`800000o`3ooolR
0?ooo`001`3oool00`000000oooo0?ooo`0H0?ooo`<00000o`3ooolO0?ooo`001`3oool00`000000
oooo0?ooo`0K0?ooo`800000o`3ooolM0?ooo`001`3oool00`000000oooo0?ooo`0M0?ooo`<00000
o`3ooolJ0?ooo`001`3oool00`000000oooo0?ooo`0P0?ooo`<00000o`3ooolG0?ooo`00203oool0
0`000000oooo0?ooo`0R0?ooo`800000o`3ooolE0?ooo`00203oool00`000000oooo0?ooo`0T0?oo
o`800000o`3ooolC0?ooo`00203oool00`000000oooo0?ooo`0V0?ooo`800000o`3ooolA0?ooo`00
2@3oool00`000000oooo0?ooo`0W0?ooo`800000o`3oool?0?ooo`002@3oool00`000000oooo0?oo
o`0Y0?ooo`800000o`3oool=0?ooo`002P3oool00`000000oooo0?ooo`0Z0?ooo`800000o`3oool;
0?ooo`002P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo203oool000/0
oooo00<000000?ooo`3oool0;03oool200000?l0oooo203oool000/0oooo00<000000?ooo`3oool0
;P3oool200000?l0oooo1P3oool000`0oooo00<000000?ooo`3oool0;`3oool200000?l0oooo103o
ool000`0oooo00<000000?ooo`3oool0<@3oool200000?l0oooo0P3oool000d0oooo00<000000?oo
o`3oool0<P3oool200000?l0oooo000>0?ooo`030000003oool0oooo03<0oooo0P00003m0?ooo`00
3P3oool00`000000oooo0?ooo`0e0?ooo`800000n`3oool000l0oooo00<000000?ooo`3oool0=P3o
ool200000?T0oooo000@0?ooo`030000003oool0oooo03L0oooo0P00003g0?ooo`00403oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0?@0oooo000A0?ooo`030000003oool0oooo03T0
oooo0P00003d0?ooo`004P3oool00`000000oooo0?ooo`0j0?ooo`800000lP3oool00180oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`3_0?ooo`004`3oool00`000000oooo0?ooo`0l
0?ooo`800000k`3oool001@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3/0?oo
o`005@3oool00`000000oooo0?ooo`0m0?ooo`800000k03oool001D0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`3Y0?ooo`005P3oool00`000000oooo0?ooo`0o0?ooo`800000j@3o
ool001L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3V0?ooo`00603oool00`00
0000oooo0?ooo`100?ooo`800000iP3oool001T0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3S0?ooo`006@3oool00`000000oooo0?ooo`120?ooo`800000h`3oool001X0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`3P0?ooo`006`3oool00`000000oooo0?ooo`13
0?ooo`800000h03oool001`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3M0?oo
o`007@3oool00`000000oooo0?ooo`140?ooo`800000g@3oool001h0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`3J0?ooo`007P3oool00`000000oooo0?ooo`160?ooo`800000fP3o
ool001l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0a0?ooo`@00000XP3oool0
0200oooo00<000000?ooo`3oool0A`3oool2000002P0oooo1000000?0?ooo`@00000V03oool00240
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`110?ooo`800000T@3oool00240oooo
00<000000?ooo`3oool0B@3oool2000001d0oooo0P00000T0?ooo`<00000SP3oool00280oooo00<0
00000?ooo`3oool0BP3oool2000001T0oooo0P00000^0?ooo`030000003oool0oooo08H0oooo000S
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`25
0?ooo`00903oool00`000000oooo0?ooo`1;0?ooo`8000003`3oool2000003L0oooo0P0000250?oo
o`009@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00X0oooo0P0000300?ooo`00
9P3oool00`000000oooo0?ooo`1<0?ooo`800000C03oool00`000000oooo0?ooo`1m0?ooo`009`3o
ool00`000000oooo0?ooo`1=0?ooo`800000B`3oool2000007d0oooo000X0?ooo`030000003oool0
oooo04h0oooo00@000000?ooo`3oool00000B@3oool00`000000oooo0?ooo`1j0?ooo`00:@3oool0
0`000000oooo0?ooo`1=0?ooo`<00000a`3oool002X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`340?ooo`00:`3oool00`000000oooo0?ooo`1?0?ooo`800000C03oool00`000000
oooo0?ooo`1e0?ooo`00;03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04X0oooo
0P00001e0?ooo`00;@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1b0?ooo`00;P3oool00`000000oooo0?ooo`11
0?ooo`8000003@3oool200000<00oooo000_0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`2m0?ooo`00;`3oool00`000000oooo0?ooo`1B0?ooo`80
0000_@3oool00300oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo06d0oooo000a0?ooo`030000003oool0oooo05<0oooo0P00001;0?ooo`030000003o
ool0oooo06`0oooo000b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo06/0oooo000c0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2f0?ooo`00=03oool00`000000
oooo0?ooo`0c0?ooo`8000007`3oool200000;H0oooo000e0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0/`3oool003H0oooo00<000000?ooo`3oool0E@3oool2000004X0oooo00<0
00000?ooo`3oool0IP3oool003L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo06D0oooo000h0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`1U0?ooo`00>@3oool2000002/0oooo00<000000?ooo`3o
ool0:@3oool2000004P0oooo00<000000?ooo`3oool0I03oool003/0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:`0oooo000l0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2[0?ooo`00?@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo0P00002[0?ooo`00?P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0:P0oooo000o0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1P0?ooo`00@03oool00`000000oooo
0?ooo`1G0?ooo`800000A@3oool00`000000oooo0?ooo`1O0?ooo`00@@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0G`3oool00480oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0GP3oool004<0oooo0P00000J0?ooo`030000003oool0oooo03`0oooo0P00002S0?oo
o`00A@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0X03oool004H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo09l0oooo00170?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0WP3o
ool004P0oooo00<000000?ooo`3oool0F03oool200000400oooo00<000000?ooo`3oool0F`3oool0
04T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
05/0oooo001:0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`1J0?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0oooo
0P00000m0?ooo`030000003oool0oooo05X0oooo001<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`2G0?ooo`00C@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0UP3oool004h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1>0?ooo`800000UP3oool004l0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`2C0?ooo`00D03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0980oooo001A0?ooo`030000003oool0oooo05/0oooo0P00000h0?ooo`030000003o
ool0oooo05L0oooo001B0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`1G0?ooo`00D`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0E`3oool005@0oooo00D000000?ooo`3oool0oooo0000001J0?oo
o`800000=@3oool00`000000oooo0?ooo`1F0?ooo`00E@3oool010000000oooo0?ooo`00001L0?oo
o`030000003oool0oooo08/0oooo001F0?ooo`800000GP3oool2000008/0oooo001G0?ooo`800000
G`3oool00`000000oooo0?ooo`280?ooo`00E`3oool00`000000oooo0000001O0?ooo`030000003o
ool0oooo08L0oooo001J0?ooo`030000003oool0oooo05d0oooo0P0000270?ooo`00F`3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0E03oool005`0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05@0
oooo001M0?ooo`800000G`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05@0oooo
001O0?ooo`030000003oool0oooo05d0oooo0P00000[0?ooo`030000003oool0oooo05@0oooo001F
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1o
0?ooo`00E@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0OP3oool005D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo07d0oooo001E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`1l0?ooo`00I03oool00`000000oooo0?ooo`1N0?ooo`800000O03o
ool006D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1i0?ooo`00IP3oool20000
0600oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1C0?ooo`00J03oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0D`3oool006T0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05<0oooo
001D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0GP3oool200000240oooo00<0
00000?ooo`3oool0DP3oool005@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo00l0oooo0P3o001R0?ooo`00E03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool03@3oool50?l00600oooo001D0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool2000000d0oooo203o001M0?ooo`00
E03oool00`000000oooo0?ooo`0G0?ooo`800000H@3oool00`000000oooo0?ooo`0:0?ooo`h0o`00
E`3oool00700oooo00<000000?ooo`3oool0;P3oool010000?l0o`000?l0003o00060?ooo`@0o`00
1@3oool50?l000D0oooo103o00060?ooo`@0o`001@3oool50?l000D0oooo4`3o001E0?ooo`00L@3o
ool00`000000oooo0?ooo`0^0?ooo`80o`00;`3oool2000000T0oooo3@3o00030?ooo`030000003o
ool0oooo0580oooo001b0?ooo`800000<03oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0
oooo00H0oooo203o00000`3oool0o`000?l000050?ooo`030000003oool0oooo0580oooo001d0?oo
o`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0;P3oool00`000000oooo0?ooo`050?oo
o`@0o`00303oool00`000000oooo0?ooo`1B0?ooo`00M@3oool00`000000oooo0?ooo`0^0?ooo`80
o`00;`3oool00`000000oooo0?ooo`040?ooo`80o`003P3oool00`000000oooo0?ooo`1B0?ooo`00
E03oool00`000000oooo0?ooo`0O0?ooo`800000<03oool00`3o0000oooo0?ooo`0]0?ooo`030000
003oool0oooo06P0oooo001D0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;P3o
ool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo06L0oooo001D0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0;P3oool20?l002h0oooo00<000000?ooo`3oool0IP3oool0
05D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo
02`0oooo00<000000?ooo`3oool0I@3oool007/0oooo00<000000?ooo`3oool0;`3oool00`3o0000
oooo0?ooo`0/0?ooo`800000I@3oool007`0oooo0P00000`0?ooo`80o`00;P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo05<0oooo001n0?ooo`030000003oool0oooo02l0oooo00<0
o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo001o
0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo05<0oooo00200?ooo`030000003oool0oooo02l0oooo0P3o000]0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0D`3oool00840oooo00<000000?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0D`3oool005H0oooo00<000000?ooo`3oool0:@3oool200000340oooo00<0o`000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1M0?ooo`00EP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo02l0oooo0P3o000/0?ooo`030000003oool0oooo05`0oooo001F0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0Z0?ooo`800000G03oool0
05H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo
02/0oooo00<000000?ooo`3oool0F@3oool008L0oooo0P00000a0?ooo`80o`00;03oool00`000000
oooo0?ooo`1H0?ooo`00R@3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo02X0oooo
00<000000?ooo`000000E`3oool008X0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?oo
o`0Z0?ooo`800000E`3oool008/0oooo0P00000a0?ooo`80o`00:P3oool3000005H0oooo002=0?oo
o`030000003oool0oooo0300oooo00<0o`000?ooo`3oool09`3oool010000000oooo0?ooo`00001E
0?ooo`00F03oool00`000000oooo0?ooo`0c0?ooo`800000<@3oool00`3o0000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0580oooo001H0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0;`3oool20?l002/0oooo00<000000?ooo`3oool0D@3oool005T0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0
D03oool005T0oooo00<000000?ooo`3oool0=P3oool200000340oooo00<0o`000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1?0?ooo`00U03oool00`000000oooo0?ooo`0_0?ooo`80o`00:P3oool0
0`000000oooo0?ooo`1>0?ooo`00U@3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo
01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1=0?ooo`00UP3oool200000340
oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04`0
oooo002H0?ooo`030000003oool0oooo02l0oooo0P3o000K0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0B`3oool009T0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?oo
o`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0BP3oool005`0oooo00<00000
0?ooo`3oool0>`3oool200000340oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`19
0?ooo`00G03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02l0oooo0P3o000X0?oo
o`030000003oool0oooo04P0oooo001M0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo04L0oooo001M0?ooo`030000
003oool0oooo03h0oooo0P00000a0?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool0
AP3oool00:00oooo00<000000?ooo`3oool0;`3oool20?l002L0oooo00<000000?ooo`3oool0A@3o
ool00:40oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0<0?ooo`8000005`3oool0
0`000000oooo0?ooo`140?ooo`00XP3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo
00/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`130?ooo`00X`3oool200000340
oooo0P3o000:0?ooo`030000003oool0oooo01T0oooo0P0000130?ooo`00H03oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool01`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0400oooo001Q0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo03l0oooo001Q
0?ooo`030000003oool0oooo04<0oooo0P00000a0?ooo`80o`009P3oool00`000000oooo0?ooo`0n
0?ooo`00HP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0300oooo00<0o`000?oo
o`3oool0903oool00`000000oooo0?ooo`0m0?ooo`00ZP3oool00`000000oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool00:/0oooo0P00000a0?ooo`80o`00
9@3oool00`000000oooo0?ooo`0k0?ooo`00[@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0o`0002D0oooo00<000000?ooo`3oool0>P3oool00:h0oooo00<000000?ooo`3oool0;03oool0
1@000000oooo0?ooo`3oool0o`0002D0oooo00<000000?ooo`3oool0>@3oool006H0oooo00<00000
0?ooo`3oool0AP3oool200000340oooo0P3o000T0?ooo`030000003oool0oooo03P0oooo001W0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0R0?oo
o`800000>03oool006L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo02<0oooo00<000000?ooo`3oool0=@3oool006P0oooo00<000000?ooo`3oool0
B03oool200000340oooo0P3o000T0?ooo`030000003oool0oooo03@0oooo002e0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0R0?ooo`030000003o
ool0oooo03<0oooo002f0?ooo`8000007`3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0280oooo00<000000?ooo`3oool0<P3oool00;P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0A0?ooo`80o`008`3oool00`000000oooo0?ooo`0a0?ooo`00K@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0300oooo001^0?ooo`030000003oool0oooo04T0oooo
0P00000a0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0;`3oool006l0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0_0?ooo`80o`008P3oool00`000000oooo0?oo
o`0^0?ooo`00_@3oool200000340oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`0^
0?ooo`00_`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo0P3o000P0?oo
o`030000003oool0oooo02d0oooo00300?ooo`8000003P3oool00`000000oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo01h0oooo00<000000?ooo`3oool0;03oool007@0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0[0?ooo`00M@3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo02l0oooo0P3o000O0?ooo`030000003oool0oooo02X0oooo001f0?ooo`800000C03oool2
00000340oooo00<0o`000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`00aP3oool01000
0000oooo0?ooo`00000^0?ooo`030?l0003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool0
0<L0oooo0P00000`0?ooo`80o`007P3oool00`000000oooo0?ooo`0W0?ooo`00O03oool00`000000
oooo0?ooo`170?ooo`80000000<0oooo0000003oool0<03oool00`3o0000oooo0?ooo`0L0?ooo`03
0000003oool0oooo02H0oooo001m0?ooo`800000B`3oool200000300oooo00<0o`000?ooo`3oool0
703oool00`000000oooo0?ooo`0U0?ooo`00O`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo02h0oooo0P3o000M0?ooo`030000003oool0oooo02@0oooo00300?ooo`8000002`3oool2
00000300oooo00<0o`000?ooo`3oool06`3oool00`000000oooo0?ooo`0S0?ooo`00_P3oool20000
00l0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo
0280oooo00250?ooo`<00000B03oool00`000000oooo0?ooo`0^0?ooo`80o`00703oool00`000000
oooo0?ooo`0Q0?ooo`00R03oool00`000000oooo0?ooo`0/0?ooo`800000603oool200000300oooo
00<0o`000?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?ooo`00]@3oool2000001`0oooo00<0
00000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo002>
0?ooo`@00000@P3oool2000002l0oooo0P3o000J0?ooo`030000003oool0oooo01l0oooo002H0?oo
o`030000003oool0oooo0100oooo1000000W0?ooo`030000003oool0oooo02h0oooo00<0o`000?oo
o`3oool0603oool00`000000oooo0?ooo`0N0?ooo`00V@3oool3000000D0oooo1@00000a0?ooo`80
0000;`3oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo01d0oooo003I0?ooo`030000
003oool0oooo02d0oooo0P3o000I0?ooo`030000003oool0oooo01`0oooo003J0?ooo`800000;`3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo003L0?ooo`030000003oool0
oooo02d0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`00g@3oool20000
02h0oooo0P3o000G0?ooo`030000003oool0oooo01X0oooo003O0?ooo`030000003oool0oooo02d0
oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0I0?ooo`00h03oool2000002h0oooo
00<0o`000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`00hP3oool00`000000oooo0?oo
o`0/0?ooo`80o`005P3oool00`000000oooo0?ooo`0G0?ooo`00h`3oool2000002h0oooo00<0o`00
0?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`00i@3oool2000002d0oooo00<0o`000?oo
o`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`00i`3oool00`000000oooo0?ooo`0[0?ooo`80
o`00503oool00`000000oooo0?ooo`0E0?ooo`00j03oool2000002d0oooo00<0o`000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0D0?ooo`00jP3oool2000002`0oooo00<0o`000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0C0?ooo`00k03oool2000002/0oooo0P3o000B0?ooo`030000003oool0
oooo01<0oooo003^0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool0403oool00`00
0000oooo0?ooo`0B0?ooo`00k`3oool2000002/0oooo00<0o`000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`00l@3oool00`000000oooo0?ooo`0Y0?ooo`80o`004@3oool00`000000oooo
0?ooo`0@0?ooo`00lP3oool2000002/0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?oo
o`0@0?ooo`00m03oool2000002X0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`00mP3oool00`000000oooo0?ooo`0X0?ooo`80o`003`3oool00`000000oooo0?ooo`0>0?oo
o`00m`3oool2000002X0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`00
n@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00?X0oooo0P00000Y0?ooo`80o`003@3oool00`000000oooo0?ooo`0<0?ooo`00o03oool2
000002T0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`00oP3oool20000
02P0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`00o`3oool10?ooo`80
00009`3oool20?l000D0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00
o`3oool30?ooo`8000009`3oool0103o0000oooo0?ooo`3oool30?l000@0oooo00<000000?ooo`3o
ool02P3oool00?l0oooo1@3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0o`00
0`3oool00`000000oooo0?ooo`0:0?ooo`00o`3oool60?ooo`8000009P3oool70?l000<0oooo00<0
00000?ooo`3oool02@3oool00?l0oooo203oool2000002@0oooo1`3o00030?ooo`030000003oool0
oooo00T0oooo003o0?ooo`X0oooo0P00000Q0?ooo`T0o`000`3oool00`000000oooo0?ooo`080?oo
o`00o`3oool<0?ooo`8000007`3oool:0?l00080oooo00<000000?ooo`3oool0203oool00?l0oooo
3P3oool3000001/0oooo303o00020?ooo`030000003oool0oooo00L0oooo003o0?oooa40oooo0P00
000K0?ooo`/0o`0000<0oooo0000003oool0203oool00?l0oooo4`3oool2000001/0oooo2P3o0000
0`3oool000000?ooo`070?ooo`00o`3ooolE0?ooo`800000703oool70?l000030?ooo`000000oooo
00L0oooo003o0?oooaL0oooo0`00000L0?ooo`D0o`0000<000000?ooo`3oool01P3oool00?l0oooo
6P3oool2000001`0oooo103o00000`000000oooo0?ooo`050?ooo`00o`3ooolL0?ooo`<00000703o
ool20?l000L0oooo003o0?oooal0oooo0`00000J0?ooo`030000003oool0oooo00D0oooo003o0?oo
ob80oooo0P00000G0?ooo`030000003oool0oooo00H0oooo003o0?ooob@0oooo0P00000E0?ooo`03
0000003oool0oooo00H0oooo003o0?ooobH0oooo0`00000A0?ooo`030000003oool0oooo00L0oooo
003o0?ooobT0oooo0`00000<0?ooo`8000002P3oool00?l0oooo;03oool<000000`0oooo003o0?oo
od@0oooo003o0?oood@0oooo003o0?oood@0oooo003o0?oood@0oooo003o0?oood@0oooo003o0?oo
od@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 322.938}, {254.938, 0}} -> {-2.10225, -1.65959, 
  0.0130195, 0.0130195}}]
}, Open  ]],

Cell[TextData[
"The function eigshow will create 37 such plots as the unit vector steps from \
0\[Degree] to 180\[Degree] by 5\[Degree].  Animate these graphics as directed \
below."], "Text"],

Cell[BoxData[
    \(eigshow[A]\)], "Input"],

Cell["\<\
General advice on animations that you need to use immediately after \
evaluating eigshow:
1.  Select the cell bracket containing all the plots (second from the inside) \
and and close the subgroup by double clicking.  (This makes it easier to move \
around in your notebook.)  While this closed group of cells is selected, \
choose from menu \"Cell, Animate Selected Graphics (Ctrl-Y)\" and things \
should start spinning.  With the \"play-back controls\" down on the lower \
bar, you can slow down the animation or, even better, click the pause button \
and then while pause is down click forward or reverse to ADVANCE ONE FRAME AT \
A TIME.
2.  You should DELETE this group of multiple plots when you are finished \
viewing them; certainly before saving the notebook or whenever the computer \
acts strange due to memory limitations.  Select the cell bracket containing \
all the plots (second from the inside) but not the input, then Cut (Ctrl-X).  \
If you are CAREFUL NOT TO DELETE YOUR INPUT, you (or I) can always recreate \
the graphics.  Many graphics take up lots of space on the disk and in \
computer memory (RAM) while using the notebook.\
\>", "Text"],

Cell["\<\
Use this animation to answer the ATLAST questions (a) to (e).\
\>", "Text"],

Cell[CellGroupData[{

Cell["(e)  exact values", "Subsubsection"],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input"],

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input"],

Cell[BoxData[
    \(\(unitImage[A, Eigenvectors[A]]; \)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(f)(i) Instructors may delete these Solutions to (f) for student distribution\
\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{\(-2\), 1}, {1, \(-2\)}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-2\), "1"},
            {"1", \(-2\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(eigshow[A]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "1"},
            {"1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, Eigenvectors[A]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.213038 0.5 0.213038 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.07392 .71304 m
.09411 .67509 L
.11739 .63581 L
.14358 .5955 L
.17248 .55446 L
.20388 .51301 L
.23753 .47146 L
.27317 .43012 L
.31054 .38932 L
.34936 .34936 L
.38932 .31054 L
.43012 .27317 L
.47146 .23753 L
.51301 .20388 L
.55446 .17248 L
.5955 .14358 L
.63581 .11739 L
.67509 .09411 L
.71304 .07392 L
.74936 .05698 L
.78379 .0434 L
.81606 .0333 L
.84592 .02676 L
.87315 .02381 L
.89753 .02449 L
.9189 .02878 L
.93707 .03667 L
.95192 .04808 L
.96333 .06293 L
.97122 .0811 L
.97551 .10247 L
.97619 .12685 L
.97324 .15408 L
.9667 .18394 L
.9566 .21621 L
.94302 .25064 L
.92608 .28696 L
.90589 .32491 L
.88261 .36419 L
.85642 .4045 L
.82752 .44554 L
.79612 .48699 L
.76247 .52854 L
.72683 .56988 L
.68946 .61068 L
.65064 .65064 L
.61068 .68946 L
.56988 .72683 L
.52854 .76247 L
.48699 .79612 L
Mistroke
.44554 .82752 L
.4045 .85642 L
.36419 .88261 L
.32491 .90589 L
.28696 .92608 L
.25064 .94302 L
.21621 .9566 L
.18394 .9667 L
.15408 .97324 L
.12685 .97619 L
.10247 .97551 L
.0811 .97122 L
.06293 .96333 L
.04808 .95192 L
.03667 .93707 L
.02878 .9189 L
.02449 .89753 L
.02381 .87315 L
.02676 .84592 L
.0333 .81606 L
.0434 .78379 L
.05698 .74936 L
.07392 .71304 L
Mfstroke
[ .01 .02 ] 0 setdash
.71304 .5 m
.71223 .51857 L
.7098 .53699 L
.70578 .55514 L
.70019 .57286 L
.69308 .59003 L
.6845 .60652 L
.67451 .62219 L
.6632 .63694 L
.65064 .65064 L
.63694 .6632 L
.62219 .67451 L
.60652 .6845 L
.59003 .69308 L
.57286 .70019 L
.55514 .70578 L
.53699 .7098 L
.51857 .71223 L
.5 .71304 L
.48143 .71223 L
.46301 .7098 L
.44486 .70578 L
.42714 .70019 L
.40997 .69308 L
.39348 .6845 L
.37781 .67451 L
.36306 .6632 L
.34936 .65064 L
.3368 .63694 L
.32549 .62219 L
.3155 .60652 L
.30692 .59003 L
.29981 .57286 L
.29422 .55514 L
.2902 .53699 L
.28777 .51857 L
.28696 .5 L
.28777 .48143 L
.2902 .46301 L
.29422 .44486 L
.29981 .42714 L
.30692 .40997 L
.3155 .39348 L
.32549 .37781 L
.3368 .36306 L
.34936 .34936 L
.36306 .3368 L
.37781 .32549 L
.39348 .3155 L
.40997 .30692 L
Mistroke
.42714 .29981 L
.44486 .29422 L
.46301 .2902 L
.48143 .28777 L
.5 .28696 L
.51857 .28777 L
.53699 .2902 L
.55514 .29422 L
.57286 .29981 L
.59003 .30692 L
.60652 .3155 L
.62219 .32549 L
.63694 .3368 L
.65064 .34936 L
.6632 .36306 L
.67451 .37781 L
.6845 .39348 L
.69308 .40997 L
.70019 .42714 L
.70578 .44486 L
.7098 .46301 L
.71223 .48143 L
.71304 .5 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .5 m
.95192 .04808 L
s
% Start of user PostScript
0 0 2.12132 -2.12132 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .5 m
.34936 .65064 L
s
% Start of user PostScript
0 0 -0.707107 0.707107 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .5 m
.34936 .34936 L
s
% Start of user PostScript
0 0 -0.707107 -0.707107 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .5 m
.65064 .65064 L
s
% Start of user PostScript
0 0 0.707107 0.707107 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00m`3oool700000280oooo003a0?ooo`H000001`3oool6000001`0oooo
003]0?ooo`@000004`3oool5000001L0oooo003Y0?ooo`@00000703oool2000001D0oooo003V0?oo
o`<000008P3oool2000001<0oooo003R0?ooo`@000009`3oool200000140oooo003O0?ooo`<00000
;@3oool2000000l0oooo003M0?ooo`800000<P3oool00`3o0000oooo0?ooo`0<0?ooo`00f`3oool2
00000380oooo0P3o00000`3oool000000?ooo`0<0?ooo`00f@3oool200000380oooo103o00000`3o
ool000000?ooo`0<0?ooo`00eP3oool3000003<0oooo103o00030?ooo`030000003oool0oooo00X0
oooo003D0?ooo`800000=03oool60?l000<0oooo00<000000?ooo`3oool02P3oool00=80oooo0P00
000e0?ooo`H0o`001@3oool00`000000oooo0?ooo`090?ooo`00d03oool2000003D0oooo1`3o0006
0?ooo`030000003oool0oooo00T0oooo003>0?ooo`800000=@3oool90?l000L0oooo00<000000?oo
o`3oool0203oool00<`0oooo0P00000f0?ooo`T0o`00203oool00`000000oooo0?ooo`080?ooo`00
bP3oool2000003T0oooo1`3o000:0?ooo`030000003oool0oooo00L0oooo00380?ooo`800000?03o
ool60?l000X0oooo00<000000?ooo`3oool01`3oool00<H0oooo0P00000n0?ooo`D0o`002`3oool0
0`000000oooo0?ooo`070?ooo`00a03oool2000003l0oooo00<0o`000?ooo`3oool00`3o000;0?oo
o`030000003oool0oooo00L0oooo00320?ooo`800000@03oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00<40oooo00<000000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo002o0?ooo`800000@@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo002m0?ooo`800000@P3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo002k0?ooo`800000@`3oool00`3o
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo002i0?ooo`800000A03oool00`3o0000
oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo002g0?ooo`800000A@3oool00`3o0000oooo
0?ooo`0F0?ooo`030000003oool0oooo00H0oooo002f0?ooo`030000003oool0oooo04@0oooo00<0
o`000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00]03oool2000004H0oooo00<0o`00
0?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`00/`3oool00`000000oooo0?ooo`150?oo
o`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00;40oooo0P0000170?ooo`03
0?l0003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00;00oooo00<000000?ooo`3oool0
AP3oool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo002^0?ooo`800000B03o
ool00`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo002]0?ooo`030000003oool0
oooo04L0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`00Z`3oool20000
04T0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`00ZP3oool00`000000
oooo0?ooo`180?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00:P0oooo
0P00001:0?ooo`030?l0003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00:L0oooo00<0
00000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo002V
0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`06
0?ooo`00Y03oool2000004/0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`060?oo
o`00X`3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3o
ool01`3oool00:80oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`0T0?ooo`030000
003oool0oooo00L0oooo002P0?ooo`800000C03oool00`3o0000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00L0oooo002O0?ooo`030000003oool0oooo04/0oooo00<0o`000?ooo`3oool09P3oool0
0`000000oooo0?ooo`070?ooo`00WP3oool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool009`0oooo0P00001=0?ooo`030?l0003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool009/0oooo00<000000?ooo`3oool0C03oool00`3o0000oooo
0?ooo`0X0?ooo`030000003oool0oooo00P0oooo002J0?ooo`030000003oool0oooo04`0oooo00<0
o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`00V03oool2000004h0oooo00<0o`00
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00U`3oool00`000000oooo0?ooo`1=0?oo
o`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool009H0oooo00<000000?ooo`3o
ool0C@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo002D0?ooo`800000
C`3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo002C0?ooo`030000003o
ool0oooo04h0oooo00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00TP3oool0
0`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool0
0940oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo
00X0oooo002?0?ooo`800000D03oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo00/0
oooo002>0?ooo`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0;0?ooo`00S@3oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0300oooo00<0
00000?ooo`3oool02`3oool008`0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`0`
0?ooo`030000003oool0oooo00`0oooo002;0?ooo`030000003oool0oooo04l0oooo00<0o`000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`00R@3oool200000540oooo00<0o`000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0=0?ooo`00R03oool00`000000oooo0?ooo`1@0?ooo`030?l0
003oool0oooo0380oooo00<000000?ooo`3oool03@3oool008L0oooo00<000000?ooo`3oool0D03o
ool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo00h0oooo00260?ooo`030000003oool0
oooo0500oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`00Q@3oool00`00
0000oooo0?ooo`1@0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool03`3oool008<0
oooo0P00001B0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool00880oooo
00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo00l0oooo
00210?ooo`030000003oool0oooo0540oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0@0?ooo`00P03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo03H0oooo00<00000
0?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0f0?oo
o`030000003oool0oooo0140oooo001m0?ooo`800000D`3oool00`3o0000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0140oooo001l0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0B0?ooo`00N`3oool00`000000oooo0?ooo`1B0?ooo`030?l0003o
ool0oooo03P0oooo00<000000?ooo`3oool04P3oool007X0oooo00<000000?ooo`3oool0DP3oool0
0`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo001i0?ooo`030000003oool0oooo
0580oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`00N03oool00`000000
oooo0?ooo`1B0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0503oool007L0oooo
00<000000?ooo`3oool04@3oool4000000D0oooo0`00000e0?ooo`030?l0003oool0oooo03X0oooo
00<000000?ooo`3oool0503oool007H0oooo00<000000?ooo`3oool02P3oool3000001H0oooo0P00
000]0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool05@3oool007@0oooo0P00000X
0?ooo`800000:P3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo001c0?oo
o`030000003oool0oooo00H0oooo0P00001;0?ooo`030?l0003oool0oooo03/0oooo00<000000?oo
o`3oool05P3oool00780oooo00<000000?ooo`3oool01@3oool2000002P0oooo0P00000R0?ooo`03
0?l0003oool0oooo03`0oooo00<000000?ooo`3oool05P3oool00740oooo00<000000?ooo`3oool0
<P3oool2000001l0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0G0?ooo`00L03o
ool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool05`3o
ool006l0oooo00@000000?ooo`3oool00000>@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo03d0oooo00<000000?ooo`3oool0603oool006h0oooo00@000000?ooo`0000000000>`3o
ool2000001D0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0H0?ooo`00K@3oool0
10000000oooo0?ooo`00000n0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0I0?ooo`00K03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0
oooo03l0oooo00<000000?ooo`3oool06@3oool006/0oooo00<000000?ooo`3oool0D`3oool00`3o
0000oooo0?ooo`0o0?ooo`030000003oool0oooo01X0oooo001Z0?ooo`800000A`3oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool06`3oool006T0oooo
0P0000190?ooo`8000002@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo01/0oooo
001X0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`100?ooo`030000003oool0oooo01`0oooo001W0?ooo`030000003oool0oooo05<0oooo00<0o`00
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0L0?ooo`00IP3oool00`000000oooo0?ooo`1C0?oo
o`030?l0003oool0oooo0440oooo00<000000?ooo`3oool07@3oool006@0oooo0P00001E0?ooo`03
0?l0003oool0oooo0480oooo00<000000?ooo`3oool07@3oool006@0oooo00<0003o0?ooo`3oool0
D`3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo01h0oooo001R0?ooo`80000000<0
oooo0000o`000?l0DP3oool00`3o0000oooo000000130?ooo`030000003oool0oooo01h0oooo001R
0?ooo`030000003oool0oooo00@0003oC`3oool01@3o0000oooo0?ooo`3oool000000440oooo00<0
00000?ooo`3oool07`3oool00640oooo00<000000?ooo`3oool00P3oool40000odd0oooo00<0o`00
0?ooo`3oool0A03oool00`000000oooo0?ooo`0O0?ooo`00H03oool00`000000oooo0?ooo`030?oo
o`H0003oBP3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo0200oooo001O0?ooo`03
0000003oool0oooo00D0oooo1`000?m70?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3o
ool08@3oool005h0oooo0P0000070?ooo`T0003oA03oool00`3o0000oooo0?ooo`090?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool08@3oool005d0oooo0P0000090?ooo`T0003o@P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool08P3o
ool005`0oooo0P00000;0?ooo`L0003o@P3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool08`3oool005/0oooo00<000000?ooo`3oool02`3oool60000
od80oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0S0?ooo`00FP3oool00`000000
oooo0?ooo`0=0?ooo`D0003o@@3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo02@0
oooo001I0?ooo`030000003oool0oooo00h0oooo0`000?l20?ooo`030000o`3oool0oooo03d0oooo
00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>`3oool00`3o0000oooo0?oo
o`170?ooo`030000003oool0oooo02D0oooo001G0?ooo`040000003oool0oooo000001H0oooo00<0
003o0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool09P3oool005H0oooo00@000000?ooo`3oool00000603oool00`000?l0oooo0?oo
o`0g0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0W0?ooo`00E@3oool010000000oooo0?ooo`00000J0?ooo`030000o`3oool0oooo03D0oooo00<0
o`000?ooo`3oool05`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02L0oooo001D
0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0I
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:03oool005<0oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo04P0oooo00<000000?oo
o`3oool0:@3oool005<0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0_0?ooo`03
0?l0003oool0oooo04T0oooo00<000000?ooo`3oool0:@3oool00580oooo00<000000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo04T0oooo00<000000?ooo`3oool0
:P3oool00540oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo04T0oooo00<000000?ooo`3oool0:`3oool00500oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0803oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02`0oooo001?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo
0240oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`00CP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool09@3oool00`3o0000
oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;@3oool004d0oooo
00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0^0?ooo`00C03oool00`000000oooo0?oo
o`0^0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0_0?ooo`00B`3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo01l0oooo00<0o`00
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00B`3oool00`000000oooo0?ooo`0a0?oo
o`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`0`0?oo
o`00BP3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0a0?ooo`00B@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0<P3oool004P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0380oooo00170?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0c0?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=03oool004H0
oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo04`0
oooo00<000000?ooo`3oool0=@3oool004D0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool0=@3oool004@0oooo00<0
00000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo04d0oooo00<0
00000?ooo`3oool0=P3oool004<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool0=`3oool00480oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0h0?ooo`00@@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo03D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0>03oool00440oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03T0oooo00100?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo03L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0j0?ooo`00?`3oool0
0`000000oooo0?ooo`1;0?ooo`050000o`3oool0oooo0?ooo`3o0000>P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03/0oooo000n0?ooo`030000003oool0oooo04d0oooo00<0003o
0?ooo`3o0000D03oool00`000000oooo0?ooo`0l0?ooo`00?@3oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0?03oool003`0oooo00<000000?ooo`3o
ool0C`3oool00`3o0000oooo0000o`1?0?ooo`030000003oool0oooo03d0oooo000l0?ooo`030000
003oool0oooo04h0oooo00D0o`000?ooo`3oool0oooo0000o`1=0?ooo`030000003oool0oooo03h0
oooo000k0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0o0?ooo`00>P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0@03oool003T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@@3oool003P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0440oooo000h0?ooo`03
0000003oool0oooo04d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0b0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0@P3oool003L0oooo00<000000?ooo`3oool0
C@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`130?ooo`00=P3oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo04@0oooo000e0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0A@3oool0
03D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
04H0oooo000d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0AP3oool003<0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`170?ooo`00<P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0B03oool00380oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04T0oooo000a0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1:0?oo
o`00<03oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0B`3oool00300oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo02h0oooo00<000000?ooo`3oool0B`3oool002l0oooo00<000000?ooo`3oool0BP3o
ool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0C03o
ool002h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0
oooo02D0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`1=0?ooo`00;@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0CP3oool002d0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0C`3oool002`0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0500oooo000[0?ooo`030000003oool0oooo04T0oooo00<0
o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0D@3oool002X0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0_
0?ooo`030000o`3oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000001D0?ooo`00:P3oool0
0`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`1C0?ooo`00:@3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
05<0oooo000X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`1D0?ooo`00:03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0E@3oool002L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo03T0oooo00<0003o0?ooo`3oool0503oool010000000oooo0?oo
o`00001H0?ooo`009P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0
00000?ooo`000000F@3oool002H0oooo00<000000?ooo`3oool0@@3oool40?l000030?ooo`3o0000
oooo03h0oooo00<0003o0?ooo`3oool00P000?l?0?ooo`030000003oool0000005X0oooo000U0?oo
o`030000003oool0oooo0480oooo0`3o00140?ooo`@0003o3`3oool00`000000oooo0?ooo`1I0?oo
o`00903oool00`000000oooo0?ooo`130?ooo`@0o`00@@3oool60000o`h0oooo00<000000?ooo`3o
ool0FP3oool002@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`090?ooo`H0o`00
?`3oool80000o``0oooo00<000000?ooo`3oool0F`3oool002<0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`080?ooo`P0o`00?@3oool80000o`/0oooo00<000000?ooo`3oool0G03o
ool00280oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`060?ooo`P0o`00?`3oool8
0000o`P0oooo0P00001O0?ooo`008P3oool00`000000oooo0?ooo`120?ooo`L0o`00A03oool60000
o`H0oooo0P00001P0?ooo`008@3oool00`000000oooo0?ooo`120?ooo`D0o`00B@3oool40000o`H0
oooo00<000000?ooo`3oool0G`3oool00200oooo00<000000?ooo`3oool0@P3oool50?l004/0oooo
10000?l40?ooo`030000003oool0oooo0600oooo000P0?ooo`030000003oool0oooo04<0oooo0P3o
001>0?ooo`@0003o0P3oool00`000000oooo0?ooo`1Q0?ooo`007`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0080o`00D03oool01@000?l0oooo0000o`3oool0000006@0oooo000O
0?ooo`030000003oool0oooo0440oooo00<000000?l0003oool0E03oool00`000?l0oooo0?ooo`1S
0?ooo`007P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0580oooo0P00001U0?oo
o`007P3oool00`000000oooo0?ooo`2G0?ooo`800000IP3oool001d0oooo00<000000?ooo`3oool0
U`3oool2000006L0oooo000M0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0I`3o
ool001`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo06P0oooo000L0?ooo`030000003oool0oooo04/0oooo0P0000170?ooo`800000J`3oool001/0
oooo00<000000?ooo`3oool0U03oool2000006`0oooo000J0?ooo`030000003oool0oooo09@0oooo
0P00001]0?ooo`006P3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo06`0oooo000I
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1]
0?ooo`006@3oool00`000000oooo0?ooo`1E0?ooo`800000>03oool200000080oooo00<000000?oo
o`3oool0KP3oool001P0oooo00<000000?ooo`3oool0SP3oool2000000<0oooo00<000000?ooo`3o
ool0K`3oool001P0oooo00<000000?ooo`3oool0G03oool2000003@0oooo00<000000?ooo`3oool0
L03oool001L0oooo00<000000?ooo`3oool0G`3oool2000002P0oooo0P0000070?ooo`030000003o
ool0oooo0740oooo000G0?ooo`030000003oool0oooo08L0oooo0P0000080?ooo`030000003oool0
oooo0780oooo000F0?ooo`030000003oool0oooo06H0oooo0P00000Y0?ooo`030000003oool0oooo
07<0oooo000F0?ooo`030000003oool0oooo06P0oooo0P00000F0?ooo`@000002`3oool2000007H0
oooo000E0?ooo`030000003oool0oooo0700oooo100000050?ooo`<000004`3oool00`000000oooo
0?ooo`1f0?ooo`005@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo07L0oooo000D
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0N03oool001@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1i0?ooo`004`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo07X0oooo000C0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
N`3oool00180oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1l0?ooo`004P3oool0
0`000000oooo0?ooo`2:0?ooo`800000O`3oool00140oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`1o0?ooo`004@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0800
oooo000@0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0P@3oool00100oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`220?ooo`00403oool00`000000oooo0?ooo`26
0?ooo`800000Q@3oool000l0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?oo
o`003`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08H0oooo000>0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0Q`3oool000h0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`280?ooo`003@3oool00`000000oooo0?ooo`230?ooo`800000R`3oool0
00d0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`2;0?ooo`00303oool00`000000
oooo0?ooo`220?ooo`030000003oool0oooo08`0oooo000<0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0S@3oool000`0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2>0?ooo`002`3oool00`000000oooo0?ooo`1o0?ooo`800000T@3oool000/0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`2A0?ooo`002`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0980oooo000:0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
T`3oool000X0oooo00<000000?ooo`3oool0N`3oool2000009H0oooo000:0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0UP3oool000X0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`2G0?ooo`002@3oool00`000000oooo0?ooo`1h0?ooo`800000VP3oool000T0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2J0?ooo`002@3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo09/0oooo00080?ooo`030000003oool0oooo07D0oooo0P00002N
0?ooo`00203oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo09h0oooo00080?ooo`03
0000003oool0oooo0780oooo0P00002Q0?ooo`00203oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0:40oooo00070?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0XP3o
ool000L0oooo00<000000?ooo`3oool0K`3oool200000:D0oooo00070?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0Y@3oool000L0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`2V0?ooo`001`3oool00`000000oooo0?ooo`1[0?ooo`800000Z@3oool000L0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`2Y0?ooo`001P3oool00`000000oooo0?ooo`1Y
0?ooo`800000[03oool000H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2/0?oo
o`001P3oool00`000000oooo0?ooo`1V0?ooo`800000[`3oool000H0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`2_0?ooo`001P3oool00`000000oooo0?ooo`1S0?ooo`800000/P3o
ool000H0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2b0?ooo`001P3oool00`00
0000oooo0?ooo`1P0?ooo`800000]@3oool000H0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`2e0?ooo`001`3oool00`000000oooo0?ooo`1L0?ooo`800000^03oool000L0oooo00<0
00000?ooo`3oool0FP3oool200000;X0oooo00070?ooo`030000003oool0oooo05P0oooo0P00002l
0?ooo`001`3oool00`000000oooo0?ooo`1F0?ooo`800000_P3oool000L0oooo00<000000?ooo`3o
ool0E03oool200000<00oooo00070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
`03oool000L0oooo00<000000?ooo`3oool0D@3oool200000<<0oooo00080?ooo`030000003oool0
oooo04h0oooo0P0000350?ooo`00203oool00`000000oooo0?ooo`1<0?ooo`800000a`3oool000P0
oooo00<000000?ooo`3oool0BP3oool200000<T0oooo00080?ooo`030000003oool0oooo04P0oooo
0P00003;0?ooo`002@3oool00`000000oooo0?ooo`150?ooo`800000c@3oool000T0oooo00<00000
0?ooo`3oool0@`3oool200000<l0oooo000:0?ooo`030000003oool0oooo0400oooo0P00003A0?oo
o`002P3oool00`000000oooo0?ooo`0n0?ooo`800000d`3oool000/0oooo00<000000?ooo`3oool0
>`3oool200000=D0oooo000;0?ooo`030000003oool0oooo03P0oooo0`00003G0?ooo`00303oool0
0`000000oooo0?ooo`0e0?ooo`800000fP3oool000`0oooo00<000000?ooo`3oool0<`3oool20000
0=`0oooo000=0?ooo`030000003oool0oooo0300oooo0P00003N0?ooo`003P3oool2000002d0oooo
0`00003P0?ooo`00403oool2000002P0oooo0`00003S0?ooo`004P3oool200000280oooo1000003V
0?ooo`00503oool2000001d0oooo0`00003Z0?ooo`005P3oool4000001D0oooo1000003]0?ooo`00
6P3oool7000000P0oooo1P00003a0?ooo`008@3oool800000?L0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.34702, -2.34702, 0.0163556, 
  0.0163556}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(f)(ii)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{\(-1\), 2}, {\(-2\), 4}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "2"},
            {\(-2\), "4"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(eigshow[A]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"2", "1"},
            {"1", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, Eigenvectors[A]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.213038 1 0.213038 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.28696 .57392 m
.32491 .64981 L
.36419 .72837 L
.4045 .809 L
.44554 .89107 L
.48699 .97398 L
.52854 1.05708 L
.56988 1.13975 L
.61068 1.22136 L
.65064 1.30128 L
.68946 1.37891 L
.72683 1.45366 L
.76247 1.52495 L
.79612 1.59225 L
.82752 1.65504 L
.85642 1.71284 L
.88261 1.76522 L
.90589 1.81178 L
.92608 1.85215 L
.94302 1.88605 L
.9566 1.91319 L
.9667 1.93339 L
.97324 1.94649 L
.97619 1.95238 L
.97551 1.95102 L
.97122 1.94243 L
.96333 1.92666 L
.95192 1.90385 L
.93707 1.87415 L
.9189 1.8378 L
.89753 1.79507 L
.87315 1.74629 L
.84592 1.69183 L
.81606 1.63211 L
.78379 1.56758 L
.74936 1.49873 L
.71304 1.42608 L
.67509 1.35019 L
.63581 1.27163 L
.5955 1.191 L
.55446 1.10893 L
.51301 1.02602 L
.47146 .94292 L
.43012 .86025 L
.38932 .77864 L
.34936 .69872 L
.31054 .62109 L
.27317 .54634 L
.23753 .47505 L
.20388 .40775 L
Mistroke
.17248 .34496 L
.14358 .28716 L
.11739 .23478 L
.09411 .18822 L
.07392 .14785 L
.05698 .11395 L
.0434 .08681 L
.0333 .06661 L
.02676 .05351 L
.02381 .04762 L
.02449 .04898 L
.02878 .05757 L
.03667 .07334 L
.04808 .09615 L
.06293 .12585 L
.0811 .1622 L
.10247 .20493 L
.12685 .25371 L
.15408 .30817 L
.18394 .36789 L
.21621 .43242 L
.25064 .50127 L
.28696 .57392 L
Mfstroke
[ .01 .02 ] 0 setdash
.71304 1 m
.71223 1.01857 L
.7098 1.03699 L
.70578 1.05514 L
.70019 1.07286 L
.69308 1.09003 L
.6845 1.10652 L
.67451 1.12219 L
.6632 1.13694 L
.65064 1.15064 L
.63694 1.1632 L
.62219 1.17451 L
.60652 1.1845 L
.59003 1.19308 L
.57286 1.20019 L
.55514 1.20578 L
.53699 1.2098 L
.51857 1.21223 L
.5 1.21304 L
.48143 1.21223 L
.46301 1.2098 L
.44486 1.20578 L
.42714 1.20019 L
.40997 1.19308 L
.39348 1.1845 L
.37781 1.17451 L
.36306 1.1632 L
.34936 1.15064 L
.3368 1.13694 L
.32549 1.12219 L
.3155 1.10652 L
.30692 1.09003 L
.29981 1.07286 L
.29422 1.05514 L
.2902 1.03699 L
.28777 1.01857 L
.28696 1 L
.28777 .98143 L
.2902 .96301 L
.29422 .94486 L
.29981 .92714 L
.30692 .90997 L
.3155 .89348 L
.32549 .87781 L
.3368 .86306 L
.34936 .84936 L
.36306 .8368 L
.37781 .82549 L
.39348 .8155 L
.40997 .80692 L
Mistroke
.42714 .79981 L
.44486 .79422 L
.46301 .7902 L
.48143 .78777 L
.5 .78696 L
.51857 .78777 L
.53699 .7902 L
.55514 .79422 L
.57286 .79981 L
.59003 .80692 L
.60652 .8155 L
.62219 .82549 L
.63694 .8368 L
.65064 .84936 L
.6632 .86306 L
.67451 .87781 L
.6845 .89348 L
.69308 .90997 L
.70019 .92714 L
.70578 .94486 L
.7098 .96301 L
.71223 .98143 L
.71304 1 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 1 m
.5 1 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 1 m
.69055 1.09527 L
s
% Start of user PostScript
0 0 0.894427 0.447214 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 1 m
.78582 1.57164 L
s
% Start of user PostScript
0 0 1.34164 2.68328 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 1 m
.59527 1.19055 L
s
% Start of user PostScript
0 0 0.447214 0.894427 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@000182000`400?l00000o`00003oT03oool0
0900oooo002@0?ooo`00T03oool00900oooo002@0?ooo`00T03oool00900oooo00030?ooo`030000
003oool0oooo08X0oooo00030?ooo`800000R`3oool000<0oooo0P00002;0?ooo`00103oool20000
08X0oooo00050?ooo`030000003oool0oooo08P0oooo00050?ooo`800000R@3oool000H0oooo00<0
00000?ooo`3oool0Q`3oool000H0oooo0P0000280?ooo`001`3oool00`000000oooo0?ooo`260?oo
o`001`3oool2000008L0oooo00080?ooo`030000003oool0oooo08D0oooo00090?ooo`030000003o
ool0oooo08@0oooo00090?ooo`030000003oool0oooo08@0oooo000:0?ooo`030000003oool0oooo
08<0oooo000:0?ooo`030000003oool0oooo08<0oooo000:0?ooo`800000Q03oool000/0oooo00<0
00000?ooo`3oool0PP3oool000/0oooo00<000000?ooo`3oool0PP3oool000`0oooo00<000000?oo
o`3oool0P@3oool000`0oooo00<000000?ooo`3oool0P@3oool000d0oooo00<000000?ooo`3oool0
P03oool000d0oooo00<000000?ooo`3oool0P03oool000h0oooo00<000000?ooo`3oool0O`3oool0
00h0oooo0P0000200?ooo`003`3oool00`000000oooo0?ooo`1n0?ooo`003`3oool2000007l0oooo
000@0?ooo`030000003oool0oooo07d0oooo000@0?ooo`800000OP3oool00140oooo00<000000?oo
o`3oool0O03oool00140oooo0P00001m0?ooo`004P3oool00`000000oooo0?ooo`1k0?ooo`004P3o
ool2000007`0oooo000C0?ooo`030000003oool0oooo07X0oooo000C0?ooo`800000N`3oool001@0
oooo00<000000?ooo`3oool0N@3oool001@0oooo0P00001j0?ooo`005@3oool00`000000oooo0?oo
o`1h0?ooo`005@3oool2000007T0oooo000F0?ooo`030000003oool0oooo07L0oooo000F0?ooo`80
0000N03oool001L0oooo00<000000?ooo`3oool0MP3oool001L0oooo0P00001g0?ooo`00603oool0
0`000000oooo0?ooo`1e0?ooo`006@3oool00`000000oooo0?ooo`1d0?ooo`006@3oool00`000000
oooo0?ooo`1d0?ooo`006P3oool00`000000oooo0?ooo`1c0?ooo`006P3oool00`000000oooo0?oo
o`1c0?ooo`006P3oool2000007@0oooo000K0?ooo`030000003oool0oooo0780oooo000K0?ooo`80
0000L`3oool001`0oooo00<000000?ooo`3oool0L@3oool001`0oooo0P00001b0?ooo`007@3oool0
0`000000oooo0?ooo`1`0?ooo`007@3oool200000740oooo000N0?ooo`030000003oool0oooo06l0
oooo000N0?ooo`800000L03oool001h0oooo0P00001`0?ooo`007`3oool00`000000oooo0?ooo`1^
0?ooo`007`3oool2000006l0oooo000P0?ooo`030000003oool0oooo06d0oooo000P0?ooo`800000
KP3oool00240oooo00<000000?ooo`3oool0K03oool00240oooo0P00001]0?ooo`008P3oool00`00
0000oooo0?ooo`1[0?ooo`008P3oool2000006`0oooo000S0?ooo`030000003oool0oooo06X0oooo
000T0?ooo`030000003oool0oooo06T0oooo000T0?ooo`800000JP3oool002D0oooo00<000000?oo
o`3oool0J03oool002D0oooo0P00001Y0?ooo`009P3oool00`000000oooo0?ooo`1W0?ooo`009`3o
ool00`000000oooo0?ooo`1V0?ooo`009`3oool00`000000oooo0?ooo`1V0?ooo`00:03oool00`00
0000oooo0?ooo`1U0?ooo`00:03oool00`000000oooo0?ooo`1U0?ooo`00:@3oool00`000000oooo
0?ooo`1T0?ooo`00:@3oool00`000000oooo0?ooo`1T0?ooo`00:P3oool00`000000oooo0?ooo`1S
0?ooo`00:P3oool00`000000oooo0?ooo`1S0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`00
:`3oool00`000000oooo0?ooo`1R0?ooo`00;03oool00`000000oooo0?ooo`1Q0?ooo`00;03oool0
0`000000oooo0?ooo`1Q0?ooo`00;03oool200000680oooo000]0?ooo`030000003oool0oooo0600
oooo000]0?ooo`800000H@3oool002h0oooo00<000000?ooo`3oool0G`3oool002h0oooo0P00001P
0?ooo`00;`3oool00`000000oooo0?ooo`1N0?ooo`00;`3oool2000005l0oooo000`0?ooo`030000
003oool0oooo05d0oooo000`0?ooo`800000GP3oool00340oooo00<000000?ooo`3oool0G03oool0
0340oooo0P00001M0?ooo`00<P3oool00`000000oooo0?ooo`1K0?ooo`00<P3oool2000005`0oooo
000c0?ooo`030000003oool0oooo05X0oooo000c0?ooo`800000F`3oool003@0oooo00<000000?oo
o`3oool0F@3oool003@0oooo0P00001J0?ooo`00=@3oool00`000000oooo0?ooo`1H0?ooo`00=@3o
ool2000005T0oooo000f0?ooo`030000003oool0oooo05L0oooo000f0?ooo`030000003oool0oooo
05L0oooo000g0?ooo`030000003oool0oooo05H0oooo000g0?ooo`030000003oool0oooo05H0oooo
000h0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`8000000P3oool300000080oooo00<0
00000?ooo`3oool0?`3oool003P0oooo00<000000?ooo`3oool00P3oool200000100oooo00@00000
0?ooo`3oool00000?@3oool003T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0j
0?ooo`00>@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03L0oooo000g0?ooo`80
000000<0oooo0000003oool06P3oool2000003P0oooo000e0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0D`3oool003@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0K0?ooo`800000=@3oool003/0oooo00<000000?ooo`3oool0DP3oool00340oooo0P0000090?oo
o`030000003oool0oooo01d0oooo0P00000b0?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0<03oool003d0oooo00<000000?ooo`3oool0
D03oool002l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1@0?ooo`00;P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;P3oool0
02h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
02d0oooo000o0?ooo`030000003oool0oooo04h0oooo000/0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:`3oool00400oooo00<00000
0?ooo`3oool0C@3oool00440oooo00<000000?ooo`3oool0C03oool002/0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02X0oooo000Z0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?ooo`00@P3o
ool00`000000oooo0?ooo`1;0?ooo`00@`3oool00`000000oooo0?ooo`1:0?ooo`00:@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:03oool002T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0
oooo00140?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool004D0oooo00<0
00000?ooo`3oool0B03oool002T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0:03oool004L0oooo00<0003o0?ooo`3oool0
AP3oool002T0oooo00<000000?ooo`3oool06`3oool20000odL0oooo000Y0?ooo`030000003oool0
oooo01`0oooo00@0003o0?ooo`3oool0o`00A03oool002T0oooo00<000000?ooo`3oool0703oool0
1@000?l0oooo0?ooo`3oool0o`0001P0oooo00<000000?ooo`3oool0:03oool004T0oooo00<0003o
0?ooo`3oool00`3oool20?l001@0oooo00<000000?ooo`3oool0:03oool004T0oooo0P000?m50?oo
o`00:@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo0P3o000k0?ooo`00
:@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0
:03oool004/0oooo00<0003o0?ooo`3oool0203oool30?l000/0oooo00<000000?ooo`3oool0:@3o
ool004/0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0`0?ooo`00:P3oool00`00
0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00/0oooo0P3o00000`3oool0o`000?l0000a0?oo
o`00:`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00`0oooo103o00040?ooo`03
0000003oool0oooo02X0oooo001=0?ooo`030000o`3oool0oooo00/0oooo1P3o00020?ooo`030000
003oool0oooo02X0oooo001=0?ooo`030000o`3oool0oooo00l0oooo103o000]0?ooo`00;03oool0
0`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0:`3oool0
02`0oooo00<000000?ooo`3oool07`3oool20000oa40oooo0P00000]0?ooo`00C`3oool00`000?l0
oooo0?ooo`0?0?ooo`030000003oool0oooo02`0oooo001?0?ooo`030000o`000000oooo03h0oooo
000^0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?oo
o`0^0?ooo`00;`3oool00`000000oooo0?ooo`0N0?ooo`80003o303oool00`000000oooo0?ooo`0_
0?ooo`00D@3oool00`000?l0oooo0000o`0:0?ooo`030000003oool0oooo02l0oooo000a0?ooo`03
0000003oool0oooo01d0oooo0`000?ll0?ooo`00<@3oool2000001d0oooo10000?l80?ooo`030000
003oool0oooo0340oooo001A0?ooo`<0003o1`3oool00`000000oooo0?ooo`0b0?ooo`00=03oool0
0`000000oooo0?ooo`0K0?ooo`<0003o>`3oool003D0oooo00<000000?ooo`3oool06`3oool20000
o`<0oooo0P00000f0?ooo`00=`3oool2000001/0oooo00<0003o0?ooo`3oool0>@3oool003T0oooo
00<000000?ooo`3oool0603oool20000ocX0oooo000k0?ooo`030000003oool0oooo01L0oooo00<0
003o0?ooo`3oool0>03oool003`0oooo0P0000000`3oool000000?ooo`0?0?ooo`<000000P3oool0
0`000?l000000?ooo`0h0?ooo`00@03oool200000080oooo0P0000020?ooo`8000000P3oool20000
00P0oooo00<0003o0?ooo`3oool0=`3oool005H0oooo00<0003o0000003oool0=`3oool005L0oooo
00<0003o0?ooo`3oool0=P3oool005L0oooo00<0003o0000003oool0=P3oool005P0oooo00<0003o
0?ooo`3oool0=@3oool005P0oooo00<0003o0000003oool0=@3oool005T0oooo00<0003o0?ooo`3o
ool0=03oool005T0oooo00<0003o0000003oool0=03oool005X0oooo00<0003o0?ooo`3oool0<`3o
ool005X0oooo00<0003o0000003oool0<`3oool005/0oooo00<0003o0?ooo`3oool0<P3oool005/0
oooo00<0003o0000003oool0<P3oool005`0oooo00<0003o0?ooo`3oool0<@3oool005`0oooo00<0
003o0000003oool0<@3oool005d0oooo00<0003o0?ooo`3oool0<03oool005d0oooo00<0003o0000
003oool0<03oool005h0oooo00<0003o0?ooo`3oool0;`3oool005h0oooo00<0003o0000003oool0
;`3oool005l0oooo00<0003o0?ooo`3oool0;P3oool005l0oooo00<0003o0000003oool0;P3oool0
0600oooo00<0003o0?ooo`3oool0;@3oool00600oooo00<0003o0000003oool0;@3oool00640oooo
00<0003o0?ooo`3oool0;03oool00640oooo00<0003o0000003oool0;03oool00680oooo00<0003o
0?ooo`3oool0:`3oool00680oooo00<0003o0?ooo`3oool0:`3oool006<0oooo00<0003o0?ooo`3o
ool0:P3oool006<0oooo00<0003o0?ooo`3oool0:P3oool006@0oooo00<0003o0?ooo`3oool0:@3o
ool006@0oooo00<0003o0?ooo`3oool0:@3oool006D0oooo00<0003o0?ooo`3oool0:03oool006D0
oooo00<0003o0?ooo`3oool0:03oool006H0oooo00<0003o0?ooo`3oool09`3oool006H0oooo00<0
003o0?ooo`3oool09`3oool006L0oooo00<0003o0?ooo`3oool09P3oool006L0oooo00<0003o0?oo
o`3oool09P3oool006P0oooo00<0003o0?ooo`3oool09@3oool006P0oooo00<0003o0000003oool0
9@3oool006T0oooo00<0003o0?ooo`3oool0903oool006T0oooo00<0003o0000003oool0903oool0
06X0oooo00<0003o0?ooo`3oool08`3oool006X0oooo00<0003o0000003oool08`3oool006/0oooo
00<0003o0?ooo`3oool08P3oool006/0oooo00<0003o0000003oool08P3oool006`0oooo00<0003o
0?ooo`3oool08@3oool006`0oooo0`000?lQ0?ooo`00J`3oool40000ob40oooo001/0?ooo`@0003o
803oool006d0oooo0`000?lP0?ooo`00K@3oool30000ob00oooo001^0?ooo`80003o803oool006l0
oooo0P000?lO0?ooo`00L03oool00`000?l0oooo0?ooo`0M0?ooo`00L03oool2000001h0oooo001a
0?ooo`030000003oool0oooo01`0oooo001a0?ooo`8000007@3oool00780oooo00<000000?ooo`3o
ool06`3oool00780oooo0P00000L0?ooo`00L`3oool00`000000oooo0?ooo`0J0?ooo`00L`3oool2
000001/0oooo001d0?ooo`030000003oool0oooo01T0oooo001d0?ooo`030000003oool0oooo01T0
oooo001e0?ooo`030000003oool0oooo01P0oooo001e0?ooo`030000003oool0oooo01P0oooo001f
0?ooo`030000003oool0oooo01L0oooo001f0?ooo`030000003oool0oooo01L0oooo001g0?ooo`03
0000003oool0oooo01H0oooo001g0?ooo`030000003oool0oooo01H0oooo001h0?ooo`030000003o
ool0oooo01D0oooo001h0?ooo`030000003oool0oooo01D0oooo001h0?ooo`8000005P3oool007T0
oooo00<000000?ooo`3oool0503oool007T0oooo0P00000E0?ooo`00NP3oool2000001@0oooo001j
0?ooo`800000503oool007/0oooo0P00000C0?ooo`00N`3oool2000001<0oooo001l0?ooo`800000
4P3oool007d0oooo00<000000?ooo`3oool0403oool007d0oooo0P00000A0?ooo`00OP3oool00`00
0000oooo0?ooo`0?0?ooo`00OP3oool200000100oooo001o0?ooo`030000003oool0oooo00h0oooo
001o0?ooo`8000003`3oool00800oooo00<000000?ooo`3oool03@3oool00800oooo0P00000>0?oo
o`00P@3oool00`000000oooo0?ooo`0<0?ooo`00P@3oool00`000000oooo0?ooo`0<0?ooo`00PP3o
ool00`000000oooo0?ooo`0;0?ooo`00PP3oool00`000000oooo0?ooo`0;0?ooo`00P`3oool00`00
0000oooo0?ooo`0:0?ooo`00P`3oool2000000/0oooo00240?ooo`030000003oool0oooo00T0oooo
00240?ooo`8000002P3oool008D0oooo00<000000?ooo`3oool0203oool008D0oooo0P0000090?oo
o`00QP3oool00`000000oooo0?ooo`070?ooo`00QP3oool2000000P0oooo00260?ooo`800000203o
ool008L0oooo0P0000070?ooo`00Q`3oool2000000L0oooo00280?ooo`030000003oool0oooo00D0
oooo00290?ooo`030000003oool0oooo00@0oooo00290?ooo`8000001@3oool008T0oooo0P000005
0?ooo`00RP3oool2000000@0oooo002;0?ooo`030000003oool0oooo0080oooo002@0?ooo`00T03o
ool00900oooo002@0?ooo`00T03oool00900oooo002@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 143}, {287, 0}} -> {-2.34702, -4.71046, 0.0328255, 
  0.0328255}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(f)(iii)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{1, \(-1\)}, {1, 1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", \(-1\)},
            {"1", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(eigshow[A]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1 - \[ImaginaryI], 1 + \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-\[ImaginaryI]\), "1"},
            {"\[ImaginaryI]", "1"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, Eigenvectors[A]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.336718 0.5 0.336718 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.83672 .83672 m
.80609 .86478 L
.77313 .89007 L
.7381 .91239 L
.70125 .93158 L
.66287 .94747 L
.62325 .95996 L
.58269 .96896 L
.5415 .97438 L
.5 .97619 L
.4585 .97438 L
.41731 .96896 L
.37675 .95996 L
.33713 .94747 L
.29875 .93158 L
.2619 .91239 L
.22687 .89007 L
.19391 .86478 L
.16328 .83672 L
.13522 .80609 L
.10993 .77313 L
.08761 .7381 L
.06842 .70125 L
.05253 .66287 L
.04004 .62325 L
.03104 .58269 L
.02562 .5415 L
.02381 .5 L
.02562 .4585 L
.03104 .41731 L
.04004 .37675 L
.05253 .33713 L
.06842 .29875 L
.08761 .2619 L
.10993 .22687 L
.13522 .19391 L
.16328 .16328 L
.19391 .13522 L
.22687 .10993 L
.2619 .08761 L
.29875 .06842 L
.33713 .05253 L
.37675 .04004 L
.41731 .03104 L
.4585 .02562 L
.5 .02381 L
.5415 .02562 L
.58269 .03104 L
.62325 .04004 L
.66287 .05253 L
Mistroke
.70125 .06842 L
.7381 .08761 L
.77313 .10993 L
.80609 .13522 L
.83672 .16328 L
.86478 .19391 L
.89007 .22687 L
.91239 .2619 L
.93158 .29875 L
.94747 .33713 L
.95996 .37675 L
.96896 .41731 L
.97438 .4585 L
.97619 .5 L
.97438 .5415 L
.96896 .58269 L
.95996 .62325 L
.94747 .66287 L
.93158 .70125 L
.91239 .7381 L
.89007 .77313 L
.86478 .80609 L
.83672 .83672 L
Mfstroke
[ .01 .02 ] 0 setdash
.83672 .5 m
.83544 .52935 L
.8316 .55847 L
.82524 .58715 L
.81641 .61516 L
.80517 .6423 L
.79161 .66836 L
.77582 .69313 L
.75794 .71644 L
.7381 .7381 L
.71644 .75794 L
.69313 .77582 L
.66836 .79161 L
.6423 .80517 L
.61516 .81641 L
.58715 .82524 L
.55847 .8316 L
.52935 .83544 L
.5 .83672 L
.47065 .83544 L
.44153 .8316 L
.41285 .82524 L
.38484 .81641 L
.3577 .80517 L
.33164 .79161 L
.30687 .77582 L
.28356 .75794 L
.2619 .7381 L
.24206 .71644 L
.22418 .69313 L
.20839 .66836 L
.19483 .6423 L
.18359 .61516 L
.17476 .58715 L
.1684 .55847 L
.16456 .52935 L
.16328 .5 L
.16456 .47065 L
.1684 .44153 L
.17476 .41285 L
.18359 .38484 L
.19483 .3577 L
.20839 .33164 L
.22418 .30687 L
.24206 .28356 L
.2619 .2619 L
.28356 .24206 L
.30687 .22418 L
.33164 .20839 L
.3577 .19483 L
Mistroke
.38484 .18359 L
.41285 .17476 L
.44153 .1684 L
.47065 .16456 L
.5 .16328 L
.52935 .16456 L
.55847 .1684 L
.58715 .17476 L
.61516 .18359 L
.6423 .19483 L
.66836 .20839 L
.69313 .22418 L
.71644 .24206 L
.7381 .2619 L
.75794 .28356 L
.77582 .30687 L
.79161 .33164 L
.80517 .3577 L
.81641 .38484 L
.82524 .41285 L
.8316 .44153 L
.83544 .47065 L
.83672 .5 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00RP3oool;000008/0oooo001n0?ooo``000002`3oool<000007l0oooo
001f0?ooo`P000008`3oool8000007L0oooo001b0?ooo`@00000<`3oool4000007<0oooo001^0?oo
o`@00000>`3oool4000006l0oooo001[0?ooo`<00000@`3oool3000006`0oooo001X0?ooo`<00000
B@3oool3000006T0oooo001U0?ooo`<00000C`3oool3000006H0oooo001R0?ooo`<00000E@3oool3
000006<0oooo001O0?ooo`<00000F`3oool300000600oooo001L0?ooo`<00000H@3oool3000005d0
oooo001J0?ooo`800000I`3oool2000005/0oooo001G0?ooo`<00000J`3oool3000005P0oooo001E
0?ooo`800000L@3oool2000005H0oooo001C0?ooo`800000M@3oool2000005@0oooo001A0?ooo`80
0000N@3oool200000580oooo001@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
C`3oool004h0oooo0P00001o0?ooo`800000C`3oool004`0oooo0P0000230?ooo`800000C@3oool0
04/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1:0?ooo`00B@3oool2000008T0
oooo0P00001:0?ooo`00A`3oool2000008d0oooo0P0000180?ooo`00AP3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo04D0oooo00140?ooo`800000T`3oool2000004D0oooo00120?oo
o`800000U`3oool2000004<0oooo00110?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0@03oool003l0oooo0P00002M0?ooo`800000@03oool003h0oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`0m0?ooo`00?@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo03`0oooo000k0?ooo`800000Y@3oool2000003`0oooo000j0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0>@3oool003P0oooo0P00002[0?ooo`800000>@3oool003L0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool0=03oool003@0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0c0?ooo`00
<P3oool200000;L0oooo0P00000c0?ooo`00<@3oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo0300oooo000`0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0;`3oool0
02l0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0^0?ooo`00;P3oool00`000000
oooo0?ooo`1O0?ooo`800000GP3oool00`000000oooo0?ooo`0]0?ooo`00;@3oool00`000000oooo
0?ooo`1A0?ooo`800000103oool4000000L0oooo0P0000050?ooo`<00000E@3oool00`000000oooo
0?ooo`0/0?ooo`00;03oool00`000000oooo0?ooo`1@0?ooo`800000803oool2000004l0oooo00<0
00000?ooo`3oool0:`3oool002/0oooo00<000000?ooo`3oool0BP3oool2000002T0oooo0P00001>
0?ooo`030000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo04T0oooo0P00000a0?oo
o`800000B@3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`130?ooo`80
0000>@3oool2000004L0oooo00<000000?ooo`3oool0:@3oool002T0oooo00<000000?ooo`3oool0
@P3oool2000008D0oooo00<000000?ooo`3oool0:03oool002P0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo03h0oooo0P0000190?ooo`800000@P3oool00`000000oooo0?ooo`0V0?ooo`009P3oool00`00
0000oooo0?ooo`0m0?ooo`800000T03oool00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo
000T0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo02<0oooo000S0?ooo`030000003oool0oooo03T0oooo0P00002J
0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0R0?ooo`008P3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00240oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
803oool00200oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo01l0oooo000P0?ooo`030000003oool0oooo03@0oooo0P00002U0?ooo`030000003oool0
oooo01l0oooo000O0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0N0?ooo`007P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool07@3oool001d0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo01`0oooo000M
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0L
0?ooo`00703oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo01/0oooo000K0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0J0?ooo`00
6`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
6P3oool001X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030000003oool0oooo
02h0oooo0P00002i0?ooo`030000003oool0oooo01P0oooo000H0?ooo`030000003oool0oooo0>/0
oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo01L0oooo000G0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0F
0?ooo`005P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool05@3oool001D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`310?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
503oool001@0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01<0oooo000D0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0C0?ooo`004`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo0180oooo000B0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?oo
o`0Z0?ooo`800000b`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`3g
0?ooo`030000003oool0oooo0140oooo000A0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`3<0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0403oool00100oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00l0oooo000@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`3A0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo0?d0oooo
00<000000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0=<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`3D0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0303o
ool000`0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00/0oooo000<0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?oo
o`00303oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool02`3oool000/0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0=/0oooo00<000000?ooo`3oool02P3oool000X0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0gP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00090?ooo`030000003oool0
oooo0=l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`002@3oool00`00
0000oooo0?ooo`3P0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool000T0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo00090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0h03oool00`000000oooo
0?ooo`080?ooo`00203oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0>40oooo00<0
00000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3R
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0oooo303oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3S0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3S0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool01P3oool000L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo00H0oooo0007
0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`00
0000oooo0?ooo`3U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool000L0
oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0
oooo00070?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3U
0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0i@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0>D0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0
o`3oool?0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0iP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0>L0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo05h0oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo0>H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo3`3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`3o0?oo
o`h0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`3U0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo
00070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo00070?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?oo
o`001`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0oooo
00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003o
ool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool01P3oool000L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2k0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool01`3oool000T0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0203oool000T0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00P0oooo
000:0?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0o`3oool80?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0:
0?ooo`00303oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool02`3oool000`0
oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000
003oool0oooo0?l0oooo103oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?oo
o`3o0?ooo`80oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00`0oooo000>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?oo
o`3o0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo0?d0oooo00<00000
0?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0>0?oo
o`003`3oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00l0oooo000A0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo0100
oooo000B0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool04@3oool00180oooo00<0
00000?ooo`3oool0m`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool04P3oool001<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003o
ool0oooo0?<0oooo00<000000?ooo`3oool04`3oool001D0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
01@0oooo000F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01H0oooo
000G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo0>/0oooo00<00000
0?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0G0?oo
o`006@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0I0?ooo`006P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0800oooo0P00000a0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo
0>D0oooo00<000000?ooo`3oool06P3oool001`0oooo00<000000?ooo`3oool0h`3oool00`000000
oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo01`0oooo
000M0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo01`0oooo000N0?ooo`030000003oool0oooo0380oooo0P00001e
0?ooo`800000=03oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool07@3oool001l0oooo00<000000?ooo`3o
ool0g@3oool00`000000oooo0?ooo`0N0?ooo`00803oool00`000000oooo0?ooo`3K0?ooo`030000
003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01l0oooo000Q0?ooo`030000003oool0
oooo03H0oooo0P00001W0?ooo`800000>03oool00`000000oooo0?ooo`0P0?ooo`008P3oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00280
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool08P3oool002@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool08`3oool002D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1F
0?ooo`800000?03oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0U0?ooo`009`3oool00`000000oooo0?ooo`0o0?ooo`800000
BP3oool200000400oooo00<000000?ooo`3oool09P3oool002P0oooo00<000000?ooo`3oool0R03o
ool200000440oooo00<000000?ooo`3oool09`3oool002T0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo02P0oooo000Z0?ooo`030000003oool0oooo
04@0oooo0P00000h0?ooo`@00000A@3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo02T0oooo000[0?ooo`030000003oool0oooo04X0oooo
1000000X0?ooo`800000C@3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo0?oo
o`1A0?ooo`800000803oool2000004h0oooo00<000000?ooo`3oool0:`3oool002d0oooo00<00000
0?ooo`3oool0DP3oool2000000D0oooo0P0000080?ooo`8000001@3oool4000005<0oooo00<00000
0?ooo`3oool0;03oool002h0oooo00<000000?ooo`3oool0FP3oool2000000@0oooo0P00001M0?oo
o`030000003oool0oooo02d0oooo000_0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool0;P3oool00300oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0_0?ooo`00<@3o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0300oooo000b0?ooo`800000]`3oool2
000003<0oooo000d0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0<`3oool003D0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo03D0oooo000g0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool0=P3oool003P0oooo0P00002[0?ooo`800000>@3oool003X0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0i0?ooo`00>`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo03X0oooo000l0?ooo`800000X`3oool2000003d0oooo000n0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0?@3oool003l0oooo0P00002M0?ooo`800000@03oool0
0440oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`100?ooo`00@P3oool2000009L0
oooo0P0000130?ooo`00A03oool2000009<0oooo0P0000150?ooo`00AP3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo04D0oooo00170?ooo`800000S@3oool2000004P0oooo00190?oo
o`800000R@3oool2000004X0oooo001;0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0BP3oool004`0oooo0P0000230?ooo`800000C@3oool004h0oooo0P00001o0?ooo`800000C`3o
ool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D@3oool20000
07T0oooo0P00001B0?ooo`00D`3oool2000007D0oooo0P00001D0?ooo`00E@3oool200000740oooo
0P00001F0?ooo`00E`3oool3000006/0oooo0`00001H0?ooo`00FP3oool2000006L0oooo0P00001K
0?ooo`00G03oool300000640oooo0`00001M0?ooo`00G`3oool3000005/0oooo0`00001P0?ooo`00
HP3oool3000005D0oooo0`00001S0?ooo`00I@3oool3000004l0oooo0`00001V0?ooo`00J03oool3
000004T0oooo0`00001Y0?ooo`00J`3oool3000004<0oooo0`00001/0?ooo`00KP3oool4000003/0
oooo1000001_0?ooo`00LP3oool4000003<0oooo1000001c0?ooo`00MP3oool7000002D0oooo1`00
001g0?ooo`00O@3oool<000000d0oooo3000001n0?ooo`00R@3oool=000008X0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.48494, -1.48494, 0.010348, 
  0.010348}}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{638, 428},
WindowMargins->{{-1, Automatic}, {Automatic, -2}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 161, 4, 66, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1895, 57, 56, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[1976, 61, 112, 3, 74, "Section"],

Cell[CellGroupData[{
Cell[2113, 68, 68, 0, 47, "Subsection"],
Cell[2184, 70, 161, 3, 52, "Text"],
Cell[2348, 75, 104, 2, 50, "Input",
  InitializationCell->True],
Cell[2455, 79, 2032, 41, 490, "Input",
  InitializationCell->True],
Cell[4490, 122, 2113, 39, 570, "Input",
  InitializationCell->True],
Cell[6606, 163, 2397, 42, 690, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9040, 210, 71, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[9136, 214, 61, 1, 30, "Input"],
Cell[9200, 217, 403, 12, 44, "Output"]
}, Open  ]],
Cell[9618, 232, 282, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[9925, 241, 59, 1, 30, "Input"],
Cell[9987, 244, 24486, 523, 264, 4054, 266, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[34488, 770, 192, 3, 52, "Text"],
Cell[34683, 775, 43, 1, 30, "Input"],
Cell[34729, 778, 1175, 18, 223, "Text"],
Cell[35907, 798, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[36017, 804, 42, 0, 43, "Subsubsection"],
Cell[36062, 806, 47, 1, 30, "Input"],
Cell[36112, 809, 48, 1, 30, "Input"],
Cell[36163, 812, 68, 1, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[36280, 819, 109, 3, 31, "Subsection"],

Cell[CellGroupData[{
Cell[36414, 826, 67, 1, 30, "Input"],
Cell[36484, 829, 199, 6, 44, "Output"]
}, Open  ]],
Cell[36698, 838, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[36766, 843, 47, 1, 30, "Input"],
Cell[36816, 846, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36920, 852, 48, 1, 30, "Input"],
Cell[36971, 855, 196, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37204, 866, 68, 1, 30, "Input"],
Cell[37275, 869, 28215, 563, 296, 4009, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[65539, 1438, 29, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[65593, 1442, 67, 1, 30, "Input"],
Cell[65663, 1445, 199, 6, 44, "Output"]
}, Open  ]],
Cell[65877, 1454, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[65945, 1459, 47, 1, 30, "Input"],
Cell[65995, 1462, 57, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66089, 1468, 48, 1, 30, "Input"],
Cell[66140, 1471, 193, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66370, 1482, 68, 1, 30, "Input"],
Cell[66441, 1485, 15494, 411, 296, 4110, 266, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[81984, 1902, 30, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[82039, 1906, 62, 1, 30, "Input"],
Cell[82104, 1909, 196, 6, 44, "Output"]
}, Open  ]],
Cell[82315, 1918, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[82383, 1923, 47, 1, 30, "Input"],
Cell[82433, 1926, 89, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82559, 1932, 48, 1, 30, "Input"],
Cell[82610, 1935, 220, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82867, 1946, 68, 1, 30, "Input"],
Cell[82938, 1949, 25199, 517, 296, 3655, 246, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

