(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1077511,      17471]*)
(*NotebookOutlinePosition[   1078249,      17497]*)
(*  CellTagsIndexPosition[   1078205,      17493]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebooks for ATLAST\nby Richard Neidinger, Davidson College, 6/1/98."
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell["ATLAST 8.2  Singular Value Decomposition Projects", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
ATLAST 8.2; 1 -- svdshow -- Tutorial
Visualizing the Singular Value Decompososition\
\>", "Section"],

Cell[CellGroupData[{

Cell["Initializations -- unitImage, eigshow, svdshow", "Subsection"],

Cell["\<\
These three programs are stand-alone, except that before any is defined the \
following cell MUST be evaluated once to load the packages.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`Arrow`; \n<< Graphics`Colors`; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(unitImage::usage\), " ", "=", " ", 
        StyleBox[
          \("\<unitImage[mat, {x1,x2}] displays the unit circle and the unit \
vector in the direction of {x1,x2}, dashed before and solid after \
transformation by the 2\[Times]2 matrix mat.
		\nunitImage[mat, {{x1,x2},{y1,y2}}] will display two unit vectors and their \
images.
		\nGraphics options such as Axes->True may be included as a last \
argument.\>"\),
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["\n",
        FontColor->RGBColor[0, 0, 1]], 
      \(unitImage[A_?MatrixQ, {v_, w_}, \ opts___Rule]\  := \ \n
        Module[{unitCircle, normalize, unitVec1, \ unitVec2}, \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tnormalize[u_]\  := \ 
            If[u \[NotEqual] {0, 0}\  && \ \ Im[u] == {0, 0}, \ u/Sqrt[u.u], 
              \ {0, 0}]; \n\t\t
          If[VectorQ[v]\ 
             (*\ v\ and\ w\ should\ be\ plane\ vectors; \ 
              complex\ are\ set\ to\ {0, 0}\ *) , \ \n\t\t\t\t\t
            unitVec1\  = \ normalize[v]; \ unitVec2\  = \ normalize[w], \n\t\t
             (*\ else\ v\ and\ w\ should\ be\ numbers\ *) \ \n\t\t\t\t\t
            unitVec1\  = \ normalize[{v, w}]; \ unitVec2\  = \ {0, 0}\n\t\t]; 
          \n\t\tShow[
            Graphics[{\n
                \t\t\t\t{Line[Transpose[A.unitCircle]], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], 
                    Line[Transpose[unitCircle]]}}, \n\t\t\t\tRed, 
                \ {Arrow[{0, 0}, A.unitVec1], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], 
                    Arrow[{0, 0}, unitVec1]}}, \n\t\t\t\tBlue, 
                \ {Arrow[{0, 0}, A.unitVec2], \n
                  \t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, unitVec2]}}
                  \n\t\t}], AspectRatio -> Automatic, \ opts]\n]\), ";"}]], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(eigshow::usage\), " ", "=", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[
          \("\<eigshow[mat] creates movie frames for animation as a unit \
vector rotates from 0\[Degree] to 180\[Degree].  Each frame displays the unit \
vector and the unit circle, dashed before and solid after transformation by \
the 2\[Times]2 matrix mat.
		\neigshow[mat, tmin, tmax, dt] varies the unit vector
		from tmin\[Degree] to tmax\[Degree] by steps of dt\[Degree].\>"\),
          FontColor->RGBColor[0, 0, 1]]}], ";", "\n", 
      \(eigshow[A_?MatrixQ, \ degMin_:  0., degMax_:  180., degStep_:  5.]\ 
         := \nModule[{num, unitCircle, circleGraphic, rotMat, R, v, t}, \n\t\t
          num[x_, {t_, b_}]\  := \ 
            ToString[PaddedForm[Chop[x, .005], {t, b}]]; \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tcircleGraphic\  = 
            \ {Line[Transpose[A.unitCircle]], {Dashing[{0.01, .02}], 
                Line[Transpose[unitCircle]]}}; \n\t\t
          rotMat[\[Theta]_]\  := 
            \ {{Cos[\[Theta]], \(-Sin[\[Theta]]\)}, {Sin[\[Theta]], 
                Cos[\[Theta]]}}; \n\t\tR\  = \ rotMat[degStep*Pi/180.]; \n\t\t
          v\  = \ rotMat[degMin*Pi/180.].{1., 0.}; \n\t\t
          Do[\n\t\t\t\t
            Show[Graphics[{\n\t\t\t\t\t\tcircleGraphic, \n\t\t\t\t\t\tRed, 
                  \ {Arrow[{0, 0}, A.v], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, v]}}
                    \n\t\t\t\t}], \n\t\t\t\t\t\tAspectRatio -> Automatic, \n
              \t\t\t\t\t\t
              PlotLabel -> 
                StringJoin[\n\t\t\t\t\t\t\t\tnum[v, {3, 2}], "\< at\>", 
                  num[t, {4, 1}], "\<\[Degree]\n\>", \n\t\t\t\t\t\t\t\t
                  "\<to image length: \>", 
                  num[Sqrt[\((A.v)\).\((A.v)\)], {4, 2}]]\n\t\t\t\t]; \n
            \t\t\t\t\(v\  = \ R.v; \)\n\t\t, {t, degMin, \ degMax, \ degStep}]
            \n]\), ";"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(svdshow::usage\), " ", "=", " ", 
        StyleBox[
          \("\<svdshow[mat] creates movie frames for animation as a pair of \
orthonormal vectors that rotate through 90\[Degree].  Each frame displays the \
orthonormal vectors and the unit circle, dashed before and solid after \
transformation by the 2\[Times]2 matrix mat.
		\nsvdshow[mat, tmin, tmax, dt] varies the first vector
		from tmin\[Degree] to tmax\[Degree] by steps of dt\[Degree].\>"\),
          FontColor->RGBColor[0, 0, 1]]}], ";", "\n", 
      \(svdshow[A_?MatrixQ, \ degMin_:  0., degMax_:  90., degStep_:  5.]\ 
         := \nModule[{num, unitCircle, circleGraphic, rotMat, R, v, w, t}, \n
          \t\tnum[x_, {t_, b_}]\  := \ 
            ToString[PaddedForm[Chop[x, .005], {t, b}]]; \n\t\t
          unitCircle\  = \ 
            Transpose[Table[N[{Cos[t], Sin[t]}], {t, 0, 2  Pi, 5  Pi/180}]]; 
          \n\t\tcircleGraphic\  = 
            \ {Line[Transpose[A.unitCircle]], {Dashing[{0.01, .02}], 
                Line[Transpose[unitCircle]]}}; \n\t\t
          rotMat[\[Theta]_]\  := 
            \ {{Cos[\[Theta]], \(-Sin[\[Theta]]\)}, {Sin[\[Theta]], 
                Cos[\[Theta]]}}; \n\t\tR\  = \ rotMat[degStep*Pi/180.]; \n\t\t
          v\  = \ rotMat[degMin*Pi/180.].{1., 0.}; \n\t\t
          w\  = \ rotMat[degMin*Pi/180.].{0., 1.}; \n\t\t
          Do[\n\t\t\t\t
            Show[Graphics[{\n\t\t\t\t\t\tcircleGraphic, \n\t\t\t\t\t\tRed, 
                  \ {Arrow[{0, 0}, A.v], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], 
                      Arrow[{0, 0}, v]}}, \n\t\t\t\t\t\tBlue, 
                  \ {Arrow[{0, 0}, A.w], \n
                    \t\t\t\t\t\t\t\t{Dashing[{0.01, .02}], Arrow[{0, 0}, w]}}
                    \n\t\t\t\t}], \n\t\t\t\t\t\tAspectRatio -> Automatic, \n
              \t\t\t\t\t\t
              PlotLabel -> 
                StringJoin[\n\t\t\t\t\t\t\t\t"\<From angles:\>", 
                  num[t, {4, 1}], \ num[t + 90, {4, 1}], "\<\n\>", \n
                  \t\t\t\t\t\t\t\t"\<to lengths: \>", \ 
                  num[Sqrt[\((A.v)\).\((A.v)\)], {4, 2}], \n\t\t\t\t\t\t\t\t
                  num[Sqrt[\((A.w)\).\((A.w)\)], {4, 2}]]\n\t\t\t\t]; \n
            \t\t\t\tv\  = \ R.v; \n\t\t\t\t\(w\  = \ R.w; \)\n
            \t\t, {t, degMin, \ degMax, \ degStep}]\n]\), ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction enabling all parts of this problem.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ {{1, 1}, {0, 2}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "1"},
            {"0", "2"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?eigshow\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"eigshow[mat] creates movie frames for animation as a unit vector \
rotates from 0\[Degree] to 180\[Degree].  Each frame displays the unit vector \
and the unit circle, dashed before and solid after transformation by the 2\
\[Times]2 matrix mat.  \neigshow[mat, tmin, tmax, dt] varies the unit vector  \
from tmin\[Degree] to tmax\[Degree] by steps of dt\[Degree]."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(eigshow[A]\)], "Input"],

Cell["\<\
General advice on animations that you need to use immediately after \
evaluating eigshow or svdshow:
1.  Select the cell bracket containing all the plots (second from the inside) \
and and close the subgroup by double clicking.  (This makes it easier to move \
around in your notebook.)  While this closed group of cells is selected, \
choose from menu \"Cell, Animate Selected Graphics (Ctrl-Y)\" and things \
should start spinning.  With the \"play-back controls\" down on the lower \
bar, you can slow down the animation or, even better, click the pause button \
and then while pause is down click forward or reverse to ADVANCE ONE FRAME AT \
A TIME.
2.  You should DELETE this group of multiple plots when you are finished \
viewing them; certainly before saving the notebook or whenever the computer \
acts strange due to memory limitations.  Select the cell bracket containing \
all the plots (second from the inside) but not the input, then Cut (Ctrl-X).  \
If you are CAREFUL NOT TO DELETE YOUR INPUT, you (or I) can always recreate \
the graphics.  Many graphics take up lots of space on the disk and in \
computer memory (RAM) while using the notebook.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, Eigenvectors[A]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.41421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.336718 0.707107 0.336718 [
[ 0 0 0 0 ]
[ 1 1.41421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.41421 L
0 1.41421 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.83672 .70711 m
.86478 .7658 L
.89007 .82405 L
.91239 .8814 L
.93158 .93744 L
.94747 .99171 L
.95996 1.04382 L
.96896 1.09337 L
.97438 1.13998 L
.97619 1.1833 L
.97438 1.22299 L
.96896 1.25875 L
.95996 1.29032 L
.94747 1.31745 L
.93158 1.33993 L
.91239 1.3576 L
.89007 1.37031 L
.86478 1.37798 L
.83672 1.38054 L
.80609 1.37798 L
.77313 1.37031 L
.7381 1.3576 L
.70125 1.33993 L
.66287 1.31745 L
.62325 1.29032 L
.58269 1.25875 L
.5415 1.22299 L
.5 1.1833 L
.4585 1.13998 L
.41731 1.09337 L
.37675 1.04382 L
.33713 .99171 L
.29875 .93744 L
.2619 .8814 L
.22687 .82405 L
.19391 .7658 L
.16328 .70711 L
.13522 .64841 L
.10993 .59017 L
.08761 .53281 L
.06842 .47678 L
.05253 .4225 L
.04004 .37039 L
.03104 .32084 L
.02562 .27423 L
.02381 .23092 L
.02562 .19123 L
.03104 .15546 L
.04004 .12389 L
.05253 .09677 L
Mistroke
.06842 .07428 L
.08761 .05662 L
.10993 .0439 L
.13522 .03623 L
.16328 .03367 L
.19391 .03623 L
.22687 .0439 L
.2619 .05662 L
.29875 .07428 L
.33713 .09677 L
.37675 .12389 L
.41731 .15546 L
.4585 .19123 L
.5 .23092 L
.5415 .27423 L
.58269 .32084 L
.62325 .37039 L
.66287 .4225 L
.70125 .47678 L
.7381 .53281 L
.77313 .59017 L
.80609 .64841 L
.83672 .70711 L
Mfstroke
[ .01 .02 ] 0 setdash
.83672 .70711 m
.83544 .73645 L
.8316 .76558 L
.82524 .79426 L
.81641 .82227 L
.80517 .84941 L
.79161 .87547 L
.77582 .90024 L
.75794 .92354 L
.7381 .9452 L
.71644 .96505 L
.69313 .98293 L
.66836 .99871 L
.6423 1.01228 L
.61516 1.02352 L
.58715 1.03235 L
.55847 1.03871 L
.52935 1.04254 L
.5 1.04382 L
.47065 1.04254 L
.44153 1.03871 L
.41285 1.03235 L
.38484 1.02352 L
.3577 1.01228 L
.33164 .99871 L
.30687 .98293 L
.28356 .96505 L
.2619 .9452 L
.24206 .92354 L
.22418 .90024 L
.20839 .87547 L
.19483 .84941 L
.18359 .82227 L
.17476 .79426 L
.1684 .76558 L
.16456 .73645 L
.16328 .70711 L
.16456 .67776 L
.1684 .64864 L
.17476 .61996 L
.18359 .59194 L
.19483 .5648 L
.20839 .53875 L
.22418 .51397 L
.24206 .49067 L
.2619 .46901 L
.28356 .44917 L
.30687 .43128 L
.33164 .4155 L
.3577 .40194 L
Mistroke
.38484 .3907 L
.41285 .38186 L
.44153 .3755 L
.47065 .37167 L
.5 .37039 L
.52935 .37167 L
.55847 .3755 L
.58715 .38186 L
.61516 .3907 L
.6423 .40194 L
.66836 .4155 L
.69313 .43128 L
.71644 .44917 L
.7381 .46901 L
.75794 .49067 L
.77582 .51397 L
.79161 .53875 L
.80517 .5648 L
.81641 .59194 L
.82524 .61996 L
.8316 .64864 L
.83544 .67776 L
.83672 .70711 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .70711 m
.83672 .70711 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.83672 .70711 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .70711 m
.97619 1.1833 L
s
% Start of user PostScript
0 0 1.41421 1.41421 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.7381 .9452 L
s
% Start of user PostScript
0 0 0.707107 0.707107 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;000182000`400?l00000o`00003ob`3oool0
0</0oooo003;0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool00</0oooo000J0?ooo`l00000
XP3oool001P0oooo0P00000?0?ooo`<00000W`3oool001D0oooo0`00000D0?ooo`<00000W03oool0
01<0oooo0P00000J0?ooo`@00000V03oool00140oooo0P00000P0?ooo`<00000U@3oool00100oooo
00<000000?ooo`3oool08`3oool2000009<0oooo000?0?ooo`030000003oool0oooo02H0oooo0P00
002A0?ooo`003P3oool00`000000oooo0?ooo`0Y0?ooo`800000S`3oool000d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`2<0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`80
0000S03oool000/0oooo00<000000?ooo`3oool0<@3oool2000008X0oooo000;0?ooo`030000003o
ool0oooo03<0oooo0P0000280?ooo`002P3oool00`000000oooo0?ooo`0f0?ooo`800000QP3oool0
00X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`230?ooo`002@3oool00`000000
oooo0?ooo`0j0?ooo`800000P`3oool000T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`200?ooo`002@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo07l0oooo0008
0?ooo`030000003oool0oooo03l0oooo0P00001o0?ooo`00203oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo07`0oooo00080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0N`3oool000L0oooo00<000000?ooo`3oool0A03oool2000007/0oooo00070?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0N03oool000L0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`1g0?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000M`3oool000H0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1d0?ooo`001P3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo07<0oooo00060?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0LP3oool000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1a
0?ooo`001@3oool00`000000oooo0?ooo`1@0?ooo`800000L@3oool000D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1^0?ooo`001@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo06d0oooo00050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0K03o
ool000D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1[0?ooo`001@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo06X0oooo00050?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0J@3oool000D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`1X0?ooo`00103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06L0oooo0004
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0IP3oool000@0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1U0?ooo`00103oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo06@0oooo00040?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
H`3oool000@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1R0?ooo`00103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0640oooo00040?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0H03oool000@0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`1O0?ooo`001@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo05h0oooo
00050?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0G@3oool000D0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1L0?ooo`001@3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo05/0oooo00050?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0FP3oool000D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1I0?ooo`001@3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo05P0oooo00050?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0E`3oool000D0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1G0?ooo`001P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05H0
oooo00060?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0E@3oool000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1D0?ooo`001P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo05<0oooo00060?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0DP3oool000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A0?ooo`00
1P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0500oooo00070?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0D03oool000L0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1?0?ooo`001`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
04h0oooo00070?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C@3oool000L0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`00203oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo04`0oooo00080?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0B`3oool000P0oooo00<000000?ooo`3oool0D03oool010000000oooo0?ooo`3oool3
000000<0oooo100000030?ooo`<000003`3oool00`000000oooo0?ooo`1:0?ooo`00203oool00`00
0000oooo0?ooo`1>0?ooo`8000005`3oool3000000X0oooo00<000000?ooo`3oool0B@3oool000P0
oooo00<000000?ooo`3oool0B03oool300000240oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`180?ooo`002@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02D0oooo
0P0000060?ooo`030000003oool0oooo04P0oooo00090?ooo`030000003oool0oooo0480oooo0P00
000]0?ooo`050000003oool0oooo0?ooo`000000B@3oool000T0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0a0?ooo`8000000P3oool00`000000oooo0?ooo`160?ooo`002@3oool0
0`000000oooo0?ooo`0l0?ooo`800000>@3oool00`000000oooo0?ooo`150?ooo`002@3oool00`00
0000oooo0?ooo`1g0?ooo`800000AP3oool000X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0m0?ooo`800000A@3oool000X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo04<0oooo000:0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`000000@P3oool000X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`15
0?ooo`040000003oool0000000000400oooo000;0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`110?ooo`002`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool000/0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`800000>`3oool000/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03h0oooo000<0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0n0?ooo`00303oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool0
00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03D0oooo000<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`0T0?ooo`800000E`3oool00`000000oooo
0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0<P3oool000d0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0340oooo000>0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo000>0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0h0?ooo`00
3P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
>03oool000l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02h0oooo000?0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0]0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0=P3oool00100oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo03D0oooo000@0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0=@3oool00100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0<`3oool00140oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0380oooo000B0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0b0?ooo`004P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3o
ool001<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02L0oooo000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo000D0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0_0?ooo`00503oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0;`3oool001D0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo000E
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T
0?ooo`005P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0903oool001H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo02`0oooo000F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0[0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0:`3oool001L0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo000H0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00603oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0R0?ooo`00603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0:@3oool001T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo02P0oooo000I0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool09`3oool001X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo000J0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0Q0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`006`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09@3o
ool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02D0oooo000L0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0903oool001`0
oooo00<000000?ooo`3oool0Q@3oool01@000000oooo0?ooo`3oool000000280oooo000M0?ooo`03
0000003oool0oooo08D0oooo00@000000?ooo`3oool000008P3oool001d0oooo00D000000?ooo`3o
ool0oooo000000230?ooo`050000003oool0oooo0?ooo`0000008@3oool001h0oooo00@000000?oo
o`3oool00000Q03oool00`000000oooo0?ooo`0R0?ooo`007P3oool010000000oooo0?ooo`000024
0?ooo`030000003oool0oooo0280oooo000O0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool08@3oool001l0oooo00<000000?ooo`3oool0O@3oool20?l000H0oooo00<000000?ooo`00
00008@3oool00200oooo00<000000?ooo`3oool0O03oool50?l000@0oooo0P00000Q0?ooo`00803o
ool2000007d0oooo2@3o000200000240oooo000Q0?ooo`030000003oool0oooo0440oooo00<0003o
0?l0003o0000@P3o000Q0?ooo`008@3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo
03H0oooo2@3o00000`3oool000000?ooo`0P0?ooo`008@3oool2000004@0oooo00<0003o0?ooo`3o
ool0=@3oool60?l000@0oooo0P00000P0?ooo`008P3oool00`000000oooo0?ooo`130?ooo`030000
o`3oool0oooo03@0oooo0P3o00090?ooo`030000003oool0oooo01h0oooo000S0?ooo`030000003o
ool0oooo04<0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`008`3oool0
0`000000oooo0?ooo`140?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool07@3oool0
0240oooo00@000000?ooo`3oool00000AP3oool00`000?l0oooo0?ooo`0k0?ooo`040000003oool0
oooo000001h0oooo000Q0?ooo`040000003oool0oooo000004L0oooo00<0003o0?ooo`3oool0>@3o
ool01@000000oooo0?ooo`3oool0000001h0oooo000Q0?ooo`050000003oool0oooo0?ooo`000000
A`3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool002D0oooo00<000000?ooo`3oool0A@3oool20000och0oooo00<000000?ooo`3oool06`3o
ool002H0oooo00<000000?ooo`3oool0A@3oool20000och0oooo00<000000?ooo`3oool06P3oool0
02H0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo
01X0oooo000R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00280oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo0380oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01P0oooo000X0?ooo`030000003oool0oooo04T0oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0H0?ooo`00:@3oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool05`3oool002T0oooo00<000000?ooo`3o
ool0BP3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo000S0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool20000obl0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0G0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04X0oooo0P000?l]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3o
ool002/0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool002/0oooo00<000000?ooo`3oool0C03oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003oool0oooo01D0oooo000/0?ooo`030000003oool0oooo04/0
oooo0P000?lg0?ooo`030000003oool0oooo01D0oooo000U0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0C03oool20000ocL0oooo00<000000?ooo`3oool0503oool002D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`009@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01@0oooo000^0?ooo`030000003oool0oooo04h0oooo00<0003o0?oo
o`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo000_0?ooo`03
0000003oool0oooo04h0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`00
<03oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0
4`3oool002L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000o`3o
ool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`009`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo000X0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0CP3oool20000oa`0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`1>0?ooo`80003o<@3oool00`000000
oooo0?ooo`0A0?ooo`00=03oool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo02h0oooo
00<000000?ooo`3oool04@3oool002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1@0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0403oool002X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo01@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`00:`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0500oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0100oooo000f0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo000g0?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0?0?ooo`00;@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo0P000?l/0?ooo`030000003o
ool0oooo00l0oooo000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0D@3oool2
0000o`030?ooo`000?l0003o00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>
0?ooo`00;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo10000?l90?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool003T0oooo00<000000?ooo`3o
ool0D@3oool50000o`T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`00
>P3oool00`000000oooo0?ooo`1?0?ooo`L0003o:03oool00`000000oooo0?ooo`0=0?ooo`00<@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500oooo1P000?lX0?ooo`030000003o
ool0oooo00d0oooo000a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0DP3oool4
0000o`@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo05<0oooo0`000?l30?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0303oool003`0oooo00<000000?ooo`3oool0D`3oool30000obL0
oooo00<000000?ooo`3oool0303oool003d0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo
0?ooo`0T0?ooo`030000003oool0oooo00`0oooo000e0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0000o`0V0?ooo`030000003oool0oooo00/0oooo000f
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool01@000000oooo0?ooo`3o
ool0003o02D0oooo00<000000?ooo`3oool02`3oool003l0oooo00<000000?ooo`3oool0EP3oool0
0`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo00/0oooo00100?ooo`030000003oool0oooo
05H0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0;0?ooo`00>@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo000j0?ooo`8000001@3oool00`000000oooo
0?ooo`1:0?ooo`8000002`3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo
00120?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?oo
o`0:0?ooo`00?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<0003o
0?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`00?`3oool200000080oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01h0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0@P3oool2000001@0oooo00<0003o0?ooo`3o
ool07@3oool00`000000oooo0?ooo`090?ooo`00A@3oool00`000000oooo0?ooo`1H0?ooo`030000
o`3oool0oooo01`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`000000?`3o
ool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0203o
ool004D0oooo0P00000m0?ooo`800000703oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0
oooo00P0oooo00170?ooo`030000003oool0000005T0oooo00<0003o0?ooo`3oool06P3oool00`00
0000oooo0?ooo`080?ooo`00B03oool010000000oooo00000000000b0?ooo`<000008`3oool00`00
0?l0oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00190?ooo`030000003oool0oooo05T0
oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`00BP3oool00`000000oooo
0?ooo`020?ooo`<000009P3oool3000002/0oooo00<0003o0?ooo`3oool0603oool00`000000oooo
0?ooo`070?ooo`00BP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo001;
0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo01H0oooo0P00000c
0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool01P3oool004`0oooo00<000000?oo
o`3oool0303oool2000000<0oooo0`0000040?ooo`<000000`3oool3000003T0oooo00<0003o0?oo
o`3oool05P3oool00`000000oooo0?ooo`060?ooo`00C@3oool00`000000oooo0?ooo`1J0?ooo`03
0000o`3oool0oooo01D0oooo00<000000?ooo`3oool01P3oool004h0oooo00<000000?ooo`3oool0
FP3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo001>0?ooo`030000003o
ool0oooo05/0oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00C`3oool0
0`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool01@3oool0
0500oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo
00D0oooo001A0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`00DP3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo0100oooo
00<000000?ooo`3oool01@3oool00580oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo001C0?ooo`030000003oool0oooo05`0oooo00<0003o
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00E03oool00`000000oooo0?ooo`1L0?oo
o`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0103oool005D0oooo00<000000?ooo`3o
ool0G03oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo001F0?ooo`030000
003oool0oooo05`0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`00EP3o
ool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0103o
ool005L0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0
oooo00@0oooo001H0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`00F@3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool005X0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo001J0?ooo`030000003oool0oooo05h0oooo00<0
003o0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`00F`3oool00`000000oooo0?ooo`1N
0?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool00`3oool005`0oooo00<000000?oo
o`3oool0GP3oool010000?l0oooo0?ooo`000?l40?ooo`030000003oool0oooo00<0oooo001M0?oo
o`030000003oool0oooo05h0oooo10000?l30?ooo`030000003oool0oooo00<0oooo001N0?ooo`03
0000003oool0oooo05`0oooo1@000?l30?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000
003oool0oooo05X0oooo1`000?l20?ooo`030000003oool0oooo00<0oooo001P0?ooo`800000F`3o
ool60000o`80oooo00<000000?ooo`3oool00`3oool00680oooo00<000000?ooo`3oool0FP3oool5
0000o`030?ooo`000000oooo00@0oooo001S0?ooo`030000003oool0oooo05/0oooo10000?l00`00
0000oooo0?ooo`030?ooo`00I03oool00`000000oooo0?ooo`1L0?ooo`80003o00<000000?ooo`3o
ool00`3oool006D0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`030?ooo`00IP3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo001W0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool00`3oool006P0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`030?ooo`00J@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0
oooo001Y0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00`3oool006X0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`030?ooo`00J`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00<0oooo001/0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool00`3oool006d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`030?ooo`00
KP3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00<0oooo001_0?ooo`800000E03o
ool00`000000oooo0?ooo`030?ooo`00L@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00<0oooo001b0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0103oool007<0
oooo0P00001?0?ooo`030000003oool0oooo00@0oooo001e0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0103oool007H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`040?ooo`00M`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00@0oooo001h0?oo
o`800000B@3oool00`000000oooo0?ooo`050?ooo`00NP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00D0oooo001k0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
1@3oool007`0oooo0P0000140?ooo`030000003oool0oooo00H0oooo001n0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool01P3oool007l0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`070?ooo`00P03oool2000003l0oooo00<000000?ooo`3oool01`3oool00880oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`080?ooo`00P`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00P0oooo00240?ooo`800000>@3oool00`000000oooo0?ooo`09
0?ooo`00QP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00270?ooo`80
0000=@3oool00`000000oooo0?ooo`0:0?ooo`00R@3oool200000380oooo00<000000?ooo`3oool0
2`3oool008/0oooo0P00000`0?ooo`030000003oool0oooo00/0oooo002=0?ooo`800000;@3oool0
0`000000oooo0?ooo`0<0?ooo`00S`3oool2000002X0oooo00<000000?ooo`3oool03@3oool00940
oooo0P00000W0?ooo`030000003oool0oooo00h0oooo002C0?ooo`800000903oool00`000000oooo
0?ooo`0?0?ooo`00U@3oool200000240oooo00<000000?ooo`3oool0403oool009L0oooo1000000K
0?ooo`8000004`3oool009/0oooo0`00000E0?ooo`<000005@3oool009h0oooo1000000?0?ooo`80
0000603oool00:80oooo3`00000J0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool00</0oooo
003;0?ooo`00b`3oool00001\
\>"],
  ImageRangeCache->{{{0, 202.625}, {287, 0}} -> {-1.48494, -2.10329, 0.014657,
   0.014657}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?svdshow\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"svdshow[mat] creates movie frames for animation as a pair of \
orthonormal vectors that rotate through 90\[Degree].  Each frame displays the \
orthonormal vectors and the unit circle, dashed before and solid after \
transformation by the 2\[Times]2 matrix mat.  \nsvdshow[mat, tmin, tmax, dt] \
varies the first vector  from tmin\[Degree] to tmax\[Degree] by steps of dt\
\[Degree]."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(svdshow[A]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, \ Eigenvectors[Transpose[A].A]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.41421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.336718 0.707107 0.336718 [
[ 0 0 0 0 ]
[ 1 1.41421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.41421 L
0 1.41421 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.83672 .70711 m
.86478 .7658 L
.89007 .82405 L
.91239 .8814 L
.93158 .93744 L
.94747 .99171 L
.95996 1.04382 L
.96896 1.09337 L
.97438 1.13998 L
.97619 1.1833 L
.97438 1.22299 L
.96896 1.25875 L
.95996 1.29032 L
.94747 1.31745 L
.93158 1.33993 L
.91239 1.3576 L
.89007 1.37031 L
.86478 1.37798 L
.83672 1.38054 L
.80609 1.37798 L
.77313 1.37031 L
.7381 1.3576 L
.70125 1.33993 L
.66287 1.31745 L
.62325 1.29032 L
.58269 1.25875 L
.5415 1.22299 L
.5 1.1833 L
.4585 1.13998 L
.41731 1.09337 L
.37675 1.04382 L
.33713 .99171 L
.29875 .93744 L
.2619 .8814 L
.22687 .82405 L
.19391 .7658 L
.16328 .70711 L
.13522 .64841 L
.10993 .59017 L
.08761 .53281 L
.06842 .47678 L
.05253 .4225 L
.04004 .37039 L
.03104 .32084 L
.02562 .27423 L
.02381 .23092 L
.02562 .19123 L
.03104 .15546 L
.04004 .12389 L
.05253 .09677 L
Mistroke
.06842 .07428 L
.08761 .05662 L
.10993 .0439 L
.13522 .03623 L
.16328 .03367 L
.19391 .03623 L
.22687 .0439 L
.2619 .05662 L
.29875 .07428 L
.33713 .09677 L
.37675 .12389 L
.41731 .15546 L
.4585 .19123 L
.5 .23092 L
.5415 .27423 L
.58269 .32084 L
.62325 .37039 L
.66287 .4225 L
.70125 .47678 L
.7381 .53281 L
.77313 .59017 L
.80609 .64841 L
.83672 .70711 L
Mfstroke
[ .01 .02 ] 0 setdash
.83672 .70711 m
.83544 .73645 L
.8316 .76558 L
.82524 .79426 L
.81641 .82227 L
.80517 .84941 L
.79161 .87547 L
.77582 .90024 L
.75794 .92354 L
.7381 .9452 L
.71644 .96505 L
.69313 .98293 L
.66836 .99871 L
.6423 1.01228 L
.61516 1.02352 L
.58715 1.03235 L
.55847 1.03871 L
.52935 1.04254 L
.5 1.04382 L
.47065 1.04254 L
.44153 1.03871 L
.41285 1.03235 L
.38484 1.02352 L
.3577 1.01228 L
.33164 .99871 L
.30687 .98293 L
.28356 .96505 L
.2619 .9452 L
.24206 .92354 L
.22418 .90024 L
.20839 .87547 L
.19483 .84941 L
.18359 .82227 L
.17476 .79426 L
.1684 .76558 L
.16456 .73645 L
.16328 .70711 L
.16456 .67776 L
.1684 .64864 L
.17476 .61996 L
.18359 .59194 L
.19483 .5648 L
.20839 .53875 L
.22418 .51397 L
.24206 .49067 L
.2619 .46901 L
.28356 .44917 L
.30687 .43128 L
.33164 .4155 L
.3577 .40194 L
Mistroke
.38484 .3907 L
.41285 .38186 L
.44153 .3755 L
.47065 .37167 L
.5 .37039 L
.52935 .37167 L
.55847 .3755 L
.58715 .38186 L
.61516 .3907 L
.6423 .40194 L
.66836 .4155 L
.69313 .43128 L
.71644 .44917 L
.7381 .46901 L
.75794 .49067 L
.77582 .51397 L
.79161 .53875 L
.80517 .5648 L
.81641 .59194 L
.82524 .61996 L
.8316 .64864 L
.83544 .67776 L
.83672 .70711 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .70711 m
.24965 .86183 L
s
% Start of user PostScript
0 0 -0.743496 0.459506 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.17229 .78447 L
s
% Start of user PostScript
0 0 -0.973249 0.229753 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .70711 m
.90507 1.36253 L
s
% Start of user PostScript
0 0 1.203 1.9465 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.57736 1.03482 L
s
% Start of user PostScript
0 0 0.229753 0.973249 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;000182000`400?l00000o`00003ob`3oool0
0</0oooo003;0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool00</0oooo000J0?ooo`l00000
XP3oool001P0oooo0P00000?0?ooo`<00000W`3oool001D0oooo0`00000D0?ooo`<00000W03oool0
01<0oooo0P00000J0?ooo`@00000V03oool00140oooo0P00000P0?ooo`<00000U@3oool00100oooo
00<000000?ooo`3oool08`3oool2000009<0oooo000?0?ooo`030000003oool0oooo02H0oooo0P00
002A0?ooo`003P3oool00`000000oooo0?ooo`0Y0?ooo`800000S`3oool000d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`2<0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`80
0000S03oool000/0oooo00<000000?ooo`3oool0<@3oool2000008X0oooo000;0?ooo`030000003o
ool0oooo03<0oooo0P0000280?ooo`002P3oool00`000000oooo0?ooo`0f0?ooo`800000QP3oool0
00X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`230?ooo`002@3oool00`000000
oooo0?ooo`0j0?ooo`800000P`3oool000T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`200?ooo`002@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo07l0oooo0008
0?ooo`030000003oool0oooo03l0oooo0P00001o0?ooo`00203oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo07`0oooo00080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0N`3oool000L0oooo00<000000?ooo`3oool0A03oool2000007/0oooo00070?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0N03oool000L0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`1g0?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000M`3oool000H0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1d0?ooo`001P3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo07<0oooo00060?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0LP3oool000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1a
0?ooo`001@3oool00`000000oooo0?ooo`1@0?ooo`800000L@3oool000D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1^0?ooo`001@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo06d0oooo00050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0K03o
ool000D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1[0?ooo`001@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo06X0oooo00050?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0J@3oool000D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`1X0?ooo`00103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06L0oooo0004
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0IP3oool000@0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1U0?ooo`00103oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo06@0oooo00040?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
H`3oool000@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1R0?ooo`00103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0640oooo00040?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0H03oool000@0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`1O0?ooo`001@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo05h0oooo
00050?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0G@3oool000D0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1L0?ooo`001@3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo05/0oooo00050?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0FP3oool000D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1I0?ooo`001@3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo05P0oooo00050?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0E`3oool000D0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1G0?ooo`001P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05H0
oooo00060?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0E@3oool000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1D0?ooo`001P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo05<0oooo00060?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0DP3oool000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A0?ooo`00
1P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0500oooo00070?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0D03oool000L0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1?0?ooo`001`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
04h0oooo00070?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C@3oool000L0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`00203oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo04`0oooo00080?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0B`3oool000P0oooo00<000000?ooo`3oool0D03oool010000000oooo0?ooo`3oool3
000000<0oooo100000030?ooo`<000003`3oool00`000000oooo0?ooo`1:0?ooo`00203oool00`00
0000oooo0?ooo`1>0?ooo`8000005`3oool3000000X0oooo00<000000?ooo`3oool0B@3oool000P0
oooo00<000000?ooo`3oool0B03oool300000240oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`180?ooo`002@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02D0oooo
0P0000060?ooo`030000003oool0oooo04P0oooo00090?ooo`030000003oool0oooo0480oooo0P00
000]0?ooo`050000003oool0oooo0?ooo`000000B@3oool000T0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0a0?ooo`8000000P3oool00`000000oooo0?ooo`160?ooo`002@3oool0
0`000000oooo0?ooo`0l0?ooo`800000>@3oool00`000000oooo0?ooo`150?ooo`002@3oool00`00
0000oooo0?ooo`1g0?ooo`800000AP3oool000X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0m0?ooo`800000A@3oool000X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo04<0oooo000:0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`000000@P3oool000X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`15
0?ooo`040000003oool0000000000400oooo000;0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`110?ooo`002`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool000/0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`800000>`3oool000/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03h0oooo000<0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0n0?ooo`00303oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool0
00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03D0oooo000<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`0T0?ooo`800000E`3oool00`000000oooo
0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0<P3oool000d0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0340oooo000>0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo000>0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0h0?ooo`00
3P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
>03oool000l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02h0oooo000?0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0]0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0=P3oool00100oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo03D0oooo000@0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0=@3oool00100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0<`3oool00140oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0380oooo000B0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0b0?ooo`004P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3o
ool001<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02L0oooo000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02H0oooo000D0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0_0?ooo`00503oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0;`3oool001D0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo000E
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T
0?ooo`005P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0903oool001H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo02`0oooo000F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0[0?ooo`005`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0:`3oool001L0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo000H0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00603oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0R0?ooo`00603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0:@3oool001T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo02P0oooo000I0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool09`3oool001X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo000J0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0Q0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`006`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09@3o
ool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02D0oooo000L0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0903oool001`0
oooo00<000000?ooo`3oool0Q@3oool01@000000oooo0?ooo`3oool000000280oooo000M0?ooo`03
0000003oool0oooo08D0oooo00@000000?ooo`3oool000008P3oool001d0oooo00D000000?ooo`3o
ool0oooo000000230?ooo`050000003oool0oooo0?ooo`0000008@3oool001h0oooo00@000000?oo
o`3oool00000Q03oool00`000000oooo0?ooo`0R0?ooo`007P3oool010000000oooo0?ooo`000024
0?ooo`030000003oool0oooo0280oooo000O0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool08@3oool001l0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0000000Q0?ooo`00
803oool00`000000oooo0?ooo`250?ooo`8000008@3oool00200oooo0P0000260?ooo`8000008@3o
ool00240oooo00<000000?ooo`3oool0?`3oool20?l000030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool07`3oool00240oooo00<000000?ooo`3oool0>`3oool0103o0000oooo0?ooo`3oool2
0?l00080003o@P3oool00`000000oooo0?ooo`0O0?ooo`008@3oool2000003X0oooo0P3o00020?oo
o`80o`000P3oool20000od80oooo0P00000P0?ooo`008P3oool00`000000oooo0?ooo`0b0?ooo`<0
o`001P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3o
ool07P3oool002<0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`080?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo01d0oooo000S0?ooo`030000003o
ool0oooo02/0oooo0P3o00090?ooo`80o`002P3oool00`000?l0oooo0?ooo`100?ooo`030000003o
ool0oooo01d0oooo000Q0?ooo`040000003oool0oooo000002H0oooo0`3o000=0?ooo`030?l0003o
ool0oooo00P0oooo00@0003o0?ooo`3oool0003o?`3oool010000000oooo0?ooo`00000N0?ooo`00
8@3oool010000000oooo0?ooo`00000P0?ooo`<0o`004@3oool20?l000/0oooo00@0003o0?ooo`3o
ool0003o?P3oool01@000000oooo0?ooo`3oool0000001h0oooo000Q0?ooo`050000003oool0oooo
0?ooo`0000006`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00`0oooo00@0003o
0?ooo`3oool0003o?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo000U
0?ooo`030000003oool0oooo01L0oooo0P3o000E0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0o
0?ooo`030000003oool0oooo01/0oooo000V0?ooo`030000003oool0oooo0100oooo0`3o000H0?oo
o`80o`005@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo01X0oooo000V0?ooo`03
0000003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0J0?ooo`00
8P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0o`001`3oool00`3o0000oooo
0?ooo`0J0?ooo`80o`005@3oool01@000?l0oooo0?ooo`3oool0003o03/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`020?ooo`030000
003o0000o`0000<0o`0000@0oooo0?l0003o0000o`007P3oool20?l001L0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool06@3oool00280oooo00@000000?ooo`3oool0oooo1`3o000Q0?ooo`030?l0003oool0oooo01L0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0603oool002@0oooo2@3o000O0?ooo`80o`00803oool00`000?l0oooo
0?ooo`0o0?ooo`030000003oool0oooo01P0oooo000R0?ooo`/0o`007@3oool20?l002<0oooo00<0
003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0G0?ooo`00:@3oool00`000000oooo0?ooo`0M
0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0G
0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo0P3o000P0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01L0oooo000S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0603oool20?l00280oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0b0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool002/0oooo00<000000?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo000[0?ooo`030000003o
ool0oooo01@0oooo0P3o000^0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool05@3o
ool002`0oooo00<000000?ooo`3oool04@3oool20?l00340oooo00<0003o0?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0E0?ooo`009@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0100oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo
01@0oooo000U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0103o0000
oooo0?ooo`3oool20?l002/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool002D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`<0o`0000<0oooo0?l0003oool0;03oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0D0?ooo`00;P3oool00`000000oooo0?ooo`060?ooo`D0o`00;`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0C0?ooo`00;`3oool00`000000oooo0?ooo`040?ooo`H0o`00>P3oool00`000?l0oooo0?oo
o`0l0?ooo`030000003oool0oooo01<0oooo000`0?ooo`030000003oool0oooo0080oooo203o000i
0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool04`3oool002L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?l003`0oooo00<0003o0?ooo`3oool0:03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo000W0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3o0000103o000d0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo000X0?ooo`030000
003oool0oooo00L0oooo0P3o000h0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
9P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000c0?ooo`030000003o
ool0oooo03H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo0140oooo000d0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0A0?ooo`00:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
04<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0@0?ooo`00:P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool08@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo000[0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0200oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`00=P3oool00`000000oooo0?oo
o`0e0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00l0oooo000g0?ooo`030000003oool0oooo0480oooo00<0003o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`00;@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0?0?oo
o`00;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo000^0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo01X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`00>@3o
ool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo000j0?ooo`030000003oool0
oooo0380oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0
oooo00d0oooo000a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo00d0oooo000a0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`130?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0<0?ooo`00?03oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0`
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<
0?ooo`00=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo00<0003o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool02`3oool003H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`130?ooo`03
0000o`3oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`00
?`3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0
2`3oool00400oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo00/0oooo000i0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0:0?ooo`00>P3oool2000000D0oooo00<000000?ooo`3oool0;@3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo0P00000^0?ooo`030000003oool0oooo
00X0oooo00120?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo00X0oooo000n0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo
000o0?ooo`8000000P3oool00`000000oooo0?ooo`0Z0?ooo`H0003o4P3oool010000?l0oooo0?oo
o`00000c0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02T0oooo1P00
0?lC0?ooo`030000o`000000oooo03<0oooo00<000000?ooo`3oool02@3oool004D0oooo00<00000
0?ooo`3oool0:@3oool50000oa<0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0000000[0?ooo`<0003o4@3oool01@000000oooo0?ooo`3oool0
003o03D0oooo00<000000?ooo`3oool0203oool004D0oooo0P00000[0?ooo`<0003o3`3oool20000
00D0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`080?ooo`00A`3oool00`000000
oooo0000000Y0?ooo`80003o5P3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo00P0
oooo00180?ooo`040000003oool00000000002H0oooo0`000?l90?ooo`<000002`3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo00190?ooo`030000003oool0oooo02L0oooo
0P000?lG0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool01`3oool004X0oooo00<0
00000?ooo`3oool00P3oool300000280oooo00@0003o0?ooo`3oool0oooo0`00000B0?ooo`030000
o`3oool0oooo0340oooo00<000000?ooo`3oool01`3oool004X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`000000oooo01L0oooo00<0003o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`070?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool0
0`000000oooo0?ooo`0F0?ooo`8000006@3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0
oooo00H0oooo001<0?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`<00000103oool30000
00<0oooo0`00000O0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool01P3oool004d0
oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo00H0
oooo001>0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo
0?ooo`060?ooo`00CP3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo02l0oooo00<0
00000?ooo`3oool01@3oool004l0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0_
0?ooo`030000003oool0oooo00D0oooo001@0?ooo`030000003oool0oooo03l0oooo00<0003o0?oo
o`3oool0;P3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`0o0?ooo`03
0000o`3oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00580oooo00<000000?ooo`3oool0
?P3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo001B0?ooo`030000003o
ool0oooo03l0oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`00D`3oool0
0`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0103oool0
05@0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo
00@0oooo001E0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool0:`3oool00`000000
oooo0?ooo`040?ooo`00EP3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo02/0oooo
00<000000?ooo`3oool0103oool005H0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?oo
o`0Z0?ooo`030000003oool0oooo00@0oooo001G0?ooo`030000003oool0oooo03h0oooo00<0003o
0?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`00F03oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool0103oool005T0oooo00<000000?ooo`3o
ool0?@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo001J0?ooo`030000
003oool0oooo03`0oooo00<0003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`00FP3o
ool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool00`3o
ool005/0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0
oooo00<0oooo001L0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`030?ooo`00G@3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo02H0
oooo00<000000?ooo`3oool00`3oool005h0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo
0?ooo`0V0?ooo`030000003oool0oooo00<0oooo001O0?ooo`030000003oool0oooo03/0oooo00<0
003o0?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`00H03oool2000003`0oooo00<0003o
0?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`00HP3oool00`000000oooo0?ooo`0i0?oo
o`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool00`3oool006<0oooo00<000000?ooo`3o
ool0>@3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo001T0?ooo`030000
003oool0oooo03T0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`00I@3o
ool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool00`3o
ool006H0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0
oooo00<0oooo001W0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool08@3oool00`00
0000oooo0?ooo`030?ooo`00J03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0200
oooo00<000000?ooo`3oool00`3oool006T0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo
0?ooo`0O0?ooo`030000003oool0oooo00<0oooo001Y0?ooo`030000003oool0oooo03L0oooo00<0
003o0?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`00JP3oool00`000000oooo0?ooo`0g
0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool00`3oool006/0oooo00<000000?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo001/0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`00
K@3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0
0`3oool006h0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003o
ool0oooo00<0oooo001_0?ooo`800000=P3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0
oooo00<0oooo001a0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool06P3oool00`00
0000oooo0?ooo`030?ooo`00LP3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo01T0
oooo00<000000?ooo`3oool0103oool007<0oooo0P00000d0?ooo`030000o`3oool0oooo01P0oooo
00<000000?ooo`3oool0103oool007D0oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`0H0?ooo`030000003oool0oooo00@0oooo001f0?ooo`030000003oool0oooo0340oooo00<0003o
0?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`00M`3oool00`000000oooo0?ooo`0a0?oo
o`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0103oool007P0oooo0P00000a0?ooo`03
0000o`3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool007X0oooo00<000000?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo001k0?ooo`030000003o
ool0oooo02l0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`00O03oool2
000002l0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`00OP3oool00`00
0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool01P3oool007l0
oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo00L0
oooo00200?ooo`800000;@3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00220?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?oo
o`080?ooo`00P`3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool008@0oooo0P00000[0?ooo`040000o`3oool0oooo0000o`X0oooo00<00000
0?ooo`3oool02@3oool008H0oooo00<000000?ooo`3oool0:03oool40000o`X0oooo00<000000?oo
o`3oool02@3oool008L0oooo0P00000W0?ooo`H0003o203oool00`000000oooo0?ooo`0:0?ooo`00
R@3oool2000002@0oooo1`000?l70?ooo`030000003oool0oooo00/0oooo002;0?ooo`8000008`3o
ool60000o`L0oooo00<000000?ooo`3oool02`3oool008d0oooo0P00000R0?ooo`D0003o1P3oool0
0`000000oooo0?ooo`0<0?ooo`00S`3oool200000240oooo1@000?l40?ooo`030000003oool0oooo
00d0oooo002A0?ooo`800000803oool40000o`<0oooo00<000000?ooo`3oool03P3oool009<0oooo
0P00000P0?ooo`80003o0P3oool00`000000oooo0?ooo`0?0?ooo`00U@3oool2000001l0oooo0P00
0?l00`000000oooo0?ooo`0@0?ooo`00U`3oool4000001/0oooo00<000000000o`3oool04P3oool0
09/0oooo0`00000E0?ooo`<000005@3oool009h0oooo1000000?0?ooo`800000603oool00:80oooo
3`00000J0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 202.625}, {287, 0}} -> {-1.48494, -2.10329, 0.014657,
   0.014657}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{UT, sings, VT} = SingularValues[N[A]]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\({0.525731112119133214`, 0.850650808352039611`}\), 
              \({0.850650808352039611`, \(-0.525731112119133214`\)}\)},
            {"2.28824561127073744`", "0.874032048897642077`"},
           
             {\({0.229752920547361005`, 0.973248989467730041`}\), 
              \({0.973248989467730041`, \(-0.229752920547361005`\)}\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[A, VT]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.41421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.336718 0.707107 0.336718 [
[ 0 0 0 0 ]
[ 1 1.41421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.41421 L
0 1.41421 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.83672 .70711 m
.86478 .7658 L
.89007 .82405 L
.91239 .8814 L
.93158 .93744 L
.94747 .99171 L
.95996 1.04382 L
.96896 1.09337 L
.97438 1.13998 L
.97619 1.1833 L
.97438 1.22299 L
.96896 1.25875 L
.95996 1.29032 L
.94747 1.31745 L
.93158 1.33993 L
.91239 1.3576 L
.89007 1.37031 L
.86478 1.37798 L
.83672 1.38054 L
.80609 1.37798 L
.77313 1.37031 L
.7381 1.3576 L
.70125 1.33993 L
.66287 1.31745 L
.62325 1.29032 L
.58269 1.25875 L
.5415 1.22299 L
.5 1.1833 L
.4585 1.13998 L
.41731 1.09337 L
.37675 1.04382 L
.33713 .99171 L
.29875 .93744 L
.2619 .8814 L
.22687 .82405 L
.19391 .7658 L
.16328 .70711 L
.13522 .64841 L
.10993 .59017 L
.08761 .53281 L
.06842 .47678 L
.05253 .4225 L
.04004 .37039 L
.03104 .32084 L
.02562 .27423 L
.02381 .23092 L
.02562 .19123 L
.03104 .15546 L
.04004 .12389 L
.05253 .09677 L
Mistroke
.06842 .07428 L
.08761 .05662 L
.10993 .0439 L
.13522 .03623 L
.16328 .03367 L
.19391 .03623 L
.22687 .0439 L
.2619 .05662 L
.29875 .07428 L
.33713 .09677 L
.37675 .12389 L
.41731 .15546 L
.4585 .19123 L
.5 .23092 L
.5415 .27423 L
.58269 .32084 L
.62325 .37039 L
.66287 .4225 L
.70125 .47678 L
.7381 .53281 L
.77313 .59017 L
.80609 .64841 L
.83672 .70711 L
Mfstroke
[ .01 .02 ] 0 setdash
.83672 .70711 m
.83544 .73645 L
.8316 .76558 L
.82524 .79426 L
.81641 .82227 L
.80517 .84941 L
.79161 .87547 L
.77582 .90024 L
.75794 .92354 L
.7381 .9452 L
.71644 .96505 L
.69313 .98293 L
.66836 .99871 L
.6423 1.01228 L
.61516 1.02352 L
.58715 1.03235 L
.55847 1.03871 L
.52935 1.04254 L
.5 1.04382 L
.47065 1.04254 L
.44153 1.03871 L
.41285 1.03235 L
.38484 1.02352 L
.3577 1.01228 L
.33164 .99871 L
.30687 .98293 L
.28356 .96505 L
.2619 .9452 L
.24206 .92354 L
.22418 .90024 L
.20839 .87547 L
.19483 .84941 L
.18359 .82227 L
.17476 .79426 L
.1684 .76558 L
.16456 .73645 L
.16328 .70711 L
.16456 .67776 L
.1684 .64864 L
.17476 .61996 L
.18359 .59194 L
.19483 .5648 L
.20839 .53875 L
.22418 .51397 L
.24206 .49067 L
.2619 .46901 L
.28356 .44917 L
.30687 .43128 L
.33164 .4155 L
.3577 .40194 L
Mistroke
.38484 .3907 L
.41285 .38186 L
.44153 .3755 L
.47065 .37167 L
.5 .37039 L
.52935 .37167 L
.55847 .3755 L
.58715 .38186 L
.61516 .3907 L
.6423 .40194 L
.66836 .4155 L
.69313 .43128 L
.71644 .44917 L
.7381 .46901 L
.75794 .49067 L
.77582 .51397 L
.79161 .53875 L
.80517 .5648 L
.81641 .59194 L
.82524 .61996 L
.8316 .64864 L
.83544 .67776 L
.83672 .70711 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 .70711 m
.90507 1.36253 L
s
% Start of user PostScript
0 0 1.203 1.9465 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.57736 1.03482 L
s
% Start of user PostScript
0 0 0.229753 0.973249 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 .70711 m
.75035 .55238 L
s
% Start of user PostScript
0 0 0.743496 -0.459506 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 .70711 m
.82771 .62974 L
s
% Start of user PostScript
0 0 0.973249 -0.229753 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.625, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;000182000`400?l00000o`00003ob`3oool0
0</0oooo003;0?ooo`00b`3oool00</0oooo003;0?ooo`00b`3oool00</0oooo000J0?ooo`l00000
XP3oool001P0oooo0P00000?0?ooo`<00000W`3oool001D0oooo0`00000D0?ooo`<00000W03oool0
01<0oooo0P00000J0?ooo`@00000V03oool00140oooo0P00000P0?ooo`<00000U@3oool00100oooo
00<000000?ooo`3oool08`3oool2000009<0oooo000?0?ooo`030000003oool0oooo02H0oooo0P00
002A0?ooo`003P3oool00`000000oooo0?ooo`0Y0?ooo`800000S`3oool000d0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`2<0?ooo`00303oool00`000000oooo0?ooo`0^0?ooo`80
0000S03oool000/0oooo00<000000?ooo`3oool0<@3oool2000008X0oooo000;0?ooo`030000003o
ool0oooo03<0oooo0P0000280?ooo`002P3oool00`000000oooo0?ooo`0f0?ooo`800000QP3oool0
00X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`230?ooo`002@3oool00`000000
oooo0?ooo`0j0?ooo`800000P`3oool000T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`200?ooo`002@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo07l0oooo0008
0?ooo`030000003oool0oooo03l0oooo0P00001o0?ooo`00203oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo07`0oooo00080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0N`3oool000L0oooo00<000000?ooo`3oool0A03oool2000007/0oooo00070?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0N03oool000L0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`1g0?ooo`001P3oool00`000000oooo0?ooo`190?ooo`800000M`3oool000H0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1d0?ooo`001P3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo07<0oooo00060?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0LP3oool000H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1a
0?ooo`001@3oool00`000000oooo0?ooo`1@0?ooo`800000L@3oool000D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1^0?ooo`001@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo06d0oooo00050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0K03o
ool000D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1[0?ooo`001@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo06X0oooo00050?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0J@3oool000D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`1X0?ooo`00103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06L0oooo0004
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0IP3oool000@0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1U0?ooo`00103oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo06@0oooo00040?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
H`3oool000@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1R0?ooo`00103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0640oooo00040?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0H03oool000@0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`1O0?ooo`001@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo05h0oooo
00050?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0G@3oool000D0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1L0?ooo`001@3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo05/0oooo00050?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0FP3oool000D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1I0?ooo`001@3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo05P0oooo00050?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0E`3oool000D0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1G0?ooo`001P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05H0
oooo00060?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0E@3oool000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1D0?ooo`001P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo05<0oooo00060?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0DP3oool000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A0?ooo`00
1P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0500oooo00070?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0D03oool000L0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1?0?ooo`001`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
04h0oooo00070?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C@3oool000L0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`00203oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo04`0oooo00080?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0B`3oool000P0oooo00<000000?ooo`3oool0D03oool010000000oooo0?ooo`3oool3
000000<0oooo100000030?ooo`<000003`3oool00`000000oooo0?ooo`1:0?ooo`00203oool00`00
0000oooo0?ooo`1>0?ooo`8000005`3oool3000000X0oooo00<000000?ooo`3oool0B@3oool000P0
oooo00<000000?ooo`3oool0B03oool300000240oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`180?ooo`002@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02D0oooo
0P0000060?ooo`030000003oool0oooo04P0oooo00090?ooo`030000003oool0oooo0480oooo0P00
000]0?ooo`050000003oool0oooo0?ooo`000000B@3oool000T0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0a0?ooo`8000000P3oool00`000000oooo0?ooo`160?ooo`002@3oool0
0`000000oooo0?ooo`0l0?ooo`800000>@3oool00`000000oooo0?ooo`150?ooo`002@3oool00`00
0000oooo0?ooo`1g0?ooo`800000AP3oool000X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0m0?ooo`800000A@3oool000X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo04<0oooo000:0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`000000@P3oool000X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`15
0?ooo`040000003oool0000000000400oooo000;0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`110?ooo`002`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool000/0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`800000>`3oool000/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03h0oooo000<0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0n0?ooo`00303oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool0
00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03D0oooo000<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`0T0?ooo`800000E`3oool00`000000oooo
0?ooo`0k0?ooo`003@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0<P3oool000d0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0340oooo000>0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo000>0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0h0?ooo`00
3P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
>03oool000l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02h0oooo000?0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0]0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0=P3oool00100oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo03D0oooo000@0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0=@3oool00100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02X0oooo000A0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`004@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0<`3oool00140oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0380oooo000B0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0b0?ooo`004P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3o
ool001<0oooo00<000000?ooo`3oool0P@3oool20000o`P0oooo00<000000?ooo`3oool09`3oool0
01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Z0?ooo`@0003o00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`00503oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo06H0oooo1`000?l20?ooo`030000003oool0oooo02l0oooo000D0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0I03oool80000o`<0oooo00<000000?ooo`3oool0
;`3oool001D0oooo00<000000?ooo`3oool0MP3oool70000o`D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0T0?ooo`005@3oool00`000000oooo0?ooo`1g0?ooo`@0003o203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003oool0oooo
07D0oooo10000?l90?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0903oool001H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1T0?ooo`80003o0P3oool00`000?l0
oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo000F0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo02/0oooo
000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3oool20000oa80oooo00<0
00000?ooo`3oool0:`3oool001L0oooo00<000000?ooo`3oool0K@3oool20000oaD0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00603oool00`000000oooo0?ooo`1[0?oo
o`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?oo
o`00603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05h0oooo0P000?lI0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool001P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1L0?ooo`80003o6`3oool00`000000oooo0?ooo`0Y0?ooo`006@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool0703o
ool00`000000oooo0?ooo`0X0?ooo`006@3oool00`000000oooo0?ooo`1S0?ooo`80003o703oool3
0000o`030?ooo`000000oooo00D0003o8`3oool001X0oooo00<000000?ooo`3oool0H03oool20000
oal0oooo2@000?l00`000000oooo0?ooo`0Q0?ooo`006P3oool00`000000oooo0?ooo`1O0?ooo`03
0000o`3oool0oooo01l0oooo1`000?l20?ooo`030000003oool0oooo0240oooo000K0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0E@3oool20000oah0oooo20000?l00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0200oooo000K0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0D`3oool20000oa`0oooo00<0003o0?ooo`3oool0103oool40000o`80oooo00<0
00000?ooo`3oool09@3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1C
0?ooo`030000o`3oool0oooo01X0oooo0P000?l80?ooo`80003o0`3oool00`000000oooo0?ooo`0U
0?ooo`00703oool00`000000oooo0?ooo`1F0?ooo`80003o5`3oool30000oa<0oooo00<000000?oo
o`3oool0903oool001`0oooo00<000000?ooo`3oool0E03oool20000oaD0oooo00<0003o0?ooo`3o
ool05`3oool01@000000oooo0?ooo`3oool000000280oooo000M0?ooo`030000003oool0oooo0580
oooo00<0003o0?ooo`3oool04`3oool20000oa/0oooo00@000000?ooo`3oool000008P3oool001d0
oooo00D000000?ooo`3oool0oooo0000001>0?ooo`80003o403oool30000ob00oooo00D000000?oo
o`3oool0oooo0000000Q0?ooo`007P3oool010000000oooo0?ooo`00001=0?ooo`030000o`3oool0
oooo00X0oooo0`000?lW0?ooo`030000003oool0oooo0280oooo000N0?ooo`040000003oool0oooo
000004/0oooo0P000?l:0?ooo`030000o`3oool0oooo02X0oooo00<000000?ooo`3oool08P3oool0
01l0oooo00<000000?ooo`3oool0B@3oool20000o`X0oooo0P000?l^0?ooo`030000003oool0oooo
0240oooo000O0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0103oool30000oc<0
oooo00<000000?ooo`0000008@3oool00200oooo00<000000?ooo`3oool0A@3oool20000o`<0oooo
00<0003o0?ooo`3oool0>03oool200000240oooo000P0?ooo`800000A03oool20000o`<0oooo0P00
0?lk0?ooo`8000008@3oool00240oooo00<000000?ooo`3oool0@@3oool30000od40oooo00<00000
0?ooo`3oool07`3oool00240oooo00<000000?ooo`3oool0@@3oool20?l00480oooo00<000000?oo
o`3oool07`3oool00240oooo0P0000120?ooo`80o`00@P3oool200000200oooo000R0?ooo`030000
003oool0oooo0480oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0N0?ooo`008`3o
ool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool07@3o
ool002<0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0
oooo01d0oooo000Q0?ooo`040000003oool0oooo00000440oooo00@0o`000?ooo`3oool0o`00?`3o
ool010000000oooo0?ooo`00000N0?ooo`008@3oool010000000oooo0?ooo`0000110?ooo`040?l0
003oool0oooo0?l003h0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`008@3oool01@000000
oooo0?ooo`3oool000000440oooo00@0o`000?ooo`3oool0o`00?@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01/0oooo000U0?ooo`030000003oool0oooo04<0oooo00<0o`000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0K0?ooo`009P3oool00`000000oooo0?ooo`120?ooo`03
0?l0003oool0oooo0400oooo00<000000?ooo`3oool06P3oool002H0oooo00<000000?ooo`3oool0
@`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo01X0oooo000R0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0?P3oool01@3o0000oooo0?ooo`3oool0o`0003/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00280oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo000X0?oo
o`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0H0?oo
o`00:@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3o
ool05`3oool002T0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0o0?ooo`030000
003oool0oooo01L0oooo000S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0G0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool002/0oooo00<000000?ooo`3oool0>`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0F0?ooo`00:`3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo03h0
oooo00<000000?ooo`3oool05@3oool002`0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo
0?ooo`0m0?ooo`030000003oool0oooo01D0oooo000U0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo01@0oooo000U
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D
0?ooo`009@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03T0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0503oool002h0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo02`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`00
;`3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0
4`3oool00300oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01<0oooo000W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool0
0`3o0000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
02L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo000X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`0A0?ooo`00=03oool00`000000oooo0?oo
o`120?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool04@3oool002X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo03/0oooo00<00000
0?ooo`3oool0403oool002X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`130?oo
o`030?l0003oool0oooo0240oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?oo
o`00:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0403oool003H0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo01l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`00=`3o
ool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool03`3o
ool002d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0
oooo03T0oooo00<000000?ooo`3oool03`3oool002d0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`130?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0>0?ooo`00;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03@0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool03P3oool003T0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0>0?ooo`00>P3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`00<@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0=
0?ooo`00<@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04<0oooo00<0o`000?oo
o`3oool0503oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo000b0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0303oool003`0oooo00<000000?ooo`3oool0
<@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool003d0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool003D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000f0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool02`3oool003l0oooo00<000000?ooo`3oool0@P3oool00`3o0000
oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo00100?ooo`030000003oool0oooo0480oooo
00<0o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00>@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?oo
o`070?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool003X0oooo0P000005
0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`05
0?ooo`800000;P3oool00`000000oooo0?ooo`0:0?ooo`00@P3oool00`000000oooo0?ooo`0]0?oo
o`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?oo
o`00?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0:0?ooo`00?`3oool200000080oooo00<000000?ooo`3oool0
:P3oool60?l00180oooo00@0o`000?ooo`3oool00000<`3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0Y0?ooo`H0o`004`3oool00`3o000000000?ooo`0c0?ooo`030000
003oool0oooo00T0oooo00150?ooo`030000003oool0oooo02T0oooo1@3o000C0?ooo`030?l0003o
ool0oooo03<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`000000:`3oool3
0?l00140oooo00D000000?ooo`3oool0oooo0?l0000e0?ooo`030000003oool0oooo00P0oooo0015
0?ooo`800000:`3oool30?l000l0oooo0P0000050?ooo`030?l0003oool0oooo0380oooo00<00000
0?ooo`3oool0203oool004L0oooo00<000000?ooo`000000:@3oool20?l001H0oooo00<0o`000?oo
o`3oool0<P3oool00`000000oooo0?ooo`080?ooo`00B03oool010000000oooo00000000000V0?oo
o`<0o`002@3oool3000000/0oooo00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`080?oo
o`00B@3oool00`000000oooo0?ooo`0W0?ooo`80o`005`3oool00`3o0000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00L0oooo001:0?ooo`030000003oool0oooo0080oooo0`00000R0?ooo`040?l0
003oool0oooo0?ooo`<000004P3oool00`3o0000oooo0?ooo`0a0?ooo`030000003oool0oooo00L0
oooo001:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`3o00000000
0?ooo`0G0?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool01`3oool004/0oooo00<0
00000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool05P3oool2000001T0oooo00<0
o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`060?ooo`00C03oool00`000000oooo0?ooo`0<
0?ooo`8000000`3oool3000000@0oooo0`0000030?ooo`<000007`3oool00`3o0000oooo0?ooo`0`
0?ooo`030000003oool0oooo00H0oooo001=0?ooo`030000003oool0oooo0400oooo00<0o`000?oo
o`3oool0;`3oool00`000000oooo0?ooo`060?ooo`00CP3oool00`000000oooo0?ooo`0o0?ooo`03
0?l0003oool0oooo02l0oooo00<000000?ooo`3oool01P3oool004h0oooo00<000000?ooo`3oool0
@03oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo001?0?ooo`030000003o
ool0oooo03l0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`00D03oool0
0`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool0
0540oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo
00D0oooo001B0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0;@3oool00`000000
oooo0?ooo`050?ooo`00DP3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo02d0oooo
00<000000?ooo`3oool0103oool005<0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?oo
o`0]0?ooo`030000003oool0oooo00@0oooo001D0?ooo`030000003oool0oooo03h0oooo00<0o`00
0?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`00E@3oool00`000000oooo0?ooo`0n0?oo
o`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool0103oool005H0oooo00<000000?ooo`3o
ool0?@3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo001F0?ooo`030000
003oool0oooo03h0oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`00E`3o
ool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool0103o
ool005P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00@0oooo001I0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`030?ooo`00FP3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo02T0
oooo00<000000?ooo`3oool00`3oool005X0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo
0?ooo`0X0?ooo`030000003oool0oooo00<0oooo001K0?ooo`030000003oool0oooo03d0oooo00<0
o`000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`00G03oool00`000000oooo0?ooo`0l
0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool005d0oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo001N0?ooo`03
0000003oool0oooo03/0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`00
G`3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool0
0`3oool00600oooo0P00000l0?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool00`3o
ool00680oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0
oooo00<0oooo001S0?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool08`3oool00`00
0000oooo0?ooo`030?ooo`00I03oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0280
oooo00<000000?ooo`3oool00`3oool006D0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo
0?ooo`0R0?ooo`030000003oool0oooo00<0oooo001V0?ooo`030000003oool0oooo03P0oooo00<0
o`000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`00I`3oool00`000000oooo0?ooo`0g
0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool00`3oool006P0oooo00<000000?oo
o`3oool0=`3oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo001Y0?ooo`03
0000003oool0oooo03L0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`00
J@3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0
0`3oool006X0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00<0oooo001[0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool07@3oool0
0`000000oooo0?ooo`030?ooo`00K03oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo
01d0oooo00<000000?ooo`3oool00`3oool006d0oooo00<000000?ooo`3oool0=P3oool00`3o0000
oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo001^0?ooo`030000003oool0oooo03D0oooo
00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00K`3oool2000003H0oooo00<0
o`000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`00L@3oool00`000000oooo0?ooo`0d
0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00780oooo00<000000?oo
o`3oool0<`3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo001c0?ooo`80
0000=03oool00`3o0000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo001e0?ooo`030000
003oool0oooo0340oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`00MP3o
ool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0103o
ool007L0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0
oooo00@0oooo001h0?ooo`800000<@3oool00`3o0000oooo0?ooo`0E0?ooo`030000003oool0oooo
00D0oooo001j0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00N`3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo01<0oooo
00<000000?ooo`3oool01@3oool007`0oooo0P00000_0?ooo`030?l0003oool0oooo0180oooo00<0
00000?ooo`3oool01P3oool007h0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo00H0oooo001o0?ooo`030000003oool0oooo02`0oooo00<0o`000?oo
o`3oool0403oool00`000000oooo0?ooo`070?ooo`00P03oool2000002d0oooo00<0o`000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`00PP3oool00`000000oooo0?ooo`0[0?ooo`030?l0
003oool0oooo00d0oooo00<000000?ooo`3oool0203oool008<0oooo00<000000?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00240?ooo`800000:`3oool0
103o0000oooo0?ooo`3o000:0?ooo`030000003oool0oooo00T0oooo00260?ooo`030000003oool0
oooo02P0oooo103o000:0?ooo`030000003oool0oooo00T0oooo00270?ooo`8000009`3oool60?l0
00P0oooo00<000000?ooo`3oool02P3oool008T0oooo0P00000T0?ooo`L0o`001`3oool00`000000
oooo0?ooo`0;0?ooo`00R`3oool2000002<0oooo1P3o00070?ooo`030000003oool0oooo00/0oooo
002=0?ooo`8000008P3oool50?l000H0oooo00<000000?ooo`3oool0303oool008l0oooo0P00000Q
0?ooo`D0o`00103oool00`000000oooo0?ooo`0=0?ooo`00T@3oool200000200oooo103o00030?oo
o`030000003oool0oooo00h0oooo002C0?ooo`800000803oool20?l00080oooo00<000000?ooo`3o
ool03`3oool009D0oooo0P00000O0?ooo`80o`0000<000000?ooo`3oool0403oool009L0oooo1000
000K0?ooo`030000003o0000oooo0180oooo002K0?ooo`<000005@3oool3000001D0oooo002N0?oo
o`@000003`3oool2000001P0oooo002R0?ooo`l000006P3oool00</0oooo003;0?ooo`00b`3oool0
0</0oooo003;0?ooo`00b`3oool00</0oooo0000\
\>"],
  ImageRangeCache->{{{0, 202.625}, {287, 0}} -> {-1.48494, -2.10329, 0.014657,
   0.014657}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(unitImage[Transpose[A], UT]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.23523 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 1.11762 0.47619 [
[ 0 0 0 0 ]
[ 1 2.23523 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.23523 L
0 2.23523 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
.97619 1.59381 m
.97438 1.675 L
.96896 1.75195 L
.95996 1.82408 L
.94747 1.89082 L
.93158 1.95169 L
.91239 2.0062 L
.89007 2.05395 L
.86478 2.09458 L
.83672 2.12777 L
.80609 2.15327 L
.77313 2.17089 L
.7381 2.1805 L
.70125 2.18201 L
.66287 2.17543 L
.62325 2.16079 L
.58269 2.13822 L
.5415 2.10788 L
.5 2.07 L
.4585 2.02487 L
.41731 1.97284 L
.37675 1.9143 L
.33713 1.8497 L
.29875 1.77952 L
.2619 1.70431 L
.22687 1.62463 L
.19391 1.54109 L
.16328 1.45433 L
.13522 1.36501 L
.10993 1.27381 L
.08761 1.18141 L
.06842 1.08854 L
.05253 .99588 L
.04004 .90415 L
.03104 .81404 L
.02562 .72624 L
.02381 .64143 L
.02562 .56023 L
.03104 .48328 L
.04004 .41116 L
.05253 .34441 L
.06842 .28355 L
.08761 .22903 L
.10993 .18128 L
.13522 .14066 L
.16328 .10746 L
.19391 .08196 L
.22687 .06434 L
.2619 .05474 L
.29875 .05322 L
Mistroke
.33713 .0598 L
.37675 .07444 L
.41731 .09702 L
.4585 .12736 L
.5 .16524 L
.5415 .21036 L
.58269 .26239 L
.62325 .32093 L
.66287 .38554 L
.70125 .45571 L
.7381 .53093 L
.77313 .6106 L
.80609 .69414 L
.83672 .7809 L
.86478 .87022 L
.89007 .96143 L
.91239 1.05382 L
.93158 1.1467 L
.94747 1.23936 L
.95996 1.33109 L
.96896 1.42119 L
.97438 1.50899 L
.97619 1.59381 L
Mfstroke
[ .01 .02 ] 0 setdash
.97619 1.11762 m
.97438 1.15912 L
.96896 1.20031 L
.95996 1.24086 L
.94747 1.28048 L
.93158 1.31886 L
.91239 1.35571 L
.89007 1.39075 L
.86478 1.42371 L
.83672 1.45433 L
.80609 1.4824 L
.77313 1.50769 L
.7381 1.53001 L
.70125 1.54919 L
.66287 1.56509 L
.62325 1.57758 L
.58269 1.58657 L
.5415 1.592 L
.5 1.59381 L
.4585 1.592 L
.41731 1.58657 L
.37675 1.57758 L
.33713 1.56509 L
.29875 1.54919 L
.2619 1.53001 L
.22687 1.50769 L
.19391 1.4824 L
.16328 1.45433 L
.13522 1.42371 L
.10993 1.39075 L
.08761 1.35571 L
.06842 1.31886 L
.05253 1.28048 L
.04004 1.24086 L
.03104 1.20031 L
.02562 1.15912 L
.02381 1.11762 L
.02562 1.07611 L
.03104 1.03493 L
.04004 .99437 L
.05253 .95475 L
.06842 .91637 L
.08761 .87952 L
.10993 .84449 L
.13522 .81153 L
.16328 .7809 L
.19391 .75283 L
.22687 .72754 L
.2619 .70522 L
.29875 .68604 L
Mistroke
.33713 .67014 L
.37675 .65765 L
.41731 .64866 L
.4585 .64324 L
.5 .64143 L
.5415 .64324 L
.58269 .64866 L
.62325 .65765 L
.66287 .67014 L
.70125 .68604 L
.7381 .70522 L
.77313 .72754 L
.80609 .75283 L
.83672 .7809 L
.86478 .81153 L
.89007 .84449 L
.91239 .87952 L
.93158 .91637 L
.94747 .95475 L
.95996 .99437 L
.96896 1.03493 L
.97438 1.07611 L
.97619 1.11762 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.5 1.11762 m
.75035 2.17811 L
s
% Start of user PostScript
0 0 0.525731 2.22703 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 1.11762 m
.75035 1.52269 L
s
% Start of user PostScript
0 0 0.525731 0.850651 MAarrowhead1
% End of user PostScript
0 0 1 r
[ ] 0 setdash
.5 1.11762 m
.90507 1.02199 L
s
% Start of user PostScript
0 0 0.850651 -0.200811 MAarrowhead1
% End of user PostScript
[ .01 .02 ] 0 setdash
.5 1.11762 m
.90507 .86727 L
s
% Start of user PostScript
0 0 0.850651 -0.525731 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{128.813, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400020000182000`400?l00000o`00003oP03oool0
0800oooo00200?ooo`00P03oool00800oooo00200?ooo`00P03oool00800oooo000O0?ooo`X00000
E`3oool001`0oooo0`00000:0?ooo`@00000D`3oool001/0oooo00<000000?ooo`3oool03`3oool2
00000540oooo000I0?ooo`800000503oool2000004l0oooo000H0?ooo`030000003oool0oooo01H0
oooo0P00001=0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`800000B`3oool001D0oooo0P00
000N0?ooo`030000003oool0oooo04P0oooo000D0?ooo`030000003oool0oooo01l0oooo0P000018
0?ooo`004`3oool00`000000oooo0?ooo`0R0?ooo`800000AP3oool00180oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`130?ooo`004P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0480oooo000A0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@@3o
ool00100oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`100?ooo`00403oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo03l0oooo000?0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0?P3oool000l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0m0?ooo`003P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03`0oooo000=
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0>`3oool000d0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0j0?ooo`00303oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo03T0oooo000<0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
>03oool000/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`002`3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo000;0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0=P3oool000X0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0e0?ooo`002P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0oooo
00090?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool000T0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0c0?ooo`00203oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0380oooo00080?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0<P3oool000P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0a0?ooo`001`3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo00070?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0;`3oool000L0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0_0?ooo`001`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02h0
oooo00060?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;@3oool000H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0]0?ooo`001P3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo02`0oooo00060?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0;03oool000H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0[0?ooo`00
1P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02X0oooo00060?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0:P3oool000D0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0Y0?ooo`001@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
02P0oooo00050?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:03oool000D0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0W0?ooo`001@3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo02L0oooo00050?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool09P3oool000D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?oo
o`00103oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02D0oooo00040?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool09@3oool000@0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0T0?ooo`00103oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo02@0oooo00030?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool08`3oool000<0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0S0?ooo`000`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0280oooo00030?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool08P3oool000<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0Q
0?ooo`000`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0240oooo00030?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0803oool000<0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0P0?ooo`000`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01l0oooo00030?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool07`3oool0
00<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0N0?ooo`000`3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo01h0oooo00030?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool07@3oool000<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0M0?ooo`000`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01d0oooo00030?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0703oool000<0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0L0?ooo`000`3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo01/0oooo00030?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool06`3o
ool000<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0K0?ooo`000`3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo01X0oooo00030?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool06P3oool000<0oooo00<000000?ooo`3oool0=03oool00`000000oooo
00000002000000030?ooo`00000000000080oooo0P00000N0?ooo`030000003oool0oooo01T0oooo
00030?ooo`030000003oool0oooo02l0oooo0P0000020?ooo`030000003oool0oooo00`0oooo0P00
00020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool000<0oooo00<00000
0?ooo`3oool0:`3oool2000001X0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0H
0?ooo`000`3oool00`000000oooo0?ooo`0W0?ooo`<00000803oool2000000030?ooo`000000oooo
0100oooo00<000000?ooo`3oool0603oool000<0oooo00<000000?ooo`3oool0903oool2000002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`000`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo0P00000=0?ooo`030000003oool0oooo01L0oooo
00030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01H0oooo00030?ooo`030000003oool0oooo01d0oooo0P00000f
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool000<0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0i0?ooo`800000203oool00`000000oooo0?ooo`0F0?oo
o`000`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`000`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`000`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0E0?ooo`000`3oool00`000000oooo0?ooo`1N0?ooo`050000003oool0
oooo0?ooo`0000005`3oool000<0oooo00<000000?ooo`3oool0503oool2000004T0oooo00D00000
0?ooo`3oool0oooo0000000F0?ooo`000`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo01@0oooo00030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0000000F0?ooo`000`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04h0
oooo0P00000F0?ooo`000`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01<0oooo
00030?ooo`030000003oool0oooo00h0oooo0P00001D0?ooo`800000503oool000<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo00030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0EP3oool2000001<0oooo00030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0000000B0?ooo`00
0`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0180oooo00030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0F@3oool010000000oooo0?ooo`00000@0?ooo`000`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05X0oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`000`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0100oooo0004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool01@000000oooo0?ooo`3o
ool0000000h0oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00040?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool03`3oool000@0oooo00<000000?ooo`3oool0I`3oool01P000000
oooo0?ooo`3oool0003o000000`0oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0000o`020000o`030?ooo`000000oooo00X0oooo00040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0G`3oool50000o`h0oooo00050?ooo`030000
003oool0oooo06H0oooo0`000?l?0?ooo`001@3oool01@000000oooo0?ooo`3oool0000006<0oooo
0`000?l50?ooo`030000003oool0oooo00P0oooo00050?ooo`050000003oool0oooo0?ooo`000000
H@3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<000000?ooo`3oool01`3oool000D0oooo
00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00050?ooo`040000003oool0oooo000005l0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00050?ooo`030000003oool0000005l0oooo00<0
003o0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0005
0?ooo`030000003oool0000005`0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0=
0?ooo`001@3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool000H0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo00@0oooo0P0000060?ooo`001P3oool00`000000oooo0?ooo`1G0?ooo`030000
o`3oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0303o
ool000H0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo0P00001D0?ooo`030000o`3oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`001@3oool200000580
oooo0P000?lG0?ooo`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo04h0oooo
00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`00103oool00`000000oooo0000
001?0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0000001=0?ooo`030000o`3oool0oooo01`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool010000000oooo0?ooo`00001;
0?ooo`030000o`3oool0oooo01L0oooo1`000?l<0?ooo`001`3oool00`000000oooo0?ooo`170?oo
o`030000o`3oool0oooo01T0oooo1P000?l00`000000oooo0?ooo`0:0?ooo`000`3oool01@000000
oooo0?ooo`3oool0000004P0oooo00<0003o0?ooo`3oool05P3oool80000o`80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`000`3oool01@000000oooo0?ooo`3oool00000
04H0oooo00<0003o0?ooo`3oool04`3oool50000o`@0oooo0P000?l50?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool000L0oooo00<000000?ooo`3oool0@P3oool20000oa80
oooo10000?l@0?ooo`030000003oool0oooo00T0oooo00070?ooo`030000003oool0oooo0400oooo
00<0003o0?ooo`3oool03`3oool40000oa@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<0
003o0?ooo`3oool02`3oool50000oaP0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03`0oooo00<0003o
0?ooo`3oool02@3oool40000oah0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`01
0?ooo`00203oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo00H0oooo10000?lR0?oo
o`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3o
ool00`3oool50000obH0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0
10000?l[0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0003o00<0003o<03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo00090?ooo`030000003oool0
oooo03<0oooo0`000?ld0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo
03<0oooo0P3o000e0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo03@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03<0oooo0P3o000e0?ooo`030000003oool0oooo00H0oooo
000:0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3o0000=03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?oo
o`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3o
0000<`3oool00`000000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0c0?ooo`040?l0
003oool0oooo0?l003<0oooo00D000000?ooo`3oool0oooo000000030?ooo`000`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0=03oool010000000
oooo0?ooo`0000040?ooo`000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0
oooo00D0o`000?ooo`3oool0oooo0?l0000b0?ooo`030000003oool0oooo00D0oooo000<0?ooo`03
0000003oool0oooo03<0oooo00D0o`000?ooo`3oool0oooo0?l0000a0?ooo`030000003oool0oooo
00D0oooo000<0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0<`3oool010000000
oooo0?ooo`0000040?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0^0?ooo`040000003oool0oooo0000
00@0oooo00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0103oool000d0oooo
00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo
000=0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0]0?ooo`8000001@3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0c
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0;03oool2000000D0oooo00050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0c0?oo
o`030000003oool0oooo00@0oooo000>0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo03<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0[0?ooo`030000
003oool0oooo00@0oooo00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool0103o
ool000h0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0
oooo00<0oooo000?0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0X0?ooo`030000003oool0000000D0oooo00070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02H0
oooo00@000000?ooo`3oool000001@3oool000P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0c0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool00`3oool000l0oooo
00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0380oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0S0?ooo`050000
003oool0oooo0?ooo`0000001@3oool000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0c0?ooo`030?l0003oool0oooo02d0oooo00D000000?ooo`3oool0oooo000000050?ooo`00
403oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
9@3oool00`000000oooo0?ooo`030?ooo`00403oool00`000000oooo0?ooo`0c0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3oool0
0`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo
0300oooo00<000000?ooo`3oool00`3oool00140oooo00<000000?ooo`3oool0<`3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool000h0oooo00D000000?ooo`3oool0oooo0000000d0?ooo`030?l0
003oool0oooo0340oooo00<000000?ooo`3oool00P3oool00180oooo00<000000?ooo`3oool0<P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`003`3oool010000000oooo0?ooo`00000e0?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo000@0?ooo`040000003oool0oooo000003@0oooo00<0o`000?ooo`3oool0<03o
ool00`000000oooo0?ooo`020?ooo`004`3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0
oooo00d0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo000B0?ooo`800000=03oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`004P3oool2000003D0
oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`00503oool00`000000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo000D0?ooo`030000003oool0oooo0380oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00P3oool001@0oooo0P00000c0?ooo`030?l0003oool0oooo02l0oooo00<00000
0?ooo`3oool00P3oool001D0oooo00<000000?ooo`000000<P3oool00`3o0000oooo0?ooo`0L0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00@3oool001D0oooo00@000000?ooo`3o
ool00000<@3oool00`3o0000oooo0?ooo`0?0?ooo`80o`002P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3o
ool03P3oool40?l000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`010?ooo`00
5P3oool01@000000oooo0?ooo`3oool0000002l0oooo00<0o`000?ooo`3oool03`3oool20?l000L0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`010?ooo`005P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool03`3oool20?l001d0oooo
00<000000?ooo`3oool00@3oool001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0[0?ooo`030?l0003oool0oooo00l0oooo0`3o00020?ooo`800000603oool00`000000oooo0?oo
o`010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo00<0o`00
0?ooo`3oool0403oool20?l001`0oooo00<000000?ooo`3oool00@3oool001L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo0P00000L0?oo
o`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0<0?ooo`800000
7`3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02@0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0040oooo000I0?ooo`030000003oool0oooo00/0oooo0P00000S0?ooo`030?l0003oool0
oooo00P0oooo0P00000S0?ooo`030000003oool0oooo0040oooo000I0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`050?ooo`8000009P3oool00`00
0000oooo0?ooo`010?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000001h0
oooo00<0o`000?ooo`3oool00P00000Z0?ooo`030000003oool0oooo0040oooo000J0?ooo`030000
003oool0oooo0180oooo00@000000?ooo`3oool000006P3oool00`3o000000000?ooo`0/0?ooo`03
0000003oool0oooo0040oooo000J0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
0P00000>0?ooo`030000003oool0oooo008000000P3oool00`3o0000oooo0?ooo`0/0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo01/0oooo0`0000001@3oool000000000
00000000oooo008000000P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo02`0oooo
00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?oo
o`0[0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0300oooo00<0o`00
0?ooo`3oool0:`3oool00`000000oooo0?ooo`010?ooo`00703oool00`000000oooo0?ooo`0_0?oo
o`030?l0003oool0oooo02/0oooo00<000000?ooo`3oool00@3oool001`0oooo00<000000?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`0[0?ooo`030000003oool0oooo0040oooo000L0?ooo`030000
003oool0oooo0300oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`010?ooo`007@3o
ool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool00@3o
ool001d0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0040oooo000N0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`010?ooo`007P3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo02X0
oooo00<000000?ooo`3oool00@3oool001l0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0040oooo000O0?ooo`030000003oool0oooo02h0oooo00<0
o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`010?ooo`00803oool00`000000oooo0?ooo`0]
0?ooo`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool00@3oool00200oooo00<000000?oo
o`3oool0;@3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0040oooo000Q0?ooo`03
0000003oool0oooo02d0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`010?ooo`00
8@3oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool0
0P3oool00280oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0080oooo000R0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool09`3oool0
0`000000oooo0?ooo`020?ooo`008`3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo
02H0oooo00<000000?ooo`3oool00P3oool002<0oooo00<000000?ooo`3oool0;03oool00`3o0000
oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02/0oooo
00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`0[0?ooo`030?l0003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool002D0oooo00<00000
0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo000U0?oo
o`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool09@3oool00`000000oooo0?ooo`020?oo
o`009P3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3o
ool00P3oool002L0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0T0?ooo`030000
003oool0oooo00<0oooo000W0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0903o
ool00`000000oooo0?ooo`030?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool002P0oooo00<000000?ooo`3oool0:@3oool00`3o
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo02P0
oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`00:@3oool00`000000oooo
0?ooo`0X0?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool002X0oooo00<0
00000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo000Z
0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`03
0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo0280oooo00<000000?oo
o`3oool00`3oool002`0oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00@0oooo000/0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0
803oool00`000000oooo0?ooo`040?ooo`00;@3oool00`000000oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo0200oooo00<000000?ooo`3oool0103oool002d0oooo00<000000?ooo`3oool09P3oool0
0`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo000^0?ooo`030000003oool0oooo
02D0oooo00<0o`000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`00;`3oool00`000000
oooo0?ooo`0U0?ooo`030?l0003oool0oooo01l0oooo00<000000?ooo`3oool0103oool002l0oooo
00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo
000`0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool07P3oool00`000000oooo0?oo
o`050?ooo`00<@3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01h0oooo00<00000
0?ooo`3oool01@3oool00340oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0N0?oo
o`030000003oool0oooo00D0oooo000b0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3o
ool0703oool00`000000oooo0?ooo`060?ooo`00<`3oool00`000000oooo0?ooo`0R0?ooo`030?l0
003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool003@0oooo00<000000?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000d0?ooo`030000003oool0
oooo0240oooo00<0o`000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`00=@3oool00`00
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool003H0
oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0
oooo000f0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool06@3oool00`000000oooo
0?ooo`080?ooo`00=`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01T0oooo00<0
00000?ooo`3oool0203oool003P0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0G
0?ooo`030000003oool0oooo00T0oooo000i0?ooo`030000003oool0oooo01h0oooo00<0o`000?oo
o`3oool05`3oool00`000000oooo0?ooo`090?ooo`00>@3oool00`000000oooo0?ooo`0N0?ooo`03
0?l0003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool003X0oooo00<000000?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo000k0?ooo`030000003o
ool0oooo01d0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`00?03oool0
0`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool0
03`0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo
00`0oooo000m0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool04`3oool00`000000
oooo0?ooo`0<0?ooo`00?P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0180oooo
00<000000?ooo`3oool03@3oool003l0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?oo
o`0A0?ooo`030000003oool0oooo00d0oooo00100?ooo`030000003oool0oooo01T0oooo00<0o`00
0?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`00@@3oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00480oooo0P00000H0?ooo`03
0?l0003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool004@0oooo00<000000?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00150?ooo`030000003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`00AP3oool2
000001D0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`00B03oool20000
01<0oooo0`3o000:0?ooo`030000003oool0oooo01<0oooo001:0?ooo`030000003oool0oooo00l0
oooo103o00090?ooo`030000003oool0oooo01@0oooo001;0?ooo`8000003`3oool40?l000P0oooo
00<000000?ooo`3oool05@3oool004d0oooo0P00000>0?ooo`<0o`001`3oool00`000000oooo0?oo
o`0F0?ooo`00C`3oool2000000`0oooo0`3o00050?ooo`8000006@3oool00540oooo0P00000;0?oo
o`80o`000`3oool2000001/0oooo001C0?ooo`@000001`3oool20?l000030?ooo`000000000001d0
oooo001G0?ooo`P0000000<0o`000000003oool07P3oool00800oooo00200?ooo`00P03oool00800
oooo00200?ooo`00P03oool00800oooo0000\
\>"],
  ImageRangeCache->{{{0, 127.813}, {287, 0}} -> {-1.05001, -2.35779, 
  0.0164305, 0.0164305}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spirit of 8.2; 2  The SVD and Digital Image Processing -- Tutorial\
\>", "Section"],

Cell["\<\
You must have access to the file HAND.RAW that should accompany this \
notebook.
This project was adapted from work by Todd Will and data file supplied Robert \
Whitton, both of Davidson College.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A Small Example", "Subsection"],

Cell["\<\
Let's create a matrix from its (full) Singular Value Decomposition.\
\>", "Text"],

Cell["\<\
U=N[{{ 1/2, -1/2,  1/2,  1/2}, 
     { 1/2,  1/2, -1/2,  1/2}, 
     { 1/2,  1/2,  1/2, -1/2}, 
     { 1/2, -1/2, -1/2, -1/2}}]
S=N[{{12,  0, 0},
     { 0,.05, 0},
     { 0,  0, 0},
     { 0,  0, 0}}]
VT=N[{{2/3,  2/3,  1/3},
      {2/3, -1/3, -2/3},
      {1/3, -2/3,  2/3}}]\
\>", "Input"],

Cell["A = U.S.VT", "Input"],

Cell[CellGroupData[{

Cell["\<\
The Reduced Singular Value Decomposition (neglecting zero singular values).\
\>", "Subsubsection"],

Cell["\<\
To recreate this matrix A from the decomposition, we can don't really need \
the zero rows and columns from S or the corresponding parts of U and VT.  \
These reduced matrices form the \"Reduced Singular Value Decomposition.\"\
\>", "Text"],

Cell["VrT = Take[VT,2]", "Input"],

Cell["\<\
Needs[\"LinearAlgebra`MatrixManipulation`\"]  (* for TakeColumns *)\
\>", "Input"],

Cell["Sr = TakeColumns[Take[S,2],2]", "Input"],

Cell["Ur = TakeColumns[U,2]", "Input"],

Cell["Ur.Sr.VrT", "Input"],

Cell["This is exactly the matrix A.", "Text"],

Cell["A", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Mma function SingularValues", "Subsubsection"],

Cell["\<\
Mma has a built-in function SingularValues that takes a matrix A and returns \
its \"Reduced Singular Value Decomposition\" in the following format.\
\>", "Text"],

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[A]\
\>", "Input"],

Cell["\<\
UrT should be the Transpose of Ur above except for possibly multiplying \
vectors by -1.\
\>", "Text"],

Cell["UrT", "Input"],

Cell["Ur = Transpose[UrT]", "Input"],

Cell["\<\
VrT should be the VrT above except for possibly multiplying (same as in UrT) \
vectors by -1.\
\>", "Text"],

Cell["VrT", "Input"],

Cell["\<\
sings is actually just a list of the nonzero singular values.  We can use \
DiagonalMatrix to recreate Sr.\
\>", "Text"],

Cell["sings", "Input"],

Cell["Sr = DiagonalMatrix[sings]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Neglecting small singular values for approximating A or \"filtering.\"\
\>", "Subsubsection"],

Cell["\<\
Ignoring the rows and columns corresponding to zero singular values worked \
perfectly to recreate A.\
\>", "Text"],

Cell["Ur.Sr.VrT", "Input"],

Cell["\<\
Since the zero singular values contributed nothing to the matrix product, \
maybe relatively small singular values won't contribute much.  In our \
example, we are mulitplying by 12(v1)+.05(v2) so the latter term is \
relatively insignificant.  Lets drop off this smallest singular value, \
leaving only one singular value (12), and one column of Ur and one row of Vr. \
 I'll use Ua, Sa, and Va to label these \"approximate\" decomposition \
elements.  What will we get?\
\>", "Text"],

Cell["Sa = {{12.}}", "Input"],

Cell["VaT = Take[VrT,1]", "Input"],

Cell["Ua = TakeColumns[Ur,1]", "Input"],

Cell["Ua.Sa.VaT", "Input"],

Cell["This is indeed \"close\" to A.", "Text"],

Cell["A", "Input"],

Cell["\<\
There are two interpretations/applications of this.  
1.  If the the 12 numbers in the original A were exact, we have accomplished \
recreating a good approximation to A from only the 8 numbers in Ua, Sa, and \
Va.  This is a \"compression of A\" so that it can be stored/sent in a \
smaller amount of computer memory.
2.  If the the 12 numbers in the original A contained some \"noise\" or small \
errors, we have filtered out this noise and found an even \"truer\" version \
of A with the noise eliminated.\
\>", "Text"],

Cell["Ua.Sa.VaT", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image Compression", "Subsection"],

Cell["\<\
In the following ReadList command, you MUST change the path for the file \
HAND.RAW to match its location on your computer.  Optional details about \
HAND.RAW:  It is a file for a gray-scale image that, I believe, contains 100 \
by 100 numbers between 0 and 256 that indicate the gray-level for one pixel.  \
Bytes in HAND.RAW represent integers, not characters, so you can't look at it \
as a text file.  You rarely find any such files since image file formats \
(jpeg for example) are already compressed and viewing programs expect this \
compression.\
\>", "Text"],

Cell["\<\
Clear[A,B,Ur,UrT,Vr,VrT,Sr,Ua,UaT,Va,VaT,Sa,hand,handMat]
hand = ReadList[\"D:\\classes\\MAT150\\mma150\\ATLAST\\hand.raw\"];
handMat = Take[Transpose[Partition[hand,100]]/256.,-85];\
\>", "Input"],

Cell["\<\
handMat is now a 85x100 matrix (a size my computer could handle) of values \
between 0 and 1, each corresponding to a gray-level (0=black, 1=white).  Here \
is the 50th row of handMat.\
\>", "Text"],

Cell["handMat[[50]]", "Input"],

Cell["\<\
Now the following function will let you view the matrix of gray-levels.\
\>", "Text"],

Cell["\<\
Clear[showImage]
showImage[imageMat_] :=
    Show[
\tGraphics[{
      Raster[ imageMat ]
\t}],AspectRatio->Automatic
\t]\
\>", "Input"],

Cell["showImage[handMat];", "Input"],

Cell["\<\
This image looks a little chunky because of the scale.  It is a small image \
of only 100 pixels width and 85 pixels height.  Try to rescale:  click on the \
image and drag one of the corner markers in.  Numbers for the displayed \
image's width and height should be changing in the lower-left corner of the \
window for this notebook.  When it gets to 100 by 85, you can release the \
mouse button to rescale to the image in actual displayed pixels.  (This \
rescaling is optional for the rest of your work.)\
\>", "Text"],

Cell["\<\
Currently this image is stored in 85x100 matrix, so it stored 8500 entries.\
\>", "Text"],

Cell["Length[Flatten[handMat]]", "Input"],

Cell[CellGroupData[{

Cell["Questions 1-4:", "Subsubsection"],

Cell["\<\
1.  In the full SVD of handMat, what would be the sizes of the U, S and V \
matices?
2.  What is the maximum rank of handMat (=the maximum number of nonzero \
singular values)?
3.  Assuming this maximum rank, what would be the size of the reduced Ur, Sr, \
and Vr matrices?
4.  Of course, only the diagonal entries of Sr need to be stored.  Based on \
your answers in 3, how many total entries are there in Ur, Sr-diagonal, and \
Vr (all together)?\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reducing the Reduced SVD", "Subsubsection"],

Cell["\<\
Let's see what Mma returns for the reduced SVD.  It will not report any zero \
singular values and very small (maybe roundoff error) singular values are \
also eliminated (controlled by a Tolerance option) as being practically zero. \
 First we see how many \"really nonzero\" singular values Mma finds.\
\>", "Text"],

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[handMat];
Length[sings]\
\>", "Input"],

Cell["\<\
Now let's count the total number of numbers saved in this reduced SVD:\
\>", "Text"],

Cell["Length[Flatten[{UrT, sings, VrT}]]", "Input"],

Cell["\<\
This is definitely not savings, the original image was 8500 entries and when \
I tried the above it showed 12462 entries stored for the reduced SVD.  But \
some of the singular values still may be relatively small, lets take a \
look.\
\>", "Text"],

Cell["sings", "Input"],

Cell["\<\
Clearly, the last few of these are negligible.  Let's only keep singular \
values larger than  0.2  (1/100 of the largest singular value) in an \
approximate SVD and try recreating an approximate image.\
\>", "Text"],

Cell["Take[sings,36]", "Input"],

Cell["\<\
bigSings = Take[sings,36];
UaT = Take[UrT,36];
VaT = Take[VrT,36];\
\>", "Input"],

Cell["\<\
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[newHand];\
\>", "Input"],

Cell["\<\
This looks as good as the original to me.  How many entries are stored in \
this approximate SVD:\
\>", "Text"],

Cell["Length[Flatten[{UaT,bigSings,VaT}]]", "Input"],

Cell["\<\
Well, this is a definite improvement over the 12462 stored in the first \
reduced SVD.  Also, it is a bit of image compression because it is less than \
the 8500 entries stored in the original handMat.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Question 5:  Try keeping even fewer singular values and report results as \
below.\
\>", "Subsubsection"],

Cell["\<\
Execute the following with several smaller values in numToKeep.  Report the \
numToKeep and total entries stored in the smallest approximate SVD you would \
use 
(a)  if you wanted to preserve an \"almost perfect\" recreated image.
(b)  if you wanted to just be able to recognize the image.\
\>", "Text"],

Cell["\<\
numToKeep = ;
bigSings = Take[sings,numToKeep];
UaT = Take[UrT,numToKeep];
VaT = Take[VrT,numToKeep];
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[handMat];  (* original on top *)
showImage[newHand];  (* recreated on bottom *)
Length[Flatten[{UaT,bigSings,VaT}]]\
\>", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image Filtering", "Subsection"],

Cell["\<\
Suppose you attempted to download the matrix handMat from the WWW, your \
noisey modem
introduced error and provided you with the matrix handErr below:\
\>", "Text"],

Cell["\<\
handErr= handMat+
  Table[If[Random[]< 1/30,.5-Random[],0],{85},{100}];
showImage[handErr];\
\>", "Input"],

Cell["As you can see the image has become speckled with noise.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Question 6:  How did introducing the noise change the size of the reduced \
SVD?  Specifically,\
\>", "Subsubsection"],

Cell["\<\
Compare the following answers with those for the original.  Do these numbers \
ring a bell?\
\>", "Text"],

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[handErr];
Length[sings]\
\>", "Input"],

Cell["Length[Flatten[{UrT, sings, VrT}]]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Maybe compressing to the important singular values will remove the spots.\
\>", "Subsubsection"],

Cell["\<\
numToKeep = 15;
bigSings = Take[sings,numToKeep];
UaT = Take[UrT,numToKeep];
VaT = Take[VrT,numToKeep];
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[handErr];  (* noisy image on top *)
showImage[newHand];  (* filtered on bottom *)
Length[Flatten[{UaT,bigSings,VaT}]]\
\>", "Input"],

Cell["Compare the original to the filtered.", "Text"],

Cell["\<\
showImage[handMat];  (* perfect original on top *)
showImage[newHand];  (* filtered from speckled on bottom *)\
\>", "Input"],

Cell["\<\
Not a perfect job, but hey that huge clef was in the original too.\
\>", "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spirit of 8.2; 2  The SVD and Digital Image Processing -- Solutions\
\>", "Section"],

Cell["\<\
You must have access to the file HAND.RAW that should accompany this \
notebook.
This project was adapted from work by Todd Will and data file supplied Robert \
Whitton, both of Davidson College.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A Small Example", "Subsection"],

Cell["\<\
Let's create a matrix from its (full) Singular Value Decomposition.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
U=N[{{ 1/2, -1/2,  1/2,  1/2}, 
     { 1/2,  1/2, -1/2,  1/2}, 
     { 1/2,  1/2,  1/2, -1/2}, 
     { 1/2, -1/2, -1/2, -1/2}}]
S=N[{{12,  0, 0},
     { 0,.05, 0},
     { 0,  0, 0},
     { 0,  0, 0}}]
VT=N[{{2/3,  2/3,  1/3},
      {2/3, -1/3, -2/3},
      {1/3, -2/3,  2/3}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.5`", \(-0.5`\), "0.5`", "0.5`"},
            {"0.5`", "0.5`", \(-0.5`\), "0.5`"},
            {"0.5`", "0.5`", "0.5`", \(-0.5`\)},
            {"0.5`", \(-0.5`\), \(-0.5`\), \(-0.5`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"11.9999999999999996`", "0", "0"},
            {"0", "0.05`", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.666666666666666607`", "0.666666666666666607`", 
              "0.333333333333333303`"},
           
             {"0.666666666666666607`", \(-0.333333333333333303`\), 
              \(-0.666666666666666607`\)},
           
             {"0.333333333333333303`", \(-0.666666666666666607`\), 
              "0.666666666666666607`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A = U.S.VT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Reduced Singular Value Decomposition (neglecting zero singular values).\
\>", "Subsubsection"],

Cell["\<\
To recreate this matrix A from the decomposition, we can don't really need \
the zero rows and columns from S or the corresponding parts of U and VT.  \
These reduced matrices form the \"Reduced Singular Value Decomposition.\"\
\>", "Text"],

Cell[CellGroupData[{

Cell["VrT = Take[VT,2]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"0.666666666666666607`", "0.666666666666666607`", 
              "0.333333333333333303`"},
           
             {"0.666666666666666607`", \(-0.333333333333333303`\), 
              \(-0.666666666666666607`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Needs[\"LinearAlgebra`MatrixManipulation`\"]  (* for TakeColumns *)\
\>", "Input"],

Cell[CellGroupData[{

Cell["Sr = TakeColumns[Take[S,2],2]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"11.9999999999999996`", "0"},
            {"0", "0.05`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ur = TakeColumns[U,2]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0.5`", \(-0.5`\)},
            {"0.5`", "0.5`"},
            {"0.5`", "0.5`"},
            {"0.5`", \(-0.5`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ur.Sr.VrT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["This is exactly the matrix A.", "Text"],

Cell[CellGroupData[{

Cell["A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Mma function SingularValues", "Subsubsection"],

Cell["\<\
Mma has a built-in function SingularValues that takes a matrix A and returns \
its \"Reduced Singular Value Decomposition\" in the following format.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[A]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\({\(-0.499999999999999911`\), \(-0.499999999999999911`\), 
                \(-0.499999999999999911`\), \(-0.499999999999999911`\)}\), 
              \({0.500000000000001953`, \(-0.499999999999999822`\), 
                \(-0.499999999999999911`\), 0.49999999999999769`}\)},
            {"12.0000000000000062`", "0.0500000000000003197`"},
           
             {\({\(-0.666666666666666607`\), \(-0.666666666666666962`\), 
                \(-0.333333333333333259`\)}\), 
              \({\(-0.666666666666671581`\), 0.333333333333343162`, 
                0.666666666666656748`}\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
UrT should be the Transpose of Ur above except for possibly multiplying \
vectors by -1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["UrT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-0.499999999999999911`\), \(-0.499999999999999911`\), 
              \(-0.499999999999999911`\), \(-0.499999999999999911`\)},
           
             {"0.500000000000001953`", \(-0.499999999999999822`\), 
              \(-0.499999999999999911`\), "0.49999999999999769`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ur = Transpose[UrT]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.499999999999999911`\), "0.500000000000001953`"},
            {\(-0.499999999999999911`\), \(-0.499999999999999822`\)},
            {\(-0.499999999999999911`\), \(-0.499999999999999911`\)},
            {\(-0.499999999999999911`\), "0.49999999999999769`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
VrT should be the VrT above except for possibly multiplying (same as in UrT) \
vectors by -1.\
\>", "Text"],

Cell[CellGroupData[{

Cell["VrT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-0.666666666666666607`\), \(-0.666666666666666962`\), 
              \(-0.333333333333333259`\)},
           
             {\(-0.666666666666671581`\), "0.333333333333343162`", 
              "0.666666666666656748`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
sings is actually just a list of the nonzero singular values.  We can use \
DiagonalMatrix to recreate Sr.\
\>", "Text"],

Cell[CellGroupData[{

Cell["sings", "Input"],

Cell[BoxData[
    \(TraditionalForm\`{12.0000000000000062`, 0.0500000000000003197`}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sr = DiagonalMatrix[sings]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"12.0000000000000062`", "0"},
            {"0", "0.0500000000000003197`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Neglecting small singular values for approximating A or \"filtering.\"\
\>", "Subsubsection"],

Cell["\<\
Ignoring the rows and columns corresponding to zero singular values worked \
perfectly to recreate A.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Ur.Sr.VrT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.98333333333333463`", "4.0083333333333373`", 
              "2.01666666666666705`"},
           
             {"4.01666666666666749`", "3.99166666666666891`", 
              "1.98333333333333339`"},
           
             {"4.01666666666666749`", "3.99166666666666891`", 
              "1.98333333333333339`"},
           
             {"3.98333333333333428`", "4.00833333333333641`", 
              "2.0166666666666666`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Since the zero singular values contributed nothing to the matrix product, \
maybe relatively small singular values won't contribute much.  In our \
example, we are mulitplying by 12(v1)+.05(v2) so the latter term is \
relatively insignificant.  Lets drop off this smallest singular value, \
leaving only one singular value (12), and one column of Ur and one row of Vr. \
 I'll use Ua, Sa, and Va to label these \"approximate\" decomposition \
elements.  What will we get?\
\>", "Text"],

Cell[CellGroupData[{

Cell["Sa = {{12.}}", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", 
        StyleBox["11.9999999999999996`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VaT = Take[VrT,1]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {\(-0.666666666666666607`\), \(-0.666666666666666962`\), 
              \(-0.333333333333333259`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ua = TakeColumns[Ur,1]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-0.499999999999999911`\)},
            {\(-0.499999999999999911`\)},
            {\(-0.499999999999999911`\)},
            {\(-0.499999999999999911`\)}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ua.Sa.VaT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.99999999999999911`", "4.00000000000000088`", 
              "1.99999999999999928`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["This is indeed \"close\" to A.", "Text"],

Cell[CellGroupData[{

Cell["A", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"4.0166666666666666`", "3.99166666666666678`", 
              "1.98333333333333339`"},
           
             {"3.98333333333333339`", "4.00833333333333374`", 
              "2.0166666666666666`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
There are two interpretations/applications of this.  
1.  If the the 12 numbers in the original A were exact, we have accomplished \
recreating a good approximation to A from only the 8 numbers in Ua, Sa, and \
Va.  This is a \"compression of A\" so that it can be stored/sent in a \
smaller amount of computer memory.
2.  If the the 12 numbers in the original A contained some \"noise\" or small \
errors, we have filtered out this noise and found an even \"truer\" version \
of A with the noise eliminated.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Ua.Sa.VaT", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
           
             {"3.99999999999999911`", "4.00000000000000088`", 
              "1.99999999999999928`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"},
           
             {"3.99999999999999857`", "4.00000000000000088`", 
              "1.99999999999999893`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image Compression", "Subsection"],

Cell["\<\
In the following ReadList command, you MUST change the path for the file \
HAND.RAW to match its location on your computer.  Optional details about \
HAND.RAW:  It is a file for a gray-scale image that, I believe, contains 100 \
by 100 numbers between 0 and 256 that indicate the gray-level for one pixel.  \
Bytes in HAND.RAW represent integers, not characters, so you can't look at it \
as a text file.  You rarely find any such files since image file formats \
(jpeg for example) are already compressed and viewing programs expect this \
compression.\
\>", "Text"],

Cell["\<\
Clear[A,B,Ur,UrT,Vr,VrT,Sr,Ua,UaT,Va,VaT,Sa,hand,handMat]
hand = ReadList[\"D:\\classes\\MAT150\\mma150\\ATLAST\\hand.raw\"];
handMat = Take[Transpose[Partition[hand,100]]/256.,-85];\
\>", "Input"],

Cell["\<\
handMat is now a 85x100 matrix (a size my computer could handle) of values \
between 0 and 1, each corresponding to a gray-level (0=black, 1=white).  Here \
is the 50th row of handMat.\
\>", "Text"],

Cell[CellGroupData[{

Cell["handMat[[50]]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0.18359375`, 0.75`, 0.90234375`, 
      0.84765625`, 0.85546875`, 0.8671875`, 0.8515625`, 0.83203125`, 
      0.73046875`, 0.5078125`, 0.50390625`, 0.4765625`, 0.37890625`, 
      0.2421875`, 0.16796875`, 0.078125`, 0.27734375`, 0.6796875`, 
      0.8359375`, 0.640625`, 0.77734375`, 0.78515625`, 0.4921875`, 0.484375`, 
      0.5625`, 0.73828125`, 0.62109375`, 0.609375`, 0.56640625`, 0.36328125`, 
      0.48828125`, 0.4921875`, 0.2265625`, 0.41796875`, 0.48046875`, 
      0.51171875`, 0.5546875`, 0.54296875`, 0.4921875`, 0.375`, 0.265625`, 
      0.21875`, 0.43359375`, 0.40234375`, 0.24609375`, 0.0234375`, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
Now the following function will let you view the matrix of gray-levels.\
\>", "Text"],

Cell["\<\
Clear[showImage]
showImage[imageMat_] :=
    Show[
\tGraphics[{
      Raster[ imageMat ]
\t}],AspectRatio->Automatic
\t]\
\>", "Input"],

Cell[CellGroupData[{

Cell["showImage[handMat];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000000001010001030202080B151A
1D1E20232522201D1913100C0C0E151D232B2B2B21100801
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000102060E18
1F1F2125282A2726211B140D0B0F171E2941515853381706
010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000100010710
1B1F22292D302F2D292319100C0F0D1726353231373B2A15
070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000010105
0E1A212933333434332B211C1C1A151C1E181115171B151C
1F1608040404030100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
030917253235363A35312C2C2F2A242C1F0F0A0D12120C0F
15191A181C21232216110A05010100000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000104132933353938353437352B293E29190C091314151F
1A0A0E04070E171B171A191715130C0C0D08030000010000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000E242E3638393C3C342929443B290B081E1B163E
270E080805000205020917151C191A221C190F0701000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000A213135393D3B32252F564C260D0351A12E3F
340B0F0604011B261B0406050406080D0E151C1B0C030100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000081E2D353A3832262D4F491F15081A748246
1C07070B0115364A4F1E020001010507070B161D180C0502
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071D2E3737342C2B323A180D131F365247
270E00001A3F382D252F22130A0405040B0A0E1114150D03
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B30343730322D2440526C8C9C8A74
531000144D4B38392A2C291F1D0E03040A09070B13211401
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000051D303431302E1F3FABD0D5CDB791
36010B4654565D6064554C3F260D09050503050D141D1001
010100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000051D32352F2A231858B0BEA57829
00063D606369605C5D584E4D50452B130301070E11130901
000001010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000031D33322C221B0E0B0C080100
00236369645A4F504845414E595157391903050B13110801
010101010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000004213231231D120601000002
133A57564F453E3C362F333D41433D2E261D091121110601
000301010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000720302B1F180C05010415
243947443F3B39373F55778B8684775D3F26101C210A0303
000404010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000006222F261B0D0907161D
1D2B3B403C3C414D6091BDCBC3BEAEAE9F6B1A1A12060605
080502010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000007282C0C0609111615
1A273039404B59657E7884ABD6E6DECEC5A53A1912140909
100B00010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000510060A0800050E111013
1D29333D4B5B72908D63374288C1DADCD0C153241F170D15
1D0900010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000003212D100202050B0F0F1017
2333414A60718B939FAB763113366F98A8A66D563F26171E
180100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000051A181F190905090F0F101222
364560798699894A205EC0AD7A3A161F5B9599939C733617
070100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000001432180F0E0A0A1112141E2944
576D7F97A1A3947E52171F52A2C39C807BACBFB6CBC78623
030503030302010000010100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000010005282B1C24211F14131C223152667B
8C91A2A2AA9FAFB4B3976335296FB6D1C9BBB4B4A6A4650E
060505060704010000030300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B301D0902020D141E324F7189949B
A2A5AF9FA7B0A18A8DA7AAB187353C518CB7BAAC956B0A05
0404070806040100000A0900000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001000311213332302C180E1D365787A1A6A6AA
ACB3BBB0AA8E38142A6685A0B5957F686BADBCA78F591E1F
0C0F0D0A0704070409170600000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000031722232F393E3D2F1C386084A3A59B9899
A6BAB8B6A3707133081F62C0DDE1E7DEB7AEB39274443A47
3227240F060512210F080000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000012737391A192221202A2B3C517F868D8A8C93
A3B2BDC5B0799372647F8988AFCDDBDACCAA8C6559394555
434E533A1E1A262F05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000011322E2A2613060714192D37454A445D5E5560
82ABC0C3BD87797B98989BA0AFB6C1D2C0973D2D3D2B3C62
3D6B8575533B3A1300010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002031251F2C2818100D1A2B3322110A245B8290
858FB9B8B0947DA9C1A497A0A5B5CFD0BA52091224182867
6660A4B2884B1B0000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000005322D2927222D2C160A1329391C161419316E7D
A19C99A39583A1DEC9B4AB9BA6C7CCD192221814100B124B
7F646CA0882A010101010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000044E6C5722282A34332B15224F4C2E27495F5973
7D7470746E669BC4A9B2BCBFC6C8CCD3723432331B080628
6572503D2002000202000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000493AD431C1C171418241F2D669D7E5D657A6E51
4E363A323461A4ADA0B1C2CCC5BDB5C97D5956543D120210
3E6466461E09000404020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000001D9D96313730210C090B1D3C76ABCCB79F816846
261B0F093AB7B6839CACA3ABB8BCBABE7F746D423F1E0402
204A62564321020106090300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000002CD4825C662A192B3C2B1E3F78A8C6DDCABEA15B
2C130C1C7BD3BE83847C7888999B9BB5847C8C6022150A02
072A5655462D0F00040E0800000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000DAAC0955B568293846D3C446895BBD7E2E5DED5
C1997EA1CED9B66D4B42608A97A9A6A9927C92924F200E08
06214F685A41220301131907000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004F9E36197AA16528263737517BA7C2D6DDEDF1
EFE9DFD7CBC8B553213D4F83979DA3B5AD8491947143230F
051A47717C5A370E00183319010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002D6395934E4A6D845B302E3A71989FBACCDADB
DDE2E7D8CDD0D08626254F6E7A826F667C828D92855F4012
030F3967886E451802264125020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004C653E9BACABA678766E5F535B85A8B6C7D1DA
E0E5EBEBECE6DFCB81414F7A6C6B5A4A5569878D84674E26
060625537F7F531E052C492A040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000063CF8E7EC7CB69222F4754473F588AB7C3C6D0
E1ECF3F1ECE7E2E4E4BE95949A97979B71475B8D866F5836
170611386C83622803214F2B060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000016EC9A6704E566E64523D3C2022354866A7C3CB
CDD2E9EBE6E0DEDEE0E5D5BCBEC0B8AA7A274A7B7E785C40
2610082660896833092D61320A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000006BAFB88E5289D4C0B3A7AA80667081706F94C7
D2C8D0D8D9DAD2D6D2D6C5B7BABDB4A06B3D5B8687816C44
2C17072759806B40174C6A3C1E0100000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000087B6AC9795CDCBBDE2EFD3C7BEA0786A84879D
D7D9D1D0C8D1CEC3BFBBB5A8A9A89670503342828C8E8659
32200B336A837542266E6246250000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000066C4B9B4B38F6568609ACDCABDAEA39B8CAA97
B9C6A9A19A9FA3A8A8969EA69C7C5D3512022A71868A855E
2F1A104782837B374479673E090000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000029C2BED3AA73B3EFD79DABB4C3E0EBEDCFBEAC
919080715A535B6E766C635D4F4B435E69521F657C818869
361D134D937C602E66683706000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000005A7C8B8C9F1F8EFEAEEE7EAF6EFEBEBD2B3A7
979BB0B4B58D81685C412A25171017325F510E547F81826C
4E2C1C629874413A76470700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000066DAC3BAD4D8CECDC8D4DDD0D4C4ACB6A28E
7E6C7D6F99B4714C80989E8D85633F14342F2D4777817D6F
48352B89956C3B5C4E0D0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000020D1D1CCD5DBE4E5EDEBDDE0AA5D3C53686E
67668DA49EC5B469445D6B748FA9B59C813C566B7A807D74
512D4F9A875F463E08000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E3CFD1DADAE6E9DADEB128060A091C58
7583BABCC4AEB8D38E555D54779FAE9C624D6F7F8483846A
482A6192734D250200010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000012BFE0CFD1D6CDDDE9DC6326271F160B28
6CA8B5C9C8AA81BBBF967E7C59534E5E435E7882858A8364
3E31727C5C29000001010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000002FC0E7D9DBDEDAD5BB82817A613E2B14
47AED6A4C7C97E7C90BD9F9C915D7D7E3A6B7B838E8B7E60
44386F673F06000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000001AABEFE0DDE3DCB6A6C1DCDFA26B4A
2C94D896A4D2CCBFACB1C1AAB2BDBE503E697989928F7A60
3F445E521A00000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000777E7EDE4D9ABA4CBECE2C49486
327CDAC4958F9FBEC898A5A4AB7D454648687D898F88775C
3D3E4D300200000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000004BB1E8E89E81A8E6C9A7898A
3D55A9C2C2C0C6ABB496937E4E213A56525D7C918E7E6F55
2F2A38110001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000003DA99C736E989A817071
464A8DAFA5A4C8BFA987370F1636454A5F6983918B796747
212130050001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000075F6C749598806955
43375F77808D8A743E0E0B191F3A4E4E5571888F85715A32
182C1E000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000386863676A605042
362A53626153361505101F271E3B4B565E728B8B7F724C2E
262C05000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000038736B6B67574432
2F291B120B0C1413121A2E3129364F597B8F827978694834
2B0900010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000002D897C756E5E482F
2B30120A10141B161D2635303B40415F828C7C7C7B664E34
0C0000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000100128A766D6565593A
352C121119161721233635314D5658697E7772826F605016
000100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000038196877A776951
492D121B1D1F19292B3C384765687480766C796958482100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001068999288817267
512D1B1E1C1A282638404355737B78786C6A5B4A49240000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001B589092867A7567
47291F231F232E304F4C5866727A79797253494017000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001D58878E88796B5D
4028282527372B4A595A6A787375797D6649310800000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000001010D59839186756556
40322F2B36314661606A757E79757D734B1C000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001040302467B897B6A5F4F
4036323A39475A6568797F83807C6D460E00000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000002030200206F8477625D52
463C42484D595E6771798182756142140001000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001010102083C7E7B6A655D
4A4650575E63656D757A735D4B4026000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010304081645626E6E67
59555A5C5E65696C695C5149413409000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010A0D0A1B233C53605F
605F5D606265646057504D42391700000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010100030D19181D272B3D5256
585E626364675F5953504B43250000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000102070E1B201E22262E4556
5D646664615D5B5858524D32030000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000002050C0F1A25262320212E3F
525B62655E5B5B5A59554310000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000001030A0E101929363F44433E46
555D606263605D5E5B552C00000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000202080C0E121A293E5666717171
717273706963615F5D450800000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010001020306080A0D121C2737434E5E656B
6F71706B615F5E5F5D1E0000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010003030404050B11151B26313B454E555D
676E716D6A6D6B7145000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010102020201060C11171D27313D474E5A68
6F757B7A7473715E0E000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010101010203050A0E131C2228323F4B54616E
777C7D7B756D672D00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000101000004090B0F141A21272D36434D596772
78797876746E490300000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000010001030202040A0C1116191E232B313A45525C6776
777477776D5B1A0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020102020203070C1015191D21272E343E4A5A636B76
736F70685E37010100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020203020102060A0C10161D1F242E3235404E5C686D6F
6E6B695E4F0E000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01050505030306080B1114171D20232C313C45536064666A
69675C562800000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
020506050609080C101013161D222429303B48535B636664
615E55410700000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000003
0506090A0A0A0E0E101112171C1E2228313E4856595C5C59
595348180000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooolT000000H00@410P00000300410@<00`<31@020P8300P820<0
2`/;0P0E5AD301XJ6P<07AdM0`0N7Qh2020P80<08b<S0`0U9BD3028R8P80820P0`0M7Ad301TI6@<0
4a<C0P0@410600`<30<03Ph>0P0E5AD301dM7@<08b<S200[:b/3024Q8@<0410@0P0820P300410Hh0
0000203oool000H0oooo9000000600410@8000000`010@4300<30`D00P820`0820P300/;2`805ADE
0`0J6QX301dM7@<07QhN0P0P820302<S8`<09BDU0`0R8R82020P80<07AdM0`0I6AT301<C4`80410@
1P0<30`300h>3P805ADE0`0M7Ad302<S8`P0:b/[0`0Q8B43010@408020P80`010@6>000000P0oooo
00060?ooocD000000P010@4300820P<01PH60P0>3Ph301PH60H07alO0P0Q8B4302DU9@<0:2PX0`0Z
:RX202LW9`<09RHV0`0Q8B4301/K6`8051@D0`0=3@d300/;2`<03`l?0P0G5aL301hN7P<0:BTY0`11
@D42055AD@<0F5QH0`1CDe<303Ph>0805aLG0`061PH300410H/00000203oool000H0oooo=@000002
00410@<00P820`061PH200h>3P<061PH1P0O7al2024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3
024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l201LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P3
05=CD`<0>3Ph0P0G5aL300H61P<00@41R`0000080?ooo`001P3ooole000000800@410`020P8300H6
1P803Ph>0`0H61P601lO7`808B4Q0`0U9BD302PX:0<0:RXZ0P0W9bL302HV9P<08B4Q0`0K6a/201@D
50<03@d=0`0;2`/300l?3`805aLG0`0N7Qh302TY:@<0@D510P1ADE4305QHF0<0De=C0`0h>3P201LG
5`<01PH60`010@6;000000P0oooo00060?ooocD000000P010@43000000<00@410P071`L3010@40<0
6a/K0`0O7al2028R8P<0:BTY0`0];Bd3030`<080;bl_0`0];Bd302TY:@<08b<S0P0I6AT3010@40<0
30`<0`0?3`l200d=3@<05aLG0`0V9RH303De=@80<S8b0`0a<C4303Lg=`<0>c/k0P0Z:RX301DE5@<0
1`L7R`0000080?ooo`001P3ooole000000800@410`00000300410@801`L70`0@410301/K6`<07alO
0P0R8R8302TY:@<0;Bd]0`0`<30202l_;`<0;Bd]0`0Y:BT302<S8`806ATI0`0@410300`<30<03`l?
0P0=3@d301LG5`<09RHV0`0e=CD2038b<P<0<C4a0`0g=cL303/k>`80:RXZ0`0E5AD300L71h/00000
203oool000H0oooo=@00000200410@<000000`010@4200L71`<0410@0`0K6a/301lO7`808R8R0`0Y
:BT302d];@<0<30`0P0_;bl302d];@<0:BTY0`0S8b<201TI6@<0410@0`0<30`300l?3`803@d=0`0G
5aL302HV9P<0=CDe0P0b<S83034a<@<0=cLg0`0k>c/202XZ:P<05ADE0`071`N;000000P0oooo0006
0?ooocX000001@010@4300D51@<03Ph>0`0J6QX2024Q8@<0:BTY1P0c<c<503@d=0<0<c<c0`0[:b/2
024Q8@H071`L0`0J6QX201DE5@<071`L0`0N7Qh301PH60804A4A0`0E5AD301LG5`<06a/K0P0E5AD3
01`L70<07alO0P0F5QH300P820P010@40`030`<300410GP00000203oool000H0oooo>P0000050041
0@<01@D50`0>3Ph301XJ6P808B4Q0`0Y:BT603<c<`D0=3@d0`0c<c<302/[:`808B4Q1P0L71`301XJ
6P805ADE0`0L71`301hN7P<061PH0P0A4A4301DE5@<05aLG0`0K6a/201DE5@<071`L0`0O7al201HF
5P<020P8200410@300<30`<00@41N00000080?ooo`001P3ooolo000000<00@410`030`<300T92@80
5aLG0`0U9BD3038b<P<0=CDe0P0f=SH303Xj>P<0=CDe0`0a<C4502`/;0<0;bl_0`0Z:RX202@T90<0
;2`/0`0O7al300l?3`802PX:0`0=3@d6018B4P8030`<0`0?3`l301DE5@806ATI0`0J6QX301PH60<0
71`L0P0Q8B4302<S8`<08R8R0`0F5QH2014A4@<02PX:0`051@D500410FP00000203oool000H0oooo
?`00000300410@<00`<30`092@T201LG5`<09BDU0`0b<S8303De=@80=SHf0`0j>SX303De=@<0<C4a
1@0/;2`302l_;`<0:RXZ0P0T92@302`/;0<07alO0`0?3`l200X:2P<03@d=1P0B4Q8200`<30<03`l?
0`0E5AD201TI6@<06QXJ0`0H61P301`L70808B4Q0`0S8b<3028R8P<05QHF0P0A4A4300X:2P<01@D5
1@010@5X000000P0oooo00060?ooocl000000`010@4300<30`<02@T90P0G5aL302DU9@<0<S8b0`0e
=CD203Hf=P<0>SXj0`0e=CD3034a<@D0;2`/0`0_;bl302XZ:P8092@T0`0/;2`301lO7`<03`l?0P0:
2PX300d=3@H04Q8B0P0<30`300l?3`<05ADE0P0I6AT301XJ6P<061PH0`0L71`2024Q8@<08b<S0`0R
8R8301HF5P804A4A0`0:2PX300D51@D00@41J00000080?ooo`001P3ooom5000000<00@410P0410@3
01<C4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT3
03hn?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph3
00@410<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`3
00d=3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C
4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn
?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@4
10<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=
3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C4`<0
:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn?P<0
:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@410<0
1`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=3@80
20P80`030`<6000000800@41DP0000080?ooo`001P3ooom=000000<03Ph>0`0T92@202h^;P<0=SHf
0`0h>3P303Ti>@D0?3`l0`0d=3@502TY:@<0A4A40`0k>c/302TY:@802`/;0`0820P301hN7P<06a/K
0P0F5QH303hn?P<09bLW0P0>3Ph600P820<01@D50P00000300820P<01@D50`020P8200T92@<05aLG
0`0E5AD301`L70806ATI0`0J6QX3028R8P<071`L0P0I6AT300l?3`<01`L70`010@5D000000P0oooo
00060?ooodd000000`0>3Ph302@T9080;Rh^0`0f=SH303Ph>0<0>CTi1@0l?3`303@d=0D0:BTY0`14
A4@303/k>`<0:BTY0P0;2`/300P820<07QhN0`0K6a/201HF5P<0?Shn0`0W9bL200h>3PH020P80`05
1@D2000000<00P820`051@D300820P802@T90`0G5aL301DE5@<071`L0P0I6AT301XJ6P<08R8R0`0L
71`201TI6@<03`l?0`071`L300410E@00000203oool000H0ooooC@00000300h>3P<092@T0P0^;Rh3
03Hf=P<0>3Ph0`0i>CT503`l?0<0=3@d1@0Y:BT304A4A0<0>c/k0`0Y:BT200/;2`<020P80`0N7Qh3
01/K6`805QHF0`0n?Sh302LW9`803Ph>1P0820P300D51@8000000`020P8300D51@<00P820P092@T3
01LG5`<05ADE0`0L71`201TI6@<06QXJ0`0R8R8301`L70806ATI0`0?3`l300L71`<00@41E0000008
0?ooo`001P3ooom@000000<02PX:0P0Q8B43034a<@<0=CDe0`0i>CT203dm?@<0>c/k0`0b<S8302DU
9@80;bl_0`1FEUH304a<C0<09RHV0P0=3@d300<30`<0DE5A0`2QXJ4202h^;P<0?clo0`0d=3@200/;
2`<03`l?0`061PH300@410800@410`0K6a/302HV9P<06a/K0P0410@300H61P<01@D50`0410@200H6
1P<020P80`0=3@d300h>3P805ADE0`0L71`301/K6`<030`<0P030`<300410Dl00000203oool000H0
ooooD000000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0<S8b0`0U9BD202l_;`<0
EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0=3@d0P0;2`/300l?3`<0
1PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<010@40P061PH300P820<0
3@d=0`0>3Ph201DE5@<071`L0`0K6a/300`<30800`<30`010@5?000000P0oooo00060?oooe<00000
0P0820P301hN7P<0;Bd]0`0e=CD203Xj>P<0>3Ph0`0b<S8302HV9P80;Bd]0`1?Cdl304U9B@<07alO
0P0E5AD300P820<06QXJ0`1dM7@208:2PP<0ATI60`0L71`500L71`<02`/;0`010@4201DE5@<0=SHf
0`1:BTX304m?C`807QhN0`020P83000000D00@410`051@D600L71`802`/;0`0F5QH301dM7@<061PH
0P0<30`300D51@<00P82C00000080?ooo`001P3ooomC0000008020P80`0N7Qh302d];@<0=CDe0P0j
>SX303Ph>0<0<S8b0`0V9RH202d];@<0Cdm?0`19BDT301lO7`805ADE0`0820P301XJ6P<0M7Ad0P22
PX8304I6AP<071`L1@071`L300/;2`<00@410P0E5AD303Hf=P<0BTY:0`1?Cdl201hN7P<00P820`00
000500410@<01@D51P071`L200/;2`<05QHF0`0M7Ad301PH608030`<0`051@D300820T`00000203o
ool000H0ooooD`00000200P820<07QhN0`0];Bd303De=@80>SXj0`0h>3P3038b<P<09RHV0P0];Bd3
04m?C`<0BDU90`0O7al201DE5@<020P80`0J6QX307AdM080PX:20`16ATH301`L70D01`L70`0;2`/3
00410@805ADE0`0f=SH304Y:BP<0Cdm?0P0N7Qh300820P<000001@010@4300D51@H01`L70P0;2`/3
01HF5P<07AdM0`0H61P200`<30<01@D50`020P9<000000P0oooo00060?oooeD000000`071`L301dM
7@<0;Rh^1@0g=cL303@d=0<0;2`/0P0[:b/3038b<P<0>SXj0`0H61P200d=3@<04a<C0`0O7al303Hf
=P80DU9B0`17AdL302LW9`803Ph>1P00000301XJ6P80?clo0`0h>3P302d];@<09BDU0P0_;bl3028R
8P<04a<C0`0:2PX200@410<01@D50`0410@300/;2`802PX:0`0>3Ph3014A4@<051@D0P0E5AD300d=
3@<00`<3C00000080?ooo`001P3ooomE000000<01`L70`0M7Ad302h^;PD0=cLg0`0d=3@302`/;080
:b/[0`0b<S8303Xj>P<061PH0P0=3@d301<C4`<07alO0`0f=SH2059BDP<0AdM70`0W9bL200h>3PH0
00000`0J6QX203lo?`<0>3Ph0`0];Bd302DU9@80;bl_0`0R8R8301<C4`<02PX:0P0410@300D51@<0
10@40`0;2`/200X:2P<03Ph>0`0A4A4301@D50805ADE0`0=3@d300<30d`00000203oool000H0oooo
E@00000300L71`<07AdM0`0^;Rh503Lg=`<0=3@d0`0/;2`202/[:`<0<S8b0`0j>SX301PH60803@d=
0`0C4a<301lO7`<0=SHf0P1BDU8304M7A`<09bLW0P0>3Ph6000000<06QXJ0P0o?cl303Ph>0<0;Bd]
0`0U9BD202l_;`<08R8R0`0C4a<300X:2P8010@40`051@D300@410<02`/;0P0:2PX300h>3P<04A4A
0`0D51@201DE5@<03@d=0`030`=<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d
=3@303Lg=`<0<30`0P0b<S8302d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1d
M7@305=CD`80410@0`00000301@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O
7al301dM7@803Ph>0`030`<300@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`01
0@5<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d=3@303Lg=`<0<30`0P0b<S83
02d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1dM7@305=CD`80410@0`000003
01@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O7al301dM7@803Ph>0`030`<3
00@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`010@5<000000P0oooo00060?oo
oe/000000`051@D201dM7@<0<30`0`0d=3@3034a<@80<30`0`0^;Rh301lO7`<0?clo0P2[Zj/30=3@
d0<0eMGE0`3=cLd20;Ng]`<0TI6A0`0f=SH200410@<02`/;0`16ATH305ADE080EUIF0`1MGEd3061P
H0<0I6AT0P1EEED304a<C0<0?clo0`0V9RH200d=3@<02@T91P051@D200<30`<01@D50`0=3@d301@D
50807AdM0`0@410800410DL00000203oool000H0ooooF`00000300D51@807AdM0`0`<30303@d=0<0
<C4a0P0`<30302h^;P<07alO0`0o?cl20:^[Z`<0d=3@0`3EeMD30<g=c@80]kNg0`2ATI4303Hf=P80
0@410`0;2`/304I6AP<0E5AD0P1FEUH305eMG@<0H61P0`1TI6@205EEE@<0C4a<0`0o?cl302HV9P80
3@d=0`092@T600D51@800`<30`051@D300d=3@<051@D0P0M7Ad3010@40P00@41A`0000080?ooo`00
1P3ooomK000000<01@D50P0M7Ad3030`<0<0=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[
0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM
0`1PH60306ATI080EEEE0`1<C4`303lo?`<09RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=
0`0D51@201dM7@<0410@20010@57000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e
=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P06
1PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15
ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P01
0@51000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<3
01PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<2
06UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<2
00410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?oo
oeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn
_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eM
G@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A
4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?ooof0000000`030`<301dM7@<0
<c<c0P0b<S8302`/;0<08R8R0`0K6a/200h>3P<02`/;0`0<30`300P820800@411P00000202<S8`<0
Hf=S0`1YJFT306ATI080FUYJ0`1?Cdl3051@D0<0B4Q80P15ADD30451@@<0CTi>0`1IFET2055AD@<0
EeMG0`0i>CT301TI6@800`<30`051@D300/;2`<04a<C0P0A4A4300P820h00@41@@0000080?ooo`00
1P3ooomP000000<00`<30`0M7Ad303<c<`80<S8b0`0/;2`3028R8P<06a/K0P0>3Ph300/;2`<030`<
0`0820P200410@H000000P0S8b<306=SH`<0JFUY0`1TI6@205YJFP<0Cdm?0`1@D50304Q8B080ADE5
0`11@D4304i>CP<0FEUI0P1ADE4305MGE`<0>CTi0`0I6AT200<30`<01@D50`0;2`/301<C4`804A4A
0`0820P>00410D400000203oool000H0ooooH000000300<30`<07AdM0`0c<c<2038b<P<0;2`/0`0R
8R8301/K6`803Ph>0`0;2`/300`<30<020P80P010@46000000808b<S0`1SHf<306UYJ@<0I6AT0P1J
FUX304m?C`<0D51@0`18B4P204E5A@<0@D510`1>CTh305UIF@80DE5A0`1GEeL303Ti>@<06ATI0P03
0`<300D51@<02`/;0`0C4a<2014A4@<020P83P010@51000000P0oooo00060?ooof<000000`0410@3
024Q8@80<S8b0`0a<C4302<S8`<07AdM0P0B4Q8300H61P<00@411@00000300820P<04a<C0P0j>SX3
05MGE`<0EUIF0`1?Cdl204E5A@<0?Shn0`0l?3`303Hf=P80;bl_0`0c<c<303dm?@<0@D510P13@d<3
03dm?@<0;Rh^0`0V9RH201dM7@<02@T90`0A4A43024Q8@804A4A0`061PH300410@<000000P030`<;
00410C`00000203oool000H0ooooH`00000300@410<08B4Q0P0b<S83034a<@<08b<S0`0M7Ad2018B
4P<01PH60`010@45000000<00P820`0C4a<203Xj>P<0EeMG0`1FEUH304m?C`80ADE50`0n?Sh303`l
?0<0=SHf0P0_;bl303<c<`<0?Cdm0`11@D4204=3@`<0?Cdm0`0^;Rh302HV9P807AdM0`092@T3014A
4@<08B4Q0P0A4A4300H61P<00@410`00000200<30`/00@41?00000080?ooo`001P3ooomV000000<0
1`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080
>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80
Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P0
0@41?00000080?ooo`001P3ooomV000000<01`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<
0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg
0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L
0`0Q8B4200X:2PH00`<30`00000500@410P00@41?00000080?ooo`001P3ooomV000000<01`L70P0P
8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17
AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1g
MgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P00@41?000
00080?ooo`001P3ooomY000000801PH60`0R8R8302l_;`<09RHV0P0K6a/300d=3@<02@T90`071`L2
01HF5PH07AdM0P0[:b/303/k>`<0@4101@0l?3`30451@@<0CDe=0`1PH602096AT@<0_Kfm0`3;bl/3
0<?3``80_[jn1P2^[Zh309nOW`80Jf][1P0J6QX3018B4PD01PH60`051@D300P820801@D50`020P88
00410C`00000203oool000H0ooooJ@00000200H61P<08R8R0`0_;bl302HV9P806a/K0`0=3@d300T9
2@<01`L70P0F5QH601dM7@80:b/[0`0k>c/30410@0D0?3`l0`11@D4304e=C@<0H61P0P2ATI430;fm
_@<0bl_;0`33`l<20;jn_PH0[Zj^0`2OWil206][J`H06QXJ0`0B4Q8500H61P<01@D50`0820P200D5
1@<00P8220010@4l000000P0oooo00060?ooofT000000P061PH3028R8P<0;bl_0`0V9RH201/K6`<0
3@d=0`092@T300L71`805QHF1P0M7Ad202/[:`<0>c/k0`10@40503`l?0<0@D510`1=CDd3061PH080
TI6A0`2m_Kd30<_;b`<0`l?30P2n_[h60:j^[P<0WinO0P1[Jf/601XJ6P<04Q8B1@061PH300D51@<0
20P80P051@D300820PP00@41?00000080?ooo`001P3ooom[000000<01`L70`0X:2P302`/;08030`<
0`061PH300T92@<04A4A0P0F5QH301DE5@<06QXJ0P0W9bL3030`<0<0>CTi0`10@40204];B`<0FEUI
0`1UIFD307inOP80N7Qh0`24Q8@30:^[Z`<0e]KF0P3Vi^H30=kNgP<0c/k>0`35aLD20:FUY@<0>SXj
0`0I6AT3018B4P8051@D1P092@T3010@40802`/;0`00000;00410CT00000203oool000H0ooooJ`00
000300L71`<0:2PX0`0/;2`200`<30<01PH60`092@T3014A4@805QHF0`0E5AD301XJ6P809bLW0`0`
<30303Ti>@<0@4100P1;Bd/305UIF@<0IFEU0`1nOWh207QhN0<0Q8B40`2[Zj/30=KFeP80i^KV0`3N
g]h30<k>cP<0aLG50P2UYJD303Xj>P<06ATI0`0B4Q8201@D50H02@T90`0@410200/;2`<000002`01
0@4i000000P0oooo00060?ooof/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A42
01HF5P<05ADE0`0J6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`1IFET306EUI@<0OWin0P1hN7P3
08B4Q0<0Zj^[0`3Fe]H20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@6
00T92@<0410@0P0;2`/3000000/00@41>@0000080?ooo`001P3ooomV000000<01@D50P0@410300H6
1P<02PX:0`0820P2000000<01@D50`0>3Ph3014A4@80410@0`0C4a<301dM7@80:BTY0`0c<c<303dm
?@<0Bd];0P1KFe/3079bLP<0T92@0`2=SHd206=SH`<0=cLg0`12@T8308R8R080`L710`3Jf]X30=cL
g0<0d=3@0P31`L4305=CD`<092@T0`0O7al201LG5`<03@d=0`0E5AD301dM7@802@T90`00000;0041
0CT00000203oool000H0ooooIP00000300D51@80410@0`061PH300X:2P<020P80P00000300D51@<0
3Ph>0`0A4A42010@40<04a<C0`0M7Ad202TY:@<0<c<c0`0m?Cd304];B`80Fe]K0`1bLW83092@T0<0
SHf=0P1SHf<303Lg=`<0@T920`28R8P20<71`@<0f][J0`3Lg=`30=3@d080`L710`1CDe<302@T90<0
7alO0P0G5aL300d=3@<05ADE0`0M7Ad200T92@<000002`010@4i000000P0oooo00060?ooof<00000
0`030`<3024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c
0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf
0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@41
1P00000;00410CH00000203oool000H0ooooH`00000300<30`<08B4Q0P0];Bd3010@40H00P820P05
1@D300/;2`H03`l?0P0@410301LG5`<08b<S0P0c<c<30451@@<0BTY:0`1PH602075aL@<0Rh^;0`2C
Ti<309nOW`80Zj^[0`1fMWH3034a<@<04a<C0P0f=SH306m_K`<0V9RH0`2XZ:P20:JVYP<0KFe]0`1F
EUH303lo?`809RHV0`0G5aL301hN7P<061PH0P010@46000000/00@41=P0000080?ooo`001P3ooomS
000000<00`<30`0Q8B4202d];@<0410@1P020P8200D51@<02`/;1P0?3`l2010@40<05aLG0`0S8b<2
03<c<`<0@D510`1:BTX3061PH080LG5a0`2;Rh/309>CT`<0WinO0P2[Zj/307IfMP<0<C4a0`0C4a<2
03Hf=P<0Kfm_0`2HV9P30:RXZ080YZJV0`1]KFd305IFEP<0?clo0P0V9RH301LG5`<07QhN0`0H61P2
00410@H000002`010@4f000000P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI
6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6
QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]K
F`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f0000
00P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H0
3`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0
820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0
W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f000000P0oooo00060?ooof000000
0`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R
0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]
0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG
0`071`L200410@H000002`010@4f000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?
3`l300h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2G
UiL30:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20
P80307]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`02
0P8300410@D000001P010@4^000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?3`l3
00h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2GUiL3
0:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20P803
07]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`020P83
00410@D000001P010@4^000000P0oooo00060?oooeD000000`010@43000000<01@D50P0X:2P302/[
:`<071`L0`0T92@2024Q8@<07alO0`0D51@301<C4`8071`L0`0R8R83034a<@<0DU9B0P1VIVH307]k
N`<0S8b<0P2ATI460::RXP<0ZZZZ0P2OWil30:n_[`<0];Bd0`2c/k<209NGU`<0Hf=S0`0e=CD302TY
:@80Kfm_0`2f][H30=7Ad@<0bLW90P2k^k/60;Bd]0<0YZJV0P2TY:@306EUI@<03Ph>0`061PH500D5
1@<01PH60P071`L300@410<00@411@00000600<30bh00000203oool000H0ooooE@00000300410@<0
00000`051@D202PX:0<0:b/[0`0L71`302@T90808B4Q0`0O7al301@D50<04a<C0P0L71`3028R8P<0
<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80
UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0
IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@40`010@45000000H00`<3;P0000080?ooo`00
1P3ooomE000000<00@410`00000300D51@80:2PX0`0[:b/301`L70<092@T0P0Q8B4301lO7`<051@D
0`0C4a<201`L70<08R8R0`0a<C43059BDP80IVIV0`1kNg/308b<S080TI6A1P2RXZ830:ZZZP80WinO
0`2_[jl30;Bd]0<0/k>c0P2GUiL306=SH`<0=CDe0`0Y:BT206m_K`<0][Jf0`3AdM430<W9b@80^k^k
1P2d];@30:JVYP80Y:BT0`1UIFD300h>3P<01PH61@051@D300H61P801`L70`0410@300410@D00000
1P030`<^000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0M7Ad300T92@D00P820`0=
3@d301@D50<07QhN0P0b<S8304m?C`<0LG5a0`29RHT209BDU0<0Vi^K0`2RXZ820:FUY@<0[jn_0`2O
Wil30:NWY`80/;2`0`2QXJ4308Z:RP<0SHf=0P2WYjL30:ZZZP<0/K6a0`27QhL203De=@<0?3`l0`1A
DE4308b<S080]kNg0`2j^[X30:b/[0<0UIFE0P1[Jf/300X:2P<01@D51@0410@300L71`<020P80P06
1PH300@410<00@411@00000300X:2P<02@T9;P0000080?ooo`001P3ooomH000000<01PH60`0K6a/2
030`<0<07AdM0`092@T500820P<03@d=0`0D51@301hN7P80<S8b0`1?Cdl3075aL@<0RHV90P2DU9@3
09^KV`<0XZ:R0P2UYJD30:n_[`<0WinO0`2WYjL20;2`/0<0XJ6Q0`2:RXX308f=S@80YjNW0`2ZZZX3
0;6a/@<0QhN70P0e=CD303`l?0<0DE5A0`2<S8`20;Ng]`<0^[Zj0`2/[:`309FEU@80Jf][0`0:2PX3
00D51@D010@40`071`L300P820801PH60`0410@300410@D000000`0:2PX300T92Bh00000203oool0
00H0ooooF000000300H61P<06a/K0P0`<30301dM7@<02@T91@020P8300d=3@<051@D0`0N7Qh2038b
<P<0Cdm?0`1aLG4308V9R@80U9BD0`2KVi/30::RXP80YJFU0`2_[jl309nOW`<0YjNW0P2`/;030:6Q
X@<0RXZ:0`2=SHd20:NWY`<0ZZZZ0`2a/K4308N7Q`80=CDe0`0l?3`3055AD@<0S8b<0P2g]kL30;Zj
^P<0[:b/0`2EUID206][J`<02PX:0`051@D500@410<01`L70`0820P200H61P<010@40`010@450000
00<02PX:0`092@T^000000P0oooo00060?oooe0000000`010@42000000<00`<30`0A4A43024Q8@80
<c<c0`0b<S83030`<0<0;2`/0P0H61P300h>3P<07AdM0`0f=SH205MGE`<0QhN70`2QXJ450:JVYP<0
ZZZZ0`2/[:`20;>c/`<0^k^k0`2`/;030:ZZZP80SXj>0`0h>3P301@D50<0:RXZ0P1VIVH308F5Q@<0
X:2P0`2e]KD209FEU@<0Ogmo0`1XJ6P306][J`80[Jf]0`2l_;`30:NWY`<0Shn?0P1IFET301hN7P<0
7alO0`0<30`200l?3`<03@d=0`0:2PX200L71`<010@40`071`L300@410802@T90`0G5aL300H61Rh0
0000203oool000H0ooooD000000300410@8000000`030`<3014A4@<08B4Q0P0c<c<3038b<P<0<30`
0`0/;2`201PH60<03Ph>0`0M7Ad303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c
0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE
0`1oOgl306QXJ0<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?
0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3o
oom@000000<00@410P00000300<30`<04A4A0`0Q8B4203<c<`<0<S8b0`0`<30302`/;08061PH0`0>
3Ph301dM7@<0=SHf0P1GEeL308N7Q`<0XJ6Q1@2VYZH30:ZZZP<0[:b/0P2c/k<30;^k^`<0/;2`0`2Z
ZZX208j>SP<0>3Ph0`0D51@302XZ:P80IVIV0`25QHD30:2PX0<0]KFe0P2EUID307moO`<0J6QX0`1[
Jf/20:f][@<0_;bl0`2WYjL308n?S`80FEUI0`0N7Qh301lO7`<030`<0P0?3`l300d=3@<02PX:0P07
1`L300@410<01`L70`0410@200T92@<05aLG0`061PH^000000P0oooo00060?oooe<000000P030`<3
01LG5`<08R8R0`0S8b<202l_;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@3
0:>SX`<0YJFU0`2KVi/209RHV0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG43
03<c<`<020P80P0O7al3069RHP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<3
09:BTP<0M7Ad0P14A4@303Xj>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83
024Q8@803`l?0`0820Pa000000P0oooo00060?oooe<000000P030`<301LG5`<08R8R0`0S8b<202l_
;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@30:>SX`<0YJFU0`2KVi/209RH
V0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG4303<c<`<020P80P0O7al3069R
HP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<309:BTP<0M7Ad0P14A4@303Xj
>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83024Q8@803`l?0`0820Pa0000
00P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0
820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80
/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80
cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80
CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe000000
0`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l
0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`
0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<
0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN
0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i
>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=
SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1T
I6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1I
FET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P05
1@Dd000000P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH3
00L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH603
08:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl2
0;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd2
06][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oo
oe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d]
;@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3
``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30
`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=C
D`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oooe0000000`0A4A42038b<P<0
;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0
A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0
Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0
?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`80
00000`010@4a000000P0oooo00060?oooe0000000`0P8202034a<@<09BDU0`0O7al302`/;080:2PX
0`0H61P3010@40<03@d=0P0J6QX302/[:`<0<c<c0`0R8R82014A4@<02PX:0`0T92@305]KF`80PX:2
0`2@T90308F5Q@80Shn?0`2i^KT30;Rh^0<0/;2`0P2DU9@307emO@<0ZJVY0`31`L420:BTY0<0UiNG
0`2PX:030:FUY@80]KFe0`3?cll30=3@d0<0^[Zj0P1BDU8300T92@<04Q8B0`0T92@201PH60<0:2PX
0`1WIfL306IVIP80H61P0`2TY:@30;:b/P80R8R80`1;Bd/301/K6cT00000203oool000H0ooooD000
0003020P8080<C4a0`0U9BD301lO7`<0;2`/0P0X:2P301PH60<0410@0`0=3@d201XJ6P<0:b/[0`0c
<c<3028R8P804A4A0`0:2PX302@T90<0Fe]K0P22PX83092@T0<0QHF50P2?Shl30;Vi^@<0^;Rh0`2`
/;0209BDU0<0OGem0`2YZJT30<71`@80Y:BT0`2GUiL30:2PX0<0YJFU0P2e]KD30<o?c`<0d=3@0`2j
^[X2059BDP<02@T90`0B4Q8302@T908061PH0`0X:2P306MWI`<0IVIV0P1PH6030:BTY0<0/[:b0P28
R8P304];B`<06a/K>@0000080?ooo`001P3ooom=000000<01@D50`0b<S8202d];@<0:BTY0`0W9bL3
028R8P80;Bd]0`0/;2`301HF5P<02PX:0P0C4a<302TY:@<0>CTi0`0L71`201HF5P<051@D0`0I6AT3
034a<@80KVi^0`1mOGd30:6QX@80W9bL0`2IVIT30:>SX`<0UIFE0P23Ph<30:6QX@<0g]kN0`39bLT2
0;Bd]0<0Zj^[0`2KVi/30:JVYP80alO70`3<c<`30=7Ad@<0TY:B0P0R8R8301PH60<051@D0`0@4102
00/;2`<04Q8B0`1;Bd/307moO`80I6AT0`1/K6`30:2PX080R8R80`0Z:RX;00410C400000203oool0
00H0ooooC@00000300D51@<0<S8b0P0];Bd302TY:@<09bLW0`0R8R8202d];@<0;2`/0`0F5QH300X:
2P804a<C0`0Y:BT303Ti>@<071`L0P0F5QH301@D50<06ATI0`0a<C4206i^KP<0OGem0`2QXJ4209bL
W0<0VIVI0`2SXj<309FEU@80Ph>30`2QXJ430=kNgP<0bLW90P2d];@30:^[Z`<0Vi^K0`2VYZH20<O7
a`<0c<c<0`3AdM4309:BTP808R8R0`0H61P301@D50<0410@0P0;2`/3018B4P<0Bd];0`1oOgl206AT
I0<0K6a/0`2PX:0208R8R0<0:RXZ2`010@4a000000P0oooo00060?ooodd000000`051@D3038b<P80
;Bd]0`0Y:BT302LW9`<08R8R0P0];Bd302`/;0<05QHF0`0:2PX201<C4`<0:BTY0`0i>CT301`L7080
5QHF0`0D51@301TI6@<0<C4a0P1^KVh307emO@<0XJ6Q0P2LW9`309VIV@<0Xj>S0`2EUID208>3P`<0
XJ6Q0`3Ng]h30<W9b@80];Bd0`2[Zj/309^KV`<0YZJV0P37alL30<c<c0<0dM7A0`2BTY82028R8P<0
61PH0`0D51@3010@40802`/;0`0B4Q8304];B`<0Ogmo0P1TI6@306a/K0<0X:2P0P28R8P302XZ:P/0
0@41<@0000080?ooo`001P3ooom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ
0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI
0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl
0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH6
0`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3o
oom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E
5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`
L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<
c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@
D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3ooom=000000<010@40`1>CTh2
06a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`2
02h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH3
09^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3
038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83
000000D00P82=00000080?ooo`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG
5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^
KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2
`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q830082
0P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?oo
o`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T9080
7alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0
>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0
]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0
IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<010@4
0`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM
0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q
0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI
0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T9
0`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g
=cL3030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2O
Wil30861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2L
W9`20:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o
?cl201hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P06
1PH300T92@<00`<3;P0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g=cL3
030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2OWil3
0861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2LW9`2
0:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o?cl2
01hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P061PH3
00T92@<00`<3;P0000080?ooo`001P3ooom=000000<0;2`/0`3De=@208:2PP<0G5aL0`1VIVH302XZ
:P806ATI0`0[:b/303`l?0<0:b/[0P0N7Qh303lo?`<0N7Qh0`2XZ:P20<K6aP<0gMgM0`3:b/X30;jn
_P80XJ6Q0`1KFe/302`/;0804a<C0`0<30`301`L70<0Ng]k0P3Cdm<30;jn_P<0Ph>30`24Q8@207al
O0<0N7Qh0`28R8P309VIV@D0Vi^K0`2e]KD308B4Q080O7al0`2<S8`3061PH0<08R8R0P0E5AD300X:
2P<00P820`071`L202XZ:P<0EUIF0`1EEED204I6AP<0;Bd]0`0?3`l30000008010@40`0>3Ph300P8
22h00000203oool000H0ooooC@00000302`/;0<0e=CD0P22PX8305aLG0<0IVIV0`0Z:RX201TI6@<0
:b/[0`0l?3`302/[:`807QhN0`0o?cl307QhN0<0Z:RX0P36a/H30=gMg@<0b/[:0`2n_[h20:6QX@<0
Fe]K0`0/;2`201<C4`<030`<0`0L71`307]kN`80dm?C0`2n_[h308>3P`<0Q8B40P1lO7`307QhN0<0
R8R80`2IVIT509^KV`<0]KFe0`24Q8@207alO0<0S8b<0`1PH603028R8P805ADE0`0:2PX300820P<0
1`L70P0Z:RX305IFEP<0EEEE0P16ATH302d];@<03`l?0`00000200@410<03Ph>0`0820P^000000P0
oooo00060?ooodd000000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0?3`l
0`0[:b/201hN7P<0?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/
0P0C4a<300`<30<071`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI
1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ
0`1FEUH305EEE@80ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P8;P0000080?ooo`001P3o
oom=000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l
?3`304A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1n
OWh30:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2V
YZH30:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1X
J6P205YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=
000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`3
04A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh3
0:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH3
0:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P2
05YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=0000
00<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`304A4
A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh30:6Q
X@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH30:VY
Z@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P205YJ
FP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom@000000<0
Cdm?0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80
YjNW0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0
]KFe0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0
TI6A0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0
=cLg0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0Cdm?
0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80YjNW
0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0]KFe
0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0TI6A
0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0=cLg
0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0;Bd]0P1S
Hf<309FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2H
V9P309nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26
QXH302HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2B
TY8308F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H
61P200820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<3
09FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P3
09nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH3
02HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY83
08F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P2
00820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<309FE
U@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P309nO
W`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH302HV
9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY8308F5
Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P20082
0P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0C4a<0P1UIFD303hn?P<0
Vi^K0`2/[:`20:^[Z`<0YZJV0`1hN7P307IfMP80KVi^0`1OGel305=CD`<0Fe]K0P25QHD30:RXZ0<0
][Jf0`37alL20=7Ad@<0f][J0`3Ph>020>GUi@H0jn_[0`3/k>`20>KViP<0gmoO0`3;bl/30861P@80
@D510`1?Cdl307YjNP<0K6a/0P1[Jf/305YJFP<0BTY:0`1EEED206UYJ@<0QhN70`2=SHd308B4Q080
IfMW0`1>CTh302HV9PD01PH60`0U9BD305=CD`D0Ogmo0`1CDe<301hN7P801@D50`0/;2`304U9B@<0
:RXZ0P0410@Y000000P0oooo00060?oooe0000000`1<C4`206EUI@<0?Shn0`2KVi/30:b/[080Zj^[
0`2VYZH307QhN0<0MWIf0P1^KVh305mOG`<0De=C0`1KFe/208F5Q@<0Z:RX0`2f][H30<O7a`80dM7A
0`3Jf]X30>3Ph080iNGU1P3[jn/30>c/k080i^KV0`3Ogml30<_;b`<0PH610P11@D4304m?C`<0NWYj
0`1/K6`206][J`<0FUYJ0`1:BTX305EEE@80JFUY0`27QhL308f=S@<0Q8B40P1WIfL304i>CP<09RHV
1@061PH302DU9@<0De=C1@1oOgl305=CD`<07QhN0P051@D302`/;0<0BDU90`0Z:RX200@412T00000
203oool000H0ooooD000000304a<C080IFEU0`0n?Sh309^KV`<0[:b/0P2[Zj/30:JVYP<0N7Qh0`1f
MWH206i^KP<0GemO0`1CDe<305]KF`80QHF50`2XZ:P30;Jf]P<0alO70P3AdM430=[JfP<0h>3P0P3U
iND60>_[j`<0k>c/0P3Vi^H30=oOg`<0bl_;0`21PH420451@@<0Cdm?0`1jNWX306a/K080Jf][0`1J
FUX304Y:BP<0EEEE0P1YJFT308N7Q`<0SHf=0`24Q8@206MWI`<0CTi>0`0V9RH500H61P<09BDU0`1C
De<507moO`<0De=C0`0N7Qh200D51@<0;2`/0`19BDT302XZ:P8010@4:@0000080?ooo`001P3ooom@
000000<0Hf=S0P3?cll308j>SP<0OWin0`37alL20<_;b`<0JFUY0`0R8R8302l_;`80AdM70`1DE5@3
04M7A`<0?clo0P1HF5P308Z:RP<0]kNg0`33`l<20<K6aP<0d=3@0`3QhN420>c/k0<0lo?c0`3alO43
0>c/k080inOW0`3Rh^860>CTi080_[jn0`2EUID309BDU0<0VYZJ1@2GUiL309^KV`<0LG5a0P17AdL3
05]KF`<0SHf=0`26QXH206m_K`<0F5QH0`0f=SH301LG5`801PH60`0A4A4303Ph>080K6a/0`23Ph<3
069RHP<0:2PX0P030`<3024Q8@<0Cdm?0`0[:b/200H61RT00000203oool000H0ooooD000000306=S
H`80clo?0`2>SXh307inOP<0alO70P3;bl/306UYJ@<08R8R0`0_;bl204M7A`<0E5AD0`17AdL303lo
?`80F5QH0`2:RXX30;Ng]`<0`l?30P36a/H30=3@d0<0hN7Q0P3/k>`30??cl`<0lO7a0`3/k>`20>OW
i`<0h^;R1P3Ti>@20;jn_P<0UIFE0`2DU9@309ZJVPD0UiNG0`2KVi/3075aL@80AdM70`1KFe/308f=
S@<0QXJ60P1_Kfl305QHF0<0=SHf0`0G5aL200H61P<04A4A0`0h>3P206a/K0<0Ph>30`1RHV8302PX
:0800`<30`0Q8B4304m?C`<0:b/[0P061PHY000000P0oooo00060?oooe0000000`1SHf<20<o?c`<0
SXj>0`1nOWh30<O7a`80bl_;0`1YJFT3028R8P<0;bl_0P17AdL305ADE0<0AdM70`0o?cl205QHF0<0
RXZ:0`2g]kL30<?3``80a/K60`3@d=030>7Qh@80k>c/0`3clo<30?7al@<0k>c/0P3WinL30>;RhPH0
i>CT0P2n_[h309FEU@<0U9BD0`2JVYX509NGU`<0Vi^K0`1aLG4204M7A`<0Fe]K0`2=SHd308J6QP80
Kfm_0`1HF5P303Hf=P<05aLG0P061PH3014A4@<0>3Ph0P1/K6`308>3P`<0HV9R0`0X:2P200<30`<0
8B4Q0`1?Cdl302/[:`801PH6:@0000080?ooo`001P3ooom=000000<00@410`1^KVh20<W9b@<0YZJV
0`1`L70304i>CP80EUIF0`1^KVh306ATI0<0DU9B0P0m?Cd303`l?0<0820P0`0R8R8203De=@<0B4Q8
0`1VIVH30:NWY`80`l?30`3;bl/30<g=c@80d];B0`3YjNT30>_[j`<0i^KV0P3Ph>060=kNgP<0h>3P
0P3UiND30=GEe@<0_;bl0`2n_[h20<30`0<0^;Rh0`2ZZZX307YjNP809bLW0`1:BTX307]kN`<0OWin
0P1hN7P305aLG0<0@4100`0V9RH2010@40<020P80`0V9RH2061PH0<0RHV90`1XJ6P303<c<`802@T9
0`0];Bd3065QH@<0<S8b0P0:2PXY000000P0oooo00060?ooodd000000`010@4306i^KP80bLW90`2V
YZH3071`L0<0CTi>0P1FEUH306i^KP<0I6AT0`1BDU8203dm?@<0?3`l0`0P8203028R8P80=CDe0`18
B4P306IVIP<0YjNW0P33`l<30<_;b`<0cLg=0P3Bd]830>WYj@<0jn_[0`3Vi^H20>3Ph0H0g]kN0`3P
h>020>GUi@<0eMGE0`2l_;`30;jn_P80`<300`2h^;P30:ZZZP<0NWYj0P0W9bL304Y:BP<0Ng]k0`1n
OWh207QhN0<0G5aL0`10@40302HV9P80410@0`0820P302HV9P80H61P0`29RHT306QXJ0<0<c<c0P09
2@T302d];@<0HF5Q0`0b<S8200X:2RT00000203oool000H0ooooD000000306][J`80[jn_0`2h^;P3
08j>SP<0DU9B0P29RHT30=CDe0<0`<300`2c/k<20:NWY`<0ZZZZ0`20P80306IVIP80L71`0`21PH43
071`L0<0Kfm_0P2DU9@30<O7a`<0d];B0P38b<P30=3@d0<0f=SH0`3IfMT20=[JfP<0d];B0`3Fe]H3
0=;BdP80e]KF0`35aLD30;Ng]`<0^[Zj0P2m_Kd30;Bd]0<0X:2P0`1[Jf/203dm?@<0Fe]K0`26QXH3
08N7Q`80PH610`1/K6`304A4A0<0;2`/0P0G5aL300L71`<09bLW0P1IFET30820P0<0Jf][0`10@402
01LG5`<0C4a<0`1ZJVX303`l?0807QhN0`010@4V000000P0oooo00060?oooe0000000`1[Jf/20:n_
[`<0^;Rh0`2>SXh3059BDP80RHV90`3De=@30<30`0<0/k>c0P2WYjL30:ZZZP<0P8200`1VIVH2071`
L0<0PH610`1`L70306m_K`80U9BD0`37alL30=;BdP80b<S80`3@d=030=SHf0<0fMWI0P3Jf]X30=;B
dP<0e]KF0`3Bd]820=KFeP<0aLG50`2g]kL30;Zj^P80_Kfm0`2d];@30:2PX0<0Jf][0P0m?Cd305]K
F`<0QXJ60`27QhL20861P@<0K6a/0`14A4@302`/;0805aLG0`071`L302LW9`80FEUI0`20P80306][
J`<0@4100P0G5aL304a<C0<0JVYZ0`0l?3`201hN7P<00@419P0000080?ooo`001P3ooom@000000<0
Jf][0P2_[jl30;Rh^0<0SXj>0`1BDU8208V9R@<0e=CD0`30`<030;>c/`80YjNW0`2ZZZX30820P0<0
IVIV0P1`L7030861P@<0L71`0`1_Kfl209BDU0<0alO70`3Bd]820<S8b0<0d=3@0`3Hf=P30=WIf@80
f][J0`3Bd]830=KFeP<0d];B0P3Fe]H30<G5a@<0]kNg0`2j^[X20;fm_@<0];Bd0`2PX:0306][J`80
?Cdm0`1KFe/308J6QP<0QhN70P21PH4306a/K0<0A4A40`0/;2`201LG5`<01`L70`0W9bL205UIF@<0
P8200`1[Jf/30410@0805aLG0`1<C4`306YZJP<0?3`l0P0N7Qh300410BH00000203oool000H0oooo
D000000308N7Q`80][Jf0`2/[:`309NGU`<0UIFE0P3=cLd30<_;b`<0_Kfm0`3Rh^820>o_k`<0dm?C
0`37alL30;jn_P80X:2P0`1hN7P306YZJP<0Q8B40P27QhL309fMW@<0emOG0P3IfMT30=7Ad@<0d=3@
0`38b<P20=7Ad@<0c/k>0`33`l<30;no_`80^k^k0`2e]KD30:RXZ0<0ZJVY0P2XZ:P309JFUP<0L71`
0`1@D50203<c<`<0@T920`22PX8308b<S080SXj>0`26QXH305UIF@<0<S8b0P0P820300/;2`<0<c<c
0P1ZJVX308>3P`<0MGEe0`12@T8202HV9P<0KVi^0`1RHV8304I6AP809BDU:@0000080?ooo`001P3o
oom@000000<0QhN70P2f][H30:b/[0<0UiNG0`2EUID20<g=c@<0bl_;0`2m_Kd30>;RhP80kno_0`3C
dm<30<O7a`<0_[jn0P2PX:0307QhN0<0JVYZ0`24Q8@208N7Q`<0WIfM0`3GemL20=WIf@<0dM7A0`3@
d=030<S8b080dM7A0`3>c/h30<?3``<0_kno0P2k^k/30;Fe]@<0Z:RX0`2YZJT20:RXZ0<0UYJF0`1`
L703051@D080<c<c0`12@T8308:2PP<0S8b<0P2>SXh308J6QP<0FEUI0`0b<S82020P80<02`/;0`0c
<c<206YZJP<0Ph>30`1eMGD30492@P809RHV0`1^KVh3069RHP<0ATI60P0U9BDY000000P0oooo0006
0?oooe0000000`27QhL20;Jf]P<0[:b/0`2GUiL309FEU@80cLg=0`3;bl/30;fm_@<0h^;R0P3_knl3
0=?Cd`<0alO70`2n_[h20:2PX0<0N7Qh0`1ZJVX308B4Q080QhN70`2MWId30=OGe`80fMWI0`3AdM43
0=3@d0<0b<S80P3AdM430<k>cP<0`l?30`2o_kl20;^k^`<0]KFe0`2XZ:P30:VYZ@80Z:RX0`2FUYH3
071`L0<0D51@0P0c<c<30492@P<0PX:20`2<S8`208j>SP<0QXJ60`1IFET3038b<P80820P0`0;2`/3
03<c<`80JVYZ0`23Ph<307EeM@<0@T920P0V9RH306i^KP<0HV9R0`16ATH202DU9BT00000203oool0
00H0ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJ
VP<0cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VY
Z@<0XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De
=@<04Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7
A`80PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0
ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0
cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0
XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<0
4Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80
PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0oooo
D000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0cLg=
0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0XJ6Q
0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<04Q8B
0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80PX:2
0`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0ooooD000
000302TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d
];@30<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1J
FUX205=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1Y
JFT2059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2C
Ti<307alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD0000003
02TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d];@3
0<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1JFUX2
05=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1YJFT2
059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2CTi<3
07alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD000000300D5
1@80YjNW0`38b<P30;Rh^0<0bLW90P3alO430?Shn0<0kno_0`3Zj^X20>k^kP<0inOW0`3Zj^X30?Kf
mP80kno_1P3[jn/30=;BdP80/k>c0`2WYjL309NGU`80Vi^K0`2`/;030;Bd]0<0]KFe0P2=SHd30861
P@<0J6QX0`1LG5`20451@@<0:RXZ0`0U9BD301LG5`80410@0`0G5aL3038b<P<0GemO0P1ADE4300h>
3P<0E5AD0`1oOgl20861P@<0PX:20`1/K6`304i>CP80;2`/0`0L71`3069RHP80V9RH0`1dM7@30451
@@<0>SXj0P1fMWH304M7A`<01`L7;P0000080?ooo`001P3ooom@000000<01@D50P2WYjL30<S8b0<0
^;Rh0`39bLT20?7al@<0n?Sh0`3_knl30>[ZjP80k^k^0`3WinL30>[ZjP<0m_Kf0P3_knl60>_[j`<0
d];B0P2c/k<30:NWY`<0UiNG0P2KVi/30;2`/0<0];Bd0`2e]KD208f=S@<0PH610`1XJ6P305aLG080
@D510`0Z:RX302DU9@<05aLG0P0@410301LG5`<0<S8b0`1OGel2055AD@<03Ph>0`1DE5@307moO`80
PH610`22PX8306a/K0<0CTi>0P0/;2`301`L70<0HV9R0P2HV9P307AdM0<0@D510`0j>SX207IfMP<0
AdM70`071`L^000000P0oooo00060?oooe0000000`051@D20:NWY`<0b<S80`2h^;P30<W9b@80lO7a
0`3hn?P30>o_k`<0j^[Z0P3^k^h30>OWi`<0j^[Z0`3fm_H20>o_k`H0jn_[0`3Bd]820;>c/`<0YjNW
0`2GUiL209^KV`<0/;2`0`2d];@30;Fe]@80SHf=0`21PH4306QXJ0<0G5aL0P11@D4302XZ:P<09BDU
0`0G5aL2010@40<05aLG0`0b<S8305mOG`80DE5A0`0>3Ph305ADE0<0Ogmo0P21PH4308:2PP<0K6a/
0`1>CTh202`/;0<071`L0`1RHV8209RHV0<0M7Ad0`11@D4303Xj>P80MWIf0`17AdL300L71bh00000
203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38
b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1m
OGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o
?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[
:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`000002
06IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=02
0=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3
075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl3
02d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`3
03/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj
^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf
]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RH
V0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861
P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=
3C400000203oool000H0ooooD`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80
kNg]0`3[jn/30=gMg@<0h>3P0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0
SHf=0`2TY:@309jNWP80aLG50`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0
]KFe0`2LW9`30861P@80?3`l0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0
Cdm?0`2JVYX208N7Q`<0GemO0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0oooo
D`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80kNg]0`3[jn/30=gMg@<0h>3P
0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0SHf=0`2TY:@309jNWP80aLG5
0`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0]KFe0`2LW9`30861P@80?3`l
0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0Cdm?0`2JVYX208N7Q`<0GemO
0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0ooooE@00000307=cL`<0hn?S0`3?
cll20=7Ad@H0f][J0`3Vi^H20>WYj@<0f][J0`3Ng]h30;6a/@80:2PX0`061PH300X:2P<02@T90P0L
71`305QHF0<0MGEe0P23Ph<30;Zj^P<0_;bl0`34a<@20:j^[P<0^;Rh0`3Cdm<308j>SP80EEEE0`1M
GEd305ADE0<0MgMg0P2OWil30:j^[P<0W9bL0`1RHV8204e=C@<0Kfm_0`1oOgl308B4Q080Ph>30`24
Q8@306YZJP<0B4Q80P0Z:RX3065QH@<0TY:B0P1cLg<304e=C@<09BDU0`020P82000000<00@41<@00
00080?ooo`001P3ooomE000000<0Lg=c0`3Shn<30<o?c`80dM7A1P3Jf]X30>KViP80jNWY0`3Jf]X3
0=kNgP<0/K6a0P0X:2P300H61P<02PX:0`092@T201`L70<0F5QH0`1eMGD208>3P`<0^[Zj0`2l_;`3
0<C4a080[Zj^0`2h^;P30=?Cd`<0SXj>0P1EEED305eMG@<0E5AD0`1gMgL209nOW`<0[Zj^0`2LW9`3
069RHP80CDe=0`1_Kfl307moO`<0Q8B40P23Ph<308B4Q0<0JVYZ0`18B4P202XZ:P<0HF5Q0`2BTY82
07=cL`<0CDe=0`0U9BD300820P8000000`010@4a000000P0oooo00060?oooeD000000`1cLg<30>?S
h`<0clo?0P3AdM460=[JfP<0i^KV0P3YjNT30=[JfP<0g]kN0`2a/K4202PX:0<01PH60`0:2PX300T9
2@8071`L0`1HF5P307EeM@80Ph>30`2j^[X30;bl_0<0a<C40P2^[Zh30;Rh^0<0dm?C0`2>SXh205EE
E@<0GEeM0`1DE5@307MgM`80WinO0`2^[Zh309bLW0<0HV9R0P1=CDd306m_K`<0Ogmo0`24Q8@208>3
P`<0Q8B40`1ZJVX304Q8B080:RXZ0`1QHF4309:BTP80Lg=c0`1=CDd302DU9@<00P820P0000030041
0C400000203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80
gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0
]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0
CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0
LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooE@000003018B4P<0_kno
0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO
0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno
0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF5
0P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000
203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3Y
jNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39
bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1N
GUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1l
O7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooF000000302l_;`<0`<300P3WinL3
0=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065QH@<0?Shn0P0[:b/3
01@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@T080_Kfm0`2OWil3
09bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3
061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0ooooF000000302l_
;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065Q
H@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@
T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>
SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0
ooooF000000302l_;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80
PH610`1jNWX3065QH@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0
OWin0`1lO7`3092@T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0
Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`0
0000203oool000H0ooooF`00000301XJ6P80Zj^[0`3_knl30>3Ph0<0gMgM0P3Shn<30=cLg0<0][Jf
0`2VYZH20<71`@<0g=cL0`3Ogml30::RXP80Jf][0`1:BTX302`/;080U9BD0`3Hf=P309JFUP<0Y:BT
0P3Bd]830<c<c0<0_kno0`2/[:`20;6a/@<0`L710`2ZZZX30;:b/P80_Kfm0`2n_[h3051@D0<0?Shn
0P1YJFT307UiN@<0RHV90`2BTY8208n?S`<0NWYj0`1PH60303lo?`80A4A40`1NGUh3059BDP806QXJ
?`0000080?ooo`001P3ooomK000000<06QXJ0P2[Zj/30>o_k`<0h>3P0`3MgMd20>?Sh`<0g=cL0`2f
][H30:JVYP80`L710`3Lg=`30=oOg`<0XZ:R0P1[Jf/304Y:BP<0;2`/0P2DU9@30=SHf0<0UYJF0`2T
Y:@20=;BdP<0c<c<0`2o_kl30:b/[080/K6a0`31`L430:ZZZP<0/[:b0P2m_Kd30;jn_P<0D51@0`0n
?Sh206UYJ@<0NGUi0`29RHT309:BTP80Shn?0`1jNWX3061PH0<0?clo0P14A4@305iNGP<0DU9B0P0J
6QXo000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/3
0:BTY080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID2
08n?S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P2
06QXJ0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o
000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BT
Y080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?
S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QX
J0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o0000
00P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BTY080
bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?S`<0
WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QXJ0<0
OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o000000P0
oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW
0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C
0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_
0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;
Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1E
EED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j
>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h
>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh3
0861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<03
0<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd3
07alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l
000000P0oooo00060?ooofT000000P0m?Cd30:VYZ@<0W9bL0`1cLg<206i^KP<0V9RH0`2JVYX30861
P@80L71`0`1aLG4304I6AP80BTY:0`2=SHd30:n_[`<0YJFU0P2TY:@30<S8b0<0_kno0`2YZJT208N7
Q`<0=cLg0`0?3`l301HF5P80=SHf0`15ADD304Y:BP<0GemO0P1YJFT308>3P`<0TI6A0`2;Rh/207Ui
N@<0IfMW0`17AdL5024Q8@<0<30`0`051@D2000000<00@41?00000080?ooo`001P3ooomY00000080
?Cdm0`2YZJT309bLW0<0Lg=c0P1^KVh309RHV0<0VYZJ0`21PH42071`L0<0LG5a0`16ATH204Y:BP<0
SHf=0`2_[jl30:FUY@80Y:BT0`38b<P30;no_`<0ZJVY0P27QhL303Lg=`<03`l?0`0F5QH203Hf=P<0
ADE50`1:BTX305mOG`80JFUY0`23Ph<3096AT@<0Rh^;0P1iNGT306MWI`<0AdM71@0Q8B43030`<0<0
1@D50P00000300410C`00000203oool000H0ooooJ`00000300L71`<0GemO0`1/K6`207AdM0<0UIFE
0`2HV9P30820P080JFUY0`1EEED304=3@`80=cLg0`1OGel307MgM`<0P8200P2=SHd308Z:RP<0M7Ad
0`0n?Sh200h>3P<02`/;0`0I6AT301lO7`80>SXj1P1>CTh305EEE@80LG5a0`28R8P308n?S`<0QHF5
0P1aLG4305YJFP<0<S8b0`0H61P202`/;0<07QhNA00000080?ooo`001P3ooom[000000<01`L70`1O
Gel306a/K080M7Ad0`2EUID309RHV0<0P8200P1YJFT305EEE@<0@d=30P0g=cL305mOG`<0MgMg0`20
P80208f=S@<0RXZ:0`1dM7@303hn?P803Ph>0`0;2`/301TI6@<07alO0P0j>SX604i>CP<0EEEE0P1a
LG4308R8R0<0Shn?0`25QHD2075aL@<0FUYJ0`0b<S8301PH6080;2`/0`0N7Qi4000000P0oooo0006
0?ooof/000000`071`L305mOG`<0K6a/0P1dM7@309FEU@<0V9RH0`20P80206UYJ@<0EEEE0`13@d<2
03Lg=`<0GemO0`1gMgL30820P080SHf=0`2:RXX307AdM0<0?Shn0P0>3Ph300/;2`<06ATI0`0O7al2
03Xj>PH0CTi>0`1EEED2075aL@<0R8R80`2?Shl308F5Q@80LG5a0`1JFUX3038b<P<061PH0P0/;2`3
01hN7T@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0JVYZ0`1PH602051@
D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<01@D50P0@410301lO
7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80LW9b0`1<C4`302h^
;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0
JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<0
1@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80
LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX
0P1SHf<306MWI`<0JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C
0`0f=SH301DE5@<01@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b
1P2;Rh/307moO`80LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00
000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K6`<04Q8B0`0;
2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?C`<0FEUI0`1k
Ng/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T3000000<00@41@@00
00080?ooo`001P3ooom^000000<0>3Ph0`1cLg<506][J`<0IfMW0`1GEeL204A4A0<0<S8b0`0_;bl2
02TY:@<06a/K0`0B4Q8300/;2`8030`<0`0D51@301<C4`<04Q8B0P0J6QX302h^;P<0<C4a0`0Y:BT2
03Hf=P<0Cdm?0`1IFET307]kN`80Shn?0`22PX8307UiN@<0N7Qh0P1YJFT304Q8B0<0=3@d0`0[:b/2
00T92@<000000`010@51000000P0oooo00060?ooofh000000`0h>3P307=cL`D0Jf][0`1WIfL305MG
E`80A4A40`0b<S8302l_;`80:BTY0`0K6a/3018B4P<02`/;0P0<30`301@D50<04a<C0`0B4Q8201XJ
6P<0;Rh^0`0a<C4302TY:@80=SHf0`1?Cdl305UIF@<0Ng]k0P2?Shl308:2PP<0NGUi0`1hN7P206UY
J@<0B4Q80`0d=3@302/[:`802@T90`00000300410D400000203oool000H0ooooKP00000302d];@<0
RHV90P1lO7`307EeM@<0KVi^0`1NGUh204Q8B0<0;bl_0`0[:b/2030`<0<04Q8B0`0:2PX3010@4080
51@D0`0K6a/301HF5P<07AdM0P0V9RH303De=@<0<30`0`0k>c/20410@0<0@D510`1OGel308:2PP80
S8b<1P1lO7`307]kN`80IVIV0`1>CTh303@d=0<030`<B@0000080?ooo`001P3ooom^000000<0;Bd]
0`29RHT207alO0<0MGEe0`1^KVh305iNGP80B4Q80`0_;bl302/[:`80<30`0`0B4Q8300X:2P<0410@
0P0D51@301/K6`<05QHF0`0M7Ad202HV9P<0=CDe0`0`<30303/k>`80@4100`11@D4305mOG`<0PX:2
0P2<S8`607alO0<0Ng]k0P1VIVH304i>CP<0=3@d0`0<30a9000000P0oooo00060?ooofT000000P01
0@43000000<04Q8B0`2:RXX207IfMP<0KFe]1P1UIFD205UIF@<0>SXj0`0e=CD202`/;0<04Q8B0`0A
4A4301TI6@805QHF0`0G5aL3024Q8@<08b<S0P0f=SH303De=@<0<C4a0`1=CDd205IFEP<0F5QH0`1Y
JFT307inOP80MgMg0`1bLW8308:2PP<0Kfm_0P1PH603051@D0<05QHF0`00000200410DL00000203o
ool000H0ooooJ@00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EUI@80FEUI0`0j>SX3
03De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf=P<0=CDe0`0a<C43
04e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061PH0<0D51@0`0F5QH3
000000800@41A`0000080?ooo`001P3ooomY000000800@410`000003018B4P<0RXZ:0P1fMWH306e]
K@H0IFEU0P1IFET303Xj>P<0=CDe0P0/;2`3018B4P<04A4A0`0I6AT201HF5P<05aLG0`0Q8B4302<S
8`80=SHf0`0e=CD3034a<@<0CDe=0P1FEUH305QHF0<0JFUY0`1nOWh207MgM`<0LW9b0`22PX8306m_
K`80H61P0`1@D50301HF5P<000000P010@57000000P0oooo00060?ooofh000000`030`<30861P@80
UYJF0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<0
6ATI0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0
NGUi0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF
0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI
0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi
0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF0`27
QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI0`0Y
:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi0`1Y
JFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`0@410306QXJ080VIVI0`2BTY83
08R8R0<0PH610P1bLW8306MWI`<0DE5A0P0];Bd301/K6`<07QhN0`0L71`201XJ6P<0:2PX0`0V9RH3
03Ph>080@4100`13@d<305EEE@<0Lg=c0P1kNg/607QhN0<0K6a/0P1ZJVX305]KF`<0BTY:0`19BDT2
02@T95800000203oool000H0ooooKP000003010@40<0J6QX0P2IVIT309:BTP<0R8R80`21PH42079b
LP<0IfMW0`1ADE4202d];@<06a/K0`0N7Qh301`L70806QXJ0`0X:2P302HV9P<0>3Ph0P10@40304=3
@`<0EEEE0`1cLg<207]kN`H0N7Qh0`1/K6`206YZJP<0Fe]K0`1:BTX304U9B@8092@TDP0000080?oo
o`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80
:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80
NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K
0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO
0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C
0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26
QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?
Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE000
00080?ooo`001P3ooom^000000<07AdM0`1HF5P208N7Q`<0SXj>0`28R8P307UiN@80Jf][0`1MGEd3
0410@0D0:2PX0`0U9BD302LW9`80=cLg0`0[:b/304Y:BP<0FEUI0P1JFUX306YZJP<0N7Qh0`1cLg<2
07EeM@<0NGUi0`1mOGd306IVIP80BDU90`0a<C4300P825L00000203oool000H0ooooKP00000301dM
7@<0F5QH0P27QhL308j>SP<0R8R80`1iNGT206][J`<0GEeM0`10@40502PX:0<09BDU0`0W9bL203Lg
=`<0:b/[0`1:BTX305UIF@80FUYJ0`1ZJVX307QhN0<0Lg=c0P1eMGD307UiN@<0OGem0`1VIVH204U9
B@<0<C4a0`0820QG000000P0oooo00060?ooofh000000`0M7Ad305QHF080QhN70`2>SXh308R8R0<0
NGUi0P1[Jf/305eMG@<0@4101@0X:2P302DU9@<09bLW0P0g=cL302/[:`<0BTY:0`1IFET205YJFP<0
JVYZ0`1hN7P307=cL`80MGEe0`1iNGT307emO@<0IVIV0P19BDT3034a<@<020P8E`0000080?ooo`00
1P3ooomY000000D00@410`0=3@d305UIF@80Ph>30`2ATI4308J6QP<0MGEe0P1UIFD305IFEP<0@410
0P0b<S8302l_;`<0:b/[0`0f=SH2034a<@<0ATI60`1QHF43061PH080JVYZ0`1eMGD307inOP<0NGUi
0P1eMGD307emO@<0Lg=c0`1;Bd/201`L75d00000203oool000H0ooooJ@00000500410@<03@d=0`1I
FET208>3P`<0TI6A0`26QXH307EeM@80IFEU0`1FEUH30410@080<S8b0`0_;bl302/[:`<0=SHf0P0a
<C4304I6AP<0HF5Q0`1PH60206YZJP<0MGEe0`1nOWh307UiN@80MGEe0`1mOGd307=cL`<0Bd];0P0L
71aM000000P0oooo00060?ooofT000001@010@4300d=3@<0FEUI0P23Ph<3096AT@<0QXJ60`1eMGD2
06EUI@<0EUIF0`10@402038b<P<0;bl_0`0[:b/303Hf=P80<C4a0`16ATH3065QH@<0H61P0P1ZJVX3
07EeM@<0OWin0`1iNGT207EeM@<0OGem0`1cLg<304];B`8071`LG@0000080?ooo`001P3ooomV0000
00<00@410P0410@300<30`<00P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410
@080=SHf0`0b<S8303Xj>P<0>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820
P080O7al0`1]KFd304I6AP<03Ph>G`0000080?ooo`001P3ooomV000000<00@410P0410@300<30`<0
0P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410@080=SHf0`0b<S8303Xj>P<0
>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820P080O7al0`1]KFd304I6AP<0
3Ph>G`0000080?ooo`001P3ooomV000000<00P820P030`<300820P<000000`0P820206m_K`<0Q8B4
0`1gMgL3069RHP80GEeM0`1BDU8304I6AP80?3`l0`12@T8304Q8B0<0CDe=0P1IFET305iNGP<0IfMW
0`1aLG4207UiN@<0PH610`22PX8307EeM@80HF5Q0`12@T8301@D50<000000P010@5M000000P0oooo
00060?ooofH000000`020P8200<30`<00P820`000003020P8080Kfm_0`24Q8@307MgM`<0HV9R0P1M
GEd3059BDP<0ATI60P0l?3`30492@P<0B4Q80`1=CDd205UIF@<0GUiN0`1WIfL3075aL@80NGUi0`21
PH4308:2PP<0MGEe0P1QHF430492@P<051@D0`00000200410Ed00000203oool000H0ooooIP000003
00820P800`<30`020P83000000<0820P0P1_Kfl308B4Q0<0MgMg0`1RHV8205eMG@<0DU9B0`16ATH2
03`l?0<0@T920`18B4P304e=C@80FEUI0`1NGUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2
065QH@<0@T920`0D51@3000000800@41G@0000080?ooo`001P3ooomV000000P00@410`020P8300P8
2080?3`l0`1nOWh307]kN`<0JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3051@D0<0EeMG0`1NGUh206=S
H`<0IFEU0`1]KFd307EeM@80NWYj0`1cLg<305eMG@<0Bd];0P10@40302HV9VD00000203oool000H0
ooooIP00000800410@<00P820`0820P203`l?0<0OWin0`1kNg/306YZJP80IFEU0`1MGEd304Y:BP80
ATI60`1@D50305MGE`<0GUiN0P1SHf<306EUI@<0KFe]0`1eMGD207YjNP<0Lg=c0`1MGEd304];B`80
@4100`0V9RIU000000P0oooo00060?ooofH0000020010@4300820P<020P80P0l?3`307inOP<0Ng]k
0`1ZJVX206EUI@<0GEeM0`1:BTX204I6AP<0D51@0`1GEeL305iNGP80Hf=S0`1UIFD306e]K@<0MGEe
0P1jNWX307=cL`<0GEeM0`1;Bd/20410@0<09RHVI@0000080?ooo`001P3ooomP000000/00@410`03
0`<300@410<020P80P0F5QH304E5A@<0HV9R1@1^KVh306MWI`<0FEUI0P1EEED305YJFP<0G5aL0`1N
GUh206EUI@<0JFUY0`1/K6`306UYJ@80G5aL0`1ADE4304U9B@<0@D510P0d=3@300T92FD00000203o
ool000H0ooooH000000;00410@<00`<30`0410@300P820805QHF0`15ADD3069RHPD0KVi^0`1WIfL3
05UIF@80EEEE0`1JFUX305aLG0<0GUiN0P1UIFD306UYJ@<0K6a/0`1YJFT205aLG0<0DE5A0`19BDT3
0451@@80=3@d0`092@UU000000P0oooo00060?ooof0000002`010@4300<30`<010@40`0820P201HF
5P<0ADE50`1RHV8506i^KP<0IfMW0`1IFET205EEE@<0FUYJ0`1LG5`305iNGP80IFEU0`1YJFT306a/
K0<0JFUY0P1LG5`3055AD@<0BDU90`11@D4203@d=0<02@T9I@0000080?ooo`001P3ooomP000000/0
0@410`0:2PX300d=3@<02PX:0P0K6a/302<S8`<0?3`l0`1CDe<2061PH0<0GemO0`1PH60205mOG`<0
GEeM0`1PH603069RHP80IFEU0`1TI6@3061PH0<0EeMG0P1@D50304e=C@<0@T920`0i>CT201LG5fP0
0000203oool000H0ooooH000000;00410@<02PX:0`0=3@d300X:2P806a/K0`0S8b<303`l?0<0De=C
0P1PH60305mOG`<0H61P0P1OGel305eMG@<0H61P0`1RHV8206EUI@<0I6AT0`1PH60305MGE`80D51@
0`1=CDd30492@P<0>CTi0P0G5aMX000000P0oooo00060?ooof0000001P010@43000000800`<30`0=
3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1S
Hf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo0006
0?ooof0000001P010@43000000800`<30`0=3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2
059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D503
04];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof0000001P010@43000000800`<30`0=3@d301TI
6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306AT
I080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof<0
00000`010@4300820P801`L70`0>3Ph301/K6`<0820P0P0N7Qh3028R8P<09RHV0`0^;Rh204E5A@<0
EUIF0`1MGEd206ATI0<0IVIV0`1TI6@3065QH@80GEeM0`1KFe/605QHF080DU9B0`1=CDd3038b<P<0
0`<3JP0000080?ooo`001P3ooomS000000<00@410`020P8200L71`<03Ph>0`0K6a/3020P80807QhN
0`0R8R8302HV9P<0;Rh^0P15ADD305IFEP<0GEeM0P1TI6@306IVIP<0I6AT0`1QHF4205eMG@<0Fe]K
1P1HF5P2059BDP<0CDe=0`0b<S8300<30fX00000203oool000H0ooooH`00000300410@<00P820P07
1`L300h>3P<06a/K0`0P820201hN7P<08R8R0`0V9RH302h^;P80ADE50`1FEUH305eMG@80I6AT0`1V
IVH306ATI0<0HF5Q0P1MGEd305]KF`H0F5QH0P1BDU8304e=C@<0<S8b0`030`=Z000000P0oooo0006
0?ooof<000000`020P8300D51@8030`<0`0?3`l301XJ6P<09BDU0P0V9RH302<S8`<0820P0`0Q8B42
02h^;P<0?clo0`1BDU8205]KF`<0HV9R0`1UIFD305iNGPD0Fe]K0`1JFUX305UIF@80EEEE0`13@d<3
010@46d00000203oool000H0ooooH`00000300820P<01@D50P0<30`300l?3`<06QXJ0`0U9BD202HV
9P<08b<S0`0P8203024Q8@80;Rh^0`0o?cl3059BDP80Fe]K0`1RHV8306EUI@<0GUiN1@1KFe/305YJ
FP<0FEUI0P1EEED304=3@`<0410@K@0000080?ooo`001P3ooomP000000<00@410`030`<300X:2P80
3Ph>0`0@410301TI6@<0:BTY0P0f=SH303lo?`<0A4A40`13@d<203hn?P<0ATI60`1EEED205eMG@<0
H61P0`1RHV8306=SH`80H61P0`1MGEd305iNGP<0Fe]K0P1EEED302`/;7000000203oool000H0oooo
H000000300410@<00`<30`0:2PX200h>3P<0410@0`0I6AT302TY:@80=SHf0`0o?cl304A4A0<0@d=3
0P0n?Sh304I6AP<0EEEE0P1MGEd3061PH0<0HV9R0`1SHf<2061PH0<0GEeM0`1NGUh305]KF`80EEEE
0`0/;2a`000000P0oooo00060?ooof0000000`010@4300<30`<02PX:0P0>3Ph3010@40<06ATI0`0Y
:BT203Hf=P<0?clo0`14A4@304=3@`80?Shn0`16ATH305EEE@80GEeM0`1PH603069RHP<0Hf=S0P1P
H60305eMG@<0GUiN0`1KFe/205EEE@<0;2`/L00000080?ooo`001P3ooomN000000D00P820`0820P3
00`<30803Ph>0`0B4Q8301XJ6P<0:BTY0P0n?Sh305IFEP<0IVIV2`1aLG42079bLP<0Lg=c0`1`L703
06UYJ@80Hf=S0`1QHF4305mOG`<0GEeM0P15ADD300P827000000203oool000H0ooooGP0000050082
0P<020P80`0<30`200h>3P<04Q8B0`0J6QX302TY:@80?Shn0`1FEUH306IVIP/0LG5a0P1bLW8307=c
L`<0L71`0`1YJFT206=SH`<0HF5Q0`1OGel305eMG@80ADE50`0820Q`000000P0oooo00060?oooeh0
00001@020P8300P820<030`<0P0>3Ph3018B4P<06QXJ0`0Y:BT203hn?P<0EUIF0`1VIVH;075aL@80
LW9b0`1cLg<3071`L0<0JFUY0P1SHf<3065QH@<0GemO0`1MGEd204E5A@<020P8L00000080?ooo`00
1P3ooom@000000D00@410`00000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B
0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][
0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00
000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13
@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1O
Gel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00000300410@<00P820P030`<3
00H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD3
06][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`000008
0?ooo`001P3ooom@000000D00@410`00000600<30`D010@40`051@D300/;2`804A4A0`0E5AD301/K
6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZ
JP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`001P3ooom@000000D00@410`00000600<30`D0
10@40`051@D300/;2`804A4A0`0E5AD301/K6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0
GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZJP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`00
1P3ooom@000000P00@4120020P8300410@<01PH60`0<30`2014A4@<05aLG0`0M7Ad302LW9`80<C4a
0`0m?Cd304M7A`<0CTi>0P1JFUX306QXJ0<0Kfm_0P1eMGD307]kN`<0NWYj0`1dM7@207=cL`<0LG5a
0`1NGUh300h>3WD00000203oool000H0ooooD000000800410@P00P820`010@4300H61P<030`<0P0A
4A4301LG5`<07AdM0`0W9bL2034a<@<0?Cdm0`17AdL304i>CP80FUYJ0`1XJ6P306m_K`80MGEe0`1k
Ng/307YjNP<0M7Ad0P1cLg<3075aL@<0GUiN0`0>3Pie000000P0oooo00060?oooe00000020010@48
00820P<00@410`061PH300`<30804A4A0`0G5aL301dM7@<09bLW0P0a<C4303dm?@<0AdM70`1>CTh2
05YJFP<0J6QX0`1_Kfl207EeM@<0Ng]k0`1jNWX307AdM080Lg=c0`1aLG4305iNGP<03Ph>M@000008
0?ooo`001P3ooom@000000/00@410`020P8200<30`<01@D50`0:2PX300h>3P804a<C0`0L71`3028R
8P<0:2PX0P0b<S8303lo?`<0Bd];0`1DE5@2065QH@<0KVi^0`1gMgL207alO0<0OGem0`1kNg/307Ee
M@80KFe]0`1WIfL302d];GP00000203oool000H0ooooD000000;00410@<00P820P030`<300D51@<0
2PX:0`0>3Ph201<C4`<071`L0`0R8R8302PX:080<S8b0`0o?cl304];B`<0E5AD0P1QHF4306i^KP<0
MgMg0P1lO7`307emO@<0Ng]k0`1eMGD206e]K@<0IfMW0`0];Beh000000P0oooo00060?oooe000000
2`010@4300820P800`<30`051@D300X:2P<03Ph>0P0C4a<301`L70<08R8R0`0X:2P2038b<P<0?clo
0`1;Bd/305ADE080HF5Q0`1^KVh307MgM`80O7al0`1mOGd307]kN`<0MGEe0P1]KFd306MWI`<0;Bd]
N00000080?ooo`001P3ooom@000000D00@411P00000300@410802@T90`0;2`/300l?3`<051@D0P0J
6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd305UIF@80IfMW0`1bLW8307QhN080NGUi0`1h
N7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N00000080?ooo`001P3ooom@000000D00@411P000003
00@410802@T90`0;2`/300l?3`<051@D0P0J6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd3
05UIF@80IfMW0`1bLW8307QhN080NGUi0`1hN7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N0000008
0?ooo`001P3ooom8000000800@410`00000300410@<00`<31@020P8300@410<02PX:0P0<30`3014A
4@<05QHF0`0I6AT201hN7P<08b<S0`0[:b/3034a<@80>SXj0`15ADD3059BDP<0G5aL0P1WIfL307If
MP<0MgMg0P1dM7@607MgM`<0KFe]0P1KFe/301XJ6W/00000203oool000H0ooooB000000200410@<0
00000`010@4300<30`D00P820`0410@300X:2P8030`<0`0A4A4301HF5P<06ATI0P0N7Qh302<S8`<0
:b/[0`0a<C4203Xj>P<0ADE50`1BDU8305aLG080IfMW0`1fMWH307MgM`80M7Ad1P1gMgL306e]K@80
Fe]K0`0J6QYk000000P0oooo00060?ooodP000000P010@43000000<00@410`030`<500820P<010@4
0`0:2PX200`<30<04A4A0`0F5QH301TI6@807QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B
0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3o
oom5000000<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M
7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_
Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P83
00410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh3
03@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh2
03Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`030`<300L7
1`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJ
FP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?oo
o`001P3ooolo000000H00@411@020P8300<30`<00P820`010@4200820P<01PH60`0:2PX300`<3080
410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080
KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?0P0>3Pin000000P0oooo00060?ooocl00000
1P010@4500820P<00`<30`020P8300410@800P820`061PH300X:2P<030`<0P0@410301HF5P<07AdM
0`0O7al202@T90<0;Rh^0`0b<S8303De=@80@4100`1>CTh305aLG0<0J6QX0P1]KFd306m_K`<0KVi^
0P1[Jf/306UYJ@<0GUiN0`1?Cdl200h>3Wh00000203oool000H0oooo?`00000600410@D00P820`03
0`<300820P<00@410P020P8300H61P<02PX:0`0<30`2010@40<05QHF0`0M7Ad301lO7`8092@T0`0^
;Rh3038b<P<0=CDe0P10@40304i>CP<0G5aL0`1XJ6P206e]K@<0Kfm_0`1^KVh206][J`<0JFUY0`1N
GUh304m?C`803Ph>OP0000080?ooo`001P3ooom2000000<00@4120051@D600<30`801PH60`0820P3
00/;2`<04A4A0P0D51@301LG5`<07AdM0`0P820202<S8`<0;2`/0`0a<C4303`l?080ADE50`1CDe<3
061PH0<0I6AT0P1VIVH306YZJP<0JFUY0P1WIfL305aLG0<0EUIF0`0X:2R0000000P0oooo00060?oo
od8000000`010@4800D51@H00`<30P061PH300P820<02`/;0`0A4A4201@D50<05aLG0`0M7Ad3020P
80808b<S0`0/;2`3034a<@<0?3`l0P15ADD305=CD`<0H61P0`1TI6@206IVIP<0JVYZ0`1YJFT206MW
I`<0G5aL0`1FEUH302PX:8000000203oool000H0oooo?`00000300410@<00P820`051@D200H61P<0
1@D50`061PH300T92@8020P80`0<30`6010@40804a<C0`0F5QH301dM7@<08R8R0P0T92@302TY:@<0
<30`0`0k>c/204Q8B0<0De=C0`1KFe/306=SH`80IVIV0`1TI6@3065QH@80GUiN0`1EEED30451@@<0
1`L7P00000080?ooo`001P3ooolo000000<00@410`020P8300D51@801PH60`051@D300H61P<02@T9
0P0820P300`<30H0410@0P0C4a<301HF5P<07AdM0`0R8R8202@T90<0:BTY0`0`<30303/k>`80B4Q8
0`1CDe<305]KF`<0Hf=S0P1VIVH306ATI0<0HF5Q0P1NGUh305EEE@<0@D510`071`N0000000P0oooo
00060?ooocl000000`010@4300820P<01@D50P061PH300D51@<01PH60`092@T200P820<030`<1P0@
410201<C4`<05QHF0`0M7Ad3028R8P8092@T0`0Y:BT3030`<0<0>c/k0P18B4P305=CD`<0Fe]K0`1S
Hf<206IVIP<0I6AT0`1QHF4205iNGP<0EEEE0`11@D4300L71h000000203oool000H0oooo?`000003
00<30`<01@D50`061PH200T92@T02PX:1@0>3Ph3010@40<04A4A0P0B4Q8301LG5`<071`L0`0N7Qh2
028R8P<0:2PX0`0a<C4303hn?P80B4Q80`1FEUH305UIF@D0G5aL1P1IFET205=CD`<0B4Q80`0H61R3
000000P0oooo00060?ooocl000000`030`<300D51@<01PH60P092@T900X:2PD03Ph>0`0@4103014A
4@804Q8B0`0G5aL301`L70<07QhN0P0R8R8302PX:0<0<C4a0`0n?Sh204Q8B0<0EUIF0`1IFET505aL
G0H0FEUI0P1CDe<304Q8B0<061PHP`0000080?ooo`001P3ooolo000000<00`<30`051@D300H61P80
2@T92@0:2PX500h>3P<0410@0`0A4A42018B4P<05aLG0`0L71`301hN7P808R8R0`0X:2P3034a<@<0
?Shn0P18B4P305IFEP<0FEUI1@1LG5`605UIF@80De=C0`18B4P301PH68<00000203oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]],

Cell["\<\
This image looks a little chunky because of the scale.  It is a small image \
of only 100 pixels width and 85 pixels height.  Try to rescale:  click on the \
image and drag one of the corner markers in.  Numbers for the displayed \
image's width and height should be changing in the lower-left corner of the \
window for this notebook.  When it gets to 100 by 85, you can release the \
mouse button to rescale to the image in actual displayed pixels.  (This \
rescaling is optional for the rest of your work.)\
\>", "Text"],

Cell["\<\
Currently this image is stored in 85x100 matrix, so it stored 8500 entries.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Length[Flatten[handMat]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`8500\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Questions 1-4:", "Subsubsection"],

Cell["\<\
1.  In the full SVD of handMat, what would be the sizes of the U, S and V \
matices?
U is 85x85
S is 85x100
V is 100x100
2.  What is the maximum rank of handMat (=the maximum number of nonzero \
singular values)?
85
3.  Assuming this maximum rank, what would be the size of the reduced Ur, Sr, \
and Vr matrices?
Ur is 85x85
Sr is 85x85
Vr is 100x85
4.  Of course, only the diagonal entries of Sr need to be stored.  Based on \
your answers in 3, how many total entries are there in Ur, Sr-diagonal, and \
Vr (all together)?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(85^2 + 85 + 85 \((100)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`15810\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reducing the Reduced SVD", "Subsubsection"],

Cell["\<\
Let's see what Mma returns for the reduced SVD.  It will not report any zero \
singular values and very small (maybe roundoff error) singular values are \
also eliminated (controlled by a Tolerance option) as being practically zero. \
 First we see how many \"really nonzero\" singular values Mma finds.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[handMat];
Length[sings]\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`67\)], "Output"]
}, Open  ]],

Cell["\<\
Now let's count the total number of numbers saved in this reduced SVD:\
\>", "Text"],

Cell[CellGroupData[{

Cell["Length[Flatten[{UrT, sings, VrT}]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`12462\)], "Output"]
}, Open  ]],

Cell["\<\
This is definitely not savings, the original image was 8500 entries and when \
I tried the above it showed 12462 entries stored for the reduced SVD.  But \
some of the singular values still may be relatively small, lets take a \
look.\
\>", "Text"],

Cell[CellGroupData[{

Cell["sings", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{20.8968787603439709`, 6.23310188350080274`, 4.98378940786858137`, 
      4.10240328672944531`, 3.80014674312589573`, 3.38852763204501261`, 
      2.4439033795775491`, 2.10705515554154132`, 1.76906206711051572`, 
      1.61528554823613745`, 1.50629589632601241`, 1.37456256947956423`, 
      1.2951197855575527`, 1.17195952970450423`, 1.12996283449227941`, 
      0.953432522974551943`, 0.897073215326233786`, 0.849147392588707106`, 
      0.757757615420413976`, 0.656914258503850589`, 0.620261028833087202`, 
      0.594462332651144365`, 0.540273771650827239`, 0.496705535656108132`, 
      0.494246720536564954`, 0.437337082952502864`, 0.411845890904690747`, 
      0.380872913381804458`, 0.338629447581178366`, 0.316057853838735569`, 
      0.297784238142995327`, 0.284663016129488788`, 0.281336973296836454`, 
      0.24647095610631915`, 0.228480921780065493`, 0.22125485748858984`, 
      0.194079088697800887`, 0.182884234493903754`, 0.159041152686707443`, 
      0.147483323915958859`, 0.135952348152151847`, 0.134190933849413851`, 
      0.126620444374285967`, 0.120955283254192513`, 0.110077032259125551`, 
      0.105163434572478475`, 0.0874964722206372513`, 0.0791318135875758166`, 
      0.0729873006705619786`, 0.069236898640847686`, 0.0621774170085157695`, 
      0.060816835854882898`, 0.0542510574370862119`, 0.0447719041448949628`, 
      0.0405594019617029033`, 0.0385996468471156148`, 0.0336637893562242229`, 
      0.0261832346859889053`, 0.0222052009963557805`, 0.0195993148309608109`, 
      0.0175604105895608642`, 0.0099179070159536149`, 
      0.00600014212334685304`, 0.00289810853644431674`, 
      0.00155349010723942253`, 0.00102708532643114502`, 
      0.000111896288058324899`}\)], "Output"]
}, Open  ]],

Cell["\<\
Clearly, the last few of these are negligible.  Let's only keep singular \
values larger than  0.2  (1/100 of the largest singular value) in an \
approximate SVD and try recreating an approximate image.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Take[sings,36]", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{20.8968787603439709`, 6.23310188350080274`, 4.98378940786858137`, 
      4.10240328672944531`, 3.80014674312589573`, 3.38852763204501261`, 
      2.4439033795775491`, 2.10705515554154132`, 1.76906206711051572`, 
      1.61528554823613745`, 1.50629589632601241`, 1.37456256947956423`, 
      1.2951197855575527`, 1.17195952970450423`, 1.12996283449227941`, 
      0.953432522974551943`, 0.897073215326233786`, 0.849147392588707106`, 
      0.757757615420413976`, 0.656914258503850589`, 0.620261028833087202`, 
      0.594462332651144365`, 0.540273771650827239`, 0.496705535656108132`, 
      0.494246720536564954`, 0.437337082952502864`, 0.411845890904690747`, 
      0.380872913381804458`, 0.338629447581178366`, 0.316057853838735569`, 
      0.297784238142995327`, 0.284663016129488788`, 0.281336973296836454`, 
      0.24647095610631915`, 0.228480921780065493`, 0.22125485748858984`}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
bigSings = Take[sings,36];
UaT = Take[UrT,36];
VaT = Take[VrT,36];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[newHand];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000103050C13
1A1E212728201F1C18130F0C0A0F141B242A2A2B20110600
000000000000000000010000000000000200000100000000
000001000000000000000101010000000000000000000000
00000000
000000000000000000000000000000000000000102050B12
1A1D22282C272725201A130C0A10161D2941505851391605
020000000000000000000000000000000000000000000000
000000000100000000000001000000000000000000000000
00000000
000000000000000000000000000000000000000002040A11
181C21282E302E2D2823180F0D0D0D1626343132363B2913
090000000000000000000000000000000100000101000000
000100000001010000000000000000000000000000000000
00000000
00000000000000000000000000000000000000000103070D
13181D252F353334332B211B1C19151D1C1712131819161C
1E1509030403020100000100000000000001000000010000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000010306
0B0F141D2B38353A35302C2C2E28232D1D0E0A0C12100D10
13191A181C1F232215100B03010000010003000000020000
020000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0105091120353439393334373529293E29180C0912141521
150E0A05070D161B16181B1516100C0D090A020000030000
020000000001010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000040F222E3537383B3C342929433C270B091C1B163A
2A0E070605000105010915161A1A19211C180D0802000000
010000000003010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000009223135383C3A32252E574B250D02519F2F3D
330C0D05040219261B0206050206080C0E151B1A0D030001
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000010004041D2B363A3633262D4C491F14051E737E48
1C04080C001338484E210002010005040A08151E140F0500
000001010000010402020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071C2D3738322B2A3238190B131D365146
280B0101183D3A2A252F21130A030405070C0E1010160F02
000000010000000000010100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010000071931353331312C233F516D8A9E8776
50110017494B3937292D281E200C01060909060A12211601
000000000000000000020000030000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000100000000071B2F35312F2F1D3FA9D2D2CDB78E
39000D4354575A6262544C3F221008030601060D131B1000
000300000001000000000000010000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01000000000000000000061A32352E2A22175AAEBCA5772C
00063E5D67665F5D5A594D4C4F452B110103080F0C110D00
000200000300000000000200000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000002000000061B30342C201A0D0D0A080100
00256269625C4E4E4943424E5754523D1605010D14100600
020201000003000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000300071F3130221E100600000003
133659584C43403A362F333C42413D2F231D0C101A130900
000101020102000103010001000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01000000000001000000020000081D302920170B04010316
233648463D3A39363E55778A8782775C3F251519190D0602
000104030000000002020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000020000000001010008212E27180E0806161B
1D2B39413C3A424B6190BCCCC2BBB1AC9E6A1D1612080306
070302010100000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010000000000000000010629290D050A101614
1A2631373F4D54697B7785A9D5E7DBD0C5A438191710080A
0D0A00010000010100000000020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000040100000000010000070E040B07000310110D14
1C28343D4959758D8E64354288C1D7DCD2BD53241E170D14
1B0A00000200020000030000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010000010002000123290F0201040C0E100D17
2332414B5D708D90A0AA762F16346D98AAA36B563E28161C
180101000001010000030000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000010200000000000004181A1E170905090D10100F24
34455F7886978B471F61BAB0793A151C5C94979599743617
060100000100000200010101000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000001010000000000001431180E0F080A1012131D2942
576D7D96A0A4937D52151F51A1C39C7E7CABBDB7CBC58522
030603020201000000000200000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000003010202272B1B23221F14111D222E526877
8C939FA1ABA0ACB5B1976135296DB8CFC8BCB2B4A9A16310
060405030804000000000500000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000201031B2F1D0801020F121F324F6D89979B
9FA5AF9CAAB09C8D8BA4AEAF84373B5385BBBCAA96630E03
040406050904000001060A04000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000211213131312B180D1D365786A2A5A6A8
ADB2BAAEAC8B3A112B6683A1B49481656DABBCA68F5A1C1E
0D0E0D0A0603070209150700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000051623222E3A3C3C2F1D375E86A3A39B9998
A5BAB8B4A4716E35071D64BDDEE0E6DDB7AEB29471433A46
3229210F0504121E0D070000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000032338371A18232022272D3A527C878D8A8B92
A4B3BAC7AD7995706480858CABCED9DBC9AC88665B384256
41505237201C262D05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000010342E2B26130408111B2A37444B435B5E5462
80A9C2C1BE86777C96999A9FAFB5C3CEC1973D2C3B2A3F5F
40658A745139321600020303000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000011E31231E2B28180E0E182D322212072559838F
8391B7B6B2927DA8C2A1999EA5B5CDD2B8510B1221182767
64659DB28A4A200000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000003322C2A26232C2B17071427381C141518316D7D
A09C98A49482A1DDC8B5A99DA4C6CDCF912217130F0C1149
81606FA0852B000102010001000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000034D6E5622262A33332A1520504B2D27495E5A70
816E72746C669AC4A8B2BBBFC6C6CCD4713432301C08042A
636C513F1E00000401010000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000992AA431B1B181317241F2B679C7E5C657A6C53
4A3A37323360A5AAA1B0C3C9C6BDB3C97F5556553C11020E
3C6964441F0B000003030000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000001B9E953034321F0B080B1B3D75ABCCB79D816846
271712063BB5B58599ADA3ABB7BCBABC7D756D433B1E0502
1E4A60574320030208070300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000012AD0865B6829172B3B2B1D4176A9C5DDC9BDA357
2D14081C7AD6BB83847B768A969A9DB2857B8B5E26120703
08295754442B0B00000C0A02000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000011AABD9559568392846B3D416994BBD5E2E5DCD7
BF9780A1CDD7B76B4B42618898A9A3AB917B92934B1F1106
04214F675B40210303151807010000000000000000000000
00000000
000000000000000000000000000000000000000000000102
0201000000509D361B79A1642726343A4F79A8C2D6DBEEEF
EFEBDDD6CACAB352213B4E83969DA3B4AD868A957640210E
0919486D7B5B340C00153219000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000003060949050476F835B2F2D3B70969FBBCBD8DA
DEE0E6DACACFD0862524506C7B806F667D7F8E9083633C12
0010366B856E4D1903273D1E000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000149663E9EA6AEA47972715B555985A7B7C6D1D8
E0E5EAEDE9E7DFC982404F786E69574C5566868B85694B28
050128537C7E501C042E482A080000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000010262D08E7BC8C869212F47524740558BB4C4C5D0
E2E9F3F1ECE5E2E4E2BF93959996999871465E8A846F5837
140511396C8261280420502C040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000270C5A66E4F556F62533B3C1F22334767A7C0CC
CCD0EAEBE3E1DEDDE0E5D3BDBDC1B5AB7A26477D7E765E3E
251006285F876A3609305E300D0000000000000000000000
00000000
000000000000000000000000000000000000000000000101
00000000006CADB78D538AD0C1B4A5A98065717E716E92C9
D0C7D1D6DBD7D2D6D1D6C5B5BABDB49C6E3A5D8782826C42
2B1906255A806B41184C693C1A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
010101000083BBAB9795C9CDBDDDF2D5C5BFA07669828B9A
D5DCCDCECCD1CAC4C0B7B8A7A6A898704B3644808C8D8458
351F083568827640256966461F0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000168C0B9B4B19164656595CDCBBBAEA5998DA796
BBC4A9A1969FA4A7A6999AA69E7B5B35120224738988855F
2D1A114285857935417A643B0E0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000027C2BFD3A973B2F1D2A1A8B3C3DFEBECCFBEAD
8E9080705B525B6C766B635D4D4C415F665320637B7F8968
371B154C927D5B2C6867370C000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000010005A8C6B7CAEEF8EDEDEAE9EAF6EFEAEBD1B3A6
989AAFB3B68D7E6A5A412925160E1A2F60500E547F817F6D
4C2C19659771433D75450900000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01000000000064DAC5B7D5D9CECACAD2DCCFD3C4ADB5A18D
7E6E7B7194B5734782979C8D86623C15362C2A4777837B6E
49342C87936C3C584B100000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000010022D0D0CBD5D9E4E5ECEADEDFAC5C39536A6E
66648EA0A3C2B36A435B6E7090A8B59C7D3E58697A7B8074
512C4E99895F413C0A000404000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E4CFD0D9DAE6E8DBDBB2270609091B57
7485B7BCC2B2B4D48C56595773A0AF98654C6B8284828269
482C628F734B220400000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000040011B9E3CDD1D5CFD9E9DD6226261E16092A
6CA4B9C6CAA582BBBE9581785A534C603F5F7A8084878662
3C316F7C5E2A050104010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000100000031BEE7D8DBDBDCD4BA828078643D2A13
45B1D2A7C3CB7D7A91BC9D9D905C7C7D3D677B848C8E7A60
433A6E683C05010000020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000001020001001CAAEFE0DDE2DAB7A5BFDEDDA3694B
2D90DB94A4CFCDBFAAB2C0AAB1BDBD513C697888938D7B60
3D425F511A01000101010001020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000020003000777E4F0E1DAAAA3CBEDE0C49582
347CD7C593909EBEC799A2A5AC7A474447697A889287755E
3E3C4E2D0300000000000100010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000020000000200004DAEE9E69F80A7E5CBA5888A
3D53AAC1C1BFC5ABB495947D4D213956525B7C908F7F6D54
2D2838130001030302010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000200020002000001000041A79C726F969B807070
434C8BAFA5A5C7BDAB84390C1735434B5F6783918A796646
21222E070000000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000202
0302000000000100010000000000000A5B6E7393987E6A56
3F385E76818B8B713F0D0A1B1C3A4E4E53728A8C81735A30
1C2B1B020000010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000002000000000000000100003C6662676A604F41
362B50645E53351703101F2421374D565D7189888572492E
26250A000001000300000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000002000000000101000000000035736B6A67574333
2D271E11080E12141218312E2939495B7C8C837C74674B34
241000000200000002020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000020000020000012B8A7B746D5D472F
2C2C14090F1419171B2635303A3F435B828C7E7E7366522F
0E0000000001020102000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001000000000000010000001588766C66635938
362B11101B111920233535304C56576B7B76747C71644919
000001010002030000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000300000000000000000000057F97867A776753
482B15181F1A1D252B3D374666687182746C75695B472001
000000000000000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000010000000000000001000C6A989088817169
4E2B1C20181C252836414256737A78766C69604A3F240600
000100000000000101030000000000000000000000000000
00000000
000000000000000000000000000000000000000000000101
010100000001000100000001000000001B598C94847B7567
462A1B261D222D324C4E55696F787B7A6D564A3A1A010003
000000010000000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000002000001010000000100001D56868F8879685D
402A2523283430445B5A667874737B7B664B250E04000000
020100000001000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000100000000000001000001020C59848E88736654
40322D2C343245606069757E78757C734A1C010000000200
010000000000010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000010000000001040203437D877C685F4E
3F3633373A48586568778180817C6C441300000002000000
000000000000020000010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000001000000000000000100030100216C8478615C52
433E3E4A4B5A5D6672768380746141160000010002000000
000000010000020300000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000100010000000001010102063E797F67675B
4A464E575D63646D7578745B4B3F24030001000000000001
000000000000000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000300010000000201000305061745606D6F65
5A55585A6164676E675B5345442F0E000001000000000001
000000000001000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000200000400010B0B0B182738545F5E
605F5C5E63656360574F4C43351801000100000002000000
000000000000000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000100000100020D18171E262C3C5255
585E636064685E59534E4C42220300000200000201000000
000101000000000100000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000020000000003060D1C1C2022252E4454
5E6366645E5F5A5856524D2E070000000300000201000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000100000100050B0F1924262220202D3E
525B61655C5C5A5957573E13000000000100000101000000
000000000000000000000000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000103080E11162A353E44423F45
555C606262605C5D5B552A02000000000001000000000000
000000000000000000000000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000010000010003070B0E1319293E5664707370
7072736E6A645E615D3F0F00000000010000020000000000
000000000000000001000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010000020305070A0C111D2538424C5E646C
6D70716A625E5B62591F0000000000000000010000000100
000000000001000001000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000003000002020403050B11121C26303A444F525F
666D716D6A68706D44050003000000000000000000000300
000000000101000001000001000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000200000002010102070A12161C292F3B494D5967
6F747A7A746F775514000001000000000000000000000100
020000000200000000010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000001000101000203040A0C141B2228313E4B53616E
767B7D7A746E632F00000100000000000000020000000100
000000000100010200000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000001020000000409090F151A1F292B37424C596673
77777975746E430B00020000000000000000030000000101
000000000100010401000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000002040001020A0D0F161B1C212D303945515C6577
777278766E561E0000020000000000000000010000010001
000000000102000000000000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000010103030003060B1115191E1F262D353B4B5A646876
746D706A5B34060002010001010000010000000000010000
000000000001000000010000010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010203030000060B0A11171B1F232E2F363D4E5D686B6E
6F6A67634613000000000000000000010200000200000100
000201000000000001020001010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00020405040007070C1113171C1F232C303B46535E646669
69655E522901000100000000000200000200000200000000
000100000000000000010001000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0103050607050B0A0F1111151D212429303B49515A626764
5E5F563B0E00000001000100000200000000010000000000
020000010000000000000202000000000000000000000000
00000000
000000000000000000000000000000000000000000000102
040608090B080F0D101012161B1F2128303F47535A5B5B5B
5456441A0000000000000000000000000000020000000100
000000010000000100000301000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooole000000800@410`030`<300D51@8030`<0`0C4a<301XJ6P<0
7QhN0P0Q8B4302LW9`<0:2PX0`0P820201lO7`<071`L0`0H61P301<C4`803`l?0`0<30`300X:2P<0
3`l?0P0D51@301/K6`<092@T1@0Z:RX302/[:`<0820P0`0A4A4200H61Q`000000P010@4A000000<0
0P821@00000300410A0000000`010@4C000000P00@41:@0000080?ooo`001P3ooole000000800@41
0`030`<300D51@8030`<0`0C4a<301XJ6P<07QhN0P0Q8B4302LW9`<0:2PX0`0P820201lO7`<071`L
0`0H61P301<C4`803`l?0`0<30`300X:2P<03`l?0P0D51@301/K6`<092@T1@0Z:RX302/[:`<0820P
0`0A4A4200H61Q`000000P010@4A000000<00P821@00000300410A0000000`010@4C000000P00@41
:@0000080?ooo`001P3ooole000000800@410`020P8300D51@802`/;0`0B4Q8301XJ6P<07AdM0P0R
8R8302PX:0<0;2`/1@0W9bL302DU9@<0820P0`0J6QX201<C4`<030`<0`0:2PX3010@40805QHF0`0M
7Ad302TY:@<0@D510P1@D50305QHF0<0DE5A0`0i>CT201HF5P<01@D50`020P9:000000800@414@00
000300410B/00000203oool000H0oooo=@00000200410@<00P820`051@D200/;2`<04Q8B0`0J6QX3
01dM7@808R8R0`0X:2P302`/;0D09bLW0`0U9BD3020P80<06QXJ0P0C4a<300`<30<02PX:0`0@4102
01HF5P<07AdM0`0Y:BT30451@@80D51@0`1HF5P3055AD@<0>CTi0P0F5QH300D51@<00P82BP000002
00410A4000000`010@4[000000P0oooo00060?ooocD000000P010@4300820P<01@D50P0;2`/3018B
4P<06QXJ0`0M7Ad2028R8P<0:2PX0`0/;2`502LW9`<09BDU0`0P820301XJ6P804a<C0`0<30`300X:
2P<0410@0P0F5QH301dM7@<0:BTY0`11@D42051@D0<0F5QH0`1ADE4303Ti>@805QHF0`051@D30082
0TX000000P010@4A000000<00@41:`0000080?ooo`001P3ooolg000000<00P820`0410@200X:2P<0
4A4A0`0H61P301`L70808B4Q0`0X:2P302h^;P<0<30`0P0^;Rh302d];@<0:2PX0`0S8b<201PH60<0
3`l?200=3@d301HF5P<09RHV0`0d=3@2034a<@<0<S8b0`0f=SH303/k>`80:BTY0`0C4a<300T92BT0
00000`010@45000000H00@412`00000200410@P000001P010@4i000000P0oooo00060?ooocL00000
0`020P8300@410802PX:0`0A4A4301PH60<071`L0P0Q8B4302PX:0<0;Rh^0`0`<30202h^;P<0;Bd]
0`0X:2P302<S8`8061PH0`0?3`l800d=3@<05QHF0`0V9RH303@d=080<C4a0`0b<S8303Hf=P<0>c/k
0P0Y:BT301<C4`<02@T9:@00000300410@D000001P010@4;000000800@412000000600410CT00000
203oool000H0oooo=`00000300820P<010@40P0:2PX3014A4@<061PH0`0L71`2024Q8@<0:2PX0`0^
;Rh3030`<080;Rh^0`0];Bd302PX:0<08b<S0P0H61P300l?3`P03@d=0`0F5QH302HV9P<0=3@d0P0a
<C43038b<P<0=SHf0`0k>c/202TY:@<04a<C0`092@TY000000<00@411@00000600410@/000000P01
0@48000000H00@41>@0000080?ooo`001P3ooolg000000<00@410`030`<200L71`<03@d=0`0C4a<3
01PH60807AdM0`0U9BD302l_;`<0=CDe0P0c<c<303@d=0<0<c<c0`0[:b/2024Q8@<06a/K0`0L71`3
01TI6@805ADE0`0M7Ad301`L70<05aLG0P0B4Q8301<C4`<061PH0`0I6AT201HF5P<071`L0`0N7Qh2
01DE5@<02@T90`030`<300@410800`<30`020P8300410@D000000`010@4A000000800@412@000002
00410E800000203oool000H0oooo=`00000300410@<00`<30P071`L300d=3@<04a<C0`0H61P201dM
7@<09BDU0`0_;bl303De=@80<c<c0`0d=3@303<c<`<0:b/[0P0Q8B4301/K6`<071`L0`0I6AT201DE
5@<07AdM0`0L71`301LG5`804Q8B0`0C4a<301PH60<06ATI0P0F5QH301`L70<07QhN0P0E5AD300T9
2@<00`<30`0410@200<30`<00P820`010@45000000<00@414@00000200410@T000000P010@5B0000
00P0oooo00060?ooocX000000`010@4200<30`<01PH60`0;2`/300l?3`8051@D0`0M7Ad302/[:`<0
>3Ph0P0e=CD303Xj>P<0=CDe0`0`<30502`/;0<0;Rh^0`0X:2P202<S8`<0;Bd]0`0M7Ad300h>3P80
2PX:0`0<30`3018B4P<0410@0P0=3@d3010@40<04a<C0P0I6AT301XJ6P<061PH0`0L71`201lO7`<0
8b<S0`0R8R8301DE5@80410@0`0;2`/300<30`<00@411@00000300410@<000000P030`<900000080
0P821P00000300820TT00000203oool000H0oooo>P00000300410@800`<30`061PH300/;2`<03`l?
0P0D51@301dM7@<0:b/[0`0h>3P203De=@<0>SXj0`0e=CD3030`<0D0;2`/0`0^;Rh302PX:0808b<S
0`0];Bd301dM7@<03Ph>0P0:2PX300`<30<04Q8B0`0@410200d=3@<0410@0`0C4a<201TI6@<06QXJ
0`0H61P301`L70807alO0`0S8b<3028R8P<05ADE0P0@410300/;2`<00`<30`010@45000000<00@41
0`00000200<30`T000000P020P86000000<00P82B@0000080?ooo`001P3ooolj000000<00@410P03
0`<300H61P<02`/;0`0?3`l201@D50<07AdM0`0[:b/303Ph>080=CDe0`0j>SX303De=@<0<30`1@0/
;2`302h^;P<0:2PX0P0S8b<302d];@<07AdM0`0>3Ph200X:2P<030`<0`0B4Q83010@40803@d=0`0@
410301<C4`806ATI0`0J6QX301PH60<071`L0P0O7al302<S8`<08R8R0`0E5AD2010@40<02`/;0`03
0`<300410@D000000`010@43000000800`<32@00000200820PH000000`020P99000000P0oooo0006
0?oood8000000`010@4300D51@802@T90`0A4A43020P80<0=CDe0P0d=3@603Ti>@<0<c<c0P0d=3@3
03Lg=`<0=CDe1@0Y:BT303hn?P<0:BTY0`0H61P200`<30<02@T90`0B4Q8301@D50805ADE0`0Q8B43
01DE5@803Ph>0`0:2PX300D51@<01`L70P0=3@d301HF5P<06a/K0`0F5QH201PH60<06a/K0`0E5AD3
01HF5P80410@0`0<30`300d=3@<02@T90P0:2PX300820PH000000P030`<6000000<00P822P000006
00410CT00000203oool000H0oooo@P00000300410@<01@D50P092@T3014A4@<0820P0`0e=CD203@d
=0H0>CTi0`0c<c<203@d=0<0=cLg0`0e=CD502TY:@<0?Shn0`0Y:BT301PH608030`<0`092@T3018B
4P<051@D0P0E5AD3024Q8@<05ADE0P0>3Ph300X:2P<01@D50`071`L200d=3@<05QHF0`0K6a/301HF
5P8061PH0`0K6a/301DE5@<05QHF0P0@410300`<30<03@d=0`092@T200X:2P<00P821P00000200<3
0`H000000`020P8:000000H00@41>@0000080?ooo`001P3ooom2000000<00@410`051@D200T92@<0
4A4A0`0P820303De=@80=3@d1P0i>CT303<c<`80=3@d0`0g=cL303De=@D0:BTY0`0n?Sh302TY:@<0
61PH0P0<30`300T92@<04Q8B0`0D51@201DE5@<08B4Q0`0E5AD200h>3P<02PX:0`051@D300L71`80
3@d=0`0F5QH301/K6`<05QHF0P0H61P301/K6`<05ADE0`0F5QH2010@40<030`<0`0=3@d300T92@80
2PX:0`020P86000000800`<31P00000300820PX000001P010@4i000000P0oooo00060?ooodX00000
0`0410@300l?3`<08R8R0P0^;Rh303De=@<0=cLg0`0h>3P203/k>`<0?3`l0`0d=3@502TY:@<0@d=3
0`0l?3`302LW9`802`/;0`092@T301`L70<06a/K0P0F5QH303Xj>P<0:RXZ0P0>3Ph300L71`<01PH6
0`051@D2000000<00@410`051@D300410@802@T90`0E5AD301HF5PD06QXJ0`0I6AT3024Q8@<071`L
0P0H61P300d=3@<020P80`020P88000000<00@412P00000300<30`<00@41>@0000080?ooo`001P3o
oom:000000<010@40`0?3`l3028R8P80;Rh^0`0e=CD303Lg=`<0>3Ph0P0k>c/303`l?0<0=3@d1@0Y
:BT304=3@`<0?3`l0`0W9bL200/;2`<02@T90`0L71`301/K6`805QHF0`0j>SX302XZ:P803Ph>0`07
1`L300H61P<01@D50P00000300410@<01@D50`010@4200T92@<05ADE0`0F5QH501XJ6P<06ATI0`0Q
8B4301`L708061PH0`0=3@d300P820<00P822000000300410@X000000`030`<300410CT00000203o
ool000H0ooooBP00000300@410<03`l?0`0R8R8202h^;P<0=CDe0`0g=cL303Ph>080>c/k0`0l?3`3
03@d=0D0:BTY0`13@d<303`l?0<09bLW0P0;2`/300T92@<071`L0`0K6a/201HF5P<0>SXj0`0Z:RX2
00h>3P<01`L70`061PH300D51@8000000`010@4300D51@<00@410P092@T301DE5@<05QHF1@0J6QX3
01TI6@<08B4Q0`0L71`201PH60<03@d=0`0820P300820PP000000`010@4:000000<00`<30`010@4i
000000P0oooo00060?oooe0000000`092@T2028R8P<0<C4a0`0e=CD303Ph>080?3`l0`0j>SX3038b
<P<09BDU0P0^;Rh305MGE`<0Bd];0`0U9BD200d=3@<00P820`1ADE4309nOW`80;bl_0`0m?Cd303<c
<`8030`<0`0=3@d300D51@<010@40P020P8301TI6@<09RHV0`0K6a/200820P<01PH60`051@D30082
0P801PH60`0820P300`<30<03Ph>0P0E5AD301/K6`<06QXJ0`0=3@d200<30`<000000`010@5<0000
00P0oooo00060?oooe0000000`092@T2028R8P<0<C4a0`0e=CD303Ph>080?3`l0`0j>SX3038b<P<0
9BDU0P0^;Rh305MGE`<0Bd];0`0U9BD200d=3@<00P820`1ADE4309nOW`80;bl_0`0m?Cd303<c<`80
30`<0`0=3@d300D51@<010@40P020P8301TI6@<09RHV0`0K6a/200820P<01PH60`051@D300820P80
1PH60`0820P300`<30<03Ph>0P0E5AD301/K6`<06QXJ0`0=3@d200<30`<000000`010@5<000000P0
oooo00060?ooodX000000`010@43000000D010@40`0M7Ad302/[:`<0=SHf0P0j>SX303Hf=P<0<c<c
0`0V9RH202d];@<0C4a<0`19BDT301lO7`8051@D0`051@D301hN7P<0Lg=c0P1nOWh304Q8B0<071`L
0P0410@300P820<030`<0`00000201<C4`<0>3Ph0`18B4P304i>CP808B4Q0`00000300820P<00@41
0P00000300D51@<010@40`0:2PX200P820<05ADE0`0N7Qh301@D50803`l?0`051@D8000000H00@41
1@00000300410@<010@41@020P8a000000P0oooo00060?ooodX000000`010@43000000D010@40`0M
7Ad302/[:`<0=SHf0P0j>SX303Hf=P<0<c<c0`0V9RH202d];@<0C4a<0`19BDT301lO7`8051@D0`05
1@D301hN7P<0Lg=c0P1nOWh304Q8B0<071`L0P0410@300P820<030`<0`00000201<C4`<0>3Ph0`18
B4P304i>CP808B4Q0`00000300820P<00@410P00000300D51@<010@40`0:2PX200P820<05ADE0`0N
7Qh301@D50803`l?0`051@D8000000H00@411@00000300410@<010@41@020P8a000000P0oooo0006
0?ooodX000000`010@43000000D010@40`0M7Ad302/[:`<0=SHf0P0j>SX303Hf=P<0<c<c0`0V9RH2
02d];@<0C4a<0`19BDT301lO7`8051@D0`051@D301hN7P<0Lg=c0P1nOWh304Q8B0<071`L0P0410@3
00P820<030`<0`00000201<C4`<0>3Ph0`18B4P304i>CP808B4Q0`00000300820P<00@410P000003
00D51@<010@40`0:2PX200P820<05ADE0`0N7Qh301@D50803`l?0`051@D8000000H00@411@000003
00410@<010@41@020P8a000000P0oooo00060?oooeD000000`071`L301`L70<0;Bd]0P0g=cL303Ph
>0<0<S8b0`0[:b/202XZ:P<0<S8b0`0h>3P301TI6@802`/;0`0C4a<301dM7@<0=SHf0P1ADE4304I6
AP<0:2PX0P0;2`/600410@<061PH0P0m?Cd303Xj>P<0:RXZ0`0U9BD202l_;`<08B4Q0`0C4a<300X:
2P800`<30`0410@300D51@<01`L70P0<30`300h>3PH0410@0P0F5QH300l?3`<00P82200000030041
0@d000001P010@4^000000P0oooo00060?oooeD000000`071`L301`L70<0;Bd]0P0g=cL303Ph>0<0
<S8b0`0[:b/202XZ:P<0<S8b0`0h>3P301TI6@802`/;0`0C4a<301dM7@<0=SHf0P1ADE4304I6AP<0
:2PX0P0;2`/600410@<061PH0P0m?Cd303Xj>P<0:RXZ0`0U9BD202l_;`<08B4Q0`0C4a<300X:2P80
0`<30`0410@300D51@<01`L70P0<30`300h>3PH0410@0P0F5QH300l?3`<00P822000000300410@d0
00001P010@4^000000P0oooo00060?oooeD000000`071`L301`L70<0;Bd]0P0g=cL303Ph>0<0<S8b
0`0[:b/202XZ:P<0<S8b0`0h>3P301TI6@802`/;0`0C4a<301dM7@<0=SHf0P1ADE4304I6AP<0:2PX
0P0;2`/600410@<061PH0P0m?Cd303Xj>P<0:RXZ0`0U9BD202l_;`<08B4Q0`0C4a<300X:2P800`<3
0`0410@300D51@<01`L70P0<30`300h>3PH0410@0P0F5QH300l?3`<00P822000000300410@d00000
1P010@4^000000P0oooo00060?oooe0000000`010@45000000<01`L70`0I6AT2034a<@<0=CDe0`0c
<c<5034a<@<0;2`/0`0S8b<303lo?`80DE5A0`1]KFd308Z:RP<0WYjN0P27QhL307IfMP<0D51@0P0A
4A43000000<05aLG0`19BDT204];B`<0>CTi0`0g=cL302TY:@80;Bd]0`0X:2P301hN7P<0820P0P0<
30`300410@<01PH61@092@T300H61P<02PX:0`0B4Q82024Q8@<05QHF0`010@4H000000<00P821P00
000200<30bT00000203oool000H0ooooD000000300410@D000000`071`L301TI6@80<C4a0`0e=CD3
03<c<`D0<C4a0`0/;2`302<S8`<0?clo0P1ADE4306e]K@<0RXZ:0`2NWYh208N7Q`<0MWIf0`1@D502
014A4@<000000`0G5aL304U9B@80Bd];0`0i>CT303Lg=`<0:BTY0P0];Bd302PX:0<07QhN0`0P8202
00`<30<00@410`061PH500T92@<01PH60`0:2PX3018B4P808B4Q0`0F5QH300410AP000000`020P86
000000800`<3:@0000080?ooo`001P3ooom=000000<00@412`00000300L71`806a/K0`0_;bl303De
=@<0<C4a1@0_;bl301dM7@<0?clo0P2YZJT60=;BdP<0cLg=0P2g]kL308j>SP<0>CTi0P00000300d=
3@<0@d=30`1DE5@205MGE`<0FUYJ1P1RHV8205ADE0<0C4a<0`0o?cl3028R8P80410@0`0820P300<3
0`<01PH60P010@4300H61P<03@d=0`0C4a<201/K6`<0410@1P00000200<30`P000000`010@4A0000
00800@41:@0000080?ooo`001P3ooom=000000<00@412`00000300L71`806a/K0`0_;bl303De=@<0
<C4a1@0_;bl301dM7@<0?clo0P2YZJT60=;BdP<0cLg=0P2g]kL308j>SP<0>CTi0P00000300d=3@<0
@d=30`1DE5@205MGE`<0FUYJ1P1RHV8205ADE0<0C4a<0`0o?cl3028R8P80410@0`0820P300<30`<0
1PH60P010@4300H61P<03@d=0`0C4a<201/K6`<0410@1P00000200<30`P000000`010@4A00000080
0@41:@0000080?ooo`001P3ooom=000000<00@412`00000300L71`806a/K0`0_;bl303De=@<0<C4a
1@0_;bl301dM7@<0?clo0P2YZJT60=;BdP<0cLg=0P2g]kL308j>SP<0>CTi0P00000300d=3@<0@d=3
0`1DE5@205MGE`<0FUYJ1P1RHV8205ADE0<0C4a<0`0o?cl3028R8P80410@0`0820P300<30`<01PH6
0P010@4300H61P<03@d=0`0C4a<201/K6`<0410@1P00000200<30`P000000`010@4A000000800@41
:@0000080?ooo`001P3ooolo000000H00@416@00000200H61P<06QXJ0`0b<S8303De=@80;Rh^0`0Z
:RX3028R8P<05aLG0P1JFUX30:j^[P<0_;bl0`2UYJD207MgM`<0;2`/0`00000200H61P<0?Shn0`1M
GEd306MWI`80IVIV0`1OGel305eMG@<0FUYJ0P1IFET304e=C@<0C4a<0`1?Cdl204E5A@<0:b/[0`0A
4A4300410@800`<30`0820P300l?3`<030`<0P0A4A4300d=3@H000000P020P86000000800`<33P00
000300820Rh00000203oool000H0oooo?`00000600410AT000000P061PH301XJ6P<0<S8b0`0e=CD2
02h^;P<0:RXZ0`0R8R8301LG5`80FUYJ0`2^[Zh30;bl_0<0YJFU0P1gMgL302`/;0<000000P061PH3
03hn?P<0GEeM0`1WIfL206IVIP<0GemO0`1MGEd305YJFP80FEUI0`1=CDd304a<C0<0Cdm?0P15ADD3
02/[:`<04A4A0`010@4200<30`<020P80`0?3`l300`<30804A4A0`0=3@d6000000800P821P000002
00<30`h000000`020P8^000000P0oooo00060?ooocl000001P010@4I000000801PH60`0J6QX3038b
<P<0=CDe0P0^;Rh302XZ:P<08R8R0`0G5aL205YJFP<0[Zj^0`2l_;`30:FUY@80MgMg0`0/;2`30000
00801PH60`0n?Sh305eMG@<0IfMW0P1VIVH305mOG`<0GEeM0`1JFUX205UIF@<0CDe=0`1<C4`304m?
C`80ADE50`0[:b/3014A4@<00@410P030`<300P820<03`l?0`0<30`2014A4@<03@d=1P0000020082
0PH000000P030`<>000000<00P82;P0000080?ooo`001P3ooomE000000<00P822000000300H61P<0
6a/K0`0`<30203@d=0<0;2`/0`0P820301XJ6PD03@d=0`0:2PX300P820800@411P00000202DU9@<0
HV9R0`1YJFT3069RHP80G5aL1P1>CTh304U9B@80@d=30`12@T8304i>CP<0EeMG0P1DE5@3059BDP<0
?Cdm0`0F5QH200D51@<00@410`0=3@d301@D5080410@0`061PH3000000D00P820`010@45000000<0
0`<3?00000080?ooo`001P3ooomE000000<00P822000000300H61P<06a/K0`0`<30203@d=0<0;2`/
0`0P820301XJ6PD03@d=0`0:2PX300P820800@411P00000202DU9@<0HV9R0`1YJFT3069RHP80G5aL
1P1>CTh304U9B@80@d=30`12@T8304i>CP<0EeMG0P1DE5@3059BDP<0?Cdm0`0F5QH200D51@<00@41
0`0=3@d301@D5080410@0`061PH3000000D00P820`010@45000000<00`<3?00000080?ooo`001P3o
oomE000000<00P822000000300H61P<06a/K0`0`<30203@d=0<0;2`/0`0P820301XJ6PD03@d=0`0:
2PX300P820800@411P00000202DU9@<0HV9R0`1YJFT3069RHP80G5aL1P1>CTh304U9B@80@d=30`12
@T8304i>CP<0EeMG0P1DE5@3059BDP<0?Cdm0`0F5QH200D51@<00@410`0=3@d301@D5080410@0`06
1PH3000000D00P820`010@45000000<00`<3?00000080?ooo`001P3ooomN000000800`<30`000003
00L71`<07alO0P0a<C43030`<0<08R8R0`0N7Qh2010@40<01PH62000000300<30`<04a<C0P0f=SH3
05UIF@<0F5QH0`1<C4`204=3@`<0@4100`0j>SX303Hf=P80;bl_0`0c<c<303`l?0<0@T920P11@D43
03dm?@<0;bl_0`0S8b<201dM7@<030`<0`0@410301XJ6P804a<C0`092@T6000000D00@410`020P82
00410@<00P820`00000300410@800`<30`010@43000000<00@41:`0000080?ooo`001P3ooomN0000
00800`<30`00000300L71`<07alO0P0a<C43030`<0<08R8R0`0N7Qh2010@40<01PH62000000300<3
0`<04a<C0P0f=SH305UIF@<0F5QH0`1<C4`204=3@`<0@4100`0j>SX303Hf=P80;bl_0`0c<c<303`l
?0<0@T920P11@D4303dm?@<0;bl_0`0S8b<201dM7@<030`<0`0@410301XJ6P804a<C0`092@T60000
00D00@410`020P8200410@<00P820`00000300410@800`<30`010@43000000<00@41:`0000080?oo
o`001P3ooolo000000H00@413P00000200410@T000000P020P86000000<020P80P0M7Ad3030`<0<0
:BTY0`0P820201LG5`<02`/;0`0410@300410@800`<30`0F5QH302<S8`80=SHf0`18B4P304I6AP<0
?Cdm0P0j>SX303Ti>@<0=SHf0`0n?Sh205EEE@<0MgMg0`2:RXX308N7Q`80PX:20`1gMgL305aLG0<0
?clo0P0U9BD301DE5@H06ATI0P0=3@d300H61P<00P820`00000200410@<010@40`030`<;000000D0
0P82<@0000080?ooo`001P3ooolo000000H00@413P00000200410@T000000P020P86000000<020P8
0P0M7Ad3030`<0<0:BTY0`0P820201LG5`<02`/;0`0410@300410@800`<30`0F5QH302<S8`80=SHf
0`18B4P304I6AP<0?Cdm0P0j>SX303Ti>@<0=SHf0`0n?Sh205EEE@<0MgMg0`2:RXX308N7Q`80PX:2
0`1gMgL305aLG0<0?clo0P0U9BD301DE5@H06ATI0P0=3@d300H61P<00P820`00000200410@<010@4
0`030`<;000000D00P82<@0000080?ooo`001P3ooolo000000H00@413P00000200410@T000000P02
0P86000000<020P80P0M7Ad3030`<0<0:BTY0`0P820201LG5`<02`/;0`0410@300410@800`<30`0F
5QH302<S8`80=SHf0`18B4P304I6AP<0?Cdm0P0j>SX303Ti>@<0=SHf0`0n?Sh205EEE@<0MgMg0`2:
RXX308N7Q`80PX:20`1gMgL305aLG0<0?clo0P0U9BD301DE5@H06ATI0P0=3@d300H61P<00P820`00
000200410@<010@40`030`<;000000D00P82<@0000080?ooo`001P3ooomC000000800P822`000006
00410@<000000P0820P3024Q8@<0;Rh^0`0W9bL201PH60<03Ph>0`0820P300H61P805QHF0`0K6a/3
01dM7@80:b/[0`0i>CT30451@@<0?3`l0P0j>SX30492@P<0Bd];0`1QHF42092@T0<0_;bl0`3<c<`3
0<;2`P80^k^k0`2a/K430:b/[0<0WYjN0P1ZJVX301dM7@<05QHF0`0B4Q8200P820<00`<30`061PH3
00L71`800`<30`020P8500410Cl00000203oool000H0ooooD`00000200820P/000001P010@430000
008020P80`0Q8B4302h^;P<09bLW0P0H61P300h>3P<020P80`061PH201HF5P<06a/K0`0M7Ad202/[
:`<0>CTi0`11@D4303`l?080>SXj0`12@T8304];B`<0HF5Q0P2@T9030;bl_0<0c<c<0`32`/820;^k
^`<0/K6a0`2/[:`309jNWP80JVYZ0`0M7Ad301HF5P<04Q8B0P0820P300<30`<01PH60`071`L200<3
0`<00P821@010@4o000000P0oooo00060?oooe<000000P020P8;000000H00@410`00000200P820<0
8B4Q0`0^;Rh302LW9`8061PH0`0>3Ph300P820<01PH60P0F5QH301/K6`<07AdM0P0[:b/303Ti>@<0
@D510`0l?3`203Xj>P<0@T920`1;Bd/3065QH@80T92@0`2l_;`30<c<c0<0`/;20P2k^k/30;6a/@<0
[:b/0`2NWYh206YZJP<07AdM0`0F5QH3018B4P8020P80`030`<300H61P<01`L70P030`<300820PD0
0@41?`0000080?ooo`001P3ooom@000000<00@415P00000200410@<01PH61P0Y:BT200d=3@<01@D5
0`0:2PX3010@40805QHF0`0D51@301XJ6P809RHV0`0a<C4303Lg=`<0?clo0P1=CDd305ADE0<0JFUY
0`1kNg/207MgM`<0QHF50`2YZJT30=GEe@80inOW0`3Kfm/30=3@d0<0aLG50P2TY:@303Ph>0<06ATI
0`0G5aL2010@40<020P80`0:2PX300d=3@802PX:0`00000300410@D000001P010@4;000000800P82
:@0000080?ooo`001P3ooom@000000<00@415P00000200410@<01PH61P0Y:BT200d=3@<01@D50`0:
2PX3010@40805QHF0`0D51@301XJ6P809RHV0`0a<C4303Lg=`<0?clo0P1=CDd305ADE0<0JFUY0`1k
Ng/207MgM`<0QHF50`2YZJT30=GEe@80inOW0`3Kfm/30=3@d0<0aLG50P2TY:@303Ph>0<06ATI0`0G
5aL2010@40<020P80`0:2PX300d=3@802PX:0`00000300410@D000001P010@4;000000800P82:@00
00080?ooo`001P3ooom@000000<00@415P00000200410@<01PH61P0Y:BT200d=3@<01@D50`0:2PX3
010@40805QHF0`0D51@301XJ6P809RHV0`0a<C4303Lg=`<0?clo0P1=CDd305ADE0<0JFUY0`1kNg/2
07MgM`<0QHF50`2YZJT30=GEe@80inOW0`3Kfm/30=3@d0<0aLG50P2TY:@303Ph>0<06ATI0`0G5aL2
010@40<020P80`0:2PX300d=3@802PX:0`00000300410@D000001P010@4;000000800P82:@000008
0?ooo`001P3ooom=000000<010@40`010@4;000000800@411P00000300L71`803Ph>0`0410@300/;
2`<01`L70P00000300<30`<0410@0`0A4A4200d=3@<051@D0`0L71`202PX:0<0=3@d0`0m?Cd304U9
B@80FEUI0`1eMGD308f=S@<0SXj>0P1TI6@303De=@<0@T920`28R8P20<71`@<0emOG0`3Lg=`30=;B
dP80_Kfm0`1CDe<302@T90<07QhN0P0G5aL300d=3@<051@D0`0K6a/200X:2PH000000P020P830000
00<00P821@00000300<30`H000000P010@4Y000000P0oooo00060?ooodd000000`0410@300410@/0
00000P010@46000000<01`L70P0>3Ph300@410<02`/;0`071`L2000000<00`<30`0@4103014A4@80
3@d=0`0D51@301`L7080:2PX0`0d=3@303dm?@<0BDU90P1IFET307EeM@<0SHf=0`2>SXh206ATI0<0
=CDe0`12@T8308R8R080`L710`3GemL30=cLg0<0d];B0P2m_Kd305=CD`<092@T0`0N7Qh201LG5`<0
3@d=0`0D51@301/K6`802PX:1P00000200820P<000000`020P85000000<00`<31P00000200410BT0
0000203oool000H0ooooD000000300410@D000000`010@43000000800P820`00000300410@<08b<S
0P0Y:BT300l?3`<00P820`010@4200@410<030`<0`0>3Ph3010@40803@d=0`0G5aL302<S8`80<S8b
0`11@D4304];B`<0GEeM0P1`L70308f=S@<0T92@0`2PX:020:ZZZP<0MWIf0`0_;bl301HF5P80=3@d
0`1]KFd309RHV0<0ZZZZ0P2SXj<306][J`<0EUIF0`0n?Sh202PX:0<05QHF0`0L71`301PH60D00@41
1@00000600410@D000000`030`<6000000800@41:@0000080?ooo`001P3ooom@000000<00@411@00
000300410@<000000P020P83000000<00@410`0S8b<202TY:@<03`l?0`020P8300410@8010@40`0<
30`300h>3P<0410@0P0=3@d301LG5`<08b<S0P0b<S830451@@<0Bd];0`1MGEd2071`L0<0SHf=0`2@
T9030:2PX080ZZZZ0`1fMWH302l_;`<05QHF0P0d=3@306e]K@<0V9RH0`2ZZZX20:>SX`<0Jf][0`1F
EUH303hn?P80:2PX0`0F5QH301`L70<061PH1@010@45000000H00@411@00000300<30`H000000P01
0@4Y000000P0oooo00060?oooe0000000`010@45000000<00@410`00000200820P<000000`010@43
02<S8`80:BTY0`0?3`l300820P<00@410P0410@300`<30<03Ph>0`0@410200d=3@<05aLG0`0S8b<2
038b<P<0@D510`1;Bd/305eMG@80L71`0`2=SHd3092@T0<0X:2P0P2ZZZX307IfMP<0;bl_0`0F5QH2
03@d=0<0KFe]0`2HV9P30:ZZZP80Xj>S0`1[Jf/305IFEP<0?Shn0P0X:2P301HF5P<071`L0`0H61P5
00410@D000001P010@45000000<00`<31P00000200410BT00000203oool000H0ooooBP0000030041
0@<00P824000000300@410<061PH0`0J6QX201hN7P<05aLG0`092@T300D51@802@T90`0=3@d6010@
40803`l?0`0T92@303@d=080ADE50`1OGel307QhN0<0QXJ60P2GUiL308^;R`<0AdM70`0O7al2065Q
H@<0^[Zj0`2`/;0307UiN@80>SXj0`0E5AD301`L70<0G5aL0P2DU9@309NGU`<0UIFE0`2IVIT207Ad
M0<0=SHf0`0G5aL300H61P800@411P00000200410@H000000`020P82000000T00@41:`0000080?oo
o`001P3ooom:000000<00@410`020P8@000000<010@40`0H61P301XJ6P807QhN0`0G5aL300T92@<0
1@D50P092@T300d=3@H0410@0P0?3`l302@T90<0=3@d0P15ADD305mOG`<0N7Qh0`26QXH209NGU`<0
Rh^;0`17AdL301lO7`80HF5Q0`2j^[X30;2`/0<0NGUi0P0j>SX301DE5@<071`L0`1LG5`209BDU0<0
UiNG0`2EUID309VIV@80M7Ad0`0f=SH301LG5`<01PH60P010@46000000800@411P00000300820P80
00002@010@4[000000P0oooo00060?ooodX000000`010@4300820Q0000000`0410@301PH60<06QXJ
0P0N7Qh301LG5`<02@T90`051@D200T92@<03@d=1P0@410200l?3`<092@T0`0d=3@204E5A@<0GemO
0`1hN7P308J6QP80UiNG0`2;Rh/304M7A`<07alO0P1QHF430;Zj^P<0/;2`0`1iNGT203Xj>P<05ADE
0`0L71`305aLG080U9BD0`2GUiL309FEU@<0VIVI0P1dM7@303Hf=P<05aLG0`061PH200410@H00000
0P010@46000000<00P820P00000900410B/00000203oool000H0ooooBP00000600410A0000000`0D
51@3034a<@<061PH0P0>3Ph300l?3`<020P80`0:2PX2010@40<04Q8B0`0C4a<301dM7@80:BTY0`12
@T8305MGE`80KFe]0`1mOGd309JFUP<0X:2P0P2TY:@309>CT`<0OGem0`1BDU8201DE5@<07alO0`1A
DE430:6QX@80`l?30`2LW9`307inOP<0O7al0P2[Zj/30;fm_@<0]kNg0`3;bl/20<G5a@<0QHF50`0R
8R8300<30`801PH60`030`<500820P<00@412`00000300820Rh00000203oool000H0ooooBP000006
00410A0000000`0D51@3034a<@<061PH0P0>3Ph300l?3`<020P80`0:2PX2010@40<04Q8B0`0C4a<3
01dM7@80:BTY0`12@T8305MGE`80KFe]0`1mOGd309JFUP<0X:2P0P2TY:@309>CT`<0OGem0`1BDU82
01DE5@<07alO0`1ADE430:6QX@80`l?30`2LW9`307inOP<0O7al0P2[Zj/30;fm_@<0]kNg0`3;bl/2
0<G5a@<0QHF50`0R8R8300<30`801PH60`030`<500820P<00@412`00000300820Rh00000203oool0
00H0ooooD`00000200<30`<00@411P020P8202LW9`<0:b/[0`0K6a/302<S8`808R8R0`0O7al301@D
50<04A4A0P0M7Ad3028R8P<0;Rh^0`1BDU8206QXJ0<0MgMg0`2<S8`209>CT`<0WinO0`2QXJ430:^[
Z`80X:2P0`2/[:`30;Fe]@<0/K6a0P2GUiL3065QH@<0=CDe0`0Y:BT206e]K@<0^;Rh0`3?cll30<S8
b080_;bl0`2b/[830;Bd]0<0ZJVY0P2QXJ4306=SH`<0410@0`061PH200@410<01@D50`030`<200P8
20<010@42`00000300D51Bh00000203oool000H0ooooD`00000200<30`<00@411P020P8202LW9`<0
:b/[0`0K6a/302<S8`808R8R0`0O7al301@D50<04A4A0P0M7Ad3028R8P<0;Rh^0`1BDU8206QXJ0<0
MgMg0`2<S8`209>CT`<0WinO0`2QXJ430:^[Z`80X:2P0`2/[:`30;Fe]@<0/K6a0P2GUiL3065QH@<0
=CDe0`0Y:BT206e]K@<0^;Rh0`3?cll30<S8b080_;bl0`2b/[830;Bd]0<0ZJVY0P2QXJ4306=SH`<0
410@0`061PH200@410<01@D50`030`<200P820<010@42`00000300D51Bh00000203oool000H0oooo
D`00000200<30`<00@411P020P8202LW9`<0:b/[0`0K6a/302<S8`808R8R0`0O7al301@D50<04A4A
0P0M7Ad3028R8P<0;Rh^0`1BDU8206QXJ0<0MgMg0`2<S8`209>CT`<0WinO0`2QXJ430:^[Z`80X:2P
0`2/[:`30;Fe]@<0/K6a0P2GUiL3065QH@<0=CDe0`0Y:BT206e]K@<0^;Rh0`3?cll30<S8b080_;bl
0`2b/[830;Bd]0<0ZJVY0P2QXJ4306=SH`<0410@0`061PH200@410<01@D50`030`<200P820<010@4
2`00000300D51Bh00000203oool000H0ooooD`00000200820P<00@410`030`<301/K6`80;bl_0`0M
7Ad300P820<00@410P020P8300l?3`<04Q8B0`0O7al2038b<P<0Cdm?0`1]KFd308V9R@80UiNG0`2K
Vi/309nOW`80YJFU0`2_[jl309bLW0<0ZZZZ0P2`/;0309bLW0<0SHf=0`2;Rh/20:BTY0<0[Zj^0`2_
[jl308B4Q080=cLg0`0k>c/305=CD`<0QHF50P2k^k/30;bl_0<0ZZZZ0`2FUYH206=SH`<03Ph>0`03
0`<500@410<01PH60`051@D200T92@<010@41P00000200410@<01PH60`0:2PX300@412/00000203o
ool000H0ooooD`00000200820P<00@410`030`<301/K6`80;bl_0`0M7Ad300P820<00@410P020P83
00l?3`<04Q8B0`0O7al2038b<P<0Cdm?0`1]KFd308V9R@80UiNG0`2KVi/309nOW`80YJFU0`2_[jl3
09bLW0<0ZZZZ0P2`/;0309bLW0<0SHf=0`2;Rh/20:BTY0<0[Zj^0`2_[jl308B4Q080=cLg0`0k>c/3
05=CD`<0QHF50P2k^k/30;bl_0<0ZZZZ0`2FUYH206=SH`<03Ph>0`030`<500@410<01PH60`051@D2
00T92@<010@41P00000200410@<01PH60`0:2PX300@412/00000203oool000H0ooooD`0000020082
0P<00@410`030`<301/K6`80;bl_0`0M7Ad300P820<00@410P020P8300l?3`<04Q8B0`0O7al2038b
<P<0Cdm?0`1]KFd308V9R@80UiNG0`2KVi/309nOW`80YJFU0`2_[jl309bLW0<0ZZZZ0P2`/;0309bL
W0<0SHf=0`2;Rh/20:BTY0<0[Zj^0`2_[jl308B4Q080=cLg0`0k>c/305=CD`<0QHF50P2k^k/30;bl
_0<0ZZZZ0`2FUYH206=SH`<03Ph>0`030`<500@410<01PH60`051@D200T92@<010@41P0000020041
0@<01PH60`0:2PX300@412/00000203oool000H0ooooE@00000300820P<04A4A0`0Q8B48034a<@<0
:b/[0P0H61P300d=3@<07AdM0`0f=SH205MGE`<0QXJ60`2RXZ830:FUY@80YZJV0`2XZ:P30:f][@80
/[:b0`2j^[X30:j^[P<0[:b/0P2;Rh/303Xj>P<04A4A0`0[:b/206IVIP<0Ph>30`2QXJ430;Bd]080
U9BD0`21PH4306EUI@<0KFe]0P2[Zj/30;bl_0<0YZJV0`2?Shl205YJFP<071`L0`0N7Qh300d=3@80
3Ph>0`0=3@d300X:2P801PH60`030`<300L71`<00P820P092@T301DE5@<01`L7;P0000080?ooo`00
1P3ooomE000000<00P820`0A4A43024Q8@P0<C4a0`0[:b/201PH60<03@d=0`0M7Ad303Hf=P80EeMG
0`26QXH30::RXP<0YJFU0P2VYZH30:RXZ0<0[Jf]0P2b/[830;Zj^P<0[Zj^0`2/[:`208^;R`<0>SXj
0`0A4A4302/[:`80IVIV0`23Ph<30:6QX@<0];Bd0P2DU9@30861P@<0IFEU0`1]KFd20:^[Z`<0_;bl
0`2VYZH308n?S`80FUYJ0`0L71`301hN7P<03@d=0P0>3Ph300d=3@<02PX:0P061PH300<30`<01`L7
0`020P8200T92@<05ADE0`071`L^000000P0oooo00060?oooeD000000`020P83014A4@<08B4Q200a
<C4302/[:`8061PH0`0=3@d301dM7@<0=SHf0P1GEeL308J6QP<0XZ:R0`2UYJD20:JVYP<0Z:RX0`2]
[Jd20;:b/P<0^[Zj0`2^[Zh30:b/[080Rh^;0`0j>SX3014A4@<0:b/[0P1VIVH308>3P`<0XJ6Q0`2d
];@209BDU0<0PH610`1UIFD306e]K@80Zj^[0`2l_;`30:JVYP<0Shn?0P1JFUX301`L70<07QhN0`0=
3@d200h>3P<03@d=0`0:2PX200H61P<00`<30`071`L300820P802@T90`0E5AD300L71bh00000203o
ool000H0ooooD`00000200D51@<05QHF0`0S8b<3028R8P80;Rh^0`0j>SX603`l?080;bl_0`0M7Ad3
03Lg=`<0GUiN0P26QXH60:>SX`<0Vi^K0P2IVIT309RHV0<0YJFU0P2j^[X30;Rh^0<0];Bd0`2TY:@2
075aL@<0KVi^0`0e=CD300L71`807AdM0`1TI6@30;fm_@<0g]kN0P3Ph>030>KViP<0gMgM0`2g]kL2
0:j^[P<0/[:b0`2DU9@3075aL@80@d=30`0j>SX304I6AP<0<S8b0P0Y:BT3024Q8@<03`l?0P051@D3
00@410<04Q8B0`0N7Qh200d=3@<01`L7<@0000080?ooo`001P3ooomC000000801@D50`0F5QH302<S
8`<08R8R0P0^;Rh303Xj>PH0?3`l0P0_;bl301dM7@<0=cLg0`1NGUh208J6QPH0Xj>S0`2KVi/209VI
V@<0V9RH0`2UYJD20;Zj^P<0^;Rh0`2d];@30:BTY080LG5a0`1^KVh303De=@<01`L70P0M7Ad306AT
I0<0_Kfm0`3Ng]h20>3Ph0<0i^KV0`3MgMd30;Ng]`80[Zj^0`2b/[8309BDU0<0LG5a0P13@d<303Xj
>P<0ATI60`0b<S8202TY:@<08B4Q0`0?3`l200D51@<010@40`0B4Q8301hN7P803@d=0`071`La0000
00P0oooo00060?oooe0000000`030`<202<S8`<0>3Ph0`0g=cL301XJ6P8061PH0`0S8b<3020P80<0
8R8R0P0W9bL302d];@<0>SXj0`1BDU8207alO0<0QhN70`2=SHd308Z:RP80Rh^;0`2BTY830:BTY080
/k>c0`2j^[X30<O7a`<0[Jf]0P1iNGT309FEU@<0L71`0`1TI6@20820P0<0QHF50`2<S8`30:^[Z`80
c/k>0`3IfMT30=_Kf`<0bLW90P2/[:`308R8R0<0IVIV0`1KFe/203Ph>0<0@T920`1FEUH30451@@80
D51@0`1BDU8303Lg=`80820P0`0L71`302HV9P<0;Bd]0P051@Dd000000P0oooo00060?oooe000000
0`030`<202<S8`<0>3Ph0`0g=cL301XJ6P8061PH0`0S8b<3020P80<08R8R0P0W9bL302d];@<0>SXj
0`1BDU8207alO0<0QhN70`2=SHd308Z:RP80Rh^;0`2BTY830:BTY080/k>c0`2j^[X30<O7a`<0[Jf]
0P1iNGT309FEU@<0L71`0`1TI6@20820P0<0QHF50`2<S8`30:^[Z`80c/k>0`3IfMT30=_Kf`<0bLW9
0P2/[:`308R8R0<0IVIV0`1KFe/203Ph>0<0@T920`1FEUH30451@@80D51@0`1BDU8303Lg=`80820P
0`0L71`302HV9P<0;Bd]0P051@Dd000000P0oooo00060?oooe0000000`030`<202<S8`<0>3Ph0`0g
=cL301XJ6P8061PH0`0S8b<3020P80<08R8R0P0W9bL302d];@<0>SXj0`1BDU8207alO0<0QhN70`2=
SHd308Z:RP80Rh^;0`2BTY830:BTY080/k>c0`2j^[X30<O7a`<0[Jf]0P1iNGT309FEU@<0L71`0`1T
I6@20820P0<0QHF50`2<S8`30:^[Z`80c/k>0`3IfMT30=_Kf`<0bLW90P2/[:`308R8R0<0IVIV0`1K
Fe/203Ph>0<0@T920`1FEUH30451@@80D51@0`1BDU8303Lg=`80820P0`0L71`302HV9P<0;Bd]0P05
1@Dd000000P0oooo00060?oooe0000000`0@410203@d=0<0;Rh^0`0[:b/302HV9P804a<C0`0410@3
00P820<04A4A0P0K6a/302XZ:P<0=cLg0`14A4@204];B`<0@d=30`1KFe/305iNGP80E5AD0`1RHV83
0820P080ZJVY0`32`/830<71`@<0_[jn0P26QXH307MgM`<0O7al0`2FUYH209VIV@<0VYZJ0`2OWil3
0:n_[`80]KFe0`33`l<30<k>cP<0`L710P2GUiL303dm?@<0;2`/0`0k>c/202XZ:P<0?clo0`1OGel3
0410@080IFEU0`2:RXX307AdM080DE5A0`0i>CT3038b<P<05QHF0P00000300820PH00`<3:`000008
0?ooo`001P3ooom@000000<0410@0P0d=3@302h^;P<0:b/[0`0V9RH201<C4`<010@40`0820P3014A
4@806a/K0`0Z:RX303Lg=`<0A4A40P1;Bd/304=3@`<0Fe]K0`1NGUh205ADE0<0HV9R0`20P8020:VY
Z@<0`/;20`31`L430;jn_P80QXJ60`1gMgL307alO0<0UYJF0P2IVIT309ZJVP<0WinO0`2_[jl20;Fe
]@<0`l?30`3>c/h30<71`@80UiNG0`0m?Cd302`/;0<0>c/k0P0Z:RX303lo?`<0GemO0`10@40206EU
I@<0RXZ:0`1dM7@2055AD@<0>CTi0`0b<S8301HF5P8000000`020P8600<30b/00000203oool000H0
ooooD0000003010@4080=3@d0`0^;Rh302/[:`<09RHV0P0C4a<300@410<020P80`0A4A4201/K6`<0
:RXZ0`0g=cL304A4A080Bd];0`13@d<305]KF`<0GUiN0P1DE5@3069RHP<0P8200P2YZJT30<;2`P<0
`L710`2n_[h208J6QP<0MgMg0`1lO7`309JFUP80VIVI0`2JVYX309nOW`<0[jn_0P2e]KD30<?3``<0
c/k>0`31`L4209NGU`<0?Cdm0`0/;2`303/k>`80:RXZ0`0o?cl305mOG`<0@4100P1UIFD308Z:RP<0
M7Ad0P1ADE4303Ti>@<0<S8b0`0F5QH2000000<00P821P030`<[000000P0oooo00060?ooodd00000
0`010@4301hN7P80<C4a0`0S8b<301hN7P<0:b/[0P0X:2P301PH60H03Ph>0P0H61P302d];@<0<S8b
0`0R8R82018B4P<01`L70`0U9BD305UIF@80Ph>30`2?Shl308>3P`80TI6A0`2g]kL30;Jf]P<0/[:b
0P2BTY8307emO@<0Z:RX0`32`/820:6QX@<0VIVI0`2NWYh30:FUY@80]KFe0`3=cLd30=;BdP<0^;Rh
0P1ADE4300/;2`<04Q8B0`0Q8B4201PH60<09bLW0`1WIfL306ATI080IFEU0`2MWId30;:b/P80RXZ:
0`1:BTX3020P83T00000203oool000H0ooooC@00000300410@<07QhN0P0a<C4302<S8`<07QhN0`0[
:b/202PX:0<061PH1P0>3Ph201PH60<0;Bd]0`0b<S83028R8P804Q8B0`071`L302DU9@<0FEUI0P23
Ph<308n?S`<0Ph>30P2ATI430;Ng]`<0][Jf0`2b/[8209:BTP<0OGem0`2XZ:P30<;2`P80XJ6Q0`2I
VIT309jNWP<0YJFU0P2e]KD30<g=c@<0d];B0`2h^;P2055AD@<02`/;0`0B4Q83024Q8@8061PH0`0W
9bL306MWI`<0I6AT0P1UIFD309fMW@<0/[:b0P2:RXX304Y:BP<0820P>@0000080?ooo`001P3ooom=
000000<00`<30`0b<S8202`/;0<0:RXZ0`0V9RH302<S8`80;2`/0`0[:b/301LG5`<01`L70P0D51@3
02LW9`<0>3Ph0`0L71`201@D50<05ADE0`0H61P3034a<@80KFe]0`1mOGd30:2PX080W9bL0`2HV9P3
0:BTY0<0U9BD0P22PX830:6QX@<0gMgM0`38b<P20;Fe]@<0ZJVY0`2MWId30:BTY080a/K60`3=cLd3
0<o?c`<0TI6A0P0R8R8301LG5`<04a<C0`0?3`l200`<30<04A4A0`19BDT30861P@80H61P0`1_Kfl3
0:2PX080QHF50`0[:b/3000000<00@410P020P8300410@<000000`010@4[000000P0oooo00060?oo
odd000000`030`<3038b<P80;2`/0`0Z:RX302HV9P<08b<S0P0/;2`302/[:`<05aLG0`071`L201@D
50<09bLW0`0h>3P301`L708051@D0`0E5AD301PH60<0<C4a0P1]KFd307emO@<0X:2P0P2LW9`309RH
V0<0Y:BT0`2DU9@208:2PP<0XJ6Q0`3MgMd30<S8b080]KFe0`2YZJT309fMW@<0Y:BT0P36a/H30<g=
c@<0clo?0`2ATI42028R8P<05aLG0`0C4a<300l?3`8030`<0`0A4A4304U9B@<0PH610P1PH60306m_
K`<0X:2P0P25QHD302/[:`<000000`010@4200820P<00@410`00000300410B/00000203oool000H0
ooooC@00000300<30`<0<S8b0P0/;2`302XZ:P<09RHV0`0S8b<202`/;0<0:b/[0`0G5aL300L71`80
51@D0`0W9bL303Ph>0<071`L0P0D51@301DE5@<061PH0`0a<C4206e]K@<0OGem0`2PX:0209bLW0<0
V9RH0`2TY:@309BDU080PX:20`2QXJ430=gMg@<0b<S80P2e]KD30:VYZ@<0WIfM0`2TY:@20<K6aP<0
cLg=0`3?cll3096AT@808R8R0`0G5aL301<C4`<03`l?0P0<30`3014A4@<0BDU90`21PH42061PH0<0
Kfm_0`2PX:0208F5Q@<0:b/[0`00000300410@800P820`010@43000000<00@41:`0000080?ooo`00
1P3ooom=000000<00`<30`1=CDd206i^KP<0EUIF0`0R8R8302HV9P80:RXZ1P0c<c<302XZ:P805ADE
0`0P8203051@D0<0Bd];0P0];Bd302LW9`<0BDU90`1NGUh205YJFP<0L71`0`21PH4206i^KP<0LW9b
0`1dM7@306a/K080IVIV0`2JVYX30<C4a0<0Z:RX0P2b/[830;^k^`<0_kno1@36a/H30<c<c0<0e=CD
0`1aLG4203@d=0<0<S8b0`0`<30301`L708020P80`0410@302XZ:P<0Hf=S0P1/K6`3055AD@<0?clo
0P0N7Qh6000000<010@41@010@46000000800@41:@0000080?ooo`001P3ooom=000000<00`<30`1=
CDd206i^KP<0EUIF0`0R8R8302HV9P80:RXZ1P0c<c<302XZ:P805ADE0`0P8203051@D0<0Bd];0P0]
;Bd302LW9`<0BDU90`1NGUh205YJFP<0L71`0`21PH4206i^KP<0LW9b0`1dM7@306a/K080IVIV0`2J
VYX30<C4a0<0Z:RX0P2b/[830;^k^`<0_kno1@36a/H30<c<c0<0e=CD0`1aLG4203@d=0<0<S8b0`0`
<30301`L708020P80`0410@302XZ:P<0Hf=S0P1/K6`3055AD@<0?clo0P0N7Qh6000000<010@41@01
0@46000000800@41:@0000080?ooo`001P3ooom=000000<00`<30`1=CDd206i^KP<0EUIF0`0R8R83
02HV9P80:RXZ1P0c<c<302XZ:P805ADE0`0P8203051@D0<0Bd];0P0];Bd302LW9`<0BDU90`1NGUh2
05YJFP<0L71`0`21PH4206i^KP<0LW9b0`1dM7@306a/K080IVIV0`2JVYX30<C4a0<0Z:RX0P2b/[83
0;^k^`<0_kno1@36a/H30<c<c0<0e=CD0`1aLG4203@d=0<0<S8b0`0`<30301`L708020P80`0410@3
02XZ:P<0Hf=S0P1/K6`3055AD@<0?clo0P0N7Qh6000000<010@41@010@46000000800@41:@000008
0?ooo`001P3ooom=000000<02@T90`2BTY820:ZZZP<0@d=31P0K6a/201PH60<04a<C0`0G5aL302@T
90807alO0`0[:b/306MWI`<0W9bL0P1nOWh305aLG0<0IFEU0`1jNWX206a/K0<0De=C0`1:BTX203Xj
>P<0=cLg0`0b<S8303<c<`80H61P0`2UYJD30:ZZZP<0XJ6Q0P2`/;030<?3``<0bLW90`36a/H20;fm
_@<0/k>c0`39bLT307moO`80EEEE0`1FEUH305EEE@<0?3`l0P0A4A4300820P<03Ph>0`0l?3`206UY
J@<0I6AT0`14A4@201lO7`<02`/;1P00000500<30c400000203oool000H0ooooC@00000300T92@<0
TY:B0P2ZZZX304=3@`H06a/K0P0H61P301<C4`<05aLG0`0T92@201lO7`<0:b/[0`1WIfL309bLW080
OWin0`1LG5`306EUI@<0NWYj0P1/K6`305=CD`<0BTY:0P0j>SX303Lg=`<0<S8b0`0c<c<2061PH0<0
YJFU0`2ZZZX30:6QX@80/;2`0`33`l<30<W9b@<0a/K60P2m_Kd30;>c/`<0bLW90`1oOgl205EEE@<0
EUIF0`1EEED303`l?0804A4A0`020P8300h>3P<0?3`l0P1YJFT306ATI0<0A4A40P0O7al300/;2`H0
00001@030`<a000000P0oooo00060?ooodd000000`092@T309:BTP80ZZZZ0`13@d<601/K6`8061PH
0`0C4a<301LG5`<092@T0P0O7al302/[:`<0IfMW0`2LW9`207inOP<0G5aL0`1UIFD307YjNP80K6a/
0`1CDe<304Y:BP80>SXj0`0g=cL3038b<P<0<c<c0P1PH6030:FUY@<0ZZZZ0`2QXJ420;2`/0<0`l?3
0`39bLT30<K6aP80_Kfm0`2c/k<30<W9b@<0Ogmo0P1EEED305IFEP<0EEEE0`0l?3`2014A4@<00P82
0`0>3Ph303`l?080JFUY0`1TI6@304A4A0807alO0`0;2`/6000000D00`<3<@0000080?ooo`001P3o
oom=000000<06a/K0`2NWYh209FEU@<0<30`0`0d=3@3038b<P807alO0`0;2`/300P820<02`/;0P0K
6a/303dm?@<0MGEe0`2[Zj/20<c<c0<0]kNg0`2MWId30861P@80J6QX0`16ATH302LW9`805aLG0`0B
4Q8300H61P<0>c/k1@2e]KD308F5Q@<0VIVI0P2][Jd30:>SX`<0Zj^[0`2g]kL20;bl_0<0^[Zj0`2l
_;`307emO@80MGEe0`1]KFd304=3@`<0>c/k0P0N7Qh300D51@<00P820`0N7Qh204Y:BP<0H61P0`1G
EeL204=3@`<0820P0`030`<300820P8020P80`071`L300<30bh00000203oool000H0ooooC@000003
01/K6`<0WYjN0P2EUID3030`<0<0=3@d0`0b<S8201lO7`<02`/;0`0820P300/;2`806a/K0`0m?Cd3
07EeM@<0Zj^[0P3<c<`30;Ng]`<0WIfM0`21PH4206QXJ0<0ATI60`0W9bL201LG5`<04Q8B0`061PH3
03/k>`D0]KFe0`25QHD309VIV@80[Jf]0`2SXj<30:^[Z`<0]kNg0P2l_;`30;Zj^P<0_;bl0`1mOGd2
07EeM@<0KFe]0`13@d<303/k>`807QhN0`051@D300820P<07QhN0P1:BTX3061PH0<0EeMG0P13@d<3
020P80<00`<30`020P8200P820<01`L70`030`<^000000P0oooo00060?ooodX000000`010@4302XZ
:P<0d=3@0P26QXH305]KF`<0J6QX0`0Y:BT201LG5`<0:b/[0`0k>c/302/[:`807AdM0`11@D4307If
MP<0ZJVY0P35aLD30=gMg@<0bLW90`2m_Kd20:>SX`<0EeMG0`0];Bd201@D50<020P80`0L71`307Yj
NP80e]KF0`2k^k/308>3P`<0Q8B40P1kNg/307IfMP<0RXZ:0`2FUYH209ZJVP<0WIfM0`2b/[8308F5
Q@80Ng]k0`2;Rh/305iNGP<09RHV0P0B4Q8300L71`<00`<30`0820P202TY:@<0EeMG0`1DE5@204A4
A0<0:b/[0`0;2`/5000000<030`<0`0:2PX300820R/00000203oool000H0ooooBP00000300410@<0
:RXZ0`3@d=0208J6QP<0Fe]K0`1XJ6P302TY:@805aLG0`0[:b/303/k>`<0:b/[0P0M7Ad30451@@<0
MWIf0`2YZJT20<G5a@<0gMgM0`39bLT30;fm_@80Xj>S0`1GEeL302d];@8051@D0`0820P301`L70<0
NWYj0P3Fe]H30;^k^`<0Ph>30`24Q8@207]kN`<0MWIf0`2:RXX309JFUP80VYZJ0`2MWId30;:b/P<0
QHF50P1kNg/308^;R`<0GUiN0`0V9RH2018B4P<01`L70`030`<300P82080:BTY0`1GEeL305ADE080
A4A40`0[:b/300/;2`D000000`0<30`300X:2P<00P82:`0000080?ooo`001P3ooom:000000<00@41
0`0Z:RX30=3@d080QXJ60`1KFe/306QXJ0<0:BTY0P0G5aL302/[:`<0>c/k0`0[:b/201dM7@<0@D51
0`1fMWH30:VYZ@80aLG50`3MgMd30<W9b@<0_Kfm0P2SXj<305MGE`<0;Bd]0P0D51@300P820<071`L
0`1jNWX20=KFeP<0^k^k0`23Ph<308B4Q080Ng]k0`1fMWH308Z:RP<0UYJF0P2JVYX309fMW@<0/[:b
0`25QHD207]kN`<0Rh^;0`1NGUh302HV9P804Q8B0`071`L300<30`<020P80P0Y:BT305MGE`<0E5AD
0P14A4@302/[:`<02`/;1@00000300`<30<02PX:0`020P8[000000P0oooo00060?ooodd000000`0A
4A430:ZZZP80_Kfm0`2EUID305UIF@<0EUIF0P23Ph<309:BTP<0Q8B40`1[Jf/203dm?@<0@D510`1Y
JFT309BDU080^k^k0`3EeMD30>;RhP<0iNGU0P3Lg=`30=OGe`<0_kno0P2GUiL30820P0<0XJ6Q0`3=
cLd20=OGe`<0]kNg0`1[Jf/304];B`80@T920`1QHF4308R8R0<0V9RH0P2YZJT30:>SX`<0Zj^[0`2A
TI4207]kN`<0TY:B0`2CTi<304];B`807alO0`0A4A4300H61P<010@40P0Q8B4304m?C`<0IfMW0P1K
Fe/30410@0<08B4Q1@030`<301DE5@<061PH0`071`L200410BT00000203oool000H0ooooC@000003
014A4@<0ZZZZ0P2m_Kd309FEU@<0FEUI0`1FEUH208>3P`<0TY:B0`24Q8@306][J`80?Cdm0`11@D43
06UYJ@<0U9BD0P2k^k/30=GEe@<0h^;R0`3UiND20=cLg0<0emOG0`2o_kl209NGU`<0P8200`2QXJ43
0<g=c@80emOG0`2g]kL306][J`<0Bd];0P12@T83065QH@<0R8R80`2HV9P20:VYZ@<0Xj>S0`2[Zj/3
096AT@80Ng]k0`2BTY8309>CT`<0Bd];0P0O7al3014A4@<01PH60`0410@2024Q8@<0Cdm?0`1WIfL2
05]KF`<0@4100`0Q8B4500<30`<05ADE0`0H61P300L71`800@41:@0000080?ooo`001P3ooom=0000
00<04A4A0`2ZZZX20;fm_@<0UIFE0`1IFET305IFEP80Ph>30`2BTY8308B4Q0<0Jf][0P0m?Cd30451
@@<0JFUY0`2DU9@20;^k^`<0eMGE0`3Rh^830>GUi@80g=cL0`3GemL30;no_`80UiNG0`20P8030:6Q
X@<0cLg=0P3GemL30;Ng]`<0Jf][0`1;Bd/20492@P<0HF5Q0`28R8P309RHV080ZJVY0`2SXj<30:^[
Z`<0TI6A0P1kNg/309:BTP<0Ti>C0`1;Bd/201lO7`<04A4A0`061PH300@410808B4Q0`1?Cdl306MW
I`80Fe]K0`10@403024Q8@D00`<30`0E5AD301PH60<01`L70P010@4Y000000P0oooo00060?ooocd0
00000P010@4600820P<00@4120000003051@D080WIfM0`0f=SH301/K6`<0NGUi0P2QXJ4306ATI0<0
9bLW0`0V9RH203@d=0<0>SXj0`1?Cdl307UiN@80Z:RX0`32`/830=KFeP<0fm_K0P3^k^h60>o_k`80
jn_[0`3MgMd30=KFePD0b/[:0`2c/k<3059BDP<08B4Q0P0k>c/304i>CP<0Ph>30`2FUYH209fMW@<0
Xj>S0`2d];@30:f][@80QXJ60`2:RXX309FEU@<0MWIf0P10@403024Q8@<03Ph>0`092@T201TI6@<0
B4Q80`1]KFd207]kN`<0Fe]K0`0d=3@300`<308000000`0E5AD3038b<P<06ATI:`0000080?ooo`00
1P3ooolm000000800@411P020P8300410@P000000`1@D50209fMW@<0=SHf0`0K6a/307UiN@80XJ6Q
0`1TI6@302LW9`<09RHV0P0d=3@303Xj>P<0Cdm?0`1iNGT20:RXZ0<0`/;20`3Fe]H30=_Kf`80k^k^
1P3_knl20>_[j`<0gMgM0`3Fe]H50<[:bP<0/k>c0`1BDU83024Q8@80>c/k0`1>CTh308>3P`<0UYJF
0P2MWId30:>SX`<0];Bd0`2][Jd208J6QP<0RXZ:0`2EUID307IfMP80@4100`0Q8B4300h>3P<02@T9
0P0I6AT304Q8B0<0KFe]0P1kNg/305]KF`<0=3@d0`0<30`2000000<05ADE0`0b<S8301TI6B/00000
203oool000H0ooooD0000003030`<080H61P0`2DU9@3092@T0<0D51@0P17AdL306m_K`<0Ph>30`1K
Fe/202l_;`<0;Bd]0`0k>c/3071`L080UYJF0`2OWil30;^k^`<0bl_;0P3Hf=P30=[JfP<0g]kN0P3P
h>030>KViP<0f][J0`3:b/X20<o?c`<0d=3@0`26QXH302DU9@8092@T0`1@D50306a/K0<0Ng]k0P20
P80306m_K`<0IVIV0`1mOGd207moO`<0SXj>0`2@T90308>3P`80Hf=S0`0l?3`3018B4P<000000P0@
410303Hf=P<0Jf][0P25QHD306i^KP<0CDe=0`0I6AT200<30`<09bLW0`0m?Cd301hN7R/00000203o
ool000H0ooooD0000003030`<080H61P0`2DU9@3092@T0<0D51@0P17AdL306m_K`<0Ph>30`1KFe/2
02l_;`<0;Bd]0`0k>c/3071`L080UYJF0`2OWil30;^k^`<0bl_;0P3Hf=P30=[JfP<0g]kN0P3Ph>03
0>KViP<0f][J0`3:b/X20<o?c`<0d=3@0`26QXH302DU9@8092@T0`1@D50306a/K0<0Ng]k0P20P803
06m_K`<0IVIV0`1mOGd207moO`<0SXj>0`2@T90308>3P`80Hf=S0`0l?3`3018B4P<000000P0@4103
03Hf=P<0Jf][0P25QHD306i^KP<0CDe=0`0I6AT200<30`<09bLW0`0m?Cd301hN7R/00000203oool0
00H0ooooD0000003030`<080H61P0`2DU9@3092@T0<0D51@0P17AdL306m_K`<0Ph>30`1KFe/202l_
;`<0;Bd]0`0k>c/3071`L080UYJF0`2OWil30;^k^`<0bl_;0P3Hf=P30=[JfP<0g]kN0P3Ph>030>KV
iP<0f][J0`3:b/X20<o?c`<0d=3@0`26QXH302DU9@8092@T0`1@D50306a/K0<0Ng]k0P20P80306m_
K`<0IVIV0`1mOGd207moO`<0SXj>0`2@T90308>3P`80Hf=S0`0l?3`3018B4P<000000P0@410303Hf
=P<0Jf][0P25QHD306i^KP<0CDe=0`0I6AT200<30`<09bLW0`0m?Cd301hN7R/00000203oool000H0
ooooC@00000300410@<0BDU90P1VIVH303hn?P<0WYjN0`2VYZH20:j^[P<0Y:BT0`1iNGT3079bLP80
LG5a0`1KFe/305EEE@<0FEUI0P25QHD30:NWY`<0]kNg0`36a/H20=7Ad@<0f=SH0`3Ph>020>GUi@<0
j^[Z0`3]kNd30>WYj@80inOW0`3Ogml30<W9b@<0PX:20P10@40304m?C`<0N7Qh0`1^KVh206UYJ@<0
EeMG0`1<C4`305EEE@80IVIV0`26QXH308^;R`<0QHF50P1YJFT304];B`<0:2PX0`051@D200410@<0
:2PX0`1CDe<207alO0<0OWin0`1@D50301`L708010@40`0^;Rh304Q8B0<0:RXZ0P0820PY000000P0
oooo00060?ooodd000000`010@4304U9B@80IVIV0`0n?Sh309jNWP<0YZJV0P2^[Zh30:BTY0<0NGUi
0`1bLW82075aL@<0Fe]K0`1EEED305UIF@80QHF50`2WYjL30;Ng]`<0a/K60P3AdM430=SHf0<0h>3P
0P3UiND30>[ZjP<0kNg]0`3YjNT20>OWi`<0gmoO0`39bLT308:2PP80@4100`1?Cdl307QhN0<0KVi^
0P1YJFT305MGE`<0C4a<0`1EEED206IVIP<0QXJ60`2;Rh/308F5Q@80JFUY0`1;Bd/302PX:0<01@D5
0P010@4302PX:0<0De=C0P1lO7`307inOP<0D51@0`0L71`200@410<0;Rh^0`18B4P302XZ:P8020P8
:@0000080?ooo`001P3ooom=000000<00@410`19BDT206IVIP<0?Shn0`2NWYh30:JVYP80[Zj^0`2T
Y:@307UiN@<0LW9b0P1aLG4305]KF`<0EEEE0`1IFET208F5Q@<0YjNW0`2g]kL30<K6aP80dM7A0`3H
f=P30>3Ph080iNGU0`3Zj^X30>g]k@<0jNWY0P3WinL30=oOg`<0bLW90`22PX820410@0<0Cdm?0`1h
N7P306i^KP80JFUY0`1GEeL304a<C0<0EEEE0P1VIVH308J6QP<0Rh^;0`25QHD206UYJ@<0Bd];0`0X
:2P300D51@800@410`0X:2P305=CD`80O7al0`1nOWh3051@D0<071`L0P0410@302h^;P<0B4Q80`0Z
:RX200P822T00000203oool000H0ooooBP00000300410@<00P820`1RHV820=3@d0<0SXj>0`1kNg/5
0<S8b0<0JFUY0`0Q8B4302l_;`80AdM70`1BDU8304M7A`<0@4100P1EEED308^;R`<0];Bd0`34a<@2
0<G5a@<0d=3@0`3Rh^820>WYj@<0lo?c0`3alO430>c/k080iNGU0`3Rh^830>CTi0<0h^;R0P2o_kl3
09>CT`<0UIFE0`2IVIT209JFUP<0VIVI0`2HV9P3075aL@80ATI60`1NGUh308Z:RP<0Q8B40P1_Kfl3
05QHF0<0=cLg0`0D51@200D51@<04A4A0`0i>CT206a/K0<0PX:20`1QHF4302PX:08010@40`0P8203
051@D0<0;2`/0P0410@Y000000P0oooo00060?ooodX000000`010@4300820P<0HV9R0P3@d=0308j>
SP<0Ng]k1@38b<P306UYJ@<08B4Q0`0_;bl204M7A`<0DU9B0`17AdL30410@080EEEE0`2;Rh/30;Bd
]0<0a<C40P35aLD30=3@d0<0h^;R0P3YjNT30??cl`<0lO7a0`3/k>`20>GUi@<0h^;R0`3Ti>@30>;R
hP80_kno0`2CTi<309FEU@<0VIVI0P2FUYH309VIV@<0V9RH0`1aLG4204I6AP<0GUiN0`2:RXX308B4
Q080Kfm_0`1HF5P303Lg=`<051@D0P051@D3014A4@<0>CTi0P1/K6`308:2PP<0HF5Q0`0X:2P200@4
10<0820P0`1@D50302`/;08010@4:@0000080?ooo`001P3ooom:000000<00@410`020P83069RHP80
d=3@0`2>SXh307]kN`D0b<S80`1YJFT3024Q8@<0;bl_0P17AdL3059BDP<0AdM70`10@40205EEE@<0
Rh^;0`2d];@30<C4a080aLG50`3@d=030>;RhP80jNWY0`3clo<30?7al@<0k>c/0P3UiND30>;RhP<0
i>CT0`3Rh^820;no_`<0Ti>C0`2EUID309VIV@80UYJF0`2IVIT309RHV0<0LG5a0P16ATH305iNGP<0
RXZ:0`24Q8@206m_K`<0F5QH0`0g=cL301@D50801@D50`0A4A4303Ti>@80K6a/0`22PX83065QH@<0
:2PX0P0410@3020P80<0D51@0`0/;2`200@412T00000203oool000H0ooooC@00000300820P<0L71`
0P35aLD30:JVYP<0KVi^0`1?Cdl205EEE@<0Kfm_0`1RHV8305=CD`80>c/k0`0l?3`301lO7`<08R8R
0P0c<c<304M7A`<0IfMW0`2WYjL20<30`0H0c<c<0P3@d=030>[ZjP<0jn_[0`3Shn<20>7Qh@<0g]kN
0`3MgMd30>3Ph080iNGU0`3Cdm<60;fm_@80`L710`2e]KD30:^[Z`<0NWYj0P0V9RH304M7A`<0OGem
0`1nOWh207IfMP<0GUiN0`0n?Sh302DU9@80410@0`061PH302PX:080GemO0`27QhL306YZJP<0=SHf
0P092@T3030`<0<0GUiN0`0`<30200d=3BT00000203oool000H0ooooC@00000300820P<0L71`0P35
aLD30:JVYP<0KVi^0`1?Cdl205EEE@<0Kfm_0`1RHV8305=CD`80>c/k0`0l?3`301lO7`<08R8R0P0c
<c<304M7A`<0IfMW0`2WYjL20<30`0H0c<c<0P3@d=030>[ZjP<0jn_[0`3Shn<20>7Qh@<0g]kN0`3M
gMd30>3Ph080iNGU0`3Cdm<60;fm_@80`L710`2e]KD30:^[Z`<0NWYj0P0V9RH304M7A`<0OGem0`1n
OWh207IfMP<0GUiN0`0n?Sh302DU9@80410@0`061PH302PX:080GemO0`27QhL306YZJP<0=SHf0P09
2@T3030`<0<0GUiN0`0`<30200d=3BT00000203oool000H0oooo?@00000500410@h000000`1/K6`2
0:f][@<0]kNg0`2=SHd305=CD`80RXZ:0`3@d=030<71`@<0];Bd0P2UYJD30:VYZ@<0P8200`1UIFD2
075aL@<0OWin0`1aLG4306i^KP80TY:B0`39bLT30=3@d080alO70`3AdM430=KFeP<0fm_K0P3GemL3
0=;BdP<0e]KF0`3AdM420=KFeP<0aLG50`2e]KD30;Zj^P80_Kfm0`2d];@309bLW0<0KVi^0P0j>SX3
05eMG@<0QhN71@22PX8306a/K0<0@T920`0[:b/201TI6@<01PH60`0U9BD205YJFP<0P8200`1[Jf/3
0451@@8061PH0`1<C4`306UYJ@<0?3`l0P0J6QXY000000P0oooo00060?ooocd000001@010@4>0000
00<0K6a/0P2][Jd30;Ng]`<0SHf=0`1CDe<208Z:RP<0d=3@0`31`L430;Bd]080YJFU0`2YZJT30820
P0<0IFEU0P1aLG4307inOP<0LG5a0`1^KVh209:BTP<0bLW90`3@d=020<O7a`<0dM7A0`3Fe]H30=_K
f`80emOG0`3Bd]830=KFeP<0dM7A0P3Fe]H30<G5a@<0]KFe0`2j^[X20;fm_@<0];Bd0`2LW9`306i^
KP80>SXj0`1MGEd308N7Q`D0PX:20`1/K6`30492@P<0:b/[0P0I6AT300H61P<09BDU0P1JFUX30820
P0<0Jf][0`11@D4201PH60<0C4a<0`1YJFT303`l?0806QXJ:@0000080?ooo`001P3ooolm000000D0
0@413P00000306a/K080[Jf]0`2g]kL308f=S@<0De=C0P2:RXX30=3@d0<0`L710`2d];@20:FUY@<0
ZJVY0`20P80306EUI@80LG5a0`1nOWh3075aL@<0KVi^0P2BTY830<W9b@<0d=3@0P37alL30=7Ad@<0
e]KF0`3Kfm/20=OGe`<0d];B0`3Fe]H30=7Ad@80e]KF0`35aLD30;Fe]@<0^[Zj0P2m_Kd30;Bd]0<0
W9bL0`1^KVh203Xj>P<0GEeM0`27QhL508:2PP<0K6a/0`12@T8302/[:`806ATI0`061PH302DU9@80
FUYJ0`20P80306][J`<0@D510P0H61P304a<C0<0JFUY0`0l?3`201XJ6RT00000203oool000H0oooo
@P00000800410@H000000`23Ph<20;^k^`<0Zj^[0`2GUiL309FEU@80bLW90`3=cLd30;fm_@<0gMgM
0P3bl_830=GEe@<0aLG50`2o_kl20:2PX0<0MWIf0`1YJFT308:2PP80Rh^;0`2JVYX30=GEe@80g=cL
0`3=cLd30<k>cP<0c<c<0P3AdM430<[:bP<0a<C40`30`<020;Ng]`<0^;Rh0`2WYjL30:JVYP80Z:RX
0`2HV9P3071`L0<0Bd];0P0f=SH304A4A0<0P8200`2<S8`208f=S@<0Q8B40`1HF5P303De=@807alO
0`0820P303De=@80J6QX0`22PX8307IfMP<0@4100P0U9BD306UYJ@<0IVIV0`16ATH201lO7bT00000
203oool000H0oooo@P00000800410@H000000`23Ph<20;^k^`<0Zj^[0`2GUiL309FEU@80bLW90`3=
cLd30;fm_@<0gMgM0P3bl_830=GEe@<0aLG50`2o_kl20:2PX0<0MWIf0`1YJFT308:2PP80Rh^;0`2J
VYX30=GEe@80g=cL0`3=cLd30<k>cP<0c<c<0P3AdM430<[:bP<0a<C40`30`<020;Ng]`<0^;Rh0`2W
YjL30:JVYP80Z:RX0`2HV9P3071`L0<0Bd];0P0f=SH304A4A0<0P8200`2<S8`208f=S@<0Q8B40`1H
F5P303De=@807alO0`0820P303De=@80J6QX0`22PX8307IfMP<0@4100P0U9BD306UYJ@<0IVIV0`16
ATH201lO7bT00000203oool000H0oooo@P00000800410@H000000`23Ph<20;^k^`<0Zj^[0`2GUiL3
09FEU@80bLW90`3=cLd30;fm_@<0gMgM0P3bl_830=GEe@<0aLG50`2o_kl20:2PX0<0MWIf0`1YJFT3
08:2PP80Rh^;0`2JVYX30=GEe@80g=cL0`3=cLd30<k>cP<0c<c<0P3AdM430<[:bP<0a<C40`30`<02
0;Ng]`<0^;Rh0`2WYjL30:JVYP80Z:RX0`2HV9P3071`L0<0Bd];0P0f=SH304A4A0<0P8200`2<S8`2
08f=S@<0Q8B40`1HF5P303De=@807alO0`0820P303De=@80J6QX0`22PX8307IfMP<0@4100P0U9BD3
06UYJ@<0IVIV0`16ATH201lO7bT00000203oool000H0ooooC@00000300410@<0J6QX0P30`<030;Vi
^@<0];Bd0`2a/K42096AT@<0I6AT1P1UIFD209FEU@<0cLg=0`3;bl/30;^k^`80[Zj^0`2UYJD309VI
V@<0SHf=0P2WYjL309JFUP<0^k^k0P34a<@30:VYZ@<0XJ6Q0`2FUYH209nOW`<0Y:BT0`2WYjL30:JV
YP80VIVI0`2JVYX30:JVYP<0WYjN0P1kNg/305]KF`<0=CDe0`0B4Q8200820P<092@T0`1cLg<308V9
R@80R8R80`25QHD305mOG`<0;Bd]0P0J6QX3014A4@<0@T921@25QHD307UiN@<0=CDe0P11@D4307Yj
NP<0I6AT0`0k>c/200h>3RT00000203oool000H0ooooC@00000300410@<0J6QX0P30`<030;Vi^@<0
];Bd0`2a/K42096AT@<0I6AT1P1UIFD209FEU@<0cLg=0`3;bl/30;^k^`80[Zj^0`2UYJD309VIV@<0
SHf=0P2WYjL309JFUP<0^k^k0P34a<@30:VYZ@<0XJ6Q0`2FUYH209nOW`<0Y:BT0`2WYjL30:JVYP80
VIVI0`2JVYX30:JVYP<0WYjN0P1kNg/305]KF`<0=CDe0`0B4Q8200820P<092@T0`1cLg<308V9R@80
R8R80`25QHD305mOG`<0;Bd]0P0J6QX3014A4@<0@T921@25QHD307UiN@<0=CDe0P11@D4307YjNP<0
I6AT0`0k>c/200h>3RT00000203oool000H0ooooC@00000300410@<0J6QX0P30`<030;Vi^@<0];Bd
0`2a/K42096AT@<0I6AT1P1UIFD209FEU@<0cLg=0`3;bl/30;^k^`80[Zj^0`2UYJD309VIV@<0SHf=
0P2WYjL309JFUP<0^k^k0P34a<@30:VYZ@<0XJ6Q0`2FUYH209nOW`<0Y:BT0`2WYjL30:JVYP80VIVI
0`2JVYX30:JVYP<0WYjN0P1kNg/305]KF`<0=CDe0`0B4Q8200820P<092@T0`1cLg<308V9R@80R8R8
0`25QHD305mOG`<0;Bd]0P0J6QX3014A4@<0@T921@25QHD307UiN@<0=CDe0P11@D4307YjNP<0I6AT
0`0k>c/200h>3RT00000203oool000H0ooooD000000302LW9`80`/;20`2o_kl30=?Cd`<0ZJVY0P1c
Lg<30;:b/P<0lO7a0`3Bd]820:6QX@<0Z:RX0`2c/k<30<?3``80gmoO0`3[jn/30>c/k0<0clo?0P2n
_[h30:f][@<0SXj>0P2@T9030820P0<0L71`0`1KFe/2059BDP<0Fe]K0`1/K6`307IfMP80Jf][0`1S
Hf<305eMG@<0CDe=0P1<C4`30451@@<0GemO0`1VIVH205=CD`<0820P0`1SHf<307]kN`80Ogmo0`29
RHT306QXJ0<0=cLg0P0K6a/301DE5@<0C4a<0P2BTY8307emO@<0Fe]K0`0/;2`206QXJ0<0IfMW0`0g
=cL300`<32/00000203oool000H0ooooD000000302LW9`80`/;20`2o_kl30=?Cd`<0ZJVY0P1cLg<3
0;:b/P<0lO7a0`3Bd]820:6QX@<0Z:RX0`2c/k<30<?3``80gmoO0`3[jn/30>c/k0<0clo?0P2n_[h3
0:f][@<0SXj>0P2@T9030820P0<0L71`0`1KFe/2059BDP<0Fe]K0`1/K6`307IfMP80Jf][0`1SHf<3
05eMG@<0CDe=0P1<C4`30451@@<0GemO0`1VIVH205=CD`<0820P0`1SHf<307]kN`80Ogmo0`29RHT3
06QXJ0<0=cLg0P0K6a/301DE5@<0C4a<0P2BTY8307emO@<0Fe]K0`0/;2`206QXJ0<0IfMW0`0g=cL3
00`<32/00000203oool000H0ooooBP00000300410@<000000`051@D20:RXZ0<0a/K60`2g]kL30<[:
bP80k^k^0`3hn?P60>g]k@80j^[Z0`3YjNT30>[ZjP<0m_Kf0P3_knl30>[ZjP<0jn_[0`3AdM420;>c
/`<0YZJV0`2HV9P209ZJVP<0[jn_0`2c/k<30;Jf]P80SHf=0`1nOWh306YZJP<0FUYJ0P11@D4302TY
:@<09BDU0`0F5QH200h>3P<06QXJ0`0_;bl3061PH080D51@0`0>3Ph305ADE0<0Ogmo0P21PH4307mo
O`<0KFe]0`1<C4`202`/;0<06ATI0`1UIFD209NGU`<0LG5a0`13@d<303dm?@80MGEe0`15ADD300T9
2Bh00000203oool000H0ooooBP00000300410@<000000`051@D20:RXZ0<0a/K60`2g]kL30<[:bP80
k^k^0`3hn?P60>g]k@80j^[Z0`3YjNT30>[ZjP<0m_Kf0P3_knl30>[ZjP<0jn_[0`3AdM420;>c/`<0
YZJV0`2HV9P209ZJVP<0[jn_0`2c/k<30;Jf]P80SHf=0`1nOWh306YZJP<0FUYJ0P11@D4302TY:@<0
9BDU0`0F5QH200h>3P<06QXJ0`0_;bl3061PH080D51@0`0>3Ph305ADE0<0Ogmo0P21PH4307moO`<0
KFe]0`1<C4`202`/;0<06ATI0`1UIFD209NGU`<0LG5a0`13@d<303dm?@80MGEe0`15ADD300T92Bh0
0000203oool000H0ooooBP00000300410@<000000`051@D20:RXZ0<0a/K60`2g]kL30<[:bP80k^k^
0`3hn?P60>g]k@80j^[Z0`3YjNT30>[ZjP<0m_Kf0P3_knl30>[ZjP<0jn_[0`3AdM420;>c/`<0YZJV
0`2HV9P209ZJVP<0[jn_0`2c/k<30;Jf]P80SHf=0`1nOWh306YZJP<0FUYJ0P11@D4302TY:@<09BDU
0`0F5QH200h>3P<06QXJ0`0_;bl3061PH080D51@0`0>3Ph305ADE0<0Ogmo0P21PH4307moO`<0KFe]
0`1<C4`202`/;0<06ATI0`1UIFD209NGU`<0LG5a0`13@d<303dm?@80MGEe0`15ADD300T92Bh00000
203oool000H0oooo@P00000300410@h000000P1TI6@30=[JfP<0aLG50`2g]kL20=GEe@<0fMWI0`3>
c/h50<[:bP<0d];B0`3Lg=`30<o?c`80dm?C0`34a<@30:f][@<0]KFe0P2QXJ4308f=S@<0OWin0P1^
KVh307]kN`<0LG5a0`2DU9@20;Fe]@<0Lg=c0`17AdL308:2PP80UiNG0`2LW9`308f=S@<0QXJ60P1R
HV8303`l?0<05ADE0`0f=SH202`/;0<0:RXZ0`17AdL307MgM`80Ph>30`1kNg/306i^KP<0BDU90P0d
=3@302`/;0<0QhN70P2CTi<306a/K0<0?3`l0`1HF5P204];B`<0410@<@0000080?ooo`001P3ooom2
000000<00@413P00000206ATI0<0f][J0`35aLD30;Ng]`80eMGE0`3IfMT30<k>cPD0b/[:0`3Bd]83
0=cLg0<0clo?0P3Cdm<30<C4a0<0[Jf]0`2e]KD20:6QX@<0SHf=0`1nOWh206i^KP<0Ng]k0`1aLG43
09BDU080]KFe0`1cLg<304M7A`<0PX:20P2GUiL309bLW0<0SHf=0`26QXH2069RHP<0?3`l0`0E5AD3
03Hf=P80;2`/0`0Z:RX304M7A`<0MgMg0P23Ph<307]kN`<0KVi^0`19BDT203@d=0<0;2`/0`27QhL2
09>CT`<0K6a/0`0l?3`305QHF080Bd];0`0@410a000000P0oooo00060?oood8000000`010@4>0000
0080I6AT0`3Jf]X30<G5a@<0]kNg0P3EeMD30=WIf@<0c/k>1@3:b/X30=;BdP<0g=cL0`3?cll20=?C
d`<0a<C40`2][Jd30;Fe]@80XJ6Q0`2=SHd307inOP80KVi^0`1kNg/3075aL@<0U9BD0P2e]KD307=c
L`<0AdM70`22PX8209NGU`<0W9bL0`2=SHd308J6QP80HV9R0`0l?3`301DE5@<0=SHf0P0/;2`302XZ
:P<0AdM70`1gMgL208>3P`<0Ng]k0`1^KVh304U9B@80=3@d0`0/;2`308N7Q`80Ti>C0`1/K6`303`l
?0<0F5QH0P1;Bd/3010@43400000203oool000H0ooooC@00000300410@<000000P0R8R860=3@d0<0
bl_;0P3EeMD30=WIf@<0i>CT0`3UiND20>c/k0<0j^[Z0`3Ng]h30=oOg`80[:b/0`1LG5`303Ti>@<0
De=C0P1ZJVX306i^KP<0IVIV0P1TI6@308j>SP<0X:2P0`2SXj<20<;2`P<0/k>c0`1ZJVX304=3@`80
Fe]K0`1^KVh3071`L0<0T92@0P2XZ:P30;Fe]@<0W9bL0`1mOGd203hn?P<0F5QH0`1YJFT307YjNP80
Ng]k0`20P80307AdM0<0DE5A0P0/;2`304i>CP<0VIVI0P29RHT305mOG`<0@D510`0l?3`200X:2P<0
00001P0410@[000000P0oooo00060?ooodd000000`010@43000000808R8R1P3@d=030<_;b`80eMGE
0`3IfMT30>CTi0<0iNGU0P3/k>`30>[ZjP<0g]kN0`3Ogml20:b/[0<0G5aL0`0i>CT305=CD`80JVYZ
0`1^KVh306IVIP80I6AT0`2>SXh30:2PX0<0Xj>S0P32`/830;>c/`<0JVYZ0`13@d<205]KF`<0KVi^
0`1`L703092@T080Z:RX0`2e]KD309bLW0<0OGem0P0n?Sh305QHF0<0JFUY0`1jNWX207]kN`<0P820
0`1dM7@3055AD@80;2`/0`1>CTh309VIV@80RHV90`1OGel30451@@<0?3`l0P0:2PX3000000H010@4
:`0000080?ooo`001P3ooomE000000<0Lg=c0`3Ti>@30<o?c`80d=3@0`3IfMT30=[JfP<0i^KV0P3X
j>P60=_Kf`<0/[:b0P0W9bL300H61PH02@T90P0K6a/305MGE`<0M7Ad0P25QHD30;Ng]`<0_;bl0`32
`/820;:b/P<0];Bd0`3De=@308b<S080EUIF0`1IFET305MGE`<0Lg=c0P2PX:030:n_[`<0V9RH0`1U
IFD204a<C0<0Jf][0`22PX8308B4Q0D0PX:20`1YJFT304Q8B080;2`/0`1RHV8308n?S`80Lg=c0`1;
Bd/3028R8P<010@41@00000300410Bh00000203oool000H0ooooE@00000307=cL`<0i>CT0`3?cll2
0=3@d0<0fMWI0`3Jf]X30>KViP80j>SX1P3Kfm/30;:b/P809bLW0`061PH600T92@806a/K0`1GEeL3
07AdM080QHF50`2g]kL30;bl_0<0`/;20P2b/[830;Bd]0<0e=CD0`2<S8`205IFEP<0FEUI0`1GEeL3
07=cL`80X:2P0`2_[jl309RHV0<0IFEU0P1<C4`306][J`<0PX:20`24Q8@508:2PP<0JFUY0`18B4P2
02`/;0<0HV9R0`2?Shl207=cL`<0Bd];0`0R8R8300@410D000000`010@4^000000P0oooo00060?oo
oeD000000`1cLg<30>CTi0<0clo?0P3@d=030=WIf@<0f][J0`3Vi^H20>SXj0H0fm_K0`2b/[8202LW
9`<01PH61P092@T201/K6`<0EeMG0`1dM7@208F5Q@<0]kNg0`2l_;`30<;2`P80/[:b0`2d];@30=CD
e0<0S8b<0P1FEUH305UIF@<0EeMG0`1cLg<20:2PX0<0[jn_0`2HV9P306EUI@80C4a<0`1[Jf/308:2
PP<0Q8B41@22PX8306UYJ@<0B4Q80P0/;2`3069RHP<0Shn?0P1cLg<304];B`<08R8R0`0410@50000
00<00@41;P0000080?ooo`001P3ooom@000000<010@40P000003014A4@<0^KVi0`3Shn<20<g=c@<0
dM7A0`3EeMD30<o?c`80fMWI0`3YjNT30=gMg@<0HV9R1@0V9RH301hN7P<05QHF0P092@T302XZ:P<0
K6a/0P2TY:@30;Vi^@<0a/K60`3:b/X20:FUY@<0PX:20`2k^k/30;jn_P80UIFE0`21PH4307QhN0<0
FUYJ0P1CDe<304a<C0<0H61P0`0o?cl205mOG`<0NWYj0`20P80308B4Q080QhN70`26QXH3069RHP<0
?3`l0P0a<C4306m_K`<0O7al0P1NGUh302XZ:P<01@D50`010@4200@410<00@41<@0000080?ooo`00
1P3ooom@000000<010@40P000003014A4@<0^KVi0`3Shn<20<g=c@<0dM7A0`3EeMD30<o?c`80fMWI
0`3YjNT30=gMg@<0HV9R1@0V9RH301hN7P<05QHF0P092@T302XZ:P<0K6a/0P2TY:@30;Vi^@<0a/K6
0`3:b/X20:FUY@<0PX:20`2k^k/30;jn_P80UIFE0`21PH4307QhN0<0FUYJ0P1CDe<304a<C0<0H61P
0`0o?cl205mOG`<0NWYj0`20P80308B4Q080QhN70`26QXH3069RHP<0?3`l0P0a<C4306m_K`<0O7al
0P1NGUh302XZ:P<01@D50`010@4200@410<00@41<@0000080?ooo`001P3ooom@000000<010@40P00
0003014A4@<0^KVi0`3Shn<20<g=c@<0dM7A0`3EeMD30<o?c`80fMWI0`3YjNT30=gMg@<0HV9R1@0V
9RH301hN7P<05QHF0P092@T302XZ:P<0K6a/0P2TY:@30;Vi^@<0a/K60`3:b/X20:FUY@<0PX:20`2k
^k/30;jn_P80UIFE0`21PH4307QhN0<0FUYJ0P1CDe<304a<C0<0H61P0`0o?cl205mOG`<0NWYj0`20
P80308B4Q080QhN70`26QXH3069RHP<0?3`l0P0a<C4306m_K`<0O7al0P1NGUh302XZ:P<01@D50`01
0@4200@410<00@41<@0000080?ooo`001P3ooom=000000<00@4120000003034a<@<0_[jn0P3WinL3
0=SHf0H0fm_K0P3Lg=`30=CDe0<0^[Zj0`22PX820820P0<0N7Qh0`1TI6@303dm?@80:RXZ0`0C4a<3
04E5A@80/K6a0`3Bd]830:NWY`<0`l?30P3;bl/307emO@<0NWYj0`2ATI420;bl_0H0WIfM0`2@T902
05aLG0<0O7al0`1mOGd303dm?@80IfMW0`1kNg/308B4Q0<0S8b<0P2>SXh307YjNP<0H61P0`13@d<2
03Xj>P<0KVi^0`1XJ6P203`l?0<01@D50`010@45000000<00P82<@0000080?ooo`001P3ooom=0000
00<00@4120000003034a<@<0_[jn0P3WinL30=SHf0H0fm_K0P3Lg=`30=CDe0<0^[Zj0`22PX820820
P0<0N7Qh0`1TI6@303dm?@80:RXZ0`0C4a<304E5A@80/K6a0`3Bd]830:NWY`<0`l?30P3;bl/307em
O@<0NWYj0`2ATI420;bl_0H0WIfM0`2@T90205aLG0<0O7al0`1mOGd303dm?@80IfMW0`1kNg/308B4
Q0<0S8b<0P2>SXh307YjNP<0H61P0`13@d<203Xj>P<0KVi^0`1XJ6P203`l?0<01@D50`010@450000
00<00P82<@0000080?ooo`001P3ooom=000000<00@4120000003034a<@<0_[jn0P3WinL30=SHf0H0
fm_K0P3Lg=`30=CDe0<0^[Zj0`22PX820820P0<0N7Qh0`1TI6@303dm?@80:RXZ0`0C4a<304E5A@80
/K6a0`3Bd]830:NWY`<0`l?30P3;bl/307emO@<0NWYj0`2ATI420;bl_0H0WIfM0`2@T90205aLG0<0
O7al0`1mOGd303dm?@80IfMW0`1kNg/308B4Q0<0S8b<0P2>SXh307YjNP<0H61P0`13@d<203Xj>P<0
KVi^0`1XJ6P203`l?0<01@D50`010@45000000<00P82<@0000080?ooo`001P3ooom=000000<00@41
0`020P82000000<00@410`00000301`L7080ZZZZ0`3_knl30>3Ph0<0gMgM0P3Rh^830=[JfP<0]kNg
0`2UYJD20;no_`<0g]kN0`3MgMd30:>SX`80JFUY0`1;Bd/302d];@80T92@0`3Kfm/309BDU0<0Y:BT
0P3?cll30<g=c@<0_kno0`2ZZZX20;:b/P<0`<300`2ZZZX30;6a/@D0_Kfm0`1ADE4303`l?080JFUY
0`1hN7P308R8R0<0Ti>C0P2=SHd307]kN`<0H61P0`0m?Cd20492@P<0GemO0`1ADE4201XJ6P<00@41
0`00000800410@<000000`010@4200820RT00000203oool000H0ooooC@00000300410@<00P820P00
000300410@<000000`0L71`20:ZZZP<0kno_0`3Ph>030=gMg@80h^;R0`3Jf]X30;Ng]`<0YJFU0P2o
_kl30=kNgP<0gMgM0`2SXj<206UYJ@<0Bd];0`0];Bd2092@T0<0fm_K0`2DU9@30:BTY080clo?0`3=
cLd30;no_`<0ZZZZ0P2b/[830<30`0<0ZZZZ0`2a/K450;fm_@<0DE5A0`0l?3`206UYJ@<0N7Qh0`28
R8P309>CT`80SHf=0`1kNg/3061PH0<0?Cdm0P12@T8305mOG`<0DE5A0P0J6QX300410@<000002001
0@43000000<00@410P020P8Y000000P0oooo00060?oooe<000000P020P83000000<00`<30`000002
00L71`<0MgMg0`3Ti>@30?3`l080hN7Q0`3Jf]X30:ZZZP<0Xj>S0P3;bl/30>g]k@<0h>3P0`34a<@2
09FEU@<0PX:20`0d=3@207alO0<0emOG0`35aLD309>CT`80T92@0`2NWYh30;jn_P<0alO70P2IVIT3
0::RXP<0YJFU0`2/[:`207YjNP<0AdM70`14A4@304M7A`80JFUY0`1jNWX308R8R0<0TY:B0P27QhL3
07EeM@<0GUiN0`0n?Sh203`l?0<0CTi>0`0];Bd200<30`h000000`010@43000000800@41:@000008
0?ooo`001P3ooomC000000800P820`00000300<30`<000000P071`L307MgM`<0i>CT0`3`l?020>7Q
h@<0f][J0`2ZZZX30:>SX`80bl_;0`3]kNd30>3Ph0<0a<C40P2EUID308:2PP<0=3@d0P1lO7`30=OG
e`<0aLG50`2CTi<2092@T0<0WYjN0`2n_[h30<O7a`80VIVI0`2RXZ830:FUY@<0[:b/0P1jNWX304M7
A`<0A4A40`17AdL206UYJ@<0NWYj0`28R8P309:BTP80QhN70`1eMGD305iNGP<0?Shn0P0l?3`304i>
CP<0;Bd]0P030`<>000000<00@410`00000200410BT00000203oool000H0ooooD`00000200820P<0
00000`030`<3000000801`L70`1gMgL30>CTi0<0l?3`0P3QhN430=[JfP<0ZZZZ0`2SXj<20<_;b`<0
kNg]0`3Ph>030<C4a080UIFE0`22PX8303@d=080O7al0`3GemL30<G5a@<0Ti>C0P2@T90309jNWP<0
_[jn0`37alL209VIV@<0XZ:R0`2UYJD30:b/[080NWYj0`17AdL304A4A0<0AdM70P1YJFT307YjNP<0
R8R80`2BTY8208N7Q`<0MGEe0`1NGUh303hn?P80?3`l0`1>CTh302d];@800`<33P00000300410@<0
00000P010@4Y000000P0oooo00060?oooe0000000`020P88000000<00P821@00000304e=C@<0[Zj^
0P3YjNT30>KViP<0WinO0`20P8020:NWY`<0iNGU0`3;bl/30:FUY@80R8R80`2:RXX303dm?@80De=C
0`2ZZZX60<71`@80_kno0`35aLD30:^[Z`<0];Bd0P2EUID309BDU0<0OGem0`1=CDd2024Q8@<0>CTi
0`1FEUH3059BDP80Fe]K0`1lO7`3092@T0<0Shn?0P1oOgl306e]K@<0E5AD0`0];Bd202PX:0<0>3Ph
0`0C4a<2000000<00@411P030`<200820P<00@41<@0000080?ooo`001P3ooom@000000<00P822000
000300820PD000000`1=CDd30:j^[P80jNWY0`3Vi^H309nOW`<0P8200P2WYjL30>GUi@<0bl_;0`2U
YJD208R8R0<0RXZ:0`0m?Cd205=CD`<0ZZZZ1P31`L420;no_`<0aLG50`2[Zj/30;Bd]080UIFE0`2D
U9@307emO@<0CDe=0P0Q8B4303Ti>@<0EUIF0`1BDU8205]KF`<0O7al0`2@T90308n?S`80Ogmo0`1]
KFd305ADE0<0;Bd]0P0X:2P303Ph>0<04a<C0P00000300410@H00`<30P020P8300410C400000203o
ool000H0ooooD000000300820PP000000`020P85000000<0CDe=0`2^[Zh20>WYj@<0i^KV0`2OWil3
0820P080YjNW0`3UiND30<_;b`<0YJFU0P28R8P308Z:RP<0?Cdm0P1CDe<30:ZZZPH0`L710P2o_kl3
0<G5a@<0Zj^[0`2d];@209FEU@<0U9BD0`1mOGd304e=C@808B4Q0`0i>CT305IFEP<0DU9B0P1KFe/3
07alO0<0T92@0`2?Shl207moO`<0KFe]0`1DE5@302d];@80:2PX0`0h>3P301<C4`8000000`010@46
00<30`800P820`010@4a000000P0oooo00060?ooodd000000`020P83000000800P820`0000030082
0PD000000`010@4600000080@D510`2WYjL309bLW0<0LW9b0P1_Kfl309JFUP<0Vi^K0`20P805071`
L0<0@d=30P1<C4`308^;R`<0[jn_1@2UYJD30<O7a`<0_Kfm0`2[Zj/208B4Q0<0>CTi0`0<30`301LG
5`80=CDe0`13@d<304];B`<0GemO0P1WIfL308>3P`<0TI6A0`2:RXX207UiN@<0IVIV0`16ATH3024Q
8@808R8R0`0^;Rh300L71a0000000`010@4^000000P0oooo00060?ooodd000000`020P8300000080
0P820`00000300820PD000000`010@4600000080@D510`2WYjL309bLW0<0LW9b0P1_Kfl309JFUP<0
Vi^K0`20P805071`L0<0@d=30P1<C4`308^;R`<0[jn_1@2UYJD30<O7a`<0_Kfm0`2[Zj/208B4Q0<0
>CTi0`0<30`301LG5`80=CDe0`13@d<304];B`<0GemO0P1WIfL308>3P`<0TI6A0`2:RXX207UiN@<0
IVIV0`16ATH3024Q8@808R8R0`0^;Rh300L71a0000000`010@4^000000P0oooo00060?ooocd00000
1@020P8300<30`<00P822`00000200410@<000000`010@4@000000<02PX:0`1KFe/306i^KP80Lg=c
0`2CTi<309RHV0<0OWin0P1ZJVX305IFEP<0?clo0P0h>3P305iNGP<0MWIf0`21PH4508^;R`<0LG5a
0`0o?cl200d=3@<02PX:0`0K6a/301`L7080>SXj1P1>CTh305=CD`80LW9b0`2:RXX308b<S0<0PH61
0P1cLg<305YJFP<0<30`0`0L71`202/[:`<06a/K0`020P85000000<00@41>@0000080?ooo`001P3o
oolm000000D00P820`030`<300820P/000000P010@43000000<00@414000000300X:2P<0Fe]K0`1^
KVh207=cL`<0Ti>C0`2HV9P307inOP80JVYZ0`1FEUH303lo?`80>3Ph0`1NGUh307IfMP<0PH611@2;
Rh/3075aL@<0?clo0P0=3@d300X:2P<06a/K0`0L71`203Xj>PH0CTi>0`1CDe<2079bLP<0RXZ:0`2<
S8`30861P@80Lg=c0`1JFUX3030`<0<071`L0P0[:b/301/K6`<00P821@00000300410CT00000203o
ool000H0oooo?@00000500820P<00`<30`020P8;000000800@410`00000300410A0000000`0:2PX3
05]KF`<0KVi^0P1cLg<309>CT`<0V9RH0`1nOWh206YZJP<0EUIF0`0o?cl203Ph>0<0GUiN0`1fMWH3
0861P@D0Rh^;0`1aLG4303lo?`803@d=0`0:2PX301/K6`<071`L0P0j>SX604i>CP<0De=C0P1bLW83
08Z:RP<0S8b<0`21PH4207=cL`<0FUYJ0`0`<30301`L7080:b/[0`0K6a/300820PD000000`010@4i
000000P0oooo00060?oooe0000000`020P8C000000<00@411@00000303`l?0<0IVIV0P1RHV8306MW
I`<0JVYZ0`1PH60204m?C`<0@D510`0f=SH202/[:`<0D51@0`1TI6@305iNGP80De=C0`0e=CD301LG
5`<00`<30P0@410301lO7`<092@T0`0Q8B4203Lg=`<0CDe=0`1FEUH305eMG@80LG5a0`29RHT308R8
R0<0QHF50P1bLW8304U9B@<0;Rh^0`0V9RH202DU9@<02PX:1@00000300410@<000000`030`<f0000
00P0oooo00060?oooe0000000`020P8C000000<00@411@00000303`l?0<0IVIV0P1RHV8306MWI`<0
JVYZ0`1PH60204m?C`<0@D510`0f=SH202/[:`<0D51@0`1TI6@305iNGP80De=C0`0e=CD301LG5`<0
0`<30P0@410301lO7`<092@T0`0Q8B4203Lg=`<0CDe=0`1FEUH305eMG@80LG5a0`29RHT308R8R0<0
QHF50P1bLW8304U9B@<0;Rh^0`0V9RH202DU9@<02PX:1@00000300410@<000000`030`<f000000P0
oooo00060?oooe0000000`020P8C000000<00@411@00000303`l?0<0IVIV0P1RHV8306MWI`<0JVYZ
0`1PH60204m?C`<0@D510`0f=SH202/[:`<0D51@0`1TI6@305iNGP80De=C0`0e=CD301LG5`<00`<3
0P0@410301lO7`<092@T0`0Q8B4203Lg=`<0CDe=0`1FEUH305eMG@80LG5a0`29RHT308R8R0<0QHF5
0P1bLW8304U9B@<0;Rh^0`0V9RH202DU9@<02PX:1@00000300410@<000000`030`<f000000P0oooo
00060?ooodd000000`020P8;000000D00@413P00000303De=@<0Lg=c0P1[Jf/306YZJP<0IfMW0`1G
EeL204=3@`<0<c<c0`0];Bd202LW9`<07QhN0`0A4A4300P820803Ph>0`0B4Q8301@D50<04Q8B0P0H
61P3034a<@<0;Rh^0`0Y:BT203Ti>@<0BDU90`1KFe/307alO080S8b<0`23Ph<307alO0<0M7Ad0P1W
IfL304];B`<0=3@d0`0T92@2010@40H000000P020P89000000D00P82<@0000080?ooo`001P3ooom=
000000<00P822`00000500410@h000000`0e=CD307=cL`80Jf][0`1ZJVX306MWI`<0EeMG0P13@d<3
03<c<`<0;Bd]0P0W9bL301hN7P<04A4A0`0820P200h>3P<04Q8B0`0D51@3018B4P8061PH0`0a<C43
02h^;P<0:BTY0P0i>CT304U9B@<0Fe]K0`1lO7`208b<S0<0Ph>30`1lO7`307AdM080IfMW0`1;Bd/3
03@d=0<092@T0P0@4106000000800P822@00000500820S400000203oool000H0ooooC@0000030082
0P/000001@010@4>000000<0=CDe0`1cLg<206][J`<0JVYZ0`1WIfL305MGE`80@d=30`0c<c<302d]
;@809bLW0`0N7Qh3014A4@<020P80P0>3Ph3018B4P<051@D0`0B4Q8201PH60<0<C4a0`0^;Rh302TY
:@80>CTi0`19BDT305]KF`<0O7al0P2<S8`308>3P`<0O7al0`1dM7@206MWI`<0Bd];0`0d=3@302@T
9080410@1P00000200820PT000001@020P8a000000P0oooo00060?oooe/000000`020P85000000<0
0P821@00000300410@<0:b/[0`2:RXX207]kN`<0M7Ad0`1]KFd305eMG@80AdM70`0_;bl502`/;0<0
51@D0`092@T300l?3`8051@D0`0I6AT301LG5`<06a/K0P0V9RH303De=@<0<30`0`0j>SX203lo?`<0
@d=30`1KFe/308:2PP80S8b<1P1nOWh307=cL`80IVIV0`1BDU8302l_;`<03Ph>2P00000300410@<0
0P820`010@4200820S@00000203oool000H0ooooF`00000300820PD000000`020P85000000<00@41
0`0[:b/308Z:RP80Ng]k0`1dM7@306e]K@<0GEeM0P17AdL302l_;`D0;2`/0`0D51@300T92@<03`l?
0P0D51@301TI6@<05aLG0`0K6a/202HV9P<0=CDe0`0`<30303Xj>P80?clo0`13@d<305]KF`<0PX:2
0P2<S8`607inOP<0Lg=c0P1VIVH3059BDP<0;bl_0`0>3Ph:000000<00@410`020P8300410@800P82
=00000080?ooo`001P3ooom@000000<00@414000000300410@P000000`0E5AD308R8R080MWIf0`1/
K6`306IVIP<0Hf=S0P1IFET303Ph>0<0=SHf0P0[:b/3014A4@<0410@0`0K6a/2014A4@<06ATI0`0P
820302<S8`D0=CDe0`0`<30304a<C080EUIF0`1GEeL306][J`<0Ng]k0P1fMWH307AdM0<0O7al0`1a
LG4206ATI0<0BDU90`0I6AT5000000H00@410P00000300820P<00`<3>@0000080?ooo`001P3ooom@
000000<00@414000000300410@P000000`0E5AD308R8R080MWIf0`1/K6`306IVIP<0Hf=S0P1IFET3
03Ph>0<0=SHf0P0[:b/3014A4@<0410@0`0K6a/2014A4@<06ATI0`0P820302<S8`D0=CDe0`0`<303
04a<C080EUIF0`1GEeL306][J`<0Ng]k0P1fMWH307AdM0<0O7al0`1aLG4206ATI0<0BDU90`0I6AT5
000000H00@410P00000300820P<00`<3>@0000080?ooo`001P3ooom@000000<00@41400000030041
0@P000000`0E5AD308R8R080MWIf0`1/K6`306IVIP<0Hf=S0P1IFET303Ph>0<0=SHf0P0[:b/3014A
4@<0410@0`0K6a/2014A4@<06ATI0`0P820302<S8`D0=CDe0`0`<30304a<C080EUIF0`1GEeL306][
J`<0Ng]k0P1fMWH307AdM0<0O7al0`1aLG4206ATI0<0BDU90`0I6AT5000000H00@410P0000030082
0P<00`<3>@0000080?ooo`001P3ooom@000000<00`<36`00000300D51@<0Ogmo0P2GUiL308J6QP<0
NWYj0`1gMgL206MWI`<0De=C0`18B4P202/[:`<05ADE0`0H61P301lO7`806QXJ0`0M7Ad302DU9@<0
:b/[0P0m?Cd303Lg=`<0ATI60`1VIVH206QXJ0<0LG5a0`22PX8307AdM080K6a/0`1eMGD306UYJ@<0
Fe]K0P17AdL3020P80<00@414`00000300410CH00000203oool000H0ooooD000000300<30a/00000
0`051@D307moO`80UiNG0`26QXH307YjNP<0MgMg0P1WIfL305=CD`<0B4Q80P0[:b/301DE5@<061PH
0`0O7al201XJ6P<07AdM0`0U9BD302/[:`80?Cdm0`0g=cL304I6AP<0IVIV0P1XJ6P3075aL@<0PX:2
0`1dM7@206a/K0<0MGEe0`1YJFT305]KF`80AdM70`0P820300410A<000000`010@4f000000P0oooo
00060?oooe0000000`030`<K000000<01@D50`1oOgl209NGU`<0QXJ60`1jNWX307MgM`80IfMW0`1C
De<304Q8B080:b/[0`0E5AD301PH60<07alO0P0J6QX301dM7@<09BDU0`0[:b/203dm?@<0=cLg0`16
ATH306IVIP80J6QX0`1aLG4308:2PP<0M7Ad0P1/K6`307EeM@<0JFUY0`1KFe/204M7A`<0820P0`01
0@4C000000<00@41=P0000080?ooo`001P3ooomC000000800@415000000200410@<000000`0<30`3
06YZJP80V9RH0`2@T90308R8R0<0PH610P1aLG4306UYJ@<0CTi>0P0[:b/301`L70<0820P0`0H61P2
01`L70<09BDU0`0X:2P303Hf=P80@D510`12@T8305IFEP<0Lg=c0P1jNWX307QhN0<0MWIf0`1/K6`2
06UYJ@<0H61P0`1:BTX303lo?`8092@T0`061PH6000000800@413P00000500410@<00`<3<@000008
0?ooo`001P3ooomC000000800@415000000200410@<000000`0<30`306YZJP80V9RH0`2@T90308R8
R0<0PH610P1aLG4306UYJ@<0CTi>0P0[:b/301`L70<0820P0`0H61P201`L70<09BDU0`0X:2P303Hf
=P80@D510`12@T8305IFEP<0Lg=c0P1jNWX307QhN0<0MWIf0`1/K6`206UYJ@<0H61P0`1:BTX303lo
?`8092@T0`061PH6000000800@413P00000500410@<00`<3<@0000080?ooo`001P3ooolm000000/0
0@412000000300410@8000000`010@48000000<00@412`00000301/K6`<0FEUI0P2<S8`309BDU0<0
Q8B40`1kNg/207EeM@<0IfMW0`16ATH202XZ:P<06a/K0`0V9RH301dM7@808R8R0`0];Bd3038b<P<0
C4a<0P1>CTh305EEE@<0JFUY0`1_Kfl207QhN0<0Ng]k0`1jNWX306e]K@80EUIF0`1:BTX303Xj>P<0
6QXJ0P010@43000000<00`<32000000300410@P000000`010@4f000000P0oooo00060?ooocd00000
2`010@48000000<00@410P00000300410@P000000`010@4;000000<06a/K0`1IFET208b<S0<0U9BD
0`24Q8@307]kN`80MGEe0`1WIfL304I6AP80:RXZ0`0K6a/302HV9P<07AdM0P0R8R8302d];@<0<S8b
0`1<C4`204i>CP<0EEEE0`1YJFT306m_K`80N7Qh0`1kNg/307YjNP<0KFe]0P1FEUH304Y:BP<0>SXj
0`0J6QX200410@<000000`030`<8000000<00@412000000300410CH00000203oool000H0oooo?@00
000;00410@P000000`010@42000000<00@412000000300410@/000000`0K6a/305UIF@80S8b<0`2D
U9@308B4Q0<0Ng]k0P1eMGD306MWI`<0ATI60P0Z:RX301/K6`<09RHV0`0M7Ad2028R8P<0;Bd]0`0b
<S8304a<C080CTi>0`1EEED306UYJ@<0Kfm_0P1hN7P307]kN`<0NWYj0`1]KFd205IFEP<0BTY:0`0j
>SX301XJ6P800@410`00000300<30`P000000`010@48000000<00@41=P0000080?ooo`001P3ooom@
000000<00P821@00000600410@P000000`010@45000000<07AdM0`1FEUH208J6QP<0Shn?0`28R8P3
07UiN@80J6QX0`1MGEd30410@080:RXZ0`0U9BD302<S8`<0:2PX0P0d=3@3030`<0<0A4A40`1KFe/2
05YJFP<0IVIV0`1hN7P307AdM080Lg=c1P1kNg/306IVIP80Bd];0`0U9BD300h>3P<010@420000003
00820P800@412000000300410@/000000`010@4^000000P0oooo00060?oooe0000000`020P850000
00H00@412000000300410@D000000`0M7Ad305IFEP80QXJ60`2?Shl308R8R0<0NGUi0P1XJ6P305eM
G@<0@4100P0Z:RX302DU9@<08b<S0`0X:2P203@d=0<0<30`0`14A4@305]KF`80FUYJ0`1VIVH307Qh
N0<0M7Ad0P1cLg<607]kN`<0IVIV0P1;Bd/302DU9@<03Ph>0`0410@8000000<00P820P010@480000
00<00@412`00000300410Bh00000203oool000H0ooooD000000300820PD000001P010@48000000<0
0@411@00000301dM7@<0EUIF0P26QXH308n?S`<0R8R80`1iNGT206QXJ0<0GEeM0`10@40202XZ:P<0
9BDU0`0S8b<302PX:080=3@d0`0`<30304A4A0<0Fe]K0P1JFUX306IVIP<0N7Qh0`1dM7@207=cL`H0
Ng]k0`1VIVH204];B`<09BDU0`0>3Ph300@410P000000`020P8200410@P000000`010@4;000000<0
0@41;P0000080?ooo`001P3ooom=000000<00@414000000300410@H000000P010@4300820P<030`<
0`1IFET208B4Q0<0SXj>0`28R8P307=cL`80IVIV0`1DE5@30410@080<S8b0`0];Bd302`/;0<0=3@d
0P0b<S8304E5A@H0H61P0P1YJFT307EeM@<0OWin0`1hN7P207EeM@<0O7al0`1cLg<304Y:BP8071`L
0`010@48000000<00P820`00000300410@d000000`010@4i000000P0oooo00060?ooodd000000`01
0@4@000000<00@411P00000200410@<00P820`0<30`305UIF@80Q8B40`2>SXh308R8R0<0Lg=c0P1V
IVH305ADE0<0@4100P0b<S8302d];@<0;2`/0`0d=3@2038b<P<0ADE51P1PH60206UYJ@<0MGEe0`1n
OWh307QhN080MGEe0`1lO7`307=cL`<0BTY:0P0L71`300410@P000000`020P83000000<00@413@00
000300410CT00000203oool000H0ooooC@00000300410A0000000`010@46000000800@410`020P83
00`<30<0FEUI0P24Q8@308j>SP<0R8R80`1cLg<206IVIP<0E5AD0`10@402038b<P<0;Bd]0`0/;2`3
03@d=080<S8b0`15ADD6061PH080JFUY0`1eMGD307inOP<0N7Qh0P1eMGD307alO0<0Lg=c0`1:BTX2
01`L70<00@412000000300820P<000000`010@4=000000<00@41>@0000080?ooo`001P3ooomH0000
00<00@412`00000300410@8010@40`020P8300<30`<0@d=30P1mOGd308N7Q`<0O7al0`1XJ6P205mO
G`<0CTi>0`0o?cl203Hf=P<0<c<c0`0g=cL303Xj>P80B4Q80`1HF5P306EUI@<0J6QX0P1gMgL30861
P@<0P8200`21PH4207alO0<0K6a/0`14A4@301<C4`P000000`020P8H000000<00P821@0000030041
0C400000203oool000H0ooooF000000300410@/000000`010@4200@410<00P820`030`<304=3@`80
OGem0`27QhL307alO0<0J6QX0P1OGel304i>CP<0?clo0P0f=SH303<c<`<0=cLg0`0j>SX204Q8B0<0
F5QH0`1UIFD306QXJ080MgMg0`21PH430820P0<0PH610P1lO7`306a/K0<0A4A40`0C4a<8000000<0
0P826000000300820PD000000`010@4a000000P0oooo00060?ooodd000000`010@4C000000<00@41
0`00000200<30`<00@410`000003024Q8@80K6a/0`24Q8@307QhN0<0HF5Q0P1LG5`3059BDP<0@d=3
1@0n?Sh304Y:BP<0Bd];0P1JFUX305eMG@<0IVIV0`1bLW8207IfMP<0Ph>30`20P80307AdM080HF5Q
0`11@D4301HF5PD000000`010@43000000<00P824000000300410@D000000`020P8300<30cH00000
203oool000H0ooooC@00000300410A<000000`010@43000000800`<30`010@43000000<08B4Q0P1/
K6`308B4Q0<0N7Qh0`1QHF4205aLG0<0DU9B0`13@d<503hn?P<0BTY:0`1;Bd/205YJFP<0GEeM0`1V
IVH3079bLP80MWIf0`23Ph<30820P0<0M7Ad0P1QHF430451@@<05QHF1@00000300410@<000000`02
0P8@000000<00@411@00000300820P<00`<3=P0000080?ooo`001P3ooom=000000<00@414`000003
00410@<000000P030`<300410@<000000`0Q8B4206a/K0<0Q8B40`1hN7P3065QH@80G5aL0`1BDU83
04=3@`D0?Shn0`1:BTX304];B`80FUYJ0`1MGEd306IVIP<0LW9b0P1fMWH308>3P`<0P8200`1dM7@2
065QH@<0@D510`0F5QH5000000<00@410`00000300820Q0000000`010@45000000<00P820`030`<f
000000P0oooo00060?oooe<000000P010@43000000<00@412`00000800410@<00P820`061PH203hn
?P<0NGUi0`1oOgl506MWI`<0Fe]K0`1:BTX204I6AP<0CTi>0`1GEeL305eMG@80Hf=S0`1TI6@306e]
K@<0MGEe0P1hN7P307AdM0<0Fe]K0`1;Bd/203lo?`<092@T0`030`<3000000800@413P0000030041
0A/000000`010@4^000000P0oooo00060?oooe<000000P010@43000000<00@412`00000800410@<0
0P820`061PH203hn?P<0NGUi0`1oOgl506MWI`<0Fe]K0`1:BTX204I6AP<0CTi>0`1GEeL305eMG@80
Hf=S0`1TI6@306e]K@<0MGEe0P1hN7P307AdM0<0Fe]K0`1;Bd/203lo?`<092@T0`030`<300000080
0@413P00000300410A/000000`010@4^000000P0oooo00060?oooe<000000P010@43000000<00@41
2`00000800410@<00P820`061PH203hn?P<0NGUi0`1oOgl506MWI`<0Fe]K0`1:BTX204I6AP<0CTi>
0`1GEeL305eMG@80Hf=S0`1TI6@306e]K@<0MGEe0P1hN7P307AdM0<0Fe]K0`1;Bd/203lo?`<092@T
0`030`<3000000800@413P00000300410A/000000`010@4^000000P0oooo00060?oooe<000000P03
0`<3000000<00@412000000300820P<00@410P00000300<30`<01@D50`061PH201LG5`<0ADE50`1P
H60306e]K@80Kfm_0`1UIFD305YJFP80EEEE0`1HF5P305YJFP<0HF5Q0P1TI6@306MWI`<0KVi^0`1W
IfL205]KF`<0De=C0`15ADD304A4A080;bl_0`0>3Ph6000000800@413P00000300410@d000000`01
0@4;000000<00@41;P0000080?ooo`001P3ooomC000000800`<30`00000300410@P000000`020P83
00410@8000000`030`<300D51@<01PH60P0G5aL304E5A@<0H61P0`1]KFd206m_K`<0IFEU0`1JFUX2
05EEE@<0F5QH0`1JFUX3065QH@80I6AT0`1WIfL306i^KP<0IfMW0P1KFe/305=CD`<0ADE50`14A4@2
02l_;`<03Ph>1P00000200410@h000000`010@4=000000<00@412`00000300410Bh00000203oool0
00H0ooooD`00000200<30`<000000`010@48000000<00P820`010@42000000<00`<30`051@D300H6
1P805aLG0`15ADD3061PH0<0KFe]0P1_Kfl306EUI@<0FUYJ0P1EEED305QHF0<0FUYJ0`1QHF4206AT
I0<0IfMW0`1^KVh306MWI`80Fe]K0`1CDe<304E5A@<0A4A40P0_;bl300h>3PH000000P010@4>0000
00<00@413@00000300410@/000000`010@4^000000P0oooo00060?oooe/000000`020P85000000<0
10@40`00000200410@T02`/;0P0H61P302LW9`<0>3Ph0`1DE5@205mOG`<0GUiN0`1PH60205mOG`<0
G5aL0`1NGUh306=SH`80IFEU0`1SHf<3061PH0<0EeMG0P1?Cdl304a<C0<0@d=30`0e=CD201PH60<0
0@410`00000300410@P000000`020P8K000000<00@41=P0000080?ooo`001P3ooomK000000<00P82
1@00000300@410<000000P010@4900/;2`8061PH0`0W9bL303Ph>0<0E5AD0P1OGel305iNGP<0H61P
0P1OGel305aLG0<0GUiN0`1SHf<206EUI@<0Hf=S0`1PH60305MGE`80Cdm?0`1<C4`304=3@`<0=CDe
0P0H61P300410@<000000`010@48000000<00P826`00000300410CH00000203oool000H0ooooF`00
000300410@D000000`010@43000000800P820`0=3@d301PH60<05aLG0P0N7Qh302HV9P<0;2`/0`0l
?3`2059BDP<0EEEE0`1HF5P205iNGP<0Hf=S0`1PH60306ATI080J6QX0`1NGUh305UIF@<0De=C0P1>
CTh304a<C0<0@T920`0R8R8200<30`H000000`020P85000000<00P820`010@4;000000D00@412`00
000300410@D000000`010@4^000000P0oooo00060?oooe/000000`010@45000000<00@410`000002
00820P<03@d=0`0H61P301LG5`807QhN0`0V9RH302`/;0<0?3`l0P1BDU8305EEE@<0F5QH0P1NGUh3
06=SH`<0H61P0`1TI6@206QXJ0<0GUiN0`1IFET305=CD`80CTi>0`1<C4`30492@P<08R8R0P030`<6
000000<00P821@00000300820P<00@412`00000500410@/000000`010@45000000<00@41;P000008
0?ooo`001P3ooomK000000<00@411@00000300410@<000000P020P8300d=3@<061PH0`0G5aL201hN
7P<09RHV0`0/;2`303`l?080DU9B0`1EEED305QHF080GUiN0`1SHf<3061PH0<0I6AT0P1XJ6P305iN
GP<0FEUI0`1CDe<204i>CP<0C4a<0`12@T83028R8P800`<31P00000300820PD000000`020P830041
0@/000001@010@4;000000<00@411@00000300410Bh00000203oool000H0ooooF000000300820P/0
00000`030`<200H61P<03@d=1P0L71`2020P80<08R8R0`0U9BD302h^;P80A4A40`1DE5@305iNGP80
Hf=S0`1VIVH306ATI0<0GUiN0P1OGel305YJFP<0F5QH0`1FEUH2059BDP<0CDe=0`0^;Rh300L71`P0
00000`030`<5000000<00P820`010@5D000000P0oooo00060?oooeP000000`020P8;000000<00`<3
0P061PH300d=3@H071`L0P0P8203028R8P<09BDU0`0^;Rh204A4A0<0E5AD0`1NGUh206=SH`<0IVIV
0`1TI6@305iNGP80GemO0`1JFUX305QHF0<0EUIF0P1BDU8304e=C@<0;Rh^0`071`L8000000<00`<3
1@00000300820P<00@41E00000080?ooo`001P3ooomH000000<00P822`00000300<30`801PH60`0=
3@d601`L7080820P0`0R8R8302DU9@<0;Rh^0P14A4@305ADE0<0GUiN0P1SHf<306IVIP<0I6AT0`1N
GUh205mOG`<0FUYJ0`1HF5P305IFEP80DU9B0`1=CDd302h^;P<01`L72000000300<30`D000000`02
0P8300410E@00000203oool000H0ooooF000000300410@D000000`010@43000000<01@D50P0;2`/3
00l?3`<06ATI0`0T92@202HV9P<08R8R1P0P820202d];@<0?Shn0`1BDU8205]KF`<0HF5Q0`1UIFD5
05aLG0<0FUYJ0`1IFET505MGE`<0?Shn0`0C4a<;000000<00@411@00000600410BT000000P010@4Y
000000P0oooo00060?oooeP000000`010@45000000<00@410`00000300D51@802`/;0`0?3`l301TI
6@<092@T0P0V9RH3028R8PH0820P0P0];Bd303hn?P<0DU9B0P1KFe/3065QH@<0IFEU1@1LG5`305YJ
FP<0FEUI1@1GEeL303hn?P<04a<C2`00000300410@D000001P010@4Y000000800@41:@0000080?oo
o`001P3ooomP000000<00@410`030`<300P820803Ph>0`0A4A4301HF5P<0:RXZ0P0e=CD303hn?P<0
A4A40`12@T8203lo?`<0ADE50`1EEED205aLG0<0H61P1P1RHV82061PH0<0G5aL0`1MGEd305]KF`80
EEEE0`0Z:RX300820Ph000000P010@4b000000800@41:@0000080?ooo`001P3ooomP000000<00@41
0`030`<300P820803Ph>0`0A4A4301HF5P<0:RXZ0P0e=CD303hn?P<0A4A40`12@T8203lo?`<0ADE5
0`1EEED205aLG0<0H61P1P1RHV82061PH0<0G5aL0`1MGEd305]KF`80EEEE0`0Z:RX300820Ph00000
0P010@4b000000800@41:@0000080?ooo`001P3ooomP000000<00@410`030`<300P820803Ph>0`0A
4A4301HF5P<0:RXZ0P0e=CD303hn?P<0A4A40`12@T8203lo?`<0ADE50`1EEED205aLG0<0H61P1P1R
HV82061PH0<0G5aL0`1MGEd305]KF`80EEEE0`0Z:RX300820Ph000000P010@4b000000800@41:@00
00080?ooo`001P3ooomC000000800@411P00000300410@8000000`030`<300L71`<02`/;0P0>3Ph3
01<C4`<06ATI0`0Y:BT203hn?P<0EUIF0`1TI6@3071`L080Lg=c1P1`L702079bLP<0Lg=c0`1^KVh3
06YZJP80I6AT0`1NGUh3065QH@<0GEeM0P0o?cl300l?3`/000000`010@45000000<00P8290000002
00410C@00000203oool000H0ooooD`00000200410@H000000`010@42000000<00`<30`071`L300/;
2`803Ph>0`0C4a<301TI6@<0:BTY0P0n?Sh305IFEP<0I6AT0`1`L70207=cL`H0L71`0P1bLW8307=c
L`<0KVi^0`1ZJVX206ATI0<0GUiN0`1QHF4305eMG@80?clo0`0?3`l;000000<00@411@0000030082
0R@000000P010@4d000000P0oooo00060?oooe<000000P010@46000000<00@410P00000300<30`<0
1`L70`0;2`/200h>3P<04a<C0`0I6AT302TY:@80?Shn0`1FEUH306ATI0<0L71`0P1cLg<6071`L080
LW9b0`1cLg<306i^KP<0JVYZ0P1TI6@305iNGP<0HF5Q0`1MGEd203lo?`<03`l?2`00000300410@D0
00000`020P8T000000800@41=00000080?ooo`001P3ooom@000000D00@411P00000300820P800`<3
0`051@D300L71`<02PX:0P0<30`3014A4@<07AdM0`0U9BD203Ph>0<0@T920`1<C4`305iNGP80I6AT
0`1/K6`306e]K@80L71`0`1aLG4306YZJP<0HV9R0P1NGUh305]KF`<0HV9R0`1IFET201lO7aH00000
0`010@48000000<00@414000000300410@H000000P010@4d000000P0oooo00060?oooe0000001@01
0@46000000<00P820P030`<300D51@<01`L70`0:2PX200`<30<04A4A0`0M7Ad302DU9@80>3Ph0`12
@T8304a<C0<0GUiN0P1TI6@306a/K0<0KFe]0P1`L703075aL@<0JVYZ0`1RHV8205iNGP<0Fe]K0`1R
HV8305UIF@807alO5P00000300410@P000000`010@4@000000<00@411P00000200410C@00000203o
ool000H0ooooD000000500410@H000000`020P8200<30`<01@D50`071`L300X:2P8030`<0`0A4A43
01dM7@<09BDU0P0h>3P30492@P<0C4a<0`1NGUh206ATI0<0K6a/0`1]KFd2071`L0<0LG5a0`1ZJVX3
069RHP80GUiN0`1KFe/3069RHP<0FEUI0P0O7alF000000<00@412000000300410A0000000`010@46
000000800@41=00000080?ooo`001P3ooom@000000<00`<31@00000600820P8010@40`030`<300D5
1@<02`/;0P0A4A43018B4P<071`L0`0V9RH2030`<0<0>SXj0`14A4@304m?C`80DU9B0`1OGel306IV
IP80KFe]0`1aLG4306e]K@<0JVYZ0P1XJ6P3071`L0<0KFe]0`14A4@200D51@<000000`030`<K0000
00<00`<33P00000500410@H000000P010@46000000<00@41:`0000080?ooo`001P3ooom@000000<0
0`<31@00000600820P8010@40`030`<300D51@<02`/;0P0A4A43018B4P<071`L0`0V9RH2030`<0<0
>SXj0`14A4@304m?C`80DU9B0`1OGel306IVIP80KFe]0`1aLG4306e]K@<0JVYZ0P1XJ6P3071`L0<0
KFe]0`14A4@200D51@<000000`030`<K000000<00`<33P00000500410@H000000P010@46000000<0
0@41:`0000080?ooo`001P3ooom=000000<00P822000000300820PD00@410`020P8300L71`<02PX:
0P0B4Q8301HF5P<071`L0`0Y:BT202l_;`<0>c/k0`19BDT304e=C@80FEUI0`1WIfL306m_K`80M7Ad
1P1jNWX307AdM080Kfm_0`1gMgL305EEE@<051@D1@00000300410A/000000`010@43000000<00P82
2000000200820P/000000`010@4a000000P0oooo00060?ooodd000000`020P88000000<00P821@01
0@4300820P<01`L70`0:2PX2018B4P<05QHF0`0L71`302TY:@80;bl_0`0k>c/304U9B@<0CDe=0P1I
FET306MWI`<0Kfm_0P1dM7@607YjNP<0M7Ad0P1_Kfl307MgM`<0EEEE0`0D51@5000000<00@416`00
000300410@<000000`020P88000000800P822`00000300410C400000203oool000H0ooooC@000003
00820PP000000`020P8500410@<00P820`071`L300X:2P804Q8B0`0F5QH301`L70<0:BTY0P0_;bl3
03/k>`<0BDU90`1=CDd205UIF@<0IfMW0`1_Kfl207AdM0H0NWYj0`1dM7@206m_K`<0MgMg0`1EEED3
01@D50D000000`010@4K000000<00@410`00000300820PP000000P020P8;000000<00@41<@000008
0?ooo`001P3ooom=000000<00@410`00000500410@<000000`020P8200<30`<010@40`0:2PX300`<
308051@D0`0K6a/3028R8P<0:2PX0P0a<C4303hn?P<0Bd];0`1CDe<2065QH@<0KVi^0`1fMWH207]k
N`<0OGem0`1jNWX307AdM080KVi^0`1SHf<302l_;`D000000`010@4C000000<00P82200000030041
0@h000000P010@43000000<00@410`020P8f000000P0oooo00060?ooodd000000`010@43000000D0
0@410`00000300820P800`<30`0410@300X:2P<030`<0P0D51@301/K6`<08R8R0`0X:2P2034a<@<0
?Shn0`1;Bd/305=CD`80HF5Q0`1^KVh307IfMP80Ng]k0`1mOGd307YjNP<0M7Ad0P1^KVh306=SH`<0
;bl_1@00000300410A<000000`020P88000000<00@413P00000200410@<000000`010@4300820SH0
0000203oool000H0ooooC@00000300410@<000001@010@43000000<00P820P030`<300@410<02PX:
0`0<30`201@D50<06a/K0`0R8R8302PX:080<C4a0`0n?Sh304];B`<0De=C0P1QHF4306i^KP<0MWIf
0P1kNg/307emO@<0NWYj0`1dM7@206i^KP<0Hf=S0`0_;bl5000000<00@414`00000300820PP00000
0`010@4>000000800@410`00000300410@<00P82=P0000080?ooo`001P3ooom=000000<00@410`02
0P88000000<010@41@092@T300l?3`<05ADE0P0J6QX301lO7`<0:BTY0`0[:b/203Lg=`<0@T920`1<
C4`305UIF@80IVIV0`1cLg<507MgM`<0NGUi0`1eMGD307AdM080KVi^0`13@d<300/;2`<000000P02
0P8F000000<00`<32000000600410@/000000P010@43000000<00@410`0410@200410C@00000203o
ool000H0ooooC@00000300410@<00P822000000300@410D02@T90`0?3`l301DE5@806QXJ0`0O7al3
02TY:@<0:b/[0P0g=cL30492@P<0C4a<0`1IFET206IVIP<0Lg=c1@1gMgL307UiN@<0MGEe0`1dM7@2
06i^KP<0@d=30`0;2`/3000000800P825P00000300<30`P000001P010@4;000000800@410`000003
00410@<010@40P010@4d000000P0oooo00060?ooodd000000`020P8300@4108000000`010@430082
0P<02PX:0P0=3@d300l?3`<05QHF0`0K6a/201`L70<08B4Q0`0];Bd3030`<080>CTi0`15ADD3055A
D@<0G5aL0P1UIFD607MgM`80LW9b0`1hN7P307IfMP<0KVi^0P1FEUH301hN7PH000000P020P8F0000
00<00@411P00000200410@<000000`010@4;000000800@410`020P8A000000800@41:@0000080?oo
o`001P3ooom=000000<00P820`0410@2000000<00@410`020P8300X:2P803@d=0`0?3`l301HF5P<0
6a/K0P0L71`3024Q8@<0;Bd]0`0`<30203Ti>@<0ADE50`1ADE4305aLG080IFEU1P1gMgL2079bLP<0
N7Qh0`1fMWH306i^KP80EUIF0`0N7Qh6000000800P825P00000300410@H000000P010@43000000<0
0@412`00000200410@<00P824@00000200410BT00000203oool000H0ooooC@00000300820P<010@4
0P00000300410@<00P820`0:2PX200d=3@<03`l?0`0F5QH301/K6`8071`L0`0Q8B4302d];@<0<30`
0P0i>CT304E5A@<0DE5A0`1LG5`206EUI@H0MgMg0P1bLW8307QhN0<0MWIf0`1^KVh205IFEP<07QhN
1P00000200820QH000000`010@46000000800@410`00000300410@/000000P010@4300820Q400000
0P010@4Y000000P0oooo00060?ooodP000001@010@4600<30`8000000`030`<300H61P<02`/;0P0A
4A4301DE5@<06ATI0`0N7Qh201lO7`<09RHV0`0];Bd303De=@80>c/k0`1;Bd/305YJFP<0I6AT0P1X
J6P307IfMP<0M7Ad0P1]KFd3071`L0<0JVYZ0`1KFe/203@d=0<01PH60`00000300820P800@410`00
000600410@D000000`010@4>000000800@414`00000300410@P000000`010@46000000800@41:@00
00080?ooo`001P3ooom8000000D00@411P030`<2000000<00`<30`061PH300/;2`804A4A0`0E5AD3
01TI6@<07QhN0P0O7al302HV9P<0;Bd]0`0e=CD203/k>`<0Bd];0`1JFUX306ATI080J6QX0`1fMWH3
07AdM080KFe]0`1`L70306YZJP<0Fe]K0P0d=3@300H61P<000000`020P8200410@<000001P010@45
000000<00@413P00000200410A<000000`010@48000000<00@411P00000200410BT00000203oool0
00H0ooooB000000500410@H00`<30P00000300<30`<01PH60`0;2`/2014A4@<05ADE0`0I6AT301hN
7P807alO0`0V9RH302d];@<0=CDe0P0k>c/304];B`<0FUYJ0`1TI6@206QXJ0<0MWIf0`1dM7@206e]
K@<0L71`0`1ZJVX305]KF`80=3@d0`061PH3000000<00P820P010@43000000H00@411@0000030041
0@h000000P010@4C000000<00@412000000300410@H000000P010@4Y000000P0oooo00060?ooodD0
00000`010@4200820PH00`<31@00000300H61P<02`/;0`0:2PX2014A4@<05aLG0`0K6a/301lO7`80
8b<S0`0^;Rh302l_;`<0=SHf0P0m?Cd304i>CP<0GEeM0`1XJ6P206][J`<0KVi^0`1_Kfl206YZJP<0
IfMW0`1SHf<304I6AP804a<C6@00000300410@<00P821@00000300820PD000000`010@4600000080
0P820`010@4>000000800@410`020P83000000D00@41:@0000080?ooo`001P3ooom5000000<00@41
0P020P8600<30`D000000`061PH300/;2`<02PX:0P0A4A4301LG5`<06a/K0`0O7al202<S8`<0;Rh^
0`0_;bl303Hf=P80?Cdm0`1>CTh305eMG@<0J6QX0P1[Jf/306i^KP<0Kfm_0P1ZJVX306MWI`<0Hf=S
0`16ATH201<C4aT000000`010@4300820PD000000`020P85000000<00@411P00000200820P<00@41
3P00000200410@<00P820`00000500410BT00000203oool000H0ooooA@00000300410@800P821P03
0`<5000000<01PH60`0;2`/300X:2P804A4A0`0G5aL301/K6`<07alO0P0S8b<302h^;P<0;bl_0`0f
=SH203dm?@<0CTi>0`1MGEd306QXJ080Jf][0`1^KVh306m_K`80JVYZ0`1WIfL306=SH`<0ATI60P0C
4a<I000000<00@410`020P85000000<00P821@00000300410@H000000P020P8300410@h000000P01
0@4300820P<000001@010@4Y000000P0oooo00060?ooodD000000`020P8200@410<01@D50`0410@3
000000D01`L70`0<30`3014A4@804a<C0`0G5aL301`L70<07alO0P0S8b<302`/;0<0<30`0`0k>c/2
04I6AP<0De=C0`1NGUh306ATI080IVIV1P1YJFT206EUI@<0GUiN0`1BDU8302TY:@800@410`000003
00410@h000000P020P86000000<00P821@00000300820Ph000000P010@4C000000<00@410`000003
00410B/00000203oool000H0ooooA@00000300820P8010@40`051@D300@410<000001@071`L300`<
30<04A4A0P0C4a<301LG5`<071`L0`0O7al202<S8`<0;2`/0`0`<30303/k>`80ATI60`1CDe<305iN
GP<0I6AT0P1VIVH606UYJ@80IFEU0`1NGUh3059BDP<0:BTY0P010@43000000<00@413P0000020082
0PH000000`020P85000000<00P823P00000200410A<000000`010@43000000<00@41:`0000080?oo
o`001P3ooom2000000<00@410`030`<200D51@<01PH60`071`L300D51@802`/;0`0:2PX300l?3`D0
4A4A0`0E5AD301dM7@<08B4Q0P0T92@302TY:@<0<30`0`0k>c/204U9B@<0DE5A0`1JFUX3069RHP80
IfMW0`1TI6@305iNGP80GemO0`1FEUH303/k>`<03Ph>2000000300410@8000000`010@4600000080
0P822`00000300410@h000000`020P85000000<00@414000000600820R/00000203oool000H0oooo
@P00000300410@<00`<30P051@D300H61P<01`L70`051@D200/;2`<02PX:0`0?3`l5014A4@<05ADE
0`0M7Ad3024Q8@8092@T0`0Y:BT3030`<0<0>c/k0P19BDT3055AD@<0FUYJ0`1RHV8206MWI`<0I6AT
0`1NGUh205mOG`<0EUIF0`0k>c/300h>3PP000000`010@42000000<00@411P00000200820P/00000
0`010@4>000000<00P821@00000300410A0000001P020P8[000000P0oooo00060?oood8000000`01
0@4300<30`801@D50`061PH300L71`<01@D50P0;2`/300X:2P<03`l?1@0A4A4301DE5@<07AdM0`0Q
8B4202@T90<0:BTY0`0`<30303/k>`80BDU90`1ADE4305YJFP<0HV9R0P1WIfL306ATI0<0GUiN0P1O
Gel305IFEP<0>c/k0`0>3Ph8000000<00@410P00000300410@H000000P020P8;000000<00@413P00
000300820PD000000`010@4@000000H00P82:`0000080?ooo`001P3ooolm000000800@410`020P83
00@410<01PH60P0820P300T92@<02`/;0`0820P200l?3`<03@d=1P0@4102018B4P<05QHF0`0K6a/3
01lO7`808B4Q0`0X:2P3030`<0<0?clo0P17AdL305=CD`<0FUYJ201KFe/305ADE080EUIF0`14A4@3
01XJ6RH000000`020P88000000<00@412`00000300410@P000000`010@45000000<00`<30`010@4[
000000P0oooo00060?ooocd000000P010@4300820P<010@40`061PH200P820<02@T90`0;2`/300P8
20803`l?0`0=3@d6010@40804Q8B0`0F5QH301/K6`<07alO0P0Q8B4302PX:0<0<30`0`0o?cl204M7
A`<0De=C0`1JFUX805]KF`<0E5AD0P1FEUH304A4A0<06QXJ9P00000300820PP000000`010@4;0000
00<00@412000000300410@D000000`030`<300410B/00000203oool000H0oooo?@00000200410@<0
0P820`0410@300H61P8020P80`092@T300/;2`<020P80P0?3`l300d=3@H0410@0P0B4Q8301HF5P<0
6a/K0`0O7al2024Q8@<0:2PX0`0`<30303lo?`80AdM70`1CDe<305YJFPP0Fe]K0`1DE5@205IFEP<0
A4A40`0J6QXV000000<00P822000000300410@/000000`010@48000000<00@411@00000300<30`<0
0@41:`0000080?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]],

Cell["\<\
This looks as good as the original to me.  How many entries are stored in \
this approximate SVD:\
\>", "Text"],

Cell[CellGroupData[{

Cell["Length[Flatten[{UaT,bigSings,VaT}]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`6696\)], "Output"]
}, Open  ]],

Cell["\<\
Well, this is a definite improvement over the 12462 stored in the first \
reduced SVD.  Also, it is a bit of image compression because it is less than \
the 8500 entries stored in the original handMat.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Question 5:  Try keeping even fewer singular values and report results as \
below.\
\>", "Subsubsection"],

Cell["\<\
Execute the following with several smaller values in numToKeep.  Report the \
numToKeep and total entries stored in the smallest approximate SVD you would \
use 
(a)  if you wanted to preserve an \"almost perfect\" recreated image.
(b)  if you wanted to just be able to recognize the image.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
numToKeep = 10;
bigSings = Take[sings,numToKeep];
UaT = Take[UrT,numToKeep];
VaT = Take[VrT,numToKeep];
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[handMat];  (* original on top *)
showImage[newHand];  (* recreated on bottom *)
Length[Flatten[{UaT,bigSings,VaT}]]\
\>", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000000001010001030202080B151A
1D1E20232522201D1913100C0C0E151D232B2B2B21100801
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000102060E18
1F1F2125282A2726211B140D0B0F171E2941515853381706
010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000100010710
1B1F22292D302F2D292319100C0F0D1726353231373B2A15
070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000010105
0E1A212933333434332B211C1C1A151C1E181115171B151C
1F1608040404030100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
030917253235363A35312C2C2F2A242C1F0F0A0D12120C0F
15191A181C21232216110A05010100000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000104132933353938353437352B293E29190C091314151F
1A0A0E04070E171B171A191715130C0C0D08030000010000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000E242E3638393C3C342929443B290B081E1B163E
270E080805000205020917151C191A221C190F0701000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000A213135393D3B32252F564C260D0351A12E3F
340B0F0604011B261B0406050406080D0E151C1B0C030100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000081E2D353A3832262D4F491F15081A748246
1C07070B0115364A4F1E020001010507070B161D180C0502
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071D2E3737342C2B323A180D131F365247
270E00001A3F382D252F22130A0405040B0A0E1114150D03
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B30343730322D2440526C8C9C8A74
531000144D4B38392A2C291F1D0E03040A09070B13211401
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000051D303431302E1F3FABD0D5CDB791
36010B4654565D6064554C3F260D09050503050D141D1001
010100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000051D32352F2A231858B0BEA57829
00063D606369605C5D584E4D50452B130301070E11130901
000001010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000031D33322C221B0E0B0C080100
00236369645A4F504845414E595157391903050B13110801
010101010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000004213231231D120601000002
133A57564F453E3C362F333D41433D2E261D091121110601
000301010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000720302B1F180C05010415
243947443F3B39373F55778B8684775D3F26101C210A0303
000404010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000006222F261B0D0907161D
1D2B3B403C3C414D6091BDCBC3BEAEAE9F6B1A1A12060605
080502010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000007282C0C0609111615
1A273039404B59657E7884ABD6E6DECEC5A53A1912140909
100B00010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000510060A0800050E111013
1D29333D4B5B72908D63374288C1DADCD0C153241F170D15
1D0900010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000003212D100202050B0F0F1017
2333414A60718B939FAB763113366F98A8A66D563F26171E
180100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000051A181F190905090F0F101222
364560798699894A205EC0AD7A3A161F5B9599939C733617
070100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000001432180F0E0A0A1112141E2944
576D7F97A1A3947E52171F52A2C39C807BACBFB6CBC78623
030503030302010000010100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000010005282B1C24211F14131C223152667B
8C91A2A2AA9FAFB4B3976335296FB6D1C9BBB4B4A6A4650E
060505060704010000030300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B301D0902020D141E324F7189949B
A2A5AF9FA7B0A18A8DA7AAB187353C518CB7BAAC956B0A05
0404070806040100000A0900000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001000311213332302C180E1D365787A1A6A6AA
ACB3BBB0AA8E38142A6685A0B5957F686BADBCA78F591E1F
0C0F0D0A0704070409170600000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000031722232F393E3D2F1C386084A3A59B9899
A6BAB8B6A3707133081F62C0DDE1E7DEB7AEB39274443A47
3227240F060512210F080000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000012737391A192221202A2B3C517F868D8A8C93
A3B2BDC5B0799372647F8988AFCDDBDACCAA8C6559394555
434E533A1E1A262F05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000011322E2A2613060714192D37454A445D5E5560
82ABC0C3BD87797B98989BA0AFB6C1D2C0973D2D3D2B3C62
3D6B8575533B3A1300010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002031251F2C2818100D1A2B3322110A245B8290
858FB9B8B0947DA9C1A497A0A5B5CFD0BA52091224182867
6660A4B2884B1B0000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000005322D2927222D2C160A1329391C161419316E7D
A19C99A39583A1DEC9B4AB9BA6C7CCD192221814100B124B
7F646CA0882A010101010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000044E6C5722282A34332B15224F4C2E27495F5973
7D7470746E669BC4A9B2BCBFC6C8CCD3723432331B080628
6572503D2002000202000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000493AD431C1C171418241F2D669D7E5D657A6E51
4E363A323461A4ADA0B1C2CCC5BDB5C97D5956543D120210
3E6466461E09000404020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000001D9D96313730210C090B1D3C76ABCCB79F816846
261B0F093AB7B6839CACA3ABB8BCBABE7F746D423F1E0402
204A62564321020106090300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000002CD4825C662A192B3C2B1E3F78A8C6DDCABEA15B
2C130C1C7BD3BE83847C7888999B9BB5847C8C6022150A02
072A5655462D0F00040E0800000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000DAAC0955B568293846D3C446895BBD7E2E5DED5
C1997EA1CED9B66D4B42608A97A9A6A9927C92924F200E08
06214F685A41220301131907000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004F9E36197AA16528263737517BA7C2D6DDEDF1
EFE9DFD7CBC8B553213D4F83979DA3B5AD8491947143230F
051A47717C5A370E00183319010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002D6395934E4A6D845B302E3A71989FBACCDADB
DDE2E7D8CDD0D08626254F6E7A826F667C828D92855F4012
030F3967886E451802264125020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004C653E9BACABA678766E5F535B85A8B6C7D1DA
E0E5EBEBECE6DFCB81414F7A6C6B5A4A5569878D84674E26
060625537F7F531E052C492A040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000063CF8E7EC7CB69222F4754473F588AB7C3C6D0
E1ECF3F1ECE7E2E4E4BE95949A97979B71475B8D866F5836
170611386C83622803214F2B060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000016EC9A6704E566E64523D3C2022354866A7C3CB
CDD2E9EBE6E0DEDEE0E5D5BCBEC0B8AA7A274A7B7E785C40
2610082660896833092D61320A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000006BAFB88E5289D4C0B3A7AA80667081706F94C7
D2C8D0D8D9DAD2D6D2D6C5B7BABDB4A06B3D5B8687816C44
2C17072759806B40174C6A3C1E0100000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000087B6AC9795CDCBBDE2EFD3C7BEA0786A84879D
D7D9D1D0C8D1CEC3BFBBB5A8A9A89670503342828C8E8659
32200B336A837542266E6246250000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000066C4B9B4B38F6568609ACDCABDAEA39B8CAA97
B9C6A9A19A9FA3A8A8969EA69C7C5D3512022A71868A855E
2F1A104782837B374479673E090000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000029C2BED3AA73B3EFD79DABB4C3E0EBEDCFBEAC
919080715A535B6E766C635D4F4B435E69521F657C818869
361D134D937C602E66683706000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000005A7C8B8C9F1F8EFEAEEE7EAF6EFEBEBD2B3A7
979BB0B4B58D81685C412A25171017325F510E547F81826C
4E2C1C629874413A76470700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000066DAC3BAD4D8CECDC8D4DDD0D4C4ACB6A28E
7E6C7D6F99B4714C80989E8D85633F14342F2D4777817D6F
48352B89956C3B5C4E0D0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000020D1D1CCD5DBE4E5EDEBDDE0AA5D3C53686E
67668DA49EC5B469445D6B748FA9B59C813C566B7A807D74
512D4F9A875F463E08000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E3CFD1DADAE6E9DADEB128060A091C58
7583BABCC4AEB8D38E555D54779FAE9C624D6F7F8483846A
482A6192734D250200010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000012BFE0CFD1D6CDDDE9DC6326271F160B28
6CA8B5C9C8AA81BBBF967E7C59534E5E435E7882858A8364
3E31727C5C29000001010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000002FC0E7D9DBDEDAD5BB82817A613E2B14
47AED6A4C7C97E7C90BD9F9C915D7D7E3A6B7B838E8B7E60
44386F673F06000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000001AABEFE0DDE3DCB6A6C1DCDFA26B4A
2C94D896A4D2CCBFACB1C1AAB2BDBE503E697989928F7A60
3F445E521A00000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000777E7EDE4D9ABA4CBECE2C49486
327CDAC4958F9FBEC898A5A4AB7D454648687D898F88775C
3D3E4D300200000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000004BB1E8E89E81A8E6C9A7898A
3D55A9C2C2C0C6ABB496937E4E213A56525D7C918E7E6F55
2F2A38110001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000003DA99C736E989A817071
464A8DAFA5A4C8BFA987370F1636454A5F6983918B796747
212130050001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000075F6C749598806955
43375F77808D8A743E0E0B191F3A4E4E5571888F85715A32
182C1E000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000386863676A605042
362A53626153361505101F271E3B4B565E728B8B7F724C2E
262C05000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000038736B6B67574432
2F291B120B0C1413121A2E3129364F597B8F827978694834
2B0900010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000002D897C756E5E482F
2B30120A10141B161D2635303B40415F828C7C7C7B664E34
0C0000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000100128A766D6565593A
352C121119161721233635314D5658697E7772826F605016
000100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000038196877A776951
492D121B1D1F19292B3C384765687480766C796958482100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001068999288817267
512D1B1E1C1A282638404355737B78786C6A5B4A49240000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001B589092867A7567
47291F231F232E304F4C5866727A79797253494017000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001D58878E88796B5D
4028282527372B4A595A6A787375797D6649310800000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000001010D59839186756556
40322F2B36314661606A757E79757D734B1C000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001040302467B897B6A5F4F
4036323A39475A6568797F83807C6D460E00000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000002030200206F8477625D52
463C42484D595E6771798182756142140001000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001010102083C7E7B6A655D
4A4650575E63656D757A735D4B4026000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010304081645626E6E67
59555A5C5E65696C695C5149413409000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010A0D0A1B233C53605F
605F5D606265646057504D42391700000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010100030D19181D272B3D5256
585E626364675F5953504B43250000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000102070E1B201E22262E4556
5D646664615D5B5858524D32030000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000002050C0F1A25262320212E3F
525B62655E5B5B5A59554310000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000001030A0E101929363F44433E46
555D606263605D5E5B552C00000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000202080C0E121A293E5666717171
717273706963615F5D450800000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010001020306080A0D121C2737434E5E656B
6F71706B615F5E5F5D1E0000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010003030404050B11151B26313B454E555D
676E716D6A6D6B7145000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010102020201060C11171D27313D474E5A68
6F757B7A7473715E0E000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010101010203050A0E131C2228323F4B54616E
777C7D7B756D672D00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000101000004090B0F141A21272D36434D596772
78797876746E490300000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000010001030202040A0C1116191E232B313A45525C6776
777477776D5B1A0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020102020203070C1015191D21272E343E4A5A636B76
736F70685E37010100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020203020102060A0C10161D1F242E3235404E5C686D6F
6E6B695E4F0E000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01050505030306080B1114171D20232C313C45536064666A
69675C562800000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
020506050609080C101013161D222429303B48535B636664
615E55410700000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000003
0506090A0A0A0E0E101112171C1E2228313E4856595C5C59
595348180000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooolT000000H00@410P00000300410@<00`<31@020P8300P820<0
2`/;0P0E5AD301XJ6P<07AdM0`0N7Qh2020P80<08b<S0`0U9BD3028R8P80820P0`0M7Ad301TI6@<0
4a<C0P0@410600`<30<03Ph>0P0E5AD301dM7@<08b<S200[:b/3024Q8@<0410@0P0820P300410Hh0
0000203oool000H0oooo9000000600410@8000000`010@4300<30`D00P820`0820P300/;2`805ADE
0`0J6QX301dM7@<07QhN0P0P820302<S8`<09BDU0`0R8R82020P80<07AdM0`0I6AT301<C4`80410@
1P0<30`300h>3P805ADE0`0M7Ad302<S8`P0:b/[0`0Q8B43010@408020P80`010@6>000000P0oooo
00060?ooocD000000P010@4300820P<01PH60P0>3Ph301PH60H07alO0P0Q8B4302DU9@<0:2PX0`0Z
:RX202LW9`<09RHV0`0Q8B4301/K6`8051@D0`0=3@d300/;2`<03`l?0P0G5aL301hN7P<0:BTY0`11
@D42055AD@<0F5QH0`1CDe<303Ph>0805aLG0`061PH300410H/00000203oool000H0oooo=@000002
00410@<00P820`061PH200h>3P<061PH1P0O7al2024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3
024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l201LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P3
05=CD`<0>3Ph0P0G5aL300H61P<00@41R`0000080?ooo`001P3ooole000000800@410`020P8300H6
1P803Ph>0`0H61P601lO7`808B4Q0`0U9BD302PX:0<0:RXZ0P0W9bL302HV9P<08B4Q0`0K6a/201@D
50<03@d=0`0;2`/300l?3`805aLG0`0N7Qh302TY:@<0@D510P1ADE4305QHF0<0De=C0`0h>3P201LG
5`<01PH60`010@6;000000P0oooo00060?ooocD000000P010@43000000<00@410P071`L3010@40<0
6a/K0`0O7al2028R8P<0:BTY0`0];Bd3030`<080;bl_0`0];Bd302TY:@<08b<S0P0I6AT3010@40<0
30`<0`0?3`l200d=3@<05aLG0`0V9RH303De=@80<S8b0`0a<C4303Lg=`<0>c/k0P0Z:RX301DE5@<0
1`L7R`0000080?ooo`001P3ooole000000800@410`00000300410@801`L70`0@410301/K6`<07alO
0P0R8R8302TY:@<0;Bd]0`0`<30202l_;`<0;Bd]0`0Y:BT302<S8`806ATI0`0@410300`<30<03`l?
0P0=3@d301LG5`<09RHV0`0e=CD2038b<P<0<C4a0`0g=cL303/k>`80:RXZ0`0E5AD300L71h/00000
203oool000H0oooo=@00000200410@<000000`010@4200L71`<0410@0`0K6a/301lO7`808R8R0`0Y
:BT302d];@<0<30`0P0_;bl302d];@<0:BTY0`0S8b<201TI6@<0410@0`0<30`300l?3`803@d=0`0G
5aL302HV9P<0=CDe0P0b<S83034a<@<0=cLg0`0k>c/202XZ:P<05ADE0`071`N;000000P0oooo0006
0?ooocX000001@010@4300D51@<03Ph>0`0J6QX2024Q8@<0:BTY1P0c<c<503@d=0<0<c<c0`0[:b/2
024Q8@H071`L0`0J6QX201DE5@<071`L0`0N7Qh301PH60804A4A0`0E5AD301LG5`<06a/K0P0E5AD3
01`L70<07alO0P0F5QH300P820P010@40`030`<300410GP00000203oool000H0oooo>P0000050041
0@<01@D50`0>3Ph301XJ6P808B4Q0`0Y:BT603<c<`D0=3@d0`0c<c<302/[:`808B4Q1P0L71`301XJ
6P805ADE0`0L71`301hN7P<061PH0P0A4A4301DE5@<05aLG0`0K6a/201DE5@<071`L0`0O7al201HF
5P<020P8200410@300<30`<00@41N00000080?ooo`001P3ooolo000000<00@410`030`<300T92@80
5aLG0`0U9BD3038b<P<0=CDe0P0f=SH303Xj>P<0=CDe0`0a<C4502`/;0<0;bl_0`0Z:RX202@T90<0
;2`/0`0O7al300l?3`802PX:0`0=3@d6018B4P8030`<0`0?3`l301DE5@806ATI0`0J6QX301PH60<0
71`L0P0Q8B4302<S8`<08R8R0`0F5QH2014A4@<02PX:0`051@D500410FP00000203oool000H0oooo
?`00000300410@<00`<30`092@T201LG5`<09BDU0`0b<S8303De=@80=SHf0`0j>SX303De=@<0<C4a
1@0/;2`302l_;`<0:RXZ0P0T92@302`/;0<07alO0`0?3`l200X:2P<03@d=1P0B4Q8200`<30<03`l?
0`0E5AD201TI6@<06QXJ0`0H61P301`L70808B4Q0`0S8b<3028R8P<05QHF0P0A4A4300X:2P<01@D5
1@010@5X000000P0oooo00060?ooocl000000`010@4300<30`<02@T90P0G5aL302DU9@<0<S8b0`0e
=CD203Hf=P<0>SXj0`0e=CD3034a<@D0;2`/0`0_;bl302XZ:P8092@T0`0/;2`301lO7`<03`l?0P0:
2PX300d=3@H04Q8B0P0<30`300l?3`<05ADE0P0I6AT301XJ6P<061PH0`0L71`2024Q8@<08b<S0`0R
8R8301HF5P804A4A0`0:2PX300D51@D00@41J00000080?ooo`001P3ooom5000000<00@410P0410@3
01<C4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT3
03hn?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph3
00@410<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`3
00d=3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C
4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn
?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@4
10<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=
3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C4`<0
:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn?P<0
:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@410<0
1`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=3@80
20P80`030`<6000000800@41DP0000080?ooo`001P3ooom=000000<03Ph>0`0T92@202h^;P<0=SHf
0`0h>3P303Ti>@D0?3`l0`0d=3@502TY:@<0A4A40`0k>c/302TY:@802`/;0`0820P301hN7P<06a/K
0P0F5QH303hn?P<09bLW0P0>3Ph600P820<01@D50P00000300820P<01@D50`020P8200T92@<05aLG
0`0E5AD301`L70806ATI0`0J6QX3028R8P<071`L0P0I6AT300l?3`<01`L70`010@5D000000P0oooo
00060?ooodd000000`0>3Ph302@T9080;Rh^0`0f=SH303Ph>0<0>CTi1@0l?3`303@d=0D0:BTY0`14
A4@303/k>`<0:BTY0P0;2`/300P820<07QhN0`0K6a/201HF5P<0?Shn0`0W9bL200h>3PH020P80`05
1@D2000000<00P820`051@D300820P802@T90`0G5aL301DE5@<071`L0P0I6AT301XJ6P<08R8R0`0L
71`201TI6@<03`l?0`071`L300410E@00000203oool000H0ooooC@00000300h>3P<092@T0P0^;Rh3
03Hf=P<0>3Ph0`0i>CT503`l?0<0=3@d1@0Y:BT304A4A0<0>c/k0`0Y:BT200/;2`<020P80`0N7Qh3
01/K6`805QHF0`0n?Sh302LW9`803Ph>1P0820P300D51@8000000`020P8300D51@<00P820P092@T3
01LG5`<05ADE0`0L71`201TI6@<06QXJ0`0R8R8301`L70806ATI0`0?3`l300L71`<00@41E0000008
0?ooo`001P3ooom@000000<02PX:0P0Q8B43034a<@<0=CDe0`0i>CT203dm?@<0>c/k0`0b<S8302DU
9@80;bl_0`1FEUH304a<C0<09RHV0P0=3@d300<30`<0DE5A0`2QXJ4202h^;P<0?clo0`0d=3@200/;
2`<03`l?0`061PH300@410800@410`0K6a/302HV9P<06a/K0P0410@300H61P<01@D50`0410@200H6
1P<020P80`0=3@d300h>3P805ADE0`0L71`301/K6`<030`<0P030`<300410Dl00000203oool000H0
ooooD000000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0<S8b0`0U9BD202l_;`<0
EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0=3@d0P0;2`/300l?3`<0
1PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<010@40P061PH300P820<0
3@d=0`0>3Ph201DE5@<071`L0`0K6a/300`<30800`<30`010@5?000000P0oooo00060?oooe<00000
0P0820P301hN7P<0;Bd]0`0e=CD203Xj>P<0>3Ph0`0b<S8302HV9P80;Bd]0`1?Cdl304U9B@<07alO
0P0E5AD300P820<06QXJ0`1dM7@208:2PP<0ATI60`0L71`500L71`<02`/;0`010@4201DE5@<0=SHf
0`1:BTX304m?C`807QhN0`020P83000000D00@410`051@D600L71`802`/;0`0F5QH301dM7@<061PH
0P0<30`300D51@<00P82C00000080?ooo`001P3ooomC0000008020P80`0N7Qh302d];@<0=CDe0P0j
>SX303Ph>0<0<S8b0`0V9RH202d];@<0Cdm?0`19BDT301lO7`805ADE0`0820P301XJ6P<0M7Ad0P22
PX8304I6AP<071`L1@071`L300/;2`<00@410P0E5AD303Hf=P<0BTY:0`1?Cdl201hN7P<00P820`00
000500410@<01@D51P071`L200/;2`<05QHF0`0M7Ad301PH608030`<0`051@D300820T`00000203o
ool000H0ooooD`00000200P820<07QhN0`0];Bd303De=@80>SXj0`0h>3P3038b<P<09RHV0P0];Bd3
04m?C`<0BDU90`0O7al201DE5@<020P80`0J6QX307AdM080PX:20`16ATH301`L70D01`L70`0;2`/3
00410@805ADE0`0f=SH304Y:BP<0Cdm?0P0N7Qh300820P<000001@010@4300D51@H01`L70P0;2`/3
01HF5P<07AdM0`0H61P200`<30<01@D50`020P9<000000P0oooo00060?oooeD000000`071`L301dM
7@<0;Rh^1@0g=cL303@d=0<0;2`/0P0[:b/3038b<P<0>SXj0`0H61P200d=3@<04a<C0`0O7al303Hf
=P80DU9B0`17AdL302LW9`803Ph>1P00000301XJ6P80?clo0`0h>3P302d];@<09BDU0P0_;bl3028R
8P<04a<C0`0:2PX200@410<01@D50`0410@300/;2`802PX:0`0>3Ph3014A4@<051@D0P0E5AD300d=
3@<00`<3C00000080?ooo`001P3ooomE000000<01`L70`0M7Ad302h^;PD0=cLg0`0d=3@302`/;080
:b/[0`0b<S8303Xj>P<061PH0P0=3@d301<C4`<07alO0`0f=SH2059BDP<0AdM70`0W9bL200h>3PH0
00000`0J6QX203lo?`<0>3Ph0`0];Bd302DU9@80;bl_0`0R8R8301<C4`<02PX:0P0410@300D51@<0
10@40`0;2`/200X:2P<03Ph>0`0A4A4301@D50805ADE0`0=3@d300<30d`00000203oool000H0oooo
E@00000300L71`<07AdM0`0^;Rh503Lg=`<0=3@d0`0/;2`202/[:`<0<S8b0`0j>SX301PH60803@d=
0`0C4a<301lO7`<0=SHf0P1BDU8304M7A`<09bLW0P0>3Ph6000000<06QXJ0P0o?cl303Ph>0<0;Bd]
0`0U9BD202l_;`<08R8R0`0C4a<300X:2P8010@40`051@D300@410<02`/;0P0:2PX300h>3P<04A4A
0`0D51@201DE5@<03@d=0`030`=<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d
=3@303Lg=`<0<30`0P0b<S8302d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1d
M7@305=CD`80410@0`00000301@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O
7al301dM7@803Ph>0`030`<300@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`01
0@5<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d=3@303Lg=`<0<30`0P0b<S83
02d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1dM7@305=CD`80410@0`000003
01@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O7al301dM7@803Ph>0`030`<3
00@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`010@5<000000P0oooo00060?oo
oe/000000`051@D201dM7@<0<30`0`0d=3@3034a<@80<30`0`0^;Rh301lO7`<0?clo0P2[Zj/30=3@
d0<0eMGE0`3=cLd20;Ng]`<0TI6A0`0f=SH200410@<02`/;0`16ATH305ADE080EUIF0`1MGEd3061P
H0<0I6AT0P1EEED304a<C0<0?clo0`0V9RH200d=3@<02@T91P051@D200<30`<01@D50`0=3@d301@D
50807AdM0`0@410800410DL00000203oool000H0ooooF`00000300D51@807AdM0`0`<30303@d=0<0
<C4a0P0`<30302h^;P<07alO0`0o?cl20:^[Z`<0d=3@0`3EeMD30<g=c@80]kNg0`2ATI4303Hf=P80
0@410`0;2`/304I6AP<0E5AD0P1FEUH305eMG@<0H61P0`1TI6@205EEE@<0C4a<0`0o?cl302HV9P80
3@d=0`092@T600D51@800`<30`051@D300d=3@<051@D0P0M7Ad3010@40P00@41A`0000080?ooo`00
1P3ooomK000000<01@D50P0M7Ad3030`<0<0=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[
0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM
0`1PH60306ATI080EEEE0`1<C4`303lo?`<09RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=
0`0D51@201dM7@<0410@20010@57000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e
=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P06
1PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15
ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P01
0@51000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<3
01PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<2
06UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<2
00410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?oo
oeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn
_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eM
G@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A
4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?ooof0000000`030`<301dM7@<0
<c<c0P0b<S8302`/;0<08R8R0`0K6a/200h>3P<02`/;0`0<30`300P820800@411P00000202<S8`<0
Hf=S0`1YJFT306ATI080FUYJ0`1?Cdl3051@D0<0B4Q80P15ADD30451@@<0CTi>0`1IFET2055AD@<0
EeMG0`0i>CT301TI6@800`<30`051@D300/;2`<04a<C0P0A4A4300P820h00@41@@0000080?ooo`00
1P3ooomP000000<00`<30`0M7Ad303<c<`80<S8b0`0/;2`3028R8P<06a/K0P0>3Ph300/;2`<030`<
0`0820P200410@H000000P0S8b<306=SH`<0JFUY0`1TI6@205YJFP<0Cdm?0`1@D50304Q8B080ADE5
0`11@D4304i>CP<0FEUI0P1ADE4305MGE`<0>CTi0`0I6AT200<30`<01@D50`0;2`/301<C4`804A4A
0`0820P>00410D400000203oool000H0ooooH000000300<30`<07AdM0`0c<c<2038b<P<0;2`/0`0R
8R8301/K6`803Ph>0`0;2`/300`<30<020P80P010@46000000808b<S0`1SHf<306UYJ@<0I6AT0P1J
FUX304m?C`<0D51@0`18B4P204E5A@<0@D510`1>CTh305UIF@80DE5A0`1GEeL303Ti>@<06ATI0P03
0`<300D51@<02`/;0`0C4a<2014A4@<020P83P010@51000000P0oooo00060?ooof<000000`0410@3
024Q8@80<S8b0`0a<C4302<S8`<07AdM0P0B4Q8300H61P<00@411@00000300820P<04a<C0P0j>SX3
05MGE`<0EUIF0`1?Cdl204E5A@<0?Shn0`0l?3`303Hf=P80;bl_0`0c<c<303dm?@<0@D510P13@d<3
03dm?@<0;Rh^0`0V9RH201dM7@<02@T90`0A4A43024Q8@804A4A0`061PH300410@<000000P030`<;
00410C`00000203oool000H0ooooH`00000300@410<08B4Q0P0b<S83034a<@<08b<S0`0M7Ad2018B
4P<01PH60`010@45000000<00P820`0C4a<203Xj>P<0EeMG0`1FEUH304m?C`80ADE50`0n?Sh303`l
?0<0=SHf0P0_;bl303<c<`<0?Cdm0`11@D4204=3@`<0?Cdm0`0^;Rh302HV9P807AdM0`092@T3014A
4@<08B4Q0P0A4A4300H61P<00@410`00000200<30`/00@41?00000080?ooo`001P3ooomV000000<0
1`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080
>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80
Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P0
0@41?00000080?ooo`001P3ooomV000000<01`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<
0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg
0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L
0`0Q8B4200X:2PH00`<30`00000500@410P00@41?00000080?ooo`001P3ooomV000000<01`L70P0P
8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17
AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1g
MgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P00@41?000
00080?ooo`001P3ooomY000000801PH60`0R8R8302l_;`<09RHV0P0K6a/300d=3@<02@T90`071`L2
01HF5PH07AdM0P0[:b/303/k>`<0@4101@0l?3`30451@@<0CDe=0`1PH602096AT@<0_Kfm0`3;bl/3
0<?3``80_[jn1P2^[Zh309nOW`80Jf][1P0J6QX3018B4PD01PH60`051@D300P820801@D50`020P88
00410C`00000203oool000H0ooooJ@00000200H61P<08R8R0`0_;bl302HV9P806a/K0`0=3@d300T9
2@<01`L70P0F5QH601dM7@80:b/[0`0k>c/30410@0D0?3`l0`11@D4304e=C@<0H61P0P2ATI430;fm
_@<0bl_;0`33`l<20;jn_PH0[Zj^0`2OWil206][J`H06QXJ0`0B4Q8500H61P<01@D50`0820P200D5
1@<00P8220010@4l000000P0oooo00060?ooofT000000P061PH3028R8P<0;bl_0`0V9RH201/K6`<0
3@d=0`092@T300L71`805QHF1P0M7Ad202/[:`<0>c/k0`10@40503`l?0<0@D510`1=CDd3061PH080
TI6A0`2m_Kd30<_;b`<0`l?30P2n_[h60:j^[P<0WinO0P1[Jf/601XJ6P<04Q8B1@061PH300D51@<0
20P80P051@D300820PP00@41?00000080?ooo`001P3ooom[000000<01`L70`0X:2P302`/;08030`<
0`061PH300T92@<04A4A0P0F5QH301DE5@<06QXJ0P0W9bL3030`<0<0>CTi0`10@40204];B`<0FEUI
0`1UIFD307inOP80N7Qh0`24Q8@30:^[Z`<0e]KF0P3Vi^H30=kNgP<0c/k>0`35aLD20:FUY@<0>SXj
0`0I6AT3018B4P8051@D1P092@T3010@40802`/;0`00000;00410CT00000203oool000H0ooooJ`00
000300L71`<0:2PX0`0/;2`200`<30<01PH60`092@T3014A4@805QHF0`0E5AD301XJ6P809bLW0`0`
<30303Ti>@<0@4100P1;Bd/305UIF@<0IFEU0`1nOWh207QhN0<0Q8B40`2[Zj/30=KFeP80i^KV0`3N
g]h30<k>cP<0aLG50P2UYJD303Xj>P<06ATI0`0B4Q8201@D50H02@T90`0@410200/;2`<000002`01
0@4i000000P0oooo00060?ooof/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A42
01HF5P<05ADE0`0J6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`1IFET306EUI@<0OWin0P1hN7P3
08B4Q0<0Zj^[0`3Fe]H20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@6
00T92@<0410@0P0;2`/3000000/00@41>@0000080?ooo`001P3ooomV000000<01@D50P0@410300H6
1P<02PX:0`0820P2000000<01@D50`0>3Ph3014A4@80410@0`0C4a<301dM7@80:BTY0`0c<c<303dm
?@<0Bd];0P1KFe/3079bLP<0T92@0`2=SHd206=SH`<0=cLg0`12@T8308R8R080`L710`3Jf]X30=cL
g0<0d=3@0P31`L4305=CD`<092@T0`0O7al201LG5`<03@d=0`0E5AD301dM7@802@T90`00000;0041
0CT00000203oool000H0ooooIP00000300D51@80410@0`061PH300X:2P<020P80P00000300D51@<0
3Ph>0`0A4A42010@40<04a<C0`0M7Ad202TY:@<0<c<c0`0m?Cd304];B`80Fe]K0`1bLW83092@T0<0
SHf=0P1SHf<303Lg=`<0@T920`28R8P20<71`@<0f][J0`3Lg=`30=3@d080`L710`1CDe<302@T90<0
7alO0P0G5aL300d=3@<05ADE0`0M7Ad200T92@<000002`010@4i000000P0oooo00060?ooof<00000
0`030`<3024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c
0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf
0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@41
1P00000;00410CH00000203oool000H0ooooH`00000300<30`<08B4Q0P0];Bd3010@40H00P820P05
1@D300/;2`H03`l?0P0@410301LG5`<08b<S0P0c<c<30451@@<0BTY:0`1PH602075aL@<0Rh^;0`2C
Ti<309nOW`80Zj^[0`1fMWH3034a<@<04a<C0P0f=SH306m_K`<0V9RH0`2XZ:P20:JVYP<0KFe]0`1F
EUH303lo?`809RHV0`0G5aL301hN7P<061PH0P010@46000000/00@41=P0000080?ooo`001P3ooomS
000000<00`<30`0Q8B4202d];@<0410@1P020P8200D51@<02`/;1P0?3`l2010@40<05aLG0`0S8b<2
03<c<`<0@D510`1:BTX3061PH080LG5a0`2;Rh/309>CT`<0WinO0P2[Zj/307IfMP<0<C4a0`0C4a<2
03Hf=P<0Kfm_0`2HV9P30:RXZ080YZJV0`1]KFd305IFEP<0?clo0P0V9RH301LG5`<07QhN0`0H61P2
00410@H000002`010@4f000000P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI
6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6
QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]K
F`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f0000
00P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H0
3`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0
820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0
W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f000000P0oooo00060?ooof000000
0`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R
0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]
0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG
0`071`L200410@H000002`010@4f000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?
3`l300h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2G
UiL30:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20
P80307]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`02
0P8300410@D000001P010@4^000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?3`l3
00h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2GUiL3
0:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20P803
07]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`020P83
00410@D000001P010@4^000000P0oooo00060?oooeD000000`010@43000000<01@D50P0X:2P302/[
:`<071`L0`0T92@2024Q8@<07alO0`0D51@301<C4`8071`L0`0R8R83034a<@<0DU9B0P1VIVH307]k
N`<0S8b<0P2ATI460::RXP<0ZZZZ0P2OWil30:n_[`<0];Bd0`2c/k<209NGU`<0Hf=S0`0e=CD302TY
:@80Kfm_0`2f][H30=7Ad@<0bLW90P2k^k/60;Bd]0<0YZJV0P2TY:@306EUI@<03Ph>0`061PH500D5
1@<01PH60P071`L300@410<00@411@00000600<30bh00000203oool000H0ooooE@00000300410@<0
00000`051@D202PX:0<0:b/[0`0L71`302@T90808B4Q0`0O7al301@D50<04a<C0P0L71`3028R8P<0
<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80
UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0
IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@40`010@45000000H00`<3;P0000080?ooo`00
1P3ooomE000000<00@410`00000300D51@80:2PX0`0[:b/301`L70<092@T0P0Q8B4301lO7`<051@D
0`0C4a<201`L70<08R8R0`0a<C43059BDP80IVIV0`1kNg/308b<S080TI6A1P2RXZ830:ZZZP80WinO
0`2_[jl30;Bd]0<0/k>c0P2GUiL306=SH`<0=CDe0`0Y:BT206m_K`<0][Jf0`3AdM430<W9b@80^k^k
1P2d];@30:JVYP80Y:BT0`1UIFD300h>3P<01PH61@051@D300H61P801`L70`0410@300410@D00000
1P030`<^000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0M7Ad300T92@D00P820`0=
3@d301@D50<07QhN0P0b<S8304m?C`<0LG5a0`29RHT209BDU0<0Vi^K0`2RXZ820:FUY@<0[jn_0`2O
Wil30:NWY`80/;2`0`2QXJ4308Z:RP<0SHf=0P2WYjL30:ZZZP<0/K6a0`27QhL203De=@<0?3`l0`1A
DE4308b<S080]kNg0`2j^[X30:b/[0<0UIFE0P1[Jf/300X:2P<01@D51@0410@300L71`<020P80P06
1PH300@410<00@411@00000300X:2P<02@T9;P0000080?ooo`001P3ooomH000000<01PH60`0K6a/2
030`<0<07AdM0`092@T500820P<03@d=0`0D51@301hN7P80<S8b0`1?Cdl3075aL@<0RHV90P2DU9@3
09^KV`<0XZ:R0P2UYJD30:n_[`<0WinO0`2WYjL20;2`/0<0XJ6Q0`2:RXX308f=S@80YjNW0`2ZZZX3
0;6a/@<0QhN70P0e=CD303`l?0<0DE5A0`2<S8`20;Ng]`<0^[Zj0`2/[:`309FEU@80Jf][0`0:2PX3
00D51@D010@40`071`L300P820801PH60`0410@300410@D000000`0:2PX300T92Bh00000203oool0
00H0ooooF000000300H61P<06a/K0P0`<30301dM7@<02@T91@020P8300d=3@<051@D0`0N7Qh2038b
<P<0Cdm?0`1aLG4308V9R@80U9BD0`2KVi/30::RXP80YJFU0`2_[jl309nOW`<0YjNW0P2`/;030:6Q
X@<0RXZ:0`2=SHd20:NWY`<0ZZZZ0`2a/K4308N7Q`80=CDe0`0l?3`3055AD@<0S8b<0P2g]kL30;Zj
^P<0[:b/0`2EUID206][J`<02PX:0`051@D500@410<01`L70`0820P200H61P<010@40`010@450000
00<02PX:0`092@T^000000P0oooo00060?oooe0000000`010@42000000<00`<30`0A4A43024Q8@80
<c<c0`0b<S83030`<0<0;2`/0P0H61P300h>3P<07AdM0`0f=SH205MGE`<0QhN70`2QXJ450:JVYP<0
ZZZZ0`2/[:`20;>c/`<0^k^k0`2`/;030:ZZZP80SXj>0`0h>3P301@D50<0:RXZ0P1VIVH308F5Q@<0
X:2P0`2e]KD209FEU@<0Ogmo0`1XJ6P306][J`80[Jf]0`2l_;`30:NWY`<0Shn?0P1IFET301hN7P<0
7alO0`0<30`200l?3`<03@d=0`0:2PX200L71`<010@40`071`L300@410802@T90`0G5aL300H61Rh0
0000203oool000H0ooooD000000300410@8000000`030`<3014A4@<08B4Q0P0c<c<3038b<P<0<30`
0`0/;2`201PH60<03Ph>0`0M7Ad303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c
0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE
0`1oOgl306QXJ0<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?
0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3o
oom@000000<00@410P00000300<30`<04A4A0`0Q8B4203<c<`<0<S8b0`0`<30302`/;08061PH0`0>
3Ph301dM7@<0=SHf0P1GEeL308N7Q`<0XJ6Q1@2VYZH30:ZZZP<0[:b/0P2c/k<30;^k^`<0/;2`0`2Z
ZZX208j>SP<0>3Ph0`0D51@302XZ:P80IVIV0`25QHD30:2PX0<0]KFe0P2EUID307moO`<0J6QX0`1[
Jf/20:f][@<0_;bl0`2WYjL308n?S`80FEUI0`0N7Qh301lO7`<030`<0P0?3`l300d=3@<02PX:0P07
1`L300@410<01`L70`0410@200T92@<05aLG0`061PH^000000P0oooo00060?oooe<000000P030`<3
01LG5`<08R8R0`0S8b<202l_;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@3
0:>SX`<0YJFU0`2KVi/209RHV0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG43
03<c<`<020P80P0O7al3069RHP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<3
09:BTP<0M7Ad0P14A4@303Xj>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83
024Q8@803`l?0`0820Pa000000P0oooo00060?oooe<000000P030`<301LG5`<08R8R0`0S8b<202l_
;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@30:>SX`<0YJFU0`2KVi/209RH
V0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG4303<c<`<020P80P0O7al3069R
HP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<309:BTP<0M7Ad0P14A4@303Xj
>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83024Q8@803`l?0`0820Pa0000
00P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0
820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80
/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80
cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80
CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe000000
0`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l
0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`
0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<
0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN
0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i
>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=
SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1T
I6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1I
FET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P05
1@Dd000000P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH3
00L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH603
08:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl2
0;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd2
06][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oo
oe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d]
;@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3
``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30
`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=C
D`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oooe0000000`0A4A42038b<P<0
;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0
A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0
Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0
?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`80
00000`010@4a000000P0oooo00060?oooe0000000`0P8202034a<@<09BDU0`0O7al302`/;080:2PX
0`0H61P3010@40<03@d=0P0J6QX302/[:`<0<c<c0`0R8R82014A4@<02PX:0`0T92@305]KF`80PX:2
0`2@T90308F5Q@80Shn?0`2i^KT30;Rh^0<0/;2`0P2DU9@307emO@<0ZJVY0`31`L420:BTY0<0UiNG
0`2PX:030:FUY@80]KFe0`3?cll30=3@d0<0^[Zj0P1BDU8300T92@<04Q8B0`0T92@201PH60<0:2PX
0`1WIfL306IVIP80H61P0`2TY:@30;:b/P80R8R80`1;Bd/301/K6cT00000203oool000H0ooooD000
0003020P8080<C4a0`0U9BD301lO7`<0;2`/0P0X:2P301PH60<0410@0`0=3@d201XJ6P<0:b/[0`0c
<c<3028R8P804A4A0`0:2PX302@T90<0Fe]K0P22PX83092@T0<0QHF50P2?Shl30;Vi^@<0^;Rh0`2`
/;0209BDU0<0OGem0`2YZJT30<71`@80Y:BT0`2GUiL30:2PX0<0YJFU0P2e]KD30<o?c`<0d=3@0`2j
^[X2059BDP<02@T90`0B4Q8302@T908061PH0`0X:2P306MWI`<0IVIV0P1PH6030:BTY0<0/[:b0P28
R8P304];B`<06a/K>@0000080?ooo`001P3ooom=000000<01@D50`0b<S8202d];@<0:BTY0`0W9bL3
028R8P80;Bd]0`0/;2`301HF5P<02PX:0P0C4a<302TY:@<0>CTi0`0L71`201HF5P<051@D0`0I6AT3
034a<@80KVi^0`1mOGd30:6QX@80W9bL0`2IVIT30:>SX`<0UIFE0P23Ph<30:6QX@<0g]kN0`39bLT2
0;Bd]0<0Zj^[0`2KVi/30:JVYP80alO70`3<c<`30=7Ad@<0TY:B0P0R8R8301PH60<051@D0`0@4102
00/;2`<04Q8B0`1;Bd/307moO`80I6AT0`1/K6`30:2PX080R8R80`0Z:RX;00410C400000203oool0
00H0ooooC@00000300D51@<0<S8b0P0];Bd302TY:@<09bLW0`0R8R8202d];@<0;2`/0`0F5QH300X:
2P804a<C0`0Y:BT303Ti>@<071`L0P0F5QH301@D50<06ATI0`0a<C4206i^KP<0OGem0`2QXJ4209bL
W0<0VIVI0`2SXj<309FEU@80Ph>30`2QXJ430=kNgP<0bLW90P2d];@30:^[Z`<0Vi^K0`2VYZH20<O7
a`<0c<c<0`3AdM4309:BTP808R8R0`0H61P301@D50<0410@0P0;2`/3018B4P<0Bd];0`1oOgl206AT
I0<0K6a/0`2PX:0208R8R0<0:RXZ2`010@4a000000P0oooo00060?ooodd000000`051@D3038b<P80
;Bd]0`0Y:BT302LW9`<08R8R0P0];Bd302`/;0<05QHF0`0:2PX201<C4`<0:BTY0`0i>CT301`L7080
5QHF0`0D51@301TI6@<0<C4a0P1^KVh307emO@<0XJ6Q0P2LW9`309VIV@<0Xj>S0`2EUID208>3P`<0
XJ6Q0`3Ng]h30<W9b@80];Bd0`2[Zj/309^KV`<0YZJV0P37alL30<c<c0<0dM7A0`2BTY82028R8P<0
61PH0`0D51@3010@40802`/;0`0B4Q8304];B`<0Ogmo0P1TI6@306a/K0<0X:2P0P28R8P302XZ:P/0
0@41<@0000080?ooo`001P3ooom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ
0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI
0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl
0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH6
0`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3o
oom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E
5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`
L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<
c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@
D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3ooom=000000<010@40`1>CTh2
06a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`2
02h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH3
09^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3
038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83
000000D00P82=00000080?ooo`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG
5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^
KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2
`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q830082
0P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?oo
o`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T9080
7alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0
>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0
]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0
IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<010@4
0`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM
0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q
0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI
0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T9
0`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g
=cL3030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2O
Wil30861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2L
W9`20:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o
?cl201hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P06
1PH300T92@<00`<3;P0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g=cL3
030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2OWil3
0861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2LW9`2
0:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o?cl2
01hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P061PH3
00T92@<00`<3;P0000080?ooo`001P3ooom=000000<0;2`/0`3De=@208:2PP<0G5aL0`1VIVH302XZ
:P806ATI0`0[:b/303`l?0<0:b/[0P0N7Qh303lo?`<0N7Qh0`2XZ:P20<K6aP<0gMgM0`3:b/X30;jn
_P80XJ6Q0`1KFe/302`/;0804a<C0`0<30`301`L70<0Ng]k0P3Cdm<30;jn_P<0Ph>30`24Q8@207al
O0<0N7Qh0`28R8P309VIV@D0Vi^K0`2e]KD308B4Q080O7al0`2<S8`3061PH0<08R8R0P0E5AD300X:
2P<00P820`071`L202XZ:P<0EUIF0`1EEED204I6AP<0;Bd]0`0?3`l30000008010@40`0>3Ph300P8
22h00000203oool000H0ooooC@00000302`/;0<0e=CD0P22PX8305aLG0<0IVIV0`0Z:RX201TI6@<0
:b/[0`0l?3`302/[:`807QhN0`0o?cl307QhN0<0Z:RX0P36a/H30=gMg@<0b/[:0`2n_[h20:6QX@<0
Fe]K0`0/;2`201<C4`<030`<0`0L71`307]kN`80dm?C0`2n_[h308>3P`<0Q8B40P1lO7`307QhN0<0
R8R80`2IVIT509^KV`<0]KFe0`24Q8@207alO0<0S8b<0`1PH603028R8P805ADE0`0:2PX300820P<0
1`L70P0Z:RX305IFEP<0EEEE0P16ATH302d];@<03`l?0`00000200@410<03Ph>0`0820P^000000P0
oooo00060?ooodd000000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0?3`l
0`0[:b/201hN7P<0?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/
0P0C4a<300`<30<071`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI
1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ
0`1FEUH305EEE@80ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P8;P0000080?ooo`001P3o
oom=000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l
?3`304A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1n
OWh30:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2V
YZH30:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1X
J6P205YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=
000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`3
04A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh3
0:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH3
0:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P2
05YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=0000
00<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`304A4
A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh30:6Q
X@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH30:VY
Z@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P205YJ
FP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom@000000<0
Cdm?0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80
YjNW0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0
]KFe0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0
TI6A0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0
=cLg0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0Cdm?
0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80YjNW
0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0]KFe
0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0TI6A
0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0=cLg
0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0;Bd]0P1S
Hf<309FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2H
V9P309nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26
QXH302HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2B
TY8308F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H
61P200820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<3
09FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P3
09nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH3
02HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY83
08F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P2
00820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<309FE
U@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P309nO
W`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH302HV
9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY8308F5
Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P20082
0P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0C4a<0P1UIFD303hn?P<0
Vi^K0`2/[:`20:^[Z`<0YZJV0`1hN7P307IfMP80KVi^0`1OGel305=CD`<0Fe]K0P25QHD30:RXZ0<0
][Jf0`37alL20=7Ad@<0f][J0`3Ph>020>GUi@H0jn_[0`3/k>`20>KViP<0gmoO0`3;bl/30861P@80
@D510`1?Cdl307YjNP<0K6a/0P1[Jf/305YJFP<0BTY:0`1EEED206UYJ@<0QhN70`2=SHd308B4Q080
IfMW0`1>CTh302HV9PD01PH60`0U9BD305=CD`D0Ogmo0`1CDe<301hN7P801@D50`0/;2`304U9B@<0
:RXZ0P0410@Y000000P0oooo00060?oooe0000000`1<C4`206EUI@<0?Shn0`2KVi/30:b/[080Zj^[
0`2VYZH307QhN0<0MWIf0P1^KVh305mOG`<0De=C0`1KFe/208F5Q@<0Z:RX0`2f][H30<O7a`80dM7A
0`3Jf]X30>3Ph080iNGU1P3[jn/30>c/k080i^KV0`3Ogml30<_;b`<0PH610P11@D4304m?C`<0NWYj
0`1/K6`206][J`<0FUYJ0`1:BTX305EEE@80JFUY0`27QhL308f=S@<0Q8B40P1WIfL304i>CP<09RHV
1@061PH302DU9@<0De=C1@1oOgl305=CD`<07QhN0P051@D302`/;0<0BDU90`0Z:RX200@412T00000
203oool000H0ooooD000000304a<C080IFEU0`0n?Sh309^KV`<0[:b/0P2[Zj/30:JVYP<0N7Qh0`1f
MWH206i^KP<0GemO0`1CDe<305]KF`80QHF50`2XZ:P30;Jf]P<0alO70P3AdM430=[JfP<0h>3P0P3U
iND60>_[j`<0k>c/0P3Vi^H30=oOg`<0bl_;0`21PH420451@@<0Cdm?0`1jNWX306a/K080Jf][0`1J
FUX304Y:BP<0EEEE0P1YJFT308N7Q`<0SHf=0`24Q8@206MWI`<0CTi>0`0V9RH500H61P<09BDU0`1C
De<507moO`<0De=C0`0N7Qh200D51@<0;2`/0`19BDT302XZ:P8010@4:@0000080?ooo`001P3ooom@
000000<0Hf=S0P3?cll308j>SP<0OWin0`37alL20<_;b`<0JFUY0`0R8R8302l_;`80AdM70`1DE5@3
04M7A`<0?clo0P1HF5P308Z:RP<0]kNg0`33`l<20<K6aP<0d=3@0`3QhN420>c/k0<0lo?c0`3alO43
0>c/k080inOW0`3Rh^860>CTi080_[jn0`2EUID309BDU0<0VYZJ1@2GUiL309^KV`<0LG5a0P17AdL3
05]KF`<0SHf=0`26QXH206m_K`<0F5QH0`0f=SH301LG5`801PH60`0A4A4303Ph>080K6a/0`23Ph<3
069RHP<0:2PX0P030`<3024Q8@<0Cdm?0`0[:b/200H61RT00000203oool000H0ooooD000000306=S
H`80clo?0`2>SXh307inOP<0alO70P3;bl/306UYJ@<08R8R0`0_;bl204M7A`<0E5AD0`17AdL303lo
?`80F5QH0`2:RXX30;Ng]`<0`l?30P36a/H30=3@d0<0hN7Q0P3/k>`30??cl`<0lO7a0`3/k>`20>OW
i`<0h^;R1P3Ti>@20;jn_P<0UIFE0`2DU9@309ZJVPD0UiNG0`2KVi/3075aL@80AdM70`1KFe/308f=
S@<0QXJ60P1_Kfl305QHF0<0=SHf0`0G5aL200H61P<04A4A0`0h>3P206a/K0<0Ph>30`1RHV8302PX
:0800`<30`0Q8B4304m?C`<0:b/[0P061PHY000000P0oooo00060?oooe0000000`1SHf<20<o?c`<0
SXj>0`1nOWh30<O7a`80bl_;0`1YJFT3028R8P<0;bl_0P17AdL305ADE0<0AdM70`0o?cl205QHF0<0
RXZ:0`2g]kL30<?3``80a/K60`3@d=030>7Qh@80k>c/0`3clo<30?7al@<0k>c/0P3WinL30>;RhPH0
i>CT0P2n_[h309FEU@<0U9BD0`2JVYX509NGU`<0Vi^K0`1aLG4204M7A`<0Fe]K0`2=SHd308J6QP80
Kfm_0`1HF5P303Hf=P<05aLG0P061PH3014A4@<0>3Ph0P1/K6`308>3P`<0HV9R0`0X:2P200<30`<0
8B4Q0`1?Cdl302/[:`801PH6:@0000080?ooo`001P3ooom=000000<00@410`1^KVh20<W9b@<0YZJV
0`1`L70304i>CP80EUIF0`1^KVh306ATI0<0DU9B0P0m?Cd303`l?0<0820P0`0R8R8203De=@<0B4Q8
0`1VIVH30:NWY`80`l?30`3;bl/30<g=c@80d];B0`3YjNT30>_[j`<0i^KV0P3Ph>060=kNgP<0h>3P
0P3UiND30=GEe@<0_;bl0`2n_[h20<30`0<0^;Rh0`2ZZZX307YjNP809bLW0`1:BTX307]kN`<0OWin
0P1hN7P305aLG0<0@4100`0V9RH2010@40<020P80`0V9RH2061PH0<0RHV90`1XJ6P303<c<`802@T9
0`0];Bd3065QH@<0<S8b0P0:2PXY000000P0oooo00060?ooodd000000`010@4306i^KP80bLW90`2V
YZH3071`L0<0CTi>0P1FEUH306i^KP<0I6AT0`1BDU8203dm?@<0?3`l0`0P8203028R8P80=CDe0`18
B4P306IVIP<0YjNW0P33`l<30<_;b`<0cLg=0P3Bd]830>WYj@<0jn_[0`3Vi^H20>3Ph0H0g]kN0`3P
h>020>GUi@<0eMGE0`2l_;`30;jn_P80`<300`2h^;P30:ZZZP<0NWYj0P0W9bL304Y:BP<0Ng]k0`1n
OWh207QhN0<0G5aL0`10@40302HV9P80410@0`0820P302HV9P80H61P0`29RHT306QXJ0<0<c<c0P09
2@T302d];@<0HF5Q0`0b<S8200X:2RT00000203oool000H0ooooD000000306][J`80[jn_0`2h^;P3
08j>SP<0DU9B0P29RHT30=CDe0<0`<300`2c/k<20:NWY`<0ZZZZ0`20P80306IVIP80L71`0`21PH43
071`L0<0Kfm_0P2DU9@30<O7a`<0d];B0P38b<P30=3@d0<0f=SH0`3IfMT20=[JfP<0d];B0`3Fe]H3
0=;BdP80e]KF0`35aLD30;Ng]`<0^[Zj0P2m_Kd30;Bd]0<0X:2P0`1[Jf/203dm?@<0Fe]K0`26QXH3
08N7Q`80PH610`1/K6`304A4A0<0;2`/0P0G5aL300L71`<09bLW0P1IFET30820P0<0Jf][0`10@402
01LG5`<0C4a<0`1ZJVX303`l?0807QhN0`010@4V000000P0oooo00060?oooe0000000`1[Jf/20:n_
[`<0^;Rh0`2>SXh3059BDP80RHV90`3De=@30<30`0<0/k>c0P2WYjL30:ZZZP<0P8200`1VIVH2071`
L0<0PH610`1`L70306m_K`80U9BD0`37alL30=;BdP80b<S80`3@d=030=SHf0<0fMWI0P3Jf]X30=;B
dP<0e]KF0`3Bd]820=KFeP<0aLG50`2g]kL30;Zj^P80_Kfm0`2d];@30:2PX0<0Jf][0P0m?Cd305]K
F`<0QXJ60`27QhL20861P@<0K6a/0`14A4@302`/;0805aLG0`071`L302LW9`80FEUI0`20P80306][
J`<0@4100P0G5aL304a<C0<0JVYZ0`0l?3`201hN7P<00@419P0000080?ooo`001P3ooom@000000<0
Jf][0P2_[jl30;Rh^0<0SXj>0`1BDU8208V9R@<0e=CD0`30`<030;>c/`80YjNW0`2ZZZX30820P0<0
IVIV0P1`L7030861P@<0L71`0`1_Kfl209BDU0<0alO70`3Bd]820<S8b0<0d=3@0`3Hf=P30=WIf@80
f][J0`3Bd]830=KFeP<0d];B0P3Fe]H30<G5a@<0]kNg0`2j^[X20;fm_@<0];Bd0`2PX:0306][J`80
?Cdm0`1KFe/308J6QP<0QhN70P21PH4306a/K0<0A4A40`0/;2`201LG5`<01`L70`0W9bL205UIF@<0
P8200`1[Jf/30410@0805aLG0`1<C4`306YZJP<0?3`l0P0N7Qh300410BH00000203oool000H0oooo
D000000308N7Q`80][Jf0`2/[:`309NGU`<0UIFE0P3=cLd30<_;b`<0_Kfm0`3Rh^820>o_k`<0dm?C
0`37alL30;jn_P80X:2P0`1hN7P306YZJP<0Q8B40P27QhL309fMW@<0emOG0P3IfMT30=7Ad@<0d=3@
0`38b<P20=7Ad@<0c/k>0`33`l<30;no_`80^k^k0`2e]KD30:RXZ0<0ZJVY0P2XZ:P309JFUP<0L71`
0`1@D50203<c<`<0@T920`22PX8308b<S080SXj>0`26QXH305UIF@<0<S8b0P0P820300/;2`<0<c<c
0P1ZJVX308>3P`<0MGEe0`12@T8202HV9P<0KVi^0`1RHV8304I6AP809BDU:@0000080?ooo`001P3o
oom@000000<0QhN70P2f][H30:b/[0<0UiNG0`2EUID20<g=c@<0bl_;0`2m_Kd30>;RhP80kno_0`3C
dm<30<O7a`<0_[jn0P2PX:0307QhN0<0JVYZ0`24Q8@208N7Q`<0WIfM0`3GemL20=WIf@<0dM7A0`3@
d=030<S8b080dM7A0`3>c/h30<?3``<0_kno0P2k^k/30;Fe]@<0Z:RX0`2YZJT20:RXZ0<0UYJF0`1`
L703051@D080<c<c0`12@T8308:2PP<0S8b<0P2>SXh308J6QP<0FEUI0`0b<S82020P80<02`/;0`0c
<c<206YZJP<0Ph>30`1eMGD30492@P809RHV0`1^KVh3069RHP<0ATI60P0U9BDY000000P0oooo0006
0?oooe0000000`27QhL20;Jf]P<0[:b/0`2GUiL309FEU@80cLg=0`3;bl/30;fm_@<0h^;R0P3_knl3
0=?Cd`<0alO70`2n_[h20:2PX0<0N7Qh0`1ZJVX308B4Q080QhN70`2MWId30=OGe`80fMWI0`3AdM43
0=3@d0<0b<S80P3AdM430<k>cP<0`l?30`2o_kl20;^k^`<0]KFe0`2XZ:P30:VYZ@80Z:RX0`2FUYH3
071`L0<0D51@0P0c<c<30492@P<0PX:20`2<S8`208j>SP<0QXJ60`1IFET3038b<P80820P0`0;2`/3
03<c<`80JVYZ0`23Ph<307EeM@<0@T920P0V9RH306i^KP<0HV9R0`16ATH202DU9BT00000203oool0
00H0ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJ
VP<0cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VY
Z@<0XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De
=@<04Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7
A`80PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0
ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0
cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0
XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<0
4Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80
PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0oooo
D000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0cLg=
0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0XJ6Q
0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<04Q8B
0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80PX:2
0`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0ooooD000
000302TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d
];@30<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1J
FUX205=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1Y
JFT2059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2C
Ti<307alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD0000003
02TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d];@3
0<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1JFUX2
05=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1YJFT2
059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2CTi<3
07alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD000000300D5
1@80YjNW0`38b<P30;Rh^0<0bLW90P3alO430?Shn0<0kno_0`3Zj^X20>k^kP<0inOW0`3Zj^X30?Kf
mP80kno_1P3[jn/30=;BdP80/k>c0`2WYjL309NGU`80Vi^K0`2`/;030;Bd]0<0]KFe0P2=SHd30861
P@<0J6QX0`1LG5`20451@@<0:RXZ0`0U9BD301LG5`80410@0`0G5aL3038b<P<0GemO0P1ADE4300h>
3P<0E5AD0`1oOgl20861P@<0PX:20`1/K6`304i>CP80;2`/0`0L71`3069RHP80V9RH0`1dM7@30451
@@<0>SXj0P1fMWH304M7A`<01`L7;P0000080?ooo`001P3ooom@000000<01@D50P2WYjL30<S8b0<0
^;Rh0`39bLT20?7al@<0n?Sh0`3_knl30>[ZjP80k^k^0`3WinL30>[ZjP<0m_Kf0P3_knl60>_[j`<0
d];B0P2c/k<30:NWY`<0UiNG0P2KVi/30;2`/0<0];Bd0`2e]KD208f=S@<0PH610`1XJ6P305aLG080
@D510`0Z:RX302DU9@<05aLG0P0@410301LG5`<0<S8b0`1OGel2055AD@<03Ph>0`1DE5@307moO`80
PH610`22PX8306a/K0<0CTi>0P0/;2`301`L70<0HV9R0P2HV9P307AdM0<0@D510`0j>SX207IfMP<0
AdM70`071`L^000000P0oooo00060?oooe0000000`051@D20:NWY`<0b<S80`2h^;P30<W9b@80lO7a
0`3hn?P30>o_k`<0j^[Z0P3^k^h30>OWi`<0j^[Z0`3fm_H20>o_k`H0jn_[0`3Bd]820;>c/`<0YjNW
0`2GUiL209^KV`<0/;2`0`2d];@30;Fe]@80SHf=0`21PH4306QXJ0<0G5aL0P11@D4302XZ:P<09BDU
0`0G5aL2010@40<05aLG0`0b<S8305mOG`80DE5A0`0>3Ph305ADE0<0Ogmo0P21PH4308:2PP<0K6a/
0`1>CTh202`/;0<071`L0`1RHV8209RHV0<0M7Ad0`11@D4303Xj>P80MWIf0`17AdL300L71bh00000
203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38
b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1m
OGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o
?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[
:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`000002
06IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=02
0=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3
075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl3
02d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`3
03/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj
^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf
]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RH
V0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861
P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=
3C400000203oool000H0ooooD`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80
kNg]0`3[jn/30=gMg@<0h>3P0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0
SHf=0`2TY:@309jNWP80aLG50`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0
]KFe0`2LW9`30861P@80?3`l0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0
Cdm?0`2JVYX208N7Q`<0GemO0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0oooo
D`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80kNg]0`3[jn/30=gMg@<0h>3P
0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0SHf=0`2TY:@309jNWP80aLG5
0`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0]KFe0`2LW9`30861P@80?3`l
0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0Cdm?0`2JVYX208N7Q`<0GemO
0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0ooooE@00000307=cL`<0hn?S0`3?
cll20=7Ad@H0f][J0`3Vi^H20>WYj@<0f][J0`3Ng]h30;6a/@80:2PX0`061PH300X:2P<02@T90P0L
71`305QHF0<0MGEe0P23Ph<30;Zj^P<0_;bl0`34a<@20:j^[P<0^;Rh0`3Cdm<308j>SP80EEEE0`1M
GEd305ADE0<0MgMg0P2OWil30:j^[P<0W9bL0`1RHV8204e=C@<0Kfm_0`1oOgl308B4Q080Ph>30`24
Q8@306YZJP<0B4Q80P0Z:RX3065QH@<0TY:B0P1cLg<304e=C@<09BDU0`020P82000000<00@41<@00
00080?ooo`001P3ooomE000000<0Lg=c0`3Shn<30<o?c`80dM7A1P3Jf]X30>KViP80jNWY0`3Jf]X3
0=kNgP<0/K6a0P0X:2P300H61P<02PX:0`092@T201`L70<0F5QH0`1eMGD208>3P`<0^[Zj0`2l_;`3
0<C4a080[Zj^0`2h^;P30=?Cd`<0SXj>0P1EEED305eMG@<0E5AD0`1gMgL209nOW`<0[Zj^0`2LW9`3
069RHP80CDe=0`1_Kfl307moO`<0Q8B40P23Ph<308B4Q0<0JVYZ0`18B4P202XZ:P<0HF5Q0`2BTY82
07=cL`<0CDe=0`0U9BD300820P8000000`010@4a000000P0oooo00060?oooeD000000`1cLg<30>?S
h`<0clo?0P3AdM460=[JfP<0i^KV0P3YjNT30=[JfP<0g]kN0`2a/K4202PX:0<01PH60`0:2PX300T9
2@8071`L0`1HF5P307EeM@80Ph>30`2j^[X30;bl_0<0a<C40P2^[Zh30;Rh^0<0dm?C0`2>SXh205EE
E@<0GEeM0`1DE5@307MgM`80WinO0`2^[Zh309bLW0<0HV9R0P1=CDd306m_K`<0Ogmo0`24Q8@208>3
P`<0Q8B40`1ZJVX304Q8B080:RXZ0`1QHF4309:BTP80Lg=c0`1=CDd302DU9@<00P820P0000030041
0C400000203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80
gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0
]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0
CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0
LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooE@000003018B4P<0_kno
0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO
0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno
0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF5
0P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000
203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3Y
jNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39
bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1N
GUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1l
O7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooF000000302l_;`<0`<300P3WinL3
0=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065QH@<0?Shn0P0[:b/3
01@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@T080_Kfm0`2OWil3
09bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3
061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0ooooF000000302l_
;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065Q
H@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@
T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>
SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0
ooooF000000302l_;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80
PH610`1jNWX3065QH@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0
OWin0`1lO7`3092@T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0
Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`0
0000203oool000H0ooooF`00000301XJ6P80Zj^[0`3_knl30>3Ph0<0gMgM0P3Shn<30=cLg0<0][Jf
0`2VYZH20<71`@<0g=cL0`3Ogml30::RXP80Jf][0`1:BTX302`/;080U9BD0`3Hf=P309JFUP<0Y:BT
0P3Bd]830<c<c0<0_kno0`2/[:`20;6a/@<0`L710`2ZZZX30;:b/P80_Kfm0`2n_[h3051@D0<0?Shn
0P1YJFT307UiN@<0RHV90`2BTY8208n?S`<0NWYj0`1PH60303lo?`80A4A40`1NGUh3059BDP806QXJ
?`0000080?ooo`001P3ooomK000000<06QXJ0P2[Zj/30>o_k`<0h>3P0`3MgMd20>?Sh`<0g=cL0`2f
][H30:JVYP80`L710`3Lg=`30=oOg`<0XZ:R0P1[Jf/304Y:BP<0;2`/0P2DU9@30=SHf0<0UYJF0`2T
Y:@20=;BdP<0c<c<0`2o_kl30:b/[080/K6a0`31`L430:ZZZP<0/[:b0P2m_Kd30;jn_P<0D51@0`0n
?Sh206UYJ@<0NGUi0`29RHT309:BTP80Shn?0`1jNWX3061PH0<0?clo0P14A4@305iNGP<0DU9B0P0J
6QXo000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/3
0:BTY080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID2
08n?S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P2
06QXJ0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o
000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BT
Y080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?
S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QX
J0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o0000
00P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BTY080
bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?S`<0
WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QXJ0<0
OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o000000P0
oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW
0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C
0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_
0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;
Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1E
EED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j
>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h
>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh3
0861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<03
0<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd3
07alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l
000000P0oooo00060?ooofT000000P0m?Cd30:VYZ@<0W9bL0`1cLg<206i^KP<0V9RH0`2JVYX30861
P@80L71`0`1aLG4304I6AP80BTY:0`2=SHd30:n_[`<0YJFU0P2TY:@30<S8b0<0_kno0`2YZJT208N7
Q`<0=cLg0`0?3`l301HF5P80=SHf0`15ADD304Y:BP<0GemO0P1YJFT308>3P`<0TI6A0`2;Rh/207Ui
N@<0IfMW0`17AdL5024Q8@<0<30`0`051@D2000000<00@41?00000080?ooo`001P3ooomY00000080
?Cdm0`2YZJT309bLW0<0Lg=c0P1^KVh309RHV0<0VYZJ0`21PH42071`L0<0LG5a0`16ATH204Y:BP<0
SHf=0`2_[jl30:FUY@80Y:BT0`38b<P30;no_`<0ZJVY0P27QhL303Lg=`<03`l?0`0F5QH203Hf=P<0
ADE50`1:BTX305mOG`80JFUY0`23Ph<3096AT@<0Rh^;0P1iNGT306MWI`<0AdM71@0Q8B43030`<0<0
1@D50P00000300410C`00000203oool000H0ooooJ`00000300L71`<0GemO0`1/K6`207AdM0<0UIFE
0`2HV9P30820P080JFUY0`1EEED304=3@`80=cLg0`1OGel307MgM`<0P8200P2=SHd308Z:RP<0M7Ad
0`0n?Sh200h>3P<02`/;0`0I6AT301lO7`80>SXj1P1>CTh305EEE@80LG5a0`28R8P308n?S`<0QHF5
0P1aLG4305YJFP<0<S8b0`0H61P202`/;0<07QhNA00000080?ooo`001P3ooom[000000<01`L70`1O
Gel306a/K080M7Ad0`2EUID309RHV0<0P8200P1YJFT305EEE@<0@d=30P0g=cL305mOG`<0MgMg0`20
P80208f=S@<0RXZ:0`1dM7@303hn?P803Ph>0`0;2`/301TI6@<07alO0P0j>SX604i>CP<0EEEE0P1a
LG4308R8R0<0Shn?0`25QHD2075aL@<0FUYJ0`0b<S8301PH6080;2`/0`0N7Qi4000000P0oooo0006
0?ooof/000000`071`L305mOG`<0K6a/0P1dM7@309FEU@<0V9RH0`20P80206UYJ@<0EEEE0`13@d<2
03Lg=`<0GemO0`1gMgL30820P080SHf=0`2:RXX307AdM0<0?Shn0P0>3Ph300/;2`<06ATI0`0O7al2
03Xj>PH0CTi>0`1EEED2075aL@<0R8R80`2?Shl308F5Q@80LG5a0`1JFUX3038b<P<061PH0P0/;2`3
01hN7T@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0JVYZ0`1PH602051@
D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<01@D50P0@410301lO
7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80LW9b0`1<C4`302h^
;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0
JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<0
1@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80
LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX
0P1SHf<306MWI`<0JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C
0`0f=SH301DE5@<01@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b
1P2;Rh/307moO`80LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00
000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K6`<04Q8B0`0;
2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?C`<0FEUI0`1k
Ng/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T3000000<00@41@@00
00080?ooo`001P3ooom^000000<0>3Ph0`1cLg<506][J`<0IfMW0`1GEeL204A4A0<0<S8b0`0_;bl2
02TY:@<06a/K0`0B4Q8300/;2`8030`<0`0D51@301<C4`<04Q8B0P0J6QX302h^;P<0<C4a0`0Y:BT2
03Hf=P<0Cdm?0`1IFET307]kN`80Shn?0`22PX8307UiN@<0N7Qh0P1YJFT304Q8B0<0=3@d0`0[:b/2
00T92@<000000`010@51000000P0oooo00060?ooofh000000`0h>3P307=cL`D0Jf][0`1WIfL305MG
E`80A4A40`0b<S8302l_;`80:BTY0`0K6a/3018B4P<02`/;0P0<30`301@D50<04a<C0`0B4Q8201XJ
6P<0;Rh^0`0a<C4302TY:@80=SHf0`1?Cdl305UIF@<0Ng]k0P2?Shl308:2PP<0NGUi0`1hN7P206UY
J@<0B4Q80`0d=3@302/[:`802@T90`00000300410D400000203oool000H0ooooKP00000302d];@<0
RHV90P1lO7`307EeM@<0KVi^0`1NGUh204Q8B0<0;bl_0`0[:b/2030`<0<04Q8B0`0:2PX3010@4080
51@D0`0K6a/301HF5P<07AdM0P0V9RH303De=@<0<30`0`0k>c/20410@0<0@D510`1OGel308:2PP80
S8b<1P1lO7`307]kN`80IVIV0`1>CTh303@d=0<030`<B@0000080?ooo`001P3ooom^000000<0;Bd]
0`29RHT207alO0<0MGEe0`1^KVh305iNGP80B4Q80`0_;bl302/[:`80<30`0`0B4Q8300X:2P<0410@
0P0D51@301/K6`<05QHF0`0M7Ad202HV9P<0=CDe0`0`<30303/k>`80@4100`11@D4305mOG`<0PX:2
0P2<S8`607alO0<0Ng]k0P1VIVH304i>CP<0=3@d0`0<30a9000000P0oooo00060?ooofT000000P01
0@43000000<04Q8B0`2:RXX207IfMP<0KFe]1P1UIFD205UIF@<0>SXj0`0e=CD202`/;0<04Q8B0`0A
4A4301TI6@805QHF0`0G5aL3024Q8@<08b<S0P0f=SH303De=@<0<C4a0`1=CDd205IFEP<0F5QH0`1Y
JFT307inOP80MgMg0`1bLW8308:2PP<0Kfm_0P1PH603051@D0<05QHF0`00000200410DL00000203o
ool000H0ooooJ@00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EUI@80FEUI0`0j>SX3
03De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf=P<0=CDe0`0a<C43
04e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061PH0<0D51@0`0F5QH3
000000800@41A`0000080?ooo`001P3ooomY000000800@410`000003018B4P<0RXZ:0P1fMWH306e]
K@H0IFEU0P1IFET303Xj>P<0=CDe0P0/;2`3018B4P<04A4A0`0I6AT201HF5P<05aLG0`0Q8B4302<S
8`80=SHf0`0e=CD3034a<@<0CDe=0P1FEUH305QHF0<0JFUY0`1nOWh207MgM`<0LW9b0`22PX8306m_
K`80H61P0`1@D50301HF5P<000000P010@57000000P0oooo00060?ooofh000000`030`<30861P@80
UYJF0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<0
6ATI0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0
NGUi0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF
0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI
0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi
0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF0`27
QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI0`0Y
:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi0`1Y
JFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`0@410306QXJ080VIVI0`2BTY83
08R8R0<0PH610P1bLW8306MWI`<0DE5A0P0];Bd301/K6`<07QhN0`0L71`201XJ6P<0:2PX0`0V9RH3
03Ph>080@4100`13@d<305EEE@<0Lg=c0P1kNg/607QhN0<0K6a/0P1ZJVX305]KF`<0BTY:0`19BDT2
02@T95800000203oool000H0ooooKP000003010@40<0J6QX0P2IVIT309:BTP<0R8R80`21PH42079b
LP<0IfMW0`1ADE4202d];@<06a/K0`0N7Qh301`L70806QXJ0`0X:2P302HV9P<0>3Ph0P10@40304=3
@`<0EEEE0`1cLg<207]kN`H0N7Qh0`1/K6`206YZJP<0Fe]K0`1:BTX304U9B@8092@TDP0000080?oo
o`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80
:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80
NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K
0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO
0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C
0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26
QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?
Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE000
00080?ooo`001P3ooom^000000<07AdM0`1HF5P208N7Q`<0SXj>0`28R8P307UiN@80Jf][0`1MGEd3
0410@0D0:2PX0`0U9BD302LW9`80=cLg0`0[:b/304Y:BP<0FEUI0P1JFUX306YZJP<0N7Qh0`1cLg<2
07EeM@<0NGUi0`1mOGd306IVIP80BDU90`0a<C4300P825L00000203oool000H0ooooKP00000301dM
7@<0F5QH0P27QhL308j>SP<0R8R80`1iNGT206][J`<0GEeM0`10@40502PX:0<09BDU0`0W9bL203Lg
=`<0:b/[0`1:BTX305UIF@80FUYJ0`1ZJVX307QhN0<0Lg=c0P1eMGD307UiN@<0OGem0`1VIVH204U9
B@<0<C4a0`0820QG000000P0oooo00060?ooofh000000`0M7Ad305QHF080QhN70`2>SXh308R8R0<0
NGUi0P1[Jf/305eMG@<0@4101@0X:2P302DU9@<09bLW0P0g=cL302/[:`<0BTY:0`1IFET205YJFP<0
JVYZ0`1hN7P307=cL`80MGEe0`1iNGT307emO@<0IVIV0P19BDT3034a<@<020P8E`0000080?ooo`00
1P3ooomY000000D00@410`0=3@d305UIF@80Ph>30`2ATI4308J6QP<0MGEe0P1UIFD305IFEP<0@410
0P0b<S8302l_;`<0:b/[0`0f=SH2034a<@<0ATI60`1QHF43061PH080JVYZ0`1eMGD307inOP<0NGUi
0P1eMGD307emO@<0Lg=c0`1;Bd/201`L75d00000203oool000H0ooooJ@00000500410@<03@d=0`1I
FET208>3P`<0TI6A0`26QXH307EeM@80IFEU0`1FEUH30410@080<S8b0`0_;bl302/[:`<0=SHf0P0a
<C4304I6AP<0HF5Q0`1PH60206YZJP<0MGEe0`1nOWh307UiN@80MGEe0`1mOGd307=cL`<0Bd];0P0L
71aM000000P0oooo00060?ooofT000001@010@4300d=3@<0FEUI0P23Ph<3096AT@<0QXJ60`1eMGD2
06EUI@<0EUIF0`10@402038b<P<0;bl_0`0[:b/303Hf=P80<C4a0`16ATH3065QH@<0H61P0P1ZJVX3
07EeM@<0OWin0`1iNGT207EeM@<0OGem0`1cLg<304];B`8071`LG@0000080?ooo`001P3ooomV0000
00<00@410P0410@300<30`<00P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410
@080=SHf0`0b<S8303Xj>P<0>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820
P080O7al0`1]KFd304I6AP<03Ph>G`0000080?ooo`001P3ooomV000000<00@410P0410@300<30`<0
0P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410@080=SHf0`0b<S8303Xj>P<0
>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820P080O7al0`1]KFd304I6AP<0
3Ph>G`0000080?ooo`001P3ooomV000000<00P820P030`<300820P<000000`0P820206m_K`<0Q8B4
0`1gMgL3069RHP80GEeM0`1BDU8304I6AP80?3`l0`12@T8304Q8B0<0CDe=0P1IFET305iNGP<0IfMW
0`1aLG4207UiN@<0PH610`22PX8307EeM@80HF5Q0`12@T8301@D50<000000P010@5M000000P0oooo
00060?ooofH000000`020P8200<30`<00P820`000003020P8080Kfm_0`24Q8@307MgM`<0HV9R0P1M
GEd3059BDP<0ATI60P0l?3`30492@P<0B4Q80`1=CDd205UIF@<0GUiN0`1WIfL3075aL@80NGUi0`21
PH4308:2PP<0MGEe0P1QHF430492@P<051@D0`00000200410Ed00000203oool000H0ooooIP000003
00820P800`<30`020P83000000<0820P0P1_Kfl308B4Q0<0MgMg0`1RHV8205eMG@<0DU9B0`16ATH2
03`l?0<0@T920`18B4P304e=C@80FEUI0`1NGUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2
065QH@<0@T920`0D51@3000000800@41G@0000080?ooo`001P3ooomV000000P00@410`020P8300P8
2080?3`l0`1nOWh307]kN`<0JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3051@D0<0EeMG0`1NGUh206=S
H`<0IFEU0`1]KFd307EeM@80NWYj0`1cLg<305eMG@<0Bd];0P10@40302HV9VD00000203oool000H0
ooooIP00000800410@<00P820`0820P203`l?0<0OWin0`1kNg/306YZJP80IFEU0`1MGEd304Y:BP80
ATI60`1@D50305MGE`<0GUiN0P1SHf<306EUI@<0KFe]0`1eMGD207YjNP<0Lg=c0`1MGEd304];B`80
@4100`0V9RIU000000P0oooo00060?ooofH0000020010@4300820P<020P80P0l?3`307inOP<0Ng]k
0`1ZJVX206EUI@<0GEeM0`1:BTX204I6AP<0D51@0`1GEeL305iNGP80Hf=S0`1UIFD306e]K@<0MGEe
0P1jNWX307=cL`<0GEeM0`1;Bd/20410@0<09RHVI@0000080?ooo`001P3ooomP000000/00@410`03
0`<300@410<020P80P0F5QH304E5A@<0HV9R1@1^KVh306MWI`<0FEUI0P1EEED305YJFP<0G5aL0`1N
GUh206EUI@<0JFUY0`1/K6`306UYJ@80G5aL0`1ADE4304U9B@<0@D510P0d=3@300T92FD00000203o
ool000H0ooooH000000;00410@<00`<30`0410@300P820805QHF0`15ADD3069RHPD0KVi^0`1WIfL3
05UIF@80EEEE0`1JFUX305aLG0<0GUiN0P1UIFD306UYJ@<0K6a/0`1YJFT205aLG0<0DE5A0`19BDT3
0451@@80=3@d0`092@UU000000P0oooo00060?ooof0000002`010@4300<30`<010@40`0820P201HF
5P<0ADE50`1RHV8506i^KP<0IfMW0`1IFET205EEE@<0FUYJ0`1LG5`305iNGP80IFEU0`1YJFT306a/
K0<0JFUY0P1LG5`3055AD@<0BDU90`11@D4203@d=0<02@T9I@0000080?ooo`001P3ooomP000000/0
0@410`0:2PX300d=3@<02PX:0P0K6a/302<S8`<0?3`l0`1CDe<2061PH0<0GemO0`1PH60205mOG`<0
GEeM0`1PH603069RHP80IFEU0`1TI6@3061PH0<0EeMG0P1@D50304e=C@<0@T920`0i>CT201LG5fP0
0000203oool000H0ooooH000000;00410@<02PX:0`0=3@d300X:2P806a/K0`0S8b<303`l?0<0De=C
0P1PH60305mOG`<0H61P0P1OGel305eMG@<0H61P0`1RHV8206EUI@<0I6AT0`1PH60305MGE`80D51@
0`1=CDd30492@P<0>CTi0P0G5aMX000000P0oooo00060?ooof0000001P010@43000000800`<30`0=
3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1S
Hf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo0006
0?ooof0000001P010@43000000800`<30`0=3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2
059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D503
04];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof0000001P010@43000000800`<30`0=3@d301TI
6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306AT
I080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof<0
00000`010@4300820P801`L70`0>3Ph301/K6`<0820P0P0N7Qh3028R8P<09RHV0`0^;Rh204E5A@<0
EUIF0`1MGEd206ATI0<0IVIV0`1TI6@3065QH@80GEeM0`1KFe/605QHF080DU9B0`1=CDd3038b<P<0
0`<3JP0000080?ooo`001P3ooomS000000<00@410`020P8200L71`<03Ph>0`0K6a/3020P80807QhN
0`0R8R8302HV9P<0;Rh^0P15ADD305IFEP<0GEeM0P1TI6@306IVIP<0I6AT0`1QHF4205eMG@<0Fe]K
1P1HF5P2059BDP<0CDe=0`0b<S8300<30fX00000203oool000H0ooooH`00000300410@<00P820P07
1`L300h>3P<06a/K0`0P820201hN7P<08R8R0`0V9RH302h^;P80ADE50`1FEUH305eMG@80I6AT0`1V
IVH306ATI0<0HF5Q0P1MGEd305]KF`H0F5QH0P1BDU8304e=C@<0<S8b0`030`=Z000000P0oooo0006
0?ooof<000000`020P8300D51@8030`<0`0?3`l301XJ6P<09BDU0P0V9RH302<S8`<0820P0`0Q8B42
02h^;P<0?clo0`1BDU8205]KF`<0HV9R0`1UIFD305iNGPD0Fe]K0`1JFUX305UIF@80EEEE0`13@d<3
010@46d00000203oool000H0ooooH`00000300820P<01@D50P0<30`300l?3`<06QXJ0`0U9BD202HV
9P<08b<S0`0P8203024Q8@80;Rh^0`0o?cl3059BDP80Fe]K0`1RHV8306EUI@<0GUiN1@1KFe/305YJ
FP<0FEUI0P1EEED304=3@`<0410@K@0000080?ooo`001P3ooomP000000<00@410`030`<300X:2P80
3Ph>0`0@410301TI6@<0:BTY0P0f=SH303lo?`<0A4A40`13@d<203hn?P<0ATI60`1EEED205eMG@<0
H61P0`1RHV8306=SH`80H61P0`1MGEd305iNGP<0Fe]K0P1EEED302`/;7000000203oool000H0oooo
H000000300410@<00`<30`0:2PX200h>3P<0410@0`0I6AT302TY:@80=SHf0`0o?cl304A4A0<0@d=3
0P0n?Sh304I6AP<0EEEE0P1MGEd3061PH0<0HV9R0`1SHf<2061PH0<0GEeM0`1NGUh305]KF`80EEEE
0`0/;2a`000000P0oooo00060?ooof0000000`010@4300<30`<02PX:0P0>3Ph3010@40<06ATI0`0Y
:BT203Hf=P<0?clo0`14A4@304=3@`80?Shn0`16ATH305EEE@80GEeM0`1PH603069RHP<0Hf=S0P1P
H60305eMG@<0GUiN0`1KFe/205EEE@<0;2`/L00000080?ooo`001P3ooomN000000D00P820`0820P3
00`<30803Ph>0`0B4Q8301XJ6P<0:BTY0P0n?Sh305IFEP<0IVIV2`1aLG42079bLP<0Lg=c0`1`L703
06UYJ@80Hf=S0`1QHF4305mOG`<0GEeM0P15ADD300P827000000203oool000H0ooooGP0000050082
0P<020P80`0<30`200h>3P<04Q8B0`0J6QX302TY:@80?Shn0`1FEUH306IVIP/0LG5a0P1bLW8307=c
L`<0L71`0`1YJFT206=SH`<0HF5Q0`1OGel305eMG@80ADE50`0820Q`000000P0oooo00060?oooeh0
00001@020P8300P820<030`<0P0>3Ph3018B4P<06QXJ0`0Y:BT203hn?P<0EUIF0`1VIVH;075aL@80
LW9b0`1cLg<3071`L0<0JFUY0P1SHf<3065QH@<0GemO0`1MGEd204E5A@<020P8L00000080?ooo`00
1P3ooom@000000D00@410`00000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B
0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][
0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00
000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13
@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1O
Gel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00000300410@<00P820P030`<3
00H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD3
06][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`000008
0?ooo`001P3ooom@000000D00@410`00000600<30`D010@40`051@D300/;2`804A4A0`0E5AD301/K
6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZ
JP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`001P3ooom@000000D00@410`00000600<30`D0
10@40`051@D300/;2`804A4A0`0E5AD301/K6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0
GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZJP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`00
1P3ooom@000000P00@4120020P8300410@<01PH60`0<30`2014A4@<05aLG0`0M7Ad302LW9`80<C4a
0`0m?Cd304M7A`<0CTi>0P1JFUX306QXJ0<0Kfm_0P1eMGD307]kN`<0NWYj0`1dM7@207=cL`<0LG5a
0`1NGUh300h>3WD00000203oool000H0ooooD000000800410@P00P820`010@4300H61P<030`<0P0A
4A4301LG5`<07AdM0`0W9bL2034a<@<0?Cdm0`17AdL304i>CP80FUYJ0`1XJ6P306m_K`80MGEe0`1k
Ng/307YjNP<0M7Ad0P1cLg<3075aL@<0GUiN0`0>3Pie000000P0oooo00060?oooe00000020010@48
00820P<00@410`061PH300`<30804A4A0`0G5aL301dM7@<09bLW0P0a<C4303dm?@<0AdM70`1>CTh2
05YJFP<0J6QX0`1_Kfl207EeM@<0Ng]k0`1jNWX307AdM080Lg=c0`1aLG4305iNGP<03Ph>M@000008
0?ooo`001P3ooom@000000/00@410`020P8200<30`<01@D50`0:2PX300h>3P804a<C0`0L71`3028R
8P<0:2PX0P0b<S8303lo?`<0Bd];0`1DE5@2065QH@<0KVi^0`1gMgL207alO0<0OGem0`1kNg/307Ee
M@80KFe]0`1WIfL302d];GP00000203oool000H0ooooD000000;00410@<00P820P030`<300D51@<0
2PX:0`0>3Ph201<C4`<071`L0`0R8R8302PX:080<S8b0`0o?cl304];B`<0E5AD0P1QHF4306i^KP<0
MgMg0P1lO7`307emO@<0Ng]k0`1eMGD206e]K@<0IfMW0`0];Beh000000P0oooo00060?oooe000000
2`010@4300820P800`<30`051@D300X:2P<03Ph>0P0C4a<301`L70<08R8R0`0X:2P2038b<P<0?clo
0`1;Bd/305ADE080HF5Q0`1^KVh307MgM`80O7al0`1mOGd307]kN`<0MGEe0P1]KFd306MWI`<0;Bd]
N00000080?ooo`001P3ooom@000000D00@411P00000300@410802@T90`0;2`/300l?3`<051@D0P0J
6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd305UIF@80IfMW0`1bLW8307QhN080NGUi0`1h
N7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N00000080?ooo`001P3ooom@000000D00@411P000003
00@410802@T90`0;2`/300l?3`<051@D0P0J6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd3
05UIF@80IfMW0`1bLW8307QhN080NGUi0`1hN7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N0000008
0?ooo`001P3ooom8000000800@410`00000300410@<00`<31@020P8300@410<02PX:0P0<30`3014A
4@<05QHF0`0I6AT201hN7P<08b<S0`0[:b/3034a<@80>SXj0`15ADD3059BDP<0G5aL0P1WIfL307If
MP<0MgMg0P1dM7@607MgM`<0KFe]0P1KFe/301XJ6W/00000203oool000H0ooooB000000200410@<0
00000`010@4300<30`D00P820`0410@300X:2P8030`<0`0A4A4301HF5P<06ATI0P0N7Qh302<S8`<0
:b/[0`0a<C4203Xj>P<0ADE50`1BDU8305aLG080IfMW0`1fMWH307MgM`80M7Ad1P1gMgL306e]K@80
Fe]K0`0J6QYk000000P0oooo00060?ooodP000000P010@43000000<00@410`030`<500820P<010@4
0`0:2PX200`<30<04A4A0`0F5QH301TI6@807QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B
0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3o
oom5000000<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M
7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_
Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P83
00410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh3
03@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh2
03Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`030`<300L7
1`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJ
FP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?oo
o`001P3ooolo000000H00@411@020P8300<30`<00P820`010@4200820P<01PH60`0:2PX300`<3080
410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080
KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?0P0>3Pin000000P0oooo00060?ooocl00000
1P010@4500820P<00`<30`020P8300410@800P820`061PH300X:2P<030`<0P0@410301HF5P<07AdM
0`0O7al202@T90<0;Rh^0`0b<S8303De=@80@4100`1>CTh305aLG0<0J6QX0P1]KFd306m_K`<0KVi^
0P1[Jf/306UYJ@<0GUiN0`1?Cdl200h>3Wh00000203oool000H0oooo?`00000600410@D00P820`03
0`<300820P<00@410P020P8300H61P<02PX:0`0<30`2010@40<05QHF0`0M7Ad301lO7`8092@T0`0^
;Rh3038b<P<0=CDe0P10@40304i>CP<0G5aL0`1XJ6P206e]K@<0Kfm_0`1^KVh206][J`<0JFUY0`1N
GUh304m?C`803Ph>OP0000080?ooo`001P3ooom2000000<00@4120051@D600<30`801PH60`0820P3
00/;2`<04A4A0P0D51@301LG5`<07AdM0`0P820202<S8`<0;2`/0`0a<C4303`l?080ADE50`1CDe<3
061PH0<0I6AT0P1VIVH306YZJP<0JFUY0P1WIfL305aLG0<0EUIF0`0X:2R0000000P0oooo00060?oo
od8000000`010@4800D51@H00`<30P061PH300P820<02`/;0`0A4A4201@D50<05aLG0`0M7Ad3020P
80808b<S0`0/;2`3034a<@<0?3`l0P15ADD305=CD`<0H61P0`1TI6@206IVIP<0JVYZ0`1YJFT206MW
I`<0G5aL0`1FEUH302PX:8000000203oool000H0oooo?`00000300410@<00P820`051@D200H61P<0
1@D50`061PH300T92@8020P80`0<30`6010@40804a<C0`0F5QH301dM7@<08R8R0P0T92@302TY:@<0
<30`0`0k>c/204Q8B0<0De=C0`1KFe/306=SH`80IVIV0`1TI6@3065QH@80GUiN0`1EEED30451@@<0
1`L7P00000080?ooo`001P3ooolo000000<00@410`020P8300D51@801PH60`051@D300H61P<02@T9
0P0820P300`<30H0410@0P0C4a<301HF5P<07AdM0`0R8R8202@T90<0:BTY0`0`<30303/k>`80B4Q8
0`1CDe<305]KF`<0Hf=S0P1VIVH306ATI0<0HF5Q0P1NGUh305EEE@<0@D510`071`N0000000P0oooo
00060?ooocl000000`010@4300820P<01@D50P061PH300D51@<01PH60`092@T200P820<030`<1P0@
410201<C4`<05QHF0`0M7Ad3028R8P8092@T0`0Y:BT3030`<0<0>c/k0P18B4P305=CD`<0Fe]K0`1S
Hf<206IVIP<0I6AT0`1QHF4205iNGP<0EEEE0`11@D4300L71h000000203oool000H0oooo?`000003
00<30`<01@D50`061PH200T92@T02PX:1@0>3Ph3010@40<04A4A0P0B4Q8301LG5`<071`L0`0N7Qh2
028R8P<0:2PX0`0a<C4303hn?P80B4Q80`1FEUH305UIF@D0G5aL1P1IFET205=CD`<0B4Q80`0H61R3
000000P0oooo00060?ooocl000000`030`<300D51@<01PH60P092@T900X:2PD03Ph>0`0@4103014A
4@804Q8B0`0G5aL301`L70<07QhN0P0R8R8302PX:0<0<C4a0`0n?Sh204Q8B0<0EUIF0`1IFET505aL
G0H0FEUI0P1CDe<304Q8B0<061PHP`0000080?ooo`001P3ooolo000000<00`<30`051@D300H61P80
2@T92@0:2PX500h>3P<0410@0`0A4A42018B4P<05aLG0`0L71`301hN7P808R8R0`0X:2P3034a<@<0
?Shn0P18B4P305IFEP<0FEUI1@1LG5`605UIF@80De=C0`18B4P301PH68<00000203oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
010101010515191513111012131211141A222625221C1308
000000000007070000000001010000000000010301010302
0206090C0C08030205040100000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020202071D231B151010131716141A263C4B4E493E2D19
030000000009090000000003020000000000030501000201
01070A0D0D08030308050000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01010203072029221D19191916120D131D2D363837352A1C
0C000000000A0C0200000000000000020000010300000000
0001040C110E070407070401000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01010102061D2726272629271E18111216171715191F1C19
15080000060F0D0600000000000202020000000200000000
0000000E16140C0605080904000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010102072226242C2E36342B2622231F0F0A0B0F181615
140D0A0C1A2A282319100705030302000000020601020100
0000061116130A0300060A05010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010102061D252A31333C3E342E27262218130F131B1714
110600000C1B1C1E1C181212141514100400000400020100
0000000E15130B0504070904010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010203050F1B2B353842443931262322221C141A241F1F
1D0F0301080C0A0C0A09080F18202320180E080802030400
0000001016120A0706050502000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0102030407091425343742463C352E2F2E313235414F423B
2A11070912191E25210F00000006101516130D0D05090600
000000010A0B040306030100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0101020406050D1E2F313A3E353332372F27262D3A4C403B
270E09101A2534494829030000000C161711080B050D0A00
000000000306000004020100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010102050808122127343A34322E2E24191B242C362D2A
1E131417222E31383425130907090D0B080D0F100A0E0700
000000000003000000000200000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020304070A0B0E1319273233322E302F43657E87897461
3F2A282A323C3C39372C1E19140D0A070811141209090100
000000000000000003000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
020203040913130700010E202D32343F4065A2CACFC5A37E
432A30343E555B5D6559463626130903020C10120A090100
000000000000000006020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
010101020616070000000A1B293033393344759796866D52
2B2A3C3D4A62605A5F616059492E1D0B000C18150E0A0000
000508000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001000000040F171D242A291C04060D0B070C12
1A354D4B4C4F4A4F50545A5751443C2B1513141214110E12
13151E160400000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000040B0F151A201F1706050908050B14
1D344846433E393C3B3D42403D3633291C1A19181C181416
131219140700000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000710141716100A0B12110D090F15
1F36433D3835323C4961798287796D583C2D1D1819110B14
161616120501040400000302010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000030D0E0F0B0404141B131012171B
243137322F2E3B5A7595ABB7C7C5BEAA805A2F1F1B0F0715
1E19140F0100020500000001020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000004000000010A0E06030000051813060A171B21
292A2C2D32344A6B7F9098A5C1D6E1DBB2864F3223140712
1F1A1A150200000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000010000000A0B0E09000000000E150000001B202B
312528343F42648B8E7A5C5875A8CDE0C69C63422E211110
1C141A150200000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000050404020005131E1B0B0000081C1E27
2625394A576487ADAC865534385A798E897D6359504A3016
130706000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000013060000000810191E201503000D231B090C13
265575758191784F3F5B818C815D452F366E9B9E987D4615
0002040000070D02000C1C11050000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010000020E1C1A1716170E0F130A151A1B2439
56768E949B96876242475968757D868B9CC5D7CCBD9A5D27
09081007060D0C010004120A020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000181C231D11141E2323200F1E37576179
858698AAADA1B6C7B084563F4C779EBBCBCEB9B0A18D5A26
10000000040D090000010C05010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000F0F000004181B1415140F08183C637681868F
939DADB4B9BAB098818084868276706A7391A39E8D703707
00000000000C0F02000B1D10040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000030100122F39372F1E0B114372909A97989E
A7B9BDB2A58A622F194077A5B39E89737B9AA49888633313
00000000050E120B000A140A020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000010E12243A423F35231431728F979F9A9A9F
AABABBAD9D785528153D78B4D8DBD7CAC1BFAA8F7D54342D
1E212E33210F0D0B00000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000051F231F201F1E1E1F222746717A7B8387939C
A7B2BCBBA784817970758299B3CAD6DDCAA0786C664B3F46
3C3C454A3C22170E07050200000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000015312B1F1A0D0408101E2C4A5A4F4445476274
8EAAC0BFA8868A8D8989919EB1C7D2D7B06D433F432F3958
575B6C6F572F1E1007050301000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000223B37312C1B0B040C1C314E442A1822345A76
97ADC2C5B08F9DB3AC9A8D8FA3C6DAE3AA49130D11062053
60637C8668361D0D03000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002E4037322E221309101F3347341C0E1A31556E
8A9BAFB3A895A8C7C5B19D98A7C5D6DA9A3A060001001243
55586F795E321A0A00000302000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000644503C312C2D292020232F4045453F44505D60
676A72757C8899ACB4B6B4B9C5D0D1C88B47221911040B26
373D4B534228170A00060B06020000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01010102117D7F4A2E1E18151515182E527889857A6E6244
2F242A35558CA29CA6AFB6BEC7CBC6C58A594A3F2C16121F
3046555241281408030B0D06010000000000000000000000
00000000
000000000000000000000000000000000000000000000102
030303041BA0914A2E1E1A1618171934679CB7B9A9917341
170309194EA0B496959AA2AFB9BDB9BF86676A5435190D14
284C655B4020090000040501000000000000000000000000
00000000
000000000000000000000000000000000000000000000203
0404060823B7A05543383C352C231D3970A8C9D6D0C09B64
320D0B1F62BFCB967F77788B969FA0AC7C6F84683B1A0500
133B5F594223060000010701000000000000000000000000
00000000
000000000000000000000000000000000000000000000102
030406081B99A47A767D9287685139406E9FC1D2E3EDE1CB
BC9D8A90B8E1C67442445F8FA5ABA4A381799581562E1103
08234B656348260C00101E0D000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
010202030B5E7D635C64716146321F224E86A6B9D0E0EBED
F7E8D8D8DDD2AE5D262C4E839DA7A4A7988B998D6D42261B
1325445F644C30130314200F000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010102065284716B707B6E57473A3C55768EA1B6C6D5DE
EFE8DEDEDDD0AE6735334A6D797A747575728E9785634327
11182C4D655B401D0D243019030000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020308537F77838FA59E84776C6E6E697891ACC6D2E1
EEE9EAEDF7F7DAA5715C5A6767645F5A565D8294846C4920
09071D425E5B3D1A0A24351C050000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000010570BD9F8E838676554A4753535460728FB8D5E8
FDE9DEE8EEF3F6E8CEB6A097929690917E5662847C6A4B28
160C0B39717C5C2A173E512C0B0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000064BA98796A6B5F443D3D45383442506488AFC8
E9E4DCE2DEDEE5E9E3E1DAD0C5B8A49679494C777A6A4D2F
1D0D002B687E65311B475B330E0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000050A6A7A09BACB1A39D9A9A806C6C6F788C9EAF
C6CED2D0D0D5D2D8D8DAD9CFC5B39D856A4C558690886E46
270F093B6D79603424454F2C0D0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000051B2C0BCB7C7D1CCC9C9CCB0948B86858C96A3
B6C6D2CCCBCFC5C5C5C5C7BCAF977F674E3548859997865F
361E1C558486673B304B4E2B0D0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000062D9CCA68C82858B8D95A69CA3ACAA9F98A3A1
A9AEAFACA0A2A19BA6AAAD9D87694B3D300B206D8A888365
3B2A1A4F8D957744405C58300E0000000000000000000000
00000000
000000000000000000000000000000000000000000000001
02030303012FABCDBEA8A2AFB6B3B3C0C2E7EBDDD6D1C2B2
9F86787260535963766D6157565752555B34296981868968
391B08447E7E62414A4F3A1C080000000000000000000000
00000000
000000000000000000000000000000000000000000000102
03030405041D83BDD1CED4E3ECEBEEFBF9F9E9DFDCD8C5BD
ACA4ABA49680746C6240271B1A232B323C282D667E889273
42262F6B8B724E354039220F040000000000000000000000
00000000
000000000000000000000000000000000000000000000001
02020203043387ACB0AFBDD4E2E3E2E8DBD7D4C8B8A69386
7A8693878283736E767B84837D68553F2D1A24576F747B67
412E34657A664A3336382714060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0101020306255794BDCCE2F0F0ECE7E7E5C28B685F5B535E
6F8BA2979B948078685F6574899BA69E7D625B6F79767D73
55446998885632231F170B04010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000001020A256CAFC9E4EDE6E7EAE9D57F2B090C1B2144
6894BEB9C1B7A9B3957159536587A3A1816D66737D80806F
543C6990774521150C050201010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000054687A5C7DAE1E9F3EFC968281815171735
518EC8C2C9C4B0B89F816E5D5D6471624B546175858B8267
4630576F542F160F07040202020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000255C81AFD0E5EEF1E6C5866B695A422F38
4288C8BAC4C8A2907E8399A0A08A825F43647B828C86755D
3D345D643913040901000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000400000B335485B2D7E6ECE7CCB3C4D8C3996E59
3D79BCB1C2D9BBABA9B5CCCFC6A08D65487188878C816A51
353554481700000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000013264472A6BFD3D7BEBBDCFBE3B2876D
457BC0B8B3B6A5A5B2B6BDAC986F5E413B616E80938E7C5F
39323A270700000810030000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000020916346582A2B5A6A1BCE1CFA58269
3F6AB1B6B8C3C3C2C3A9916B503837323B60758897927C58
34333A1E060000010B020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000002010002000000162E4F6C73737A9695867467
4857899EA3ADC2C5B77F4618091A365367777E878A826945
2B2B32190D03000005000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000003130C0000000000020A18284265778F8F7F6D5D
464A626F7881815C41281A16182538516986968E81694926
121D28150B02000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000004000000000004080D122A5765706B584C42
39424F545149401C0B0B16232D353F5069848C878067482A
11171A0E0A06050305040000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000005090200000006080B0F27636F7068564332
20191A1E1912190D11151B24334351647E8A7C7A75634829
110D0200020407080F0A0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000090A0100000007090B102868797C73604A35
1F15151A17151D12181E242C3A4753657E8B7E7C76644726
0F0B0000000307080F0B0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000B0B0100000006060609205F72777264513E
291C181C1A18211921282E3746545E6D818978736B583C1E
0B070000000307080D0A0200000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000001020C0900000001070400001A618089887F6A53
38241B1D1E1F261D25313C4D5F6A707A83846E60523D2410
060500000000020408050000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001010102040C080000000408040000165E848F928C7760
432C2020202027222D3C495B6C74767A7A71564636231107
040500000000000306020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0101010103070C06000000040704000017567D898D8A7861
422B202121232E33414E566473797A7A705E3E2C1E0F0303
070800000000000104000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001010103080B050000000307070306195077848886755F
402B2424242735425561656D797B7A76644926160A000003
0B0C05000000000003000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000001020A1006000000000709080D194771818481745F
42312E2D2B2D3C50677375787C7770674F2F0E0300000004
0E0F06000000000204000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000002141502000000020A0E0E121435657B7C756A56
3C363A38384249556B7C8686816B58452A15040000000000
080D05000000000201030302010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000116150000000000090F11140E245773756E6757
40414A494954555B6B7A838072543C240D04010100000000
020700000000010100050905020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000012100000000000030A0F140C1644656D6E6B61
4D4C57585860636A71716C5F4E3524130300000100000000
000100000000010000040A06020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000C0C000000000201050A0F05062A4958626665
5A58616461616268665D514435251A0F0300000100000000
000000000001020000020A06010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000809000000020301060B0F04001935434D565B
585C6768645E5C5F594F45392B1C13080000000200000000
000000000005050000020B06010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000607000000000101080F14090016303C444D52
50586668635D5A5D564A3F3122140C030000000304030001
020305000105040000020906010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000040000000000000711180D001129353F4951
505766696157585F59483624150C08030000000104060406
050405010407050000020805010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000100000000000009141D12010E232D363F46
444C5E625C5458605A452E1A0B0504030000000206080809
080709040405030000010503010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001020000000000010A151F190F223B474F5355
4B4C5C625D575C625B412611030001020000000304060606
060608030202000000000201000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000200000104030208111C1A1A36556875797A
6C646E746B5D5F6255371906000000030600000200010102
020103010303000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000010001060805030810191814294457666C70
67616B706859595A4A2C1000000000040600000200000102
020206050604000000000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000003000001080B0704081019180F203A4D5A6167
61606D726D625E5742240B00000000010200070703010001
02050F0D0904000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000003000000080D0805080D14150F233E505B646B
6A6D797C756558452A1305010000000000000C0A05000001
010715120D05000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000A100D0A0B0D1114132A44555E676F
6F747E7D725D4A32170601040000000000000C0A06000002
010714140E06010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000010D1513111111121619324B5B61686F
6F747C786B523C21080000070300000000000B0906000004
000612130E06010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000510181817171615181F384E5D636970
6F73777261422C1601000007050000000000050504000107
02040D110E07040100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000040812191C1C1B19181A27405461676A6F
6B6B6C6551301D0D00000005050000000000000002000309
0301060C0D07050404000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000100000000070B13191D1F1E1C1A1D2D46566368696C
6663615A442111080000000304000000030000000000050B
040001090C07060607020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000101010000000C0E13181D201F1C1B1E334B5964686667
5D57534C371709030000000204010000050000000000060B
040000070C0807070A040000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00010101000000101014181E201E1B1A1E354D596366625F
5349433D2B10050100000002030100000500000000000509
030000050B0807080B050000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01010101000005131214181D1F1D191A1F374E5960615B54
4639312C1F0B030000000001030100000500000000000307
020000040A0807070B050000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooom2000000/00@410`051@D301DE5@806ATI0`0E5AD301<C4`<0
4A4A0P0@4103018B4P<04a<C0`0B4Q82014A4@<051@D0`0J6QX3028R8P809RHV0`0U9BD3028R8P<0
71`L0P0C4a<300P820h000001@071`L;000000H00@413@00000300410@<00`<31@010@4300<30`H0
0P820P061PH300T92@D030`<0`0820P300<30`<00P820P051@D300@410<00@41;P0000080?ooo`00
1P3ooom2000000/00@410`051@D301DE5@806ATI0`0E5AD301<C4`<04A4A0P0@4103018B4P<04a<C
0`0B4Q82014A4@<051@D0`0J6QX3028R8P809RHV0`0U9BD3028R8P<071`L0P0C4a<300P820h00000
1@071`L;000000H00@413@00000300410@<00`<31@010@4300<30`H00P820P061PH300T92@D030`<
0`0820P300<30`<00P820P051@D300@410<00@41;P0000080?ooo`001P3ooolo000000H00@412002
0P8300L71`<07AdM0P0S8b<301/K6`<05ADE1@0@410301<C4`<05aLG0`0F5QH201@D50<06QXJ0`0V
9RH303`l?080Bd];0`1>CTh304U9B@<0?Shn0P0];Bd301TI6@<00`<32`00000500T92@/000000`03
0`<300820Pd000000`030`<300D51@<00@410P00000300820PH00@410P071`L300X:2PD03@d=0`08
20P600<30`8020P80`051@Da000000P0oooo00060?ooocl000001P010@4800820P<01`L70`0M7Ad2
02<S8`<06a/K0`0E5AD5010@40<04a<C0`0G5aL301HF5P8051@D0`0J6QX302HV9P<0?3`l0P1;Bd/3
04i>CP<0BDU90`0n?Sh202d];@<06ATI0`030`<;000000D02@T92`00000300<30`<00P823@000003
00<30`<01@D50`010@42000000<00P821P010@4200L71`<02PX:1@0=3@d300P820H00`<30P0820P3
00D51C400000203oool000H0oooo?`00000600410@P00P820`071`L301dM7@808b<S0`0K6a/301DE
5@D0410@0`0C4a<301LG5`<05QHF0P0D51@301XJ6P<09RHV0`0l?3`204];B`<0CTi>0`19BDT303hn
?P80;Bd]0`0I6AT300<30`/000001@092@T;000000<00`<30`020P8=000000<00`<30`051@D30041
0@8000000`020P8600410@801`L70`0:2PX500d=3@<020P81P030`<200P820<01@D5<@0000080?oo
o`001P3ooolo000000T00@410P020P8300<30`<01`L70`0P820202TY:@<08R8R0`0M7Ad801TI6@<0
5QHF0`0B4Q8200d=3@<04a<C0`0M7Ad302d];@80=SHf0`0h>3P303Lg=`<0=CDe0P0Z:RX301`L70<0
30`<2`00000200X:2P<030`<0`020P8C000000<00P821@00000300410@<00`<33P00000200410@<0
10@40`0<30`2014A4@<03Ph>0`071`L300@410D01`L70`0410@300410B/00000203oool000H0oooo
?`00000900410@800P820`030`<300L71`<0820P0P0Y:BT3028R8P<07AdM200I6AT301HF5P<04Q8B
0P0=3@d301<C4`<07AdM0`0];Bd203Hf=P<0>3Ph0`0g=cL303De=@80:RXZ0`0L71`300`<30/00000
0P0:2PX300`<30<00P824`00000300820PD000000`010@4300<30`h000000P010@4300@410<030`<
0P0A4A4300h>3P<01`L70`0410@500L71`<010@40`010@4[000000P0oooo00060?ooocl000002@01
0@4200820P<00`<30`071`L3020P8080:BTY0`0R8R8301dM7@P06ATI0`0F5QH3018B4P803@d=0`0C
4a<301dM7@<0;Bd]0P0f=SH303Ph>0<0=cLg0`0e=CD202XZ:P<071`L0`0<30`;000000802PX:0`0<
30`300820Q<000000`020P85000000<00@410`030`<>000000800@410`0410@300`<30804A4A0`0>
3Ph300L71`<010@41@071`L300@410<00@41:`0000080?ooo`001P3ooom2000000P00@410`020P83
00H61P<07AdM0P0W9bL302HV9P<09bLW0`0V9RH202TY:@<09bLW0`0N7Qh301PH60804A4A0`0B4Q83
01HF5PD05aLG0`0E5AD301TI6@<07alO0P0L71`301TI6@<05ADE0P0820P6000000<01PH60P0?3`l3
00d=3@<01PH63P00000800820PP000000`020P8C000000<03Ph>0P0F5QH301@D50<030`<0`061PH2
00D51@<020P80`092@T300@412/00000203oool000H0oooo@P00000800410@<00P820`061PH301dM
7@809bLW0`0V9RH302LW9`<09RHV0P0Y:BT302LW9`<07QhN0`0H61P2014A4@<04Q8B0`0F5QH501LG
5`<05ADE0`0I6AT301lO7`8071`L0`0I6AT301DE5@8020P81P00000300H61P803`l?0`0=3@d300H6
1Ph0000020020P88000000<00P824`00000300h>3P805QHF0`0D51@300`<30<01PH60P051@D300P8
20<02@T90`0410@[000000P0oooo00060?ooodD000001@010@4300820P<01`L70`0R8R8202HV9P<0
92@T0`0/;2`302h^;P80=SHf0`0d=3@302/[:`<09RHV0P0R8R8302<S8`<07alO0`0?3`l200X:2P<0
2`/;0`0?3`l301PH60805QHF0`0E5AD301@D50803@d=0`0:2PX300`<30<06QXJ0P0Z:RX302PX:0<0
8b<S0`0I6AT2010@40<01`L70`051@D500<30`<00P822000000300820P<01PH60`010@4200820P<0
0@412000000300H61P<04A4A0P0F5QH301<C4`<02PX:0`030`<2000000<01PH60`0:2PX300D51@80
0@41:@0000080?ooo`001P3ooom5000000D00@410`020P8300L71`<08R8R0P0V9RH302@T90<0;2`/
0`0^;Rh203Hf=P<0=3@d0`0[:b/302HV9P808R8R0`0S8b<301lO7`<03`l?0P0:2PX300/;2`<03`l?
0`0H61P201HF5P<05ADE0`0D51@200d=3@<02PX:0`0<30`301XJ6P80:RXZ0`0X:2P302<S8`<06ATI
0P0@410300L71`<01@D51@030`<300820PP000000`020P8300H61P<00@410P020P8300410@P00000
0`061PH3014A4@805QHF0`0C4a<300X:2P<00`<30P00000300H61P<02PX:0`051@D200410BT00000
203oool000H0ooooA@00000500410@<00P820`071`L3028R8P809RHV0`0T92@302`/;0<0;Rh^0P0f
=SH303@d=0<0:b/[0`0V9RH2028R8P<08b<S0`0O7al300l?3`802PX:0`0;2`/300l?3`<061PH0P0F
5QH301DE5@<051@D0P0=3@d300X:2P<030`<0`0J6QX202XZ:P<0:2PX0`0S8b<301TI6@80410@0`07
1`L300D51@D00`<30`020P88000000<00P820`061PH300410@800P820`010@48000000<01PH60`0A
4A4201HF5P<04a<C0`0:2PX300<30`8000000`061PH300X:2P<01@D50P010@4Y000000P0oooo0006
0?ooodD000001@010@4300820P<01PH60`0M7Ad202DU9@<0:RXZ0`0a<C4303<c<`80?3`l0`0n?Sh3
03@d=0<0;Rh^0P0W9bL302HV9P<08R8R0`0H61P201<C4`<03`l?0`0C4a<301/K6`805aLG0`0D51@3
014A4@801PH61P00000300`<30806a/K0`0L71`301hN7P<071`L0P0H61P6018B4P<051@D0P0E5AD3
01@D50<0410@0`0410@5000000<010@40`00000200820P<00@412`00000300h>3P805ADE0`0C4a<3
00/;2`<01@D50P0410@300L71`<02@T90`0410@200410BT00000203oool000H0ooooA@0000050041
0@<00P820`061PH301dM7@809BDU0`0Z:RX3034a<@<0<c<c0P0l?3`303hn?P<0=3@d0`0^;Rh202LW
9`<09RHV0`0R8R8301PH60804a<C0`0?3`l301<C4`<06a/K0P0G5aL301@D50<04A4A0P061PH60000
00<030`<0P0K6a/301`L70<07QhN0`0L71`201PH60H04Q8B0`0D51@201DE5@<051@D0`0@410300@4
10D000000`0410@3000000800P820`010@4;000000<03Ph>0P0E5AD301<C4`<02`/;0`051@D200@4
10<01`L70`092@T300@410800@41:@0000080?ooo`001P3ooom5000000D00@410`020P8300H61P<0
7AdM0P0U9BD302XZ:P<0<C4a0`0c<c<203`l?0<0?Shn0`0d=3@302h^;P809bLW0`0V9RH3028R8P<0
61PH0P0C4a<300l?3`<04a<C0`0K6a/201LG5`<051@D0`0A4A4200H61PH000000`0<30`201/K6`<0
71`L0`0N7Qh301`L708061PH1P0B4Q8301@D50805ADE0`0D51@3010@40<010@41@00000300@410<0
00000P020P8300410@/000000`0>3Ph201DE5@<04a<C0`0;2`/300D51@8010@40`071`L300T92@<0
10@40P010@4Y000000P0oooo00060?ooodD000000`010@4200820P<00`<30`051@D300l?3`806a/K
0`0[:b/303De=@<0>3Ph0P12@T8304A4A0<0>CTi0`0a<C4202HV9P<08b<S1P0R8R8201`L70<051@D
0`0J6QX302@T90D07alO0`0M7Ad200l?3`<00`<30`010@4300P8208030`<0`0:2PX300`<30<02PX:
0P092@T300P820<03`l?0`0H61P2020P80<08b<S0`0P820301PH60803Ph>1P0820P300820P800`<3
0`0410@;000000<0410@0P0F5QH3018B4P<02PX:0`071`L200H61PH01@D50`020P8[000000P0oooo
00060?ooodD000000`010@4200820P<00`<30`051@D300l?3`806a/K0`0[:b/303De=@<0>3Ph0P12
@T8304A4A0<0>CTi0`0a<C4202HV9P<08b<S1P0R8R8201`L70<051@D0`0J6QX302@T90D07alO0`0M
7Ad200l?3`<00`<30`010@4300P8208030`<0`0:2PX300`<30<02PX:0P092@T300P820<03`l?0`0H
61P2020P80<08b<S0`0P820301PH60803Ph>1P0820P300820P800`<30`0410@;000000<0410@0P0F
5QH3018B4P<02PX:0`071`L200H61PH01@D50`020P8[000000P0oooo00060?ooodD000000`010@42
00820P<00`<30`051@D300l?3`806a/K0`0[:b/303De=@<0>3Ph0P12@T8304A4A0<0>CTi0`0a<C42
02HV9P<08b<S1P0R8R8201`L70<051@D0`0J6QX302@T90D07alO0`0M7Ad200l?3`<00`<30`010@43
00P8208030`<0`0:2PX300`<30<02PX:0P092@T300P820<03`l?0`0H61P2020P80<08b<S0`0P8203
01PH60803Ph>1P0820P300820P800`<30`0410@;000000<0410@0P0F5QH3018B4P<02PX:0`071`L2
00H61PH01@D50`020P8[000000P0oooo00060?oood8000000`010@4300820P800`<30`0410@300L7
1`<02@T90P0D51@302DU9@<0=3@d0`0g=cL20492@P<0ATI60`0l?3`303De=@80;Rh^0`0_;bl302h^
;P<0<C4a0P0b<S8303De=@<0@D510`1?Cdl20492@P<0>c/k0`0Z:RX2014A4@<01`L70`092@T3018B
4P806ATI0`0N7Qh302DU9@<08B4Q0P0?3`l9000000801PH60`0@410301DE5@<05QHF0P0C4a<600d=
3@<01@D50P092@T300H61P/000000`010@4200X:2P<02`/;0`0410@300<30`801PH60`030`<30041
0Bh00000203oool000H0oooo@P00000300410@<00P820P030`<300@410<01`L70`092@T201@D50<0
9BDU0`0d=3@303Lg=`80@T920`16ATH303`l?0<0=CDe0P0^;Rh302l_;`<0;Rh^0`0a<C42038b<P<0
=CDe0`11@D4304m?C`80@T920`0k>c/302XZ:P804A4A0`071`L300T92@<04Q8B0P0I6AT301hN7P<0
9BDU0`0Q8B4200l?3`T000000P061PH3010@40<05ADE0`0F5QH201<C4`H03@d=0`051@D200T92@<0
1PH62`00000300410@802PX:0`0;2`/300@410<00`<30P061PH300<30`<00@41;P0000080?ooo`00
1P3ooom2000000H00@410P020P8300@410<01PH60`051@D200d=3@<07QhN0`0_;bl3034a<@80>SXj
0`0n?Sh303De=@<0<c<c0P0b<S8303Lg=`<0;bl_0`0W9bL202HV9P<0;Bd]0`0j>SX304a<C080@410
0`0k>c/302LW9`803Ph>0`092@T3010@40<06QXJ0P0U9BD303@d=0<0BDU90`18B4P202TY:@<00`<3
2000000300`<30<05QHF0`0G5aL2014A4@<020P80`0;2`/300D51@803@d=0`0:2PX>000000800`<3
0`061PH60000008010@40`020P8300410Bh00000203oool000H0oooo@P00000600410@800P820`04
10@300H61P<01@D50P0=3@d301hN7P<0;bl_0`0a<C4203Xj>P<0?Shn0`0e=CD303<c<`80<S8b0`0g
=cL302l_;`<09bLW0P0V9RH302d];@<0>SXj0`1<C4`20410@0<0>c/k0`0W9bL200h>3P<02@T90`0@
410301XJ6P809BDU0`0d=3@304U9B@<0B4Q80P0Y:BT300<30`P000000`0<30`301HF5P<05aLG0P0A
4A4300P820<02`/;0`051@D200d=3@<02PX:3P00000200<30`<01PH61P00000200@410<00P820`01
0@4^000000P0oooo00060?oood8000001P010@4200820P<010@40`061PH300D51@803@d=0`0N7Qh3
02l_;`<0<C4a0P0j>SX303hn?P<0=CDe0`0c<c<2038b<P<0=cLg0`0_;bl302LW9`809RHV0`0];Bd3
03Xj>P<0C4a<0P10@40303/k>`<09bLW0P0>3Ph300T92@<0410@0`0J6QX202DU9@<0=3@d0`19BDT3
04Q8B080:BTY0`030`<8000000<030`<0`0F5QH301LG5`804A4A0`0820P300/;2`<01@D50P0=3@d3
00X:2Ph000000P030`<300H61PH000000P0410@300820P<00@41;P0000080?ooo`001P3ooom50000
00D00@410`020P8300D51@D020P80`0B4Q83024Q8@<09bLW0P0d=3@303Xj>P<0=3@d0`0b<S8502h^
;P<092@T0`0I6AT201/K6`<092@T0`0/;2`303Hf=P80;Bd]0`0Z:RX301hN7P804a<C0`0D51@301LG
5`<08R8R0P0^;Rh3034a<@<0>3Ph0`0d=3@202DU9@<04a<C0`092@T300L71`802@T90`0=3@d300/;
2`<020P80P0=3@d300l?3`<0410@0`0:2PX200h>3P<01`L74000000300<30`/000000`020P8^0000
00P0oooo00060?ooodD000001@010@4300820P<01@D51@0820P3018B4P<08B4Q0`0W9bL203@d=0<0
>SXj0`0d=3@3038b<PD0;Rh^0`0T92@301TI6@806a/K0`0T92@302`/;0<0=SHf0P0];Bd302XZ:P<0
7QhN0P0C4a<301@D50<05aLG0`0R8R8202h^;P<0<C4a0`0h>3P303@d=0809BDU0`0C4a<300T92@<0
1`L70P092@T300d=3@<02`/;0`0820P200d=3@<03`l?0`0@410300X:2P803Ph>0`071`L@000000<0
0`<32`00000300820Rh00000203oool000H0ooooA@00000500410@<00P820`051@D500P820<04Q8B
0`0Q8B4302LW9`80=3@d0`0j>SX303@d=0<0<S8b1@0^;Rh302@T90<06ATI0P0K6a/302@T90<0;2`/
0`0f=SH202d];@<0:RXZ0`0N7Qh201<C4`<051@D0`0G5aL3028R8P80;Rh^0`0a<C4303Ph>0<0=3@d
0P0U9BD301<C4`<02@T90`071`L200T92@<03@d=0`0;2`/300P820803@d=0`0?3`l3010@40<02PX:
0P0>3Ph300L71a0000000`030`<;000000<00P82;P0000080?ooo`001P3ooolo000000H00@410`02
0P8200<30`<010@40`071`L300X:2P802`/;0`0>3Ph301<C4`<06ATI0P0W9bL3038b<P<0<c<c0`0b
<S8202h^;P<0<30`0`0_;bl304=3@`80IFEU0`1nOWh308N7Q`<0RHV90P1dM7@3065QH@<0?clo0P0Z
:RX302PX:0<0:RXZ0`0b<S8503`l?0<0>CTi0`0g=cL202`/;0<07QhN0`0I6AT301@D50803@d=0`0:
2PX300L71`<020P80P0A4A4301@D50<04Q8B1@092@T300410AT000000P030`<d000000P0oooo0006
0?ooocl000001P010@4300820P800`<30`0410@300L71`<02PX:0P0;2`/300h>3P<04a<C0`0I6AT2
02LW9`<0<S8b0`0c<c<3038b<P80;Rh^0`0`<30302l_;`<0@d=30P1UIFD307inOP<0QhN70`29RHT2
07AdM0<0HF5Q0`0o?cl202XZ:P<0:2PX0`0Z:RX3038b<PD0?3`l0`0i>CT303Lg=`80;2`/0`0N7Qh3
01TI6@<051@D0P0=3@d300X:2P<01`L70`0820P2014A4@<051@D0`0B4Q8500T92@<00@416@000002
00<30c@00000203oool000H0oooo?`00000300410@H00P820P030`<300@410<02@T91@0C4a<300L7
1`<000000`010@4200h>3P<0820P0`0];Bd3038b<P80=3@d0`0o?cl30410@0<0IFEU0P2RXZ830<[:
bP<0clo?0`35aLD20:>SX`<0OWin0`13@d<202XZ:P<0<30`0`0d=3@303hn?P80EEEE0`1KFe/305eM
G@<0IFEU0P1IFET304I6AP<0=SHf0`0V9RH201<C4`<02@T90`030`<300820P8030`<0`0@4103018B
4P<02PX:0P092@T300410AT000000P061PH300820S400000203oool000H0oooo?`00000300410@H0
0P820P030`<300@410<02@T91@0C4a<300L71`<000000`010@4200h>3P<0820P0`0];Bd3038b<P80
=3@d0`0o?cl30410@0<0IFEU0P2RXZ830<[:bP<0clo?0`35aLD20:>SX`<0OWin0`13@d<202XZ:P<0
<30`0`0d=3@303hn?P80EEEE0`1KFe/305eMG@<0IFEU0P1IFET304I6AP<0=SHf0`0V9RH201<C4`<0
2@T90`030`<300820P8030`<0`0@4103018B4P<02PX:0P092@T300410AT000000P061PH300820S40
0000203oool000H0oooo?`00000300410@H00P820P030`<300@410<02@T91@0C4a<300L71`<00000
0`010@4200h>3P<0820P0`0];Bd3038b<P80=3@d0`0o?cl30410@0<0IFEU0P2RXZ830<[:bP<0clo?
0`35aLD20:>SX`<0OWin0`13@d<202XZ:P<0<30`0`0d=3@303hn?P80EEEE0`1KFe/305eMG@<0IFEU
0P1IFET304I6AP<0=SHf0`0V9RH201<C4`<02@T90`030`<300820P8030`<0`0@4103018B4P<02PX:
0P092@T300410AT000000P061PH300820S400000203oool000H0oooo@P00000800410@<00P820`06
1PH301HF5P801`L72@00000200X:2P<06a/K0`0Y:BT3030`<080<c<c0`0i>CT303<c<`<0A4A40P1e
MGD309NGU`<0UYJF0`26QXH206e]K@<0DU9B0`0[:b/202XZ:P<0?3`l0`0m?Cd304Y:BP80HV9R0`1P
H60305YJFP<0GemO0P1QHF43061PH0<0FEUI0`19BDT202h^;P<07AdM0`0;2`/30000008030`<0`0H
61P301DE5@<03Ph>0P0:2PX9000000801@D50`0820Q4000000P0oooo00060?oood80000020010@43
00820P<01PH60`0F5QH200L71`T000000P0:2PX301/K6`<0:BTY0`0`<30203<c<`<0>CTi0`0c<c<3
04A4A080MGEe0`2GUiL309JFUP<0QXJ60P1]KFd3059BDP<0:b/[0P0Z:RX303`l?0<0?Cdm0`1:BTX2
069RHP<0H61P0`1JFUX305mOG`80HF5Q0`1PH60305UIF@<0BDU90P0^;Rh301dM7@<02`/;0`000002
00`<30<061PH0`0E5AD300h>3P802PX:2@00000200D51@<020P8A00000080?ooo`001P3ooom20000
00P00@410`020P8300H61P<05QHF0P071`L9000000802PX:0`0K6a/302TY:@<0<30`0P0c<c<303Ti
>@<0<c<c0`14A4@207EeM@<0UiNG0`2FUYH308J6QP80KFe]0`1BDU8302/[:`80:RXZ0`0l?3`303dm
?@<0BTY:0P1RHV83061PH0<0FUYJ0`1OGel2065QH@<0H61P0`1IFET304U9B@80;Rh^0`0M7Ad300/;
2`<000000P0<30`301PH60<05ADE0`0>3Ph200X:2PT000000P051@D300P824@00000203oool000H0
ooooD000000300410@P000000`0410@200l?3`<05aLG0`0M7Ad302@T9080:RXZ0`0Y:BT301`L70<0
10@40P061PH300d=3@<02`/;0`071`L200`<30<04Q8B0`0J6QX203De=@<0CDe=0`1;Bd/304a<C080
Cdm?0`1:BTX304m?C`<0D51@0P1DE5@305YJFP<0EeMG0`1ADE4204A4A0<0?3`l0`0[:b/301DE5@80
4a<C0`0D51@3018B4P<051@D0P0A4A4300h>3P<04Q8B0`0C4a<201DE5@<07QhN0`0F5QH200@413l0
0000203oool000H0ooooD000000300410@P000000`0410@200l?3`<05aLG0`0M7Ad302@T9080:RXZ
0`0Y:BT301`L70<010@40P061PH300d=3@<02`/;0`071`L200`<30<04Q8B0`0J6QX203De=@<0CDe=
0`1;Bd/304a<C080Cdm?0`1:BTX304m?C`<0D51@0P1DE5@305YJFP<0EeMG0`1ADE4204A4A0<0?3`l
0`0[:b/301DE5@804a<C0`0D51@3018B4P<051@D0P0A4A4300h>3P<04Q8B0`0C4a<201DE5@<07QhN
0`0F5QH200@413l00000203oool000H0ooooD000000300410@P000000`0410@200l?3`<05aLG0`0M
7Ad302@T9080:RXZ0`0Y:BT301`L70<010@40P061PH300d=3@<02`/;0`071`L200`<30<04Q8B0`0J
6QX203De=@<0CDe=0`1;Bd/304a<C080Cdm?0`1:BTX304m?C`<0D51@0P1DE5@305YJFP<0EeMG0`1A
DE4204A4A0<0?3`l0`0[:b/301DE5@804a<C0`0D51@3018B4P<051@D0P0A4A4300h>3P<04Q8B0`0C
4a<201DE5@<07QhN0`0F5QH200@413l00000203oool000H0ooooF`00000300@410802`/;0`0?3`l3
01DE5@<06QXJ0P0P820301lO7`<05aLG0`061PH200D51@<02@T90`0820P300D51@802`/;0`0D51@3
01dM7@80=3@d0`18B4P304I6AP<0@d=30P0n?Sh303Ti>@<0?3`l0`0k>c/203dm?@<0@T920`10@403
03dm?@80=SHf0`0c<c<302TY:@<071`L0P0J6QX301TI6@<061PH0`0L71`201PH60<051@D0`0F5QH3
01<C4`804Q8B0`0I6AT301@D50801`L7?`0000080?ooo`001P3ooomK000000<010@40P0;2`/300l?
3`<05ADE0`0J6QX2020P80<07alO0`0G5aL300H61P801@D50`092@T300P820<01@D50P0;2`/301@D
50<07AdM0P0d=3@304Q8B0<0ATI60`13@d<203hn?P<0>CTi0`0l?3`303/k>`80?Cdm0`12@T830410
@0<0?Cdm0P0f=SH303<c<`<0:BTY0`0L71`201XJ6P<06ATI0`0H61P301`L708061PH0`0D51@301HF
5P<04a<C0P0B4Q8301TI6@<051@D0P071`Lo000000P0oooo00060?oooeh000000P071`L3010@40<0
51@D0`0G5aL201HF5P<0410@0`0:2PX300/;2`804Q8B0`0A4A4300d=3@<02@T90P0?3`l301DE5@<0
7alO0P0f=SH304=3@`<0?Cdm0`0h>3P203De=@<0<S8b0`0l?3`304U9B@80HF5Q0`1iNGT308:2PP<0
QhN70P1iNGT306e]K@<0F5QH0`0l?3`202d];@<07AdM0`0H61P301TI6@804A4A0`0;2`/301@D50P0
5QHF0`0B4Q8200D51@<00@411P0410@5000000<00`<30`020P8200410BT00000203oool000H0oooo
GP00000200L71`<0410@0`0D51@301LG5`805QHF0`0@410300X:2P<02`/;0P0B4Q83014A4@<03@d=
0`092@T200l?3`<05ADE0`0O7al203Hf=P<0@d=30`0m?Cd303Ph>080=CDe0`0b<S8303`l?0<0BDU9
0P1QHF4307UiN@<0PX:20`27QhL207UiN@<0KFe]0`1HF5P303`l?080;Bd]0`0M7Ad301PH60<06ATI
0P0A4A4300/;2`<051@D200F5QH3018B4P801@D50`010@4600@410D000000`030`<300820P800@41
:@0000080?ooo`001P3ooomN000000801`L70`0@410301@D50<05aLG0P0F5QH3010@40<02PX:0`0;
2`/2018B4P<04A4A0`0=3@d300T92@803`l?0`0E5AD301lO7`80=SHf0`13@d<303dm?@<0>3Ph0P0e
=CD3038b<P<0?3`l0`19BDT2065QH@<0NGUi0`22PX8308N7Q`80NGUi0`1]KFd305QHF0<0?3`l0P0]
;Bd301dM7@<061PH0`0I6AT2014A4@<02`/;0`0D51@801HF5P<04Q8B0P051@D300410@H010@41@00
000300<30`<00P820P010@4Y000000P0oooo00060?oooeh000000P030`<300d=3@<03Ph>0`0?3`l2
00/;2`H010@40`0D51@201/K6`<04a<C0`0@4103018B4P805aLG0`0K6a/302@T9080<C4a0`0g=cL3
038b<P<0;bl_0P0^;Rh303/k>`<0FUYJ0`1eMGD209FEU@<0Zj^[0`2g]kL30<O7a`80aLG50`2n_[h3
0:ZZZP<0P8200P1JFUX302l_;`<07alO0`0K6a/200l?3`<01`L70`0E5AD301hN7P806ATI0`0D51@3
00l?3`800@410`00000300820P<01@D52000000300410@800P82:@0000080?ooo`001P3ooomN0000
00800`<30`0=3@d300h>3P<03`l?0P0;2`/600@410<051@D0P0K6a/301<C4`<0410@0`0B4Q8201LG
5`<06a/K0`0T92@2034a<@<0=cLg0`0b<S8302l_;`80;Rh^0`0k>c/305YJFP<0MGEe0P2EUID30:^[
Z`<0]kNg0`37alL20<G5a@<0_[jn0`2ZZZX30820P080FUYJ0`0_;bl301lO7`<06a/K0P0?3`l300L7
1`<05ADE0`0N7Qh201TI6@<051@D0`0?3`l200410@<000000`020P8300D51@P000000`010@420082
0RT00000203oool000H0ooooGP00000200<30`<03@d=0`0>3Ph300l?3`802`/;1P0410@301@D5080
6a/K0`0C4a<3010@40<04Q8B0P0G5aL301/K6`<092@T0P0a<C4303Lg=`<0<S8b0`0_;bl202h^;P<0
>c/k0`1JFUX307EeM@80UIFE0`2[Zj/30;Ng]`<0alO70P35aLD30;jn_P<0ZZZZ0`20P80205YJFP<0
;bl_0`0O7al301/K6`803`l?0`071`L301DE5@<07QhN0P0I6AT301@D50<03`l?0P010@43000000<0
0P820`051@D8000000<00@410P020P8Y000000P0oooo00060?oooe0000000`0410@8000000<00@41
0P0:2PX300h>3P<01PH60`030`<5000000<01@D50`0H61P201<C4`<01PH60`0:2PX301LG5`806a/K
0`0Q8B4302TY:@80:RXZ0`0/;2`302d];@<0<S8b0P0d=3@304Y:BP<0Jf][0`1oOgl2092@T0<0V9RH
0`2UYJD30<71`@80e]KF0`3QhN430=_Kf`<0/[:b0P26QXH304m?C`<0<S8b0`0S8b<201@D50<01`L7
0`0B4Q8301lO7`D06QXJ0`0E5AD200820Sl00000203oool000H0ooooD000000300@410P000000`01
0@4200X:2P<03Ph>0`061PH300<30`D000000`051@D301PH60804a<C0`061PH300X:2P<05aLG0P0K
6a/3024Q8@<0:BTY0P0Z:RX302`/;0<0;Bd]0`0b<S8203@d=0<0BTY:0`1[Jf/307moO`80T92@0`2H
V9P30:FUY@<0`L710P3Fe]H30>7Qh@<0fm_K0`2b/[8208J6QP<0Cdm?0`0b<S8302<S8`8051@D0`07
1`L3018B4P<07alO1@0J6QX301DE5@800P82?`0000080?ooo`001P3ooom@000000<010@420000003
00410@802PX:0`0>3Ph300H61P<00`<31@00000300D51@<061PH0P0C4a<300H61P<02PX:0`0G5aL2
01/K6`<08B4Q0`0Y:BT202XZ:P<0;2`/0`0];Bd3038b<P80=3@d0`1:BTX306][J`<0Ogmo0P2@T903
09RHV0<0YJFU0`31`L420=KFeP<0hN7Q0`3Kfm/30;:b/P80QXJ60`1?Cdl3038b<P<08b<S0P0D51@3
00L71`<04Q8B0`0O7al501XJ6P<05ADE0P020P8o000000P0oooo00060?ooodd000000`010@480000
00<02PX:0`0;2`/200h>3P<02@T92`00000300h>3P<05ADE2000000301/K6`80820P0`0[:b/3034a
<@809BDU0`0X:2P303@d=0<0?clo0P12@T8306ATI0<0Rh^;0`2>SXh207YjNP<0G5aL0`1HF5P307Ee
M@80Z:RX0`3=cLd30>3Ph0<0a/K60P2LW9`306=SH`<0@T920`0^;Rh2024Q8@<04A4A0`0@410301`L
708051@D0`0J6QX301DE5@800P82?`0000080?ooo`001P3ooom=000000<00@412000000300X:2P<0
2`/;0P0>3Ph300T92@/000000`0>3Ph301DE5@P000000`0K6a/2020P80<0:b/[0`0a<C4202DU9@<0
:2PX0`0d=3@303lo?`80@T920`1TI6@308^;R`<0SXj>0P1jNWX305aLG0<0F5QH0`1eMGD20:RXZ0<0
cLg=0`3Ph>030<K6aP80W9bL0`1SHf<30492@P<0;Rh^0P0Q8B43014A4@<0410@0`0L71`201@D50<0
6QXJ0`0E5AD200820Sl00000203oool000H0ooooF000000300D51@D010@40`020P83000000<01@D5
0P0C4a<301hN7P<06a/K0`0;2`/5000000<020P80`0L71`201hN7P<09bLW0`0V9RH202DU9@<0>CTi
0`1:BTX305MGE`80I6AT0`27QhL30:f][@<0[:b/0P26QXH305EEE@<0=3@d0`0h>3P205YJFP<0NGUi
0`2>SXh308V9R@80OGem0`1SHf<305UIF@<0D51@0P1:BTX3030`<0<05QHF0`0C4a<200L71`<01PH6
A00000080?ooo`001P3ooomH000000<01@D51@0410@300820P<000000`051@D201<C4`<07QhN0`0K
6a/300/;2`D000000`0820P301`L70807QhN0`0W9bL302HV9P809BDU0`0i>CT304Y:BP<0EeMG0P1T
I6@308N7Q`<0[Jf]0`2/[:`208J6QP<0EEEE0`0d=3@303Ph>080FUYJ0`1iNGT308j>SP<0RHV90P1m
OGd306=SH`<0FEUI0`1@D50204Y:BP<0<30`0`0F5QH301<C4`801`L70`061PI4000000P0oooo0006
0?oooeP000000`051@D500@410<00P820`00000300D51@804a<C0`0N7Qh301/K6`<02`/;1@000003
00P820<071`L0P0N7Qh302LW9`<09RHV0P0U9BD303Ti>@<0BTY:0`1GEeL206ATI0<0QhN70`2][Jd3
0:b/[080QXJ60`1EEED303@d=0<0>3Ph0P1JFUX307UiN@<0SXj>0`29RHT207emO@<0Hf=S0`1IFET3
051@D080BTY:0`0`<30301HF5P<04a<C0P071`L300H61T@00000203oool000H0ooooD000000301<C
4`801PH62@00000200P820<0410@0`0I6AT301hN7P80820P0`0E5AD300<30`<000000P0=3@d302<S
8`<06a/K0`092@T200`<30<04a<C0`0V9RH205EEE@H0MGEe0`21PH42096AT@<0N7Qh0`1?Cdl303lo
?`80Fe]K0`21PH4308b<S0<0PH610P1MGEd304E5A@<0;bl_0`0f=SH206i^KP<0Vi^K0`2NWYh309RH
V080OGem0`16ATH301DE5@<000000P020P8300@410D000000`071`L300d=3@<00P820P00000300`<
30<071`L0`0A4A4200D51BT00000203oool000H0ooooD000000301<C4`801PH62@00000200P820<0
410@0`0I6AT301hN7P80820P0`0E5AD300<30`<000000P0=3@d302<S8`<06a/K0`092@T200`<30<0
4a<C0`0V9RH205EEE@H0MGEe0`21PH42096AT@<0N7Qh0`1?Cdl303lo?`80Fe]K0`21PH4308b<S0<0
PH610P1MGEd304E5A@<0;bl_0`0f=SH206i^KP<0Vi^K0`2NWYh309RHV080OGem0`16ATH301DE5@<0
00000P020P8300@410D000000`071`L300d=3@<00P820P00000300`<30<071`L0`0A4A4200D51BT0
0000203oool000H0ooooD000000301<C4`801PH62@00000200P820<0410@0`0I6AT301hN7P80820P
0`0E5AD300<30`<000000P0=3@d302<S8`<06a/K0`092@T200`<30<04a<C0`0V9RH205EEE@H0MGEe
0`21PH42096AT@<0N7Qh0`1?Cdl303lo?`80Fe]K0`21PH4308b<S0<0PH610P1MGEd304E5A@<0;bl_
0`0f=SH206i^KP<0Vi^K0`2NWYh309RHV080OGem0`16ATH301DE5@<000000P020P8300@410D00000
0`071`L300d=3@<00P820P00000300`<30<071`L0`0A4A4200D51BT00000203oool000H0ooooD000
000300410@D000000`020P8300h>3P8071`L0`0J6QX301LG5`<05QHF0P0G5aL300h>3P<03`l?0`0C
4a<200X:2P<05ADE0`0J6QX301/K6`8092@T0`0i>CT305IFEP80MWIf0`2>SXh309BDU0<0Vi^K0P2F
UYH308N7Q`<0HV9R0`12@T8204M7A`<0FEUI0`1XJ6P307EeM@80OGem0`26QXH308^;R`<0W9bL0P35
aLD30=OGe`<0c<c<0`2m_Kd209ZJVP<0GEeM0`0W9bL300T92@8020P80`0@410300L71`801PH60`0=
3@d300`<30<00@410P00000300@410<04Q8B0`0:2PX200820RT00000203oool000H0ooooD0000003
00410@D000000`020P8300h>3P8071`L0`0J6QX301LG5`<05QHF0P0G5aL300h>3P<03`l?0`0C4a<2
00X:2P<05ADE0`0J6QX301/K6`8092@T0`0i>CT305IFEP80MWIf0`2>SXh309BDU0<0Vi^K0P2FUYH3
08N7Q`<0HV9R0`12@T8204M7A`<0FEUI0`1XJ6P307EeM@80OGem0`26QXH308^;R`<0W9bL0P35aLD3
0=OGe`<0c<c<0`2m_Kd209ZJVP<0GEeM0`0W9bL300T92@8020P80`0@410300L71`801PH60`0=3@d3
00`<30<00@410P00000300@410<04Q8B0`0:2PX200820RT00000203oool000H0ooooF000000301PH
60<071`L0P0S8b<301dM7@<04A4A0`0D51@201hN7PH08b<S0`0P820200l?3`<07QhN0`0g=cL305MG
E`80HF5Q0`1iNGT308F5Q@80QXJ60`2HV9P30:ZZZP<0[Jf]0P2QXJ430;Jf]P<0alO70`2`/;0208B4
Q0<0EUIF0`0o?cl304a<C080MgMg0`2NWYh30;^k^`<0bl_;0P3>c/h30;Vi^@<0/;2`0`2QXJ4208f=
S@<0FUYJ0`0V9RH3010@40P000000P0410@300d=3@<02@T91@00000300410@<030`<0`051@D20041
0BT00000203oool000H0ooooF000000301PH60<071`L0P0S8b<301dM7@<04A4A0`0D51@201hN7PH0
8b<S0`0P820200l?3`<07QhN0`0g=cL305MGE`80HF5Q0`1iNGT308F5Q@80QXJ60`2HV9P30:ZZZP<0
[Jf]0P2QXJ430;Jf]P<0alO70`2`/;0208B4Q0<0EUIF0`0o?cl304a<C080MgMg0`2NWYh30;^k^`<0
bl_;0P3>c/h30;Vi^@<0/;2`0`2QXJ4208f=S@<0FUYJ0`0V9RH3010@40P000000P0410@300d=3@<0
2@T91@00000300410@<030`<0`051@D200410BT00000203oool000H0ooooF000000301PH60<071`L
0P0S8b<301dM7@<04A4A0`0D51@201hN7PH08b<S0`0P820200l?3`<07QhN0`0g=cL305MGE`80HF5Q
0`1iNGT308F5Q@80QXJ60`2HV9P30:ZZZP<0[Jf]0P2QXJ430;Jf]P<0alO70`2`/;0208B4Q0<0EUIF
0`0o?cl304a<C080MgMg0`2NWYh30;^k^`<0bl_;0P3>c/h30;Vi^@<0/;2`0`2QXJ4208f=S@<0FUYJ
0`0V9RH3010@40P000000P0410@300d=3@<02@T91@00000300410@<030`<0`051@D200410BT00000
203oool000H0ooooD000000500l?3`H000000`0410@201PH60<06a/K0`0D51@301DE5@8051@D0`0?
3`l300P820<061PH0P0l?3`306=SH`<0MWIf0`21PH4208J6QP<0Shn?0`2CTi<209fMW@<0[Jf]0`2d
];@30;Vi^@80^[Zj0`2`/;0309RHV0<0PH610P20P80308B4Q0<0QXJ60`22PX8207IfMP<0L71`0`1Z
JVX307=cL`80TI6A0`2SXj<309jNWP<0SHf=0P1`L70303Lg=`<01`L73@00000300`<30<03`l?0`02
0P82000000<02`/;0`0M7Ad3010@408010@4:@0000080?ooo`001P3ooom@000000D03`l?1P000003
00@4108061PH0`0K6a/301@D50<05ADE0P0D51@300l?3`<020P80`0H61P203`l?0<0Hf=S0`1fMWH3
0861P@80QXJ60`2?Shl309>CT`80WIfM0`2][Jd30;Bd]0<0^KVi0P2j^[X30;2`/0<0V9RH0`21PH42
0820P0<0Q8B40`26QXH308:2PP80MWIf0`1`L70306YZJP<0Lg=c0P2ATI430:>SX`<0WYjN0`2=SHd2
071`L0<0=cLg0`071`L=000000<030`<0`0?3`l300820P8000000`0;2`/301dM7@<0410@0P0410@Y
000000P0oooo00060?oooe0000001@0?3`l6000000<010@40P0H61P301/K6`<051@D0`0E5AD201@D
50<03`l?0`0820P301PH6080?3`l0`1SHf<307IfMP<0PH610P26QXH308n?S`<0Ti>C0P2MWId30:f]
[@<0];Bd0`2i^KT20;Zj^P<0/;2`0`2HV9P30861P@80P8200`24Q8@308J6QP<0PX:20P1fMWH3071`
L0<0JVYZ0`1cLg<2096AT@<0Xj>S0`2NWYh308f=S@80L71`0`0g=cL300L71`d000000`0<30`300l?
3`<00P820P00000300/;2`<07AdM0`0@410200@412T00000203oool000H0ooooD`00000200<30`<0
0@410`000003018B4P80;bl_0`0i>CT303Lg=`<0;bl_0P0N7Qh300/;2`<04A4A0`13@d<2079bLP<0
T92@0`2JVYX309NGU`80V9RH0`2NWYh30:NWY`80^KVi0`2m_Kd30;:b/P<0YJFU0P2:RXX3069RHP<0
;bl_0`0I6AT20410@0<0MgMg0`2UYJD30;>c/`80WYjN0`29RHT307=cL`<0Ng]k0P2JVYX30:BTY0<0
V9RH0`28R8P206=SH`<0<c<c0`0C4a<;000000801@D50`0>3Ph3018B4P<02`/;0P00000300X:2P<0
51@D0`0:2PX200820RT00000203oool000H0ooooD`00000200<30`<00@410`000003018B4P80;bl_
0`0i>CT303Lg=`<0;bl_0P0N7Qh300/;2`<04A4A0`13@d<2079bLP<0T92@0`2JVYX309NGU`80V9RH
0`2NWYh30:NWY`80^KVi0`2m_Kd30;:b/P<0YJFU0P2:RXX3069RHP<0;bl_0`0I6AT20410@0<0MgMg
0`2UYJD30;>c/`80WYjN0`29RHT307=cL`<0Ng]k0P2JVYX30:BTY0<0V9RH0`28R8P206=SH`<0<c<c
0`0C4a<;000000801@D50`0>3Ph3018B4P<02`/;0P00000300X:2P<051@D0`0:2PX200820RT00000
203oool000H0ooooD`00000200<30`<00@410`000003018B4P80;bl_0`0i>CT303Lg=`<0;bl_0P0N
7Qh300/;2`<04A4A0`13@d<2079bLP<0T92@0`2JVYX309NGU`80V9RH0`2NWYh30:NWY`80^KVi0`2m
_Kd30;:b/P<0YJFU0P2:RXX3069RHP<0;bl_0`0I6AT20410@0<0MgMg0`2UYJD30;>c/`80WYjN0`29
RHT307=cL`<0Ng]k0P2JVYX30:BTY0<0V9RH0`28R8P206=SH`<0<c<c0`0C4a<;000000801@D50`0>
3Ph3018B4P<02`/;0P00000300X:2P<051@D0`0:2PX200820RT00000203oool000H0ooooD`000002
00410@<03Ph>0`0B4Q8302@T9080>SXj0`12@T8303lo?`<0=CDe0P0S8b<301@D50<0<C4a0`1bLW82
08n?S`<0UiNG0`2OWil509ZJVP<0WinO0`2ZZZX20;Zj^P<0^k^k0`2][Jd309fMW@80N7Qh0`1EEED3
02PX:0<05ADE0P0m?Cd307QhN0<0];Bd0`3Hf=P20=_Kf`<0emOG0`3:b/X30<71`@80_kno0`2ZZZX3
08n?S`<0OGem0P1DE5@303@d=0<0;Bd]0`0N7Qh2024Q8@<0;Rh^0`0c<c<2024Q8@<03`l?0`0=3@d3
00/;2cH00000203oool000H0ooooD`00000200410@<03Ph>0`0B4Q8302@T9080>SXj0`12@T8303lo
?`<0=CDe0P0S8b<301@D50<0<C4a0`1bLW8208n?S`<0UiNG0`2OWil509ZJVP<0WinO0`2ZZZX20;Zj
^P<0^k^k0`2][Jd309fMW@80N7Qh0`1EEED302PX:0<05ADE0P0m?Cd307QhN0<0];Bd0`3Hf=P20=_K
f`<0emOG0`3:b/X30<71`@80_kno0`2ZZZX308n?S`<0OGem0P1DE5@303@d=0<0;Bd]0`0N7Qh2024Q
8@<0;Rh^0`0c<c<2024Q8@<03`l?0`0=3@d300/;2cH00000203oool000H0ooooD000000300D51@80
7alO0`0S8b<301lO7`<0820P0P0O7al601hN7P<07alO0P0R8R8302LW9`<0ATI60`1aLG4207YjNP<0
Ng]k0`23Ph<308N7Q`80Ti>C0`2LW9`30:NWY`80/[:b0`2l_;`30;^k^`<0YjNW0P24Q8@30861P@<0
NGUi0`1`L70207EeM@<0PX:20`2IVIT30;>c/`80b/[:0`3Fe]H30=gMg@<0b/[:0P2PX:0307QhN0<0
K6a/0`1VIVH204];B`<0?clo0`16ATH503`l?0<0ADE50`1:BTX203`l?0<08R8R0`0G5aL300h>3P80
1`L70`051@D300820Rh00000203oool000H0ooooD000000300D51@807alO0`0S8b<301lO7`<0820P
0P0O7al601hN7P<07alO0P0R8R8302LW9`<0ATI60`1aLG4207YjNP<0Ng]k0`23Ph<308N7Q`80Ti>C
0`2LW9`30:NWY`80/[:b0`2l_;`30;^k^`<0YjNW0P24Q8@30861P@<0NGUi0`1`L70207EeM@<0PX:2
0`2IVIT30;>c/`80b/[:0`3Fe]H30=gMg@<0b/[:0P2PX:0307QhN0<0K6a/0`1VIVH204];B`<0?clo
0`16ATH503`l?0<0ADE50`1:BTX203`l?0<08R8R0`0G5aL300h>3P801`L70`051@D300820Rh00000
203oool000H0ooooD000000300D51@807alO0`0S8b<301lO7`<0820P0P0O7al601hN7P<07alO0P0R
8R8302LW9`<0ATI60`1aLG4207YjNP<0Ng]k0`23Ph<308N7Q`80Ti>C0`2LW9`30:NWY`80/[:b0`2l
_;`30;^k^`<0YjNW0P24Q8@30861P@<0NGUi0`1`L70207EeM@<0PX:20`2IVIT30;>c/`80b/[:0`3F
e]H30=gMg@<0b/[:0P2PX:0307QhN0<0K6a/0`1VIVH204];B`<0?clo0`16ATH503`l?0<0ADE50`1:
BTX203`l?0<08R8R0`0G5aL300h>3P801`L70`051@D300820Rh00000203oool000H0ooooD0000003
01DE5@80<C4a0`0[:b/301lO7`<06QXJ0P0=3@d300@410<020P80`0@410201hN7P<0;2`/0`1:BTX3
05YJFP80Cdm?0`14A4@304E5A@<0AdM70P1RHV8307AdM0<0SXj>0P2ZZZX30<30`0<0_kno0`2XZ:P2
08J6QP<0RXZ:0`2=SHd508V9R@<0TI6A0`2NWYh30;6a/@80alO70`3Bd]830=OGe`<0/;2`0P1]KFd3
04=3@`<0?clo0`13@d<202l_;`<0>CTi0`1HF5P305MGE`80Fe]K0`1/K6`306m_K`80EeMG0`0_;bl3
01hN7P<0410@0P071`L300D51@<00`<30`010@4[000000P0oooo00060?oooe0000000`0E5AD2034a
<@<0:b/[0`0O7al301XJ6P803@d=0`0410@300P820<0410@0P0N7Qh302`/;0<0BTY:0`1JFUX204m?
C`<0A4A40`15ADD304M7A`80HV9R0`1dM7@308j>SP80ZZZZ0`30`<030;no_`<0Z:RX0P26QXH308Z:
RP<0SHf=1@29RHT3096AT@<0WYjN0`2a/K420<O7a`<0d];B0`3GemL30;2`/080KFe]0`13@d<303lo
?`<0@d=30P0_;bl303Ti>@<0F5QH0`1GEeL205]KF`<0K6a/0`1_Kfl205MGE`<0;bl_0`0N7Qh3010@
40801`L70`051@D300<30`<00@41:`0000080?ooo`001P3ooom@000000<05ADE0P0a<C4302/[:`<0
7alO0`0J6QX200d=3@<010@40`0820P3010@40807QhN0`0/;2`304Y:BP<0FUYJ0P1?Cdl304A4A0<0
ADE50`17AdL2069RHP<0M7Ad0`2>SXh20:ZZZP<0`<300`2o_kl30:RXZ080QXJ60`2:RXX308f=S@D0
RHV90`2ATI4309jNWP<0/K6a0P37alL30=;BdP<0emOG0`2`/;0206e]K@<0@d=30`0o?cl304=3@`80
;bl_0`0i>CT305QHF0<0EeMG0P1KFe/306a/K0<0Kfm_0P1GEeL302l_;`<07QhN0`0@410200L71`<0
1@D50`030`<300410B/00000203oool000H0ooooD0000003028R8P80>c/k0`0g=cL3034a<@<0;2`/
0P0K6a/300/;2`<010@40`0<30`201`L70<0<C4a0`1>CTh304A4A080:RXZ0`0H61P3028R8P<0=3@d
0P1JFUX307IfMP<0UiNG0P2][Jd30<;2`P<0aLG50`2`/;0208n?S`<0WIfM0`2c/k<30:b/[080VYZJ
0`2=SHd308n?S`<0Xj>S0P36a/H30=[JfP<0hn?S0`2ZZZX204U9B@<04a<C0`0=3@d3014A4@801PH6
0`0P820305=CD`<0H61P0P1SHf<307alO0<0QXJ60P1XJ6P303Hf=P<07AdM0`0=3@d200<30c@00000
203oool000H0ooooD0000003028R8P80>c/k0`0g=cL3034a<@<0;2`/0P0K6a/300/;2`<010@40`0<
30`201`L70<0<C4a0`1>CTh304A4A080:RXZ0`0H61P3028R8P<0=3@d0P1JFUX307IfMP<0UiNG0P2]
[Jd30<;2`P<0aLG50`2`/;0208n?S`<0WIfM0`2c/k<30:b/[080VYZJ0`2=SHd308n?S`<0Xj>S0P36
a/H30=[JfP<0hn?S0`2ZZZX204U9B@<04a<C0`0=3@d3014A4@801PH60`0P820305=CD`<0H61P0P1S
Hf<307alO0<0QXJ60P1XJ6P303Hf=P<07AdM0`0=3@d200<30c@00000203oool000H0ooooD0000003
02h^;P80@4100`0g=cL3038b<P<0;Rh^0P0R8R8301<C4`<02@T90`0@410201lO7`<0<c<c0`17AdL3
03@d=08071`L0`0>3Ph301XJ6P<0<C4a0P1EEED306i^KP<0RXZ:0P2KVi/30:n_[`<0/k>c0`2XZ:P2
09FEU@<0Z:RX0`37alL30<G5a@80/K6a0`2MWId309RHV0<0YjNW0P35aLD30=KFeP<0f][J0`2JVYX2
03Xj>P<01PH60`00000300410@8000000`0B4Q8304=3@`<0EEEE0P1HF5P306m_K`<0NGUi0P1NGUh3
038b<P<06QXJ0`0:2PX5000000<00`<30`020P8[000000P0oooo00060?oooe0000000`0^;Rh20410
@0<0=cLg0`0b<S8302h^;P808R8R0`0C4a<300T92@<0410@0P0O7al303<c<`<0AdM70`0d=3@201`L
70<03Ph>0`0J6QX3034a<@80EEEE0`1^KVh308Z:RP80Vi^K0`2_[jl30;>c/`<0Z:RX0P2EUID30:RX
Z0<0alO70`35aLD20;6a/@<0WIfM0`2HV9P30:NWY`80aLG50`3Fe]H30=[JfP<0VYZJ0P0j>SX300H6
1P<000000`010@42000000<04Q8B0`13@d<305EEE@80F5QH0`1_Kfl307UiN@80GUiN0`0b<S8301XJ
6P<02PX:1@00000300<30`<00P82:`0000080?ooo`001P3ooom@000000<0;Rh^0P10@40303Lg=`<0
<S8b0`0^;Rh2028R8P<04a<C0`092@T3010@40807alO0`0c<c<304M7A`<0=3@d0P0L71`300h>3P<0
6QXJ0`0a<C4205EEE@<0KVi^0`2:RXX209^KV`<0[jn_0`2c/k<30:RXZ080UIFE0`2XZ:P30<O7a`<0
aLG50P2a/K4309fMW@<0V9RH0`2WYjL20<G5a@<0e]KF0`3Jf]X309ZJVP80>SXj0`061PH3000000<0
0@410P000003018B4P<0@d=30`1EEED205QHF0<0Kfm_0`1iNGT205iNGP<0<S8b0`0J6QX300X:2PD0
00000`030`<300820R/00000203oool000H0ooooC@00000300H61P<0A4A40P1@D50303`l?0<0<C4a
0`0/;2`202d];@<0:BTY1P0P820202<S8`<0;bl_0`10@40504E5A@<0?clo0`14A4@3051@D080GEeM
0`1PH60306MWI`80JVYZ0`1bLW8307EeM@<0O7al0P28R8P309VIV@<0[:b/0`2d];@20;Jf]P<0];Bd
0`2i^KT30<G5a@80d=3@0`3AdM430<S8b0<0Rh^;0P17AdL3028R8P<06ATI0`0A4A4200@410<02`/;
0`0V9RH303Lg=`80?Cdm0`1;Bd/305=CD`80@T920`0X:2P301LG5`<02PX:0P00000300H61P<02`/;
0`061PH200820RT00000203oool000H0ooooC@00000300H61P<0A4A40P1@D50303`l?0<0<C4a0`0/
;2`202d];@<0:BTY1P0P820202<S8`<0;bl_0`10@40504E5A@<0?clo0`14A4@3051@D080GEeM0`1P
H60306MWI`80JVYZ0`1bLW8307EeM@<0O7al0P28R8P309VIV@<0[:b/0`2d];@20;Jf]P<0];Bd0`2i
^KT30<G5a@80d=3@0`3AdM430<S8b0<0Rh^;0P17AdL3028R8P<06ATI0`0A4A4200@410<02`/;0`0V
9RH303Lg=`80?Cdm0`1;Bd/305=CD`80@T920`0X:2P301LG5`<02PX:0P00000300H61P<02`/;0`06
1PH200820RT00000203oool000H0ooooC@00000300H61P<0A4A40P1@D50303`l?0<0<C4a0`0/;2`2
02d];@<0:BTY1P0P820202<S8`<0;bl_0`10@40504E5A@<0?clo0`14A4@3051@D080GEeM0`1PH603
06MWI`80JVYZ0`1bLW8307EeM@<0O7al0P28R8P309VIV@<0[:b/0`2d];@20;Jf]P<0];Bd0`2i^KT3
0<G5a@80d=3@0`3AdM430<S8b0<0Rh^;0P17AdL3028R8P<06ATI0`0A4A4200@410<02`/;0`0V9RH3
03Lg=`80?Cdm0`1;Bd/305=CD`80@T920`0X:2P301LG5`<02PX:0P00000300H61P<02`/;0`061PH2
00820RT00000203oool000H0oooo?`00000;00410@<00P820`0A4A4307emO@80Ogmo0`1:BTX302h^
;P<07QhN0P0H61P901DE5@8061PH0`0^;Rh3059BDP<0N7Qh0P29RHT308F5Q@<0NWYj0`1^KVh2069R
HP<0A4A40`0_;bl202@T90<0:RXZ0`0e=CD305EEE@80S8b<0`2RXZ8309bLW0<0YZJV0P2_[jl30;Jf
]P<0_[jn0`37alL20<_;b`<0a/K60`35aLD308Z:RP80FEUI0`1:BTX303lo?`<0;2`/0P0F5QH3018B
4P<07alO0`0`<30204I6AP<0EEEE0`1BDU820451@@<0:2PX0`0D51@300P820800`<30`0;2`/300d=
3@<01PH60P010@4Y000000P0oooo00060?ooocl000002`010@4300820P<04A4A0`1mOGd207moO`<0
BTY:0`0^;Rh301hN7P8061PH2@0E5AD201PH60<0;Rh^0`1BDU8307QhN080RHV90`25QHD307YjNP<0
KVi^0P1RHV8304A4A0<0;bl_0P0T92@302XZ:P<0=CDe0`1EEED208b<S0<0XZ:R0`2LW9`30:JVYP80
[jn_0`2f][H30;jn_P<0alO70P3;bl/30<K6aP<0aLG50`2:RXX205UIF@<0BTY:0`0o?cl302`/;080
5QHF0`0B4Q8301lO7`<0<30`0P16ATH305EEE@<0DU9B0P11@D4302PX:0<051@D0`0820P200<30`<0
2`/;0`0=3@d300H61P800@41:@0000080?ooo`001P3ooolo000000/00@410`020P83014A4@<0OGem
0P1oOgl304Y:BP<0;Rh^0`0N7Qh201PH60T05ADE0P0H61P302h^;P<0DU9B0`1hN7P208V9R@<0QHF5
0`1jNWX306i^KP80HV9R0`14A4@302l_;`8092@T0`0Z:RX303De=@<0EEEE0P2<S8`30::RXP<0W9bL
0`2VYZH20:n_[`<0][Jf0`2n_[h30<O7a`80bl_;0`36a/H30<G5a@<0RXZ:0P1IFET304Y:BP<0?clo
0`0/;2`201HF5P<04Q8B0`0O7al3030`<080ATI60`1EEED3059BDP80@D510`0X:2P301@D50<020P8
0P030`<300/;2`<03@d=0`061PH200410BT00000203oool000H0oooo?@00000200410@<00P822003
0`<300@410<06a/K0`2PX:02096AT@<0BTY:0`0^;Rh301hN7P806QXJ0`0F5QH301PH60<05aLG0P0I
6AT303@d=0<0IfMW0`2LW9`20;Ng]`<0^KVi0`2YZJT3096AT@80Lg=c0`11@D4301LG5`800`<30`09
2@T301TI6@<0CTi>0P2PX:030;Bd]0<0UYJF0`2EUID209ZJVP<0XZ:R0`2_[jl30;Vi^@80_Kfm0`2i
^KT30;no_`<0QXJ60P1WIfL306YZJP<0E5AD0`0e=CD201TI6@<03@d=0`0D51@302PX:080C4a<0`1U
IFD305]KF`80@4100`0P820300T92@D000000`0410@300D51@<00@41:`0000080?ooo`001P3ooolm
000000800@410`020P8800<30`<010@40`0K6a/30:2PX080TI6A0`1:BTX302h^;P<07QhN0P0J6QX3
01HF5P<061PH0`0G5aL201TI6@<0=3@d0`1WIfL309bLW080]kNg0`2i^KT30:VYZ@<0TI6A0P1cLg<3
0451@@<05aLG0P030`<300T92@<06ATI0`1>CTh20:2PX0<0];Bd0`2FUYH309FEU@80VYZJ0`2RXZ83
0:n_[`<0^KVi0P2m_Kd30;Vi^@<0_kno0`26QXH206MWI`<0JVYZ0`1DE5@303De=@806ATI0`0=3@d3
01@D50<0:2PX0P1<C4`306EUI@<0Fe]K0P10@403020P80<02@T91@00000300@410<01@D50`010@4[
000000P0oooo00060?ooocd000000P020P8300<30`H010@40P061PH300P820<08b<S0`2g]kL20:2P
X0<0EEEE0`13@d<303Ph>080?3`l0`0e=CD302`/;0<08b<S0P0M7Ad303Ti>@<0L71`0`2XZ:P20<W9
b@<0e]KF0`3@d=030<30`080Vi^K0`1TI6@3038b<P803@d=0`0;2`/301lO7`<0HV9R0P2o_kl30<_;
b`<0UYJF0`1oOgl207MgM`<0N7Qh0`2;Rh/309JFUP80WinO0`2PX:030:b/[0<0O7al0P1_Kfl308B4
Q0<0J6QX0`0k>c/201XJ6P<01@D50`00000301<C4`80>c/k0`1OGel305UIF@80@T920`0S8b<300H6
1PD000000`010@4300L71`<00@41:`0000080?ooo`001P3ooolm000000800P820`030`<600@41080
1PH60`0820P302<S8`<0]kNg0P2PX:0305EEE@<0@d=30`0h>3P203`l?0<0=CDe0`0/;2`302<S8`80
7AdM0`0i>CT3071`L0<0Z:RX0P39bLT30=KFeP<0d=3@0`30`<0209^KV`<0I6AT0`0b<S8200d=3@<0
2`/;0`0O7al3069RHP80_kno0`3;bl/309JFUP<0Ogmo0P1gMgL307QhN0<0Rh^;0`2FUYH209nOW`<0
X:2P0`2/[:`307alO080Kfm_0`24Q8@306QXJ0<0>c/k0P0J6QX300D51@<000000`0C4a<203/k>`<0
GemO0`1IFET20492@P<08b<S0`061PH5000000<00@410`071`L300410B/00000203oool000H0oooo
?@00000200820P<00`<31P0410@200H61P<020P80`0S8b<30;Ng]`80X:2P0`1EEED304=3@`<0>3Ph
0P0l?3`303De=@<0;2`/0`0S8b<201dM7@<0>CTi0`1`L7030:RXZ080bLW90`3Fe]H30=3@d0<0`<30
0P2KVi/306ATI0<0<S8b0P0=3@d300/;2`<07alO0`1RHV820;no_`<0bl_;0`2FUYH307moO`80MgMg
0`1hN7P308^;R`<0UYJF0P2OWil30:2PX0<0[:b/0`1lO7`206m_K`<0Q8B40`1XJ6P303/k>`806QXJ
0`051@D3000000<04a<C0P0k>c/305mOG`<0FEUI0P12@T8302<S8`<01PH61@00000300410@<01`L7
0`010@4[000000P0oooo00060?ooocd000000P010@4300820P<00`<30`0410@200H61P<020P80`0K
6a/309VIV@80Y:BT0`1jNWX307IfMP<0OGem0P2BTY8308N7Q`<0J6QX0`1ADE4203Ti>@<0@4100`1^
KVh309nOW`80`L710`3Bd]830>?Sh`<0kNg]0P3QhN430<_;b`<0_;bl0P2MWId308Z:RP<0T92@0`2h
^;P20>7Qh@<0a/K60`1dM7@30492@P80A4A40`1OGel308n?S`<0YJFU0P2[Zj/30:BTY0<0Xj>S0`21
PH4207UiN@<0UIFE0`21PH4305IFEP80;Rh^0`0A4A4300<30`<020P80P0S8b<304];B`<0IFEU0P1S
Hf<304Q8B0<09RHV0`0<30`2000000<0410@0`0N7Qh300d=3B/00000203oool000H0oooo?@000002
00410@<00P820`030`<300@410801PH60`0820P301/K6`<0VIVI0P2TY:@307YjNP<0MWIf0`1mOGd2
09:BTP<0QhN70`1XJ6P3055AD@80>CTi0`10@40306i^KP<0WinO0P31`L430=;BdP<0hn?S0`3]kNd2
0>7Qh@<0bl_;0`2l_;`209fMW@<0RXZ:0`2@T9030;Rh^080hN7Q0`36a/H307AdM0<0@T920P14A4@3
05mOG`<0Shn?0`2UYJD20:^[Z`<0Y:BT0`2SXj<30861P@80NGUi0`2EUID30861P@<0EUIF0P0^;Rh3
014A4@<00`<30`0820P202<S8`<0Bd];0`1UIFD206=SH`<0B4Q80`0V9RH300`<308000000`0@4103
01hN7P<03@d=:`0000080?ooo`001P3ooolm000000800@410`020P8300<30`<010@40P061PH300P8
20<06a/K0`2IVIT20:BTY0<0NWYj0`1fMWH307emO@80TY:B0`27QhL306QXJ0<0DE5A0P0i>CT30410
@0<0KVi^0`2OWil20<71`@<0d];B0`3Shn<30>g]k@80hN7Q0`3;bl/30;bl_080WIfM0`2:RXX3092@
T0<0^;Rh0P3QhN430<K6aP<0M7Ad0`12@T8204A4A0<0GemO0`2?Shl30:FUY@80Zj^[0`2TY:@30:>S
X`<0PH610P1iNGT309FEU@<0PH610`1FEUH202h^;P<04A4A0`030`<300P820808b<S0`1;Bd/306EU
I@80Hf=S0`18B4P302HV9P<030`<0P000003010@40<07QhN0`0=3@d[000000P0oooo00060?ooocl0
00001P010@4500820P<00`<30`0;2`/305iNGP80OGem0`1SHf<305aLG0<0I6AT0P1aLG43065QH@<0
ATI60`0b<S8201lO7`<08R8R0`1>CTh308J6QP80YZJV0`2i^KT30=3@d0<0h>3P0P3[jn/30>g]k@<0
moOg0P3Xj>P60=SHf0<0gMgM0P3Bd]830:j^[P<0GEeM0`0V9RH202`/;0<0CTi>0`23Ph<309fMW@80
YjNW0`2TY:@30:NWY`<0V9RH0P2;Rh/309VIV@<0SHf=0`1]KFd20492@P<09RHV0`0K6a/301<C4`80
9BDU0`14A4@305mOG`80I6AT0`1<C4`3030`<0<04a<C0P030`<301@D50<0820P0`0?3`l[000000P0
oooo00060?ooocl000001P010@4500820P<00`<30`0;2`/305iNGP80OGem0`1SHf<305aLG0<0I6AT
0P1aLG43065QH@<0ATI60`0b<S8201lO7`<08R8R0`1>CTh308J6QP80YZJV0`2i^KT30=3@d0<0h>3P
0P3[jn/30>g]k@<0moOg0P3Xj>P60=SHf0<0gMgM0P3Bd]830:j^[P<0GEeM0`0V9RH202`/;0<0CTi>
0`23Ph<309fMW@80YjNW0`2TY:@30:NWY`<0V9RH0P2;Rh/309VIV@<0SHf=0`1]KFd20492@P<09RHV
0`0K6a/301<C4`809BDU0`14A4@305mOG`80I6AT0`1<C4`3030`<0<04a<C0P030`<301@D50<0820P
0`0?3`l[000000P0oooo00060?ooodD000001@010@4300820P<01PH60`1BDU8208B4Q0<0LG5a0`1[
Jf/3071`L080Ng]k0`1^KVh305MGE`<0AdM70P0j>SX303`l?0<0EEEE0`1fMWH208j>SP<0XJ6Q0`2f
][H30<K6aP80eMGE0`3Ng]h30>o_k`80j>SX1P3Ng]h30=gMg@80d=3@0`2^[Zh306MWI`<0=CDe0P0c
<c<304Y:BP<0KFe]0`1iNGT207YjNP<0M7Ad1P1eMGD2079bLP<0SXj>0`2GUiL308F5Q@80Hf=S0`13
@d<302LW9`<04A4A0P0H61P302`/;0<0CDe=0P1UIFD305]KF`<0@4100`0M7Ad200d=3@<092@T0`0`
<30301TI6@800`<3:@0000080?ooo`001P3ooom5000000D00@410`020P8300H61P<0DU9B0P24Q8@3
075aL@<0Jf][0`1`L70207]kN`<0KVi^0`1GEeL304M7A`80>SXj0`0l?3`305EEE@<0MWIf0P2>SXh3
0:6QX@<0][Jf0`36a/H20=GEe@<0g]kN0`3_knl20>SXj0H0g]kN0`3MgMd20=3@d0<0[Zj^0`1WIfL3
03De=@80<c<c0`1:BTX306e]K@<0NGUi0P1jNWX307AdM0H0MGEe0P1bLW8308j>SP<0UiNG0`25QHD2
06=SH`<0@d=30`0W9bL3014A4@8061PH0`0/;2`304e=C@80IFEU0`1KFe/30410@0<07AdM0P0=3@d3
02@T90<0<30`0`0I6AT200<30bT00000203oool000H0ooooA@00000500410@<00P820`061PH3059B
DP80Q8B40`1aLG4306][J`<0L71`0P1kNg/306i^KP<0EeMG0`17AdL203Xj>P<0?3`l0`1EEED307If
MP80SXj>0`2QXJ430;Jf]P<0a/K60P3EeMD30=kNgP<0kno_0P3Xj>P60=kNgP<0gMgM0P3@d=030:j^
[P<0IfMW0`0e=CD203<c<`<0BTY:0`1]KFd307UiN@80NWYj0`1dM7@607EeM@80LW9b0`2>SXh309NG
U`<0QHF50P1SHf<304=3@`<09bLW0`0A4A4201PH60<0;2`/0`1=CDd206EUI@<0Fe]K0`10@40301dM
7@803@d=0`0T92@3030`<0<06ATI0P030`<Y000000P0oooo00060?ooodD000000`010@4200820P<0
0`<30`0820P305=CD`80Ogmo0`1gMgL308>3P`<0Shn?0P2UYJD309jNWP<0Q8B40`1gMgL206a/K0H0
KVi^0`1YJFT207QhN0<0TI6A0`2/[:`30<K6aP80d];B0`3QhN430>k^kP80jNWY0`3Zj^X30>g]k@D0
moOg0`3Jf]X30:FUY@<0LG5a0P1LG5`305YJFPH0IfMW0P1TI6@305mOG`<0FUYJ0`1FEUH205eMG@<0
PX:20`2DU9@308B4Q080K6a/0`19BDT3020P80<02@T90P071`L301dM7@<0@T920P1NGUh305]KF`<0
?Cdm0`0J6QX200X:2P<092@T0`0e=CD301`L70801@D5:@0000080?ooo`001P3ooom5000000<00@41
0P020P8300<30`<020P80`1CDe<207moO`<0MgMg0`23Ph<308n?S`80YJFU0`2NWYh308B4Q0<0MgMg
0P1/K6`606i^KP<0JFUY0P1hN7P3096AT@<0[:b/0`36a/H20=;BdP<0hN7Q0`3^k^h20>WYj@<0j^[Z
0`3]kNd50?Ogm`<0f][J0`2UYJD3075aL@80G5aL0`1JFUX606MWI`80I6AT0`1OGel305YJFP<0EUIF
0P1MGEd308:2PP<0U9BD0`24Q8@206a/K0<0BDU90`0P820300T92@801`L70`0M7Ad30492@P80GUiN
0`1KFe/303dm?@<06QXJ0P0:2PX302@T90<0=CDe0`0L71`200D51BT00000203oool000H0ooooA@00
000300410@800P820`030`<300P820<0De=C0P1oOgl307MgM`<0Ph>30`2?Shl20:FUY@<0WYjN0`24
Q8@307MgM`80K6a/1P1^KVh306UYJ@80N7Qh0`2ATI430:b/[0<0a/K60P3Bd]830>7Qh@<0k^k^0P3Y
jNT30>[ZjP<0kNg]1@3gmoL30=[JfP<0YJFU0`1aLG4205aLG0<0FUYJ1P1WIfL206ATI0<0GemO0`1J
FUX305IFEP80GEeM0`22PX8309BDU0<0Q8B40P1/K6`304U9B@<0820P0`092@T200L71`<07AdM0`12
@T8205iNGP<0Fe]K0`0m?Cd301XJ6P802PX:0`0T92@303De=@<071`L0P051@DY000000P0oooo0006
0?ooodX000000`010@4300D51@<0L71`0P2m_Kd309nOW`<0SXj>0`23Ph<208J6QP<0MWIf0`1EEED3
04Y:BP80AdM71P1CDe<305ADE080H61P0`1bLW8308n?S`<0^;Rh0P3EeMD30>SXj0<0oOgm0P3YjNT3
0=kNgP<0j>SX0`3^k^h20??cl`<0m_Kf0`3Xj>P30<k>cP80][Jf0`2PX:0309NGU`<0TY:B0P2FUYH3
092@T0<0TI6A0`1nOWh205IFEP<0HV9R0`24Q8@307alO080JVYZ0`1;Bd/302PX:0<05QHF0P0<30`3
00/;2`<0>CTi0P1aLG4307alO0<0G5aL0`0Z:RX201LG5`<0?Shn0`1ADE4302`/;0802`/;:@000008
0?ooo`001P3ooom:000000<00@410`051@D3071`L080_Kfm0`2OWil308j>SP<0Ph>30P26QXH307If
MP<0EEEE0`1:BTX204M7A`H0De=C0`1DE5@2061PH0<0LW9b0`2?Shl30;Rh^080eMGE0`3Xj>P30?gm
o@80jNWY0`3Ng]h30>SXj0<0k^k^0P3clo<30?KfmP<0j>SX0`3>c/h20;Jf]P<0X:2P0`2GUiL309:B
TP80UYJF0`2@T903096AT@<0OWin0P1FEUH3069RHP<0Q8B40`1lO7`206YZJP<0Bd];0`0X:2P301HF
5P8030`<0`0;2`/303Ti>@80LG5a0`1lO7`305aLG0<0:RXZ0P0G5aL303hn?P<0DE5A0`0/;2`200/;
2bT00000203oool000H0ooooBP00000300410@<01@D50`1`L7020;fm_@<0WinO0`2>SXh308>3P`80
QXJ60`1fMWH305EEE@<0BTY:0P17AdL605=CD`<0E5AD0P1PH603079bLP<0Shn?0`2h^;P20=GEe@<0
j>SX0`3moOd20>WYj@<0g]kN0`3Xj>P30>k^kP80lo?c0`3fm_H30>SXj0<0c/k>0P2f][H30:2PX0<0
UiNG0`2BTY8209JFUP<0T92@0`2ATI4307inOP80EUIF0`1RHV8308B4Q0<0O7al0P1ZJVX304];B`<0
:2PX0`0F5QH200`<30<02`/;0`0i>CT2075aL@<0O7al0`1LG5`302XZ:P805aLG0`0n?Sh3055AD@<0
;2`/0P0;2`/Y000000P0oooo00060?oooe0000000`1TI6@20;Zj^P<0V9RH0`1iNGT306YZJP80Jf][
0`1OGel304A4A0D0?Cdm0`15ADD303Ph>0<0=3@d0P12@T83051@D0<0I6AT0`28R8P20:n_[`<0b<S8
0`3YjNT20>CTi0<0g=cL0`3Rh^850=kNgP<0iNGU0`3YjNT30>?Sh`80hN7Q0`3Jf]X30=3@d0<0aLG5
0P2h^;P30:BTY0<0UYJF0`1iNGT204U9B@<0C4a<0`1gMgL307YjNP80JVYZ0`1=CDd302l_;`<07AdM
0P0=3@d3000000<0:b/[0P1XJ6P307inOP<0IFEU0`0a<C4201/K6`<0AdM70`1KFe/303<c<`803Ph>
:@0000080?ooo`001P3ooom@000000<0I6AT0P2j^[X309RHV0<0NGUi0`1ZJVX206][J`<0GemO0`14
A4@503dm?@<0ADE50`0h>3P303@d=080@T920`1@D50306ATI0<0R8R80P2_[jl30<S8b0<0jNWY0P3T
i>@30=cLg0<0h^;R1@3Ng]h30>GUi@<0jNWY0`3Shn<20>7Qh@<0f][J0`3@d=030<G5a@80^;Rh0`2T
Y:@309JFUP<0NGUi0P19BDT304a<C0<0MgMg0`1jNWX206YZJP<0CDe=0`0_;bl301dM7@803@d=0`00
000302/[:`80J6QX0`1nOWh306EUI@<0<C4a0P0K6a/304M7A`<0Fe]K0`0c<c<200h>3RT00000203o
ool000H0ooooD0000003051@D080YZJV0`2WYjL30:2PX0<0Vi^K0P2/[:`30;6a/@<0Xj>S0`2MWId5
09ZJVP<0P8201@1/K6`306m_K`<0N7Qh0`2<S8`209jNWP<0[jn_0`36a/H20<k>cP<0d];B1P3@d=02
0=GEe@<0d];B1P3Hf=P20=[JfP<0fMWI0`3?cll30<G5a@80/k>c0`2MWId308F5Q@<0JVYZ0P1<C4`3
05EEE@<0QXJ60`2@T90208R8R0<0KVi^0`16ATH302LW9`803`l?0`092@T303/k>`80KFe]0`1iNGT3
061PH0<0=3@d0P0T92@304E5A@<0Cdm?0`0/;2`200d=3BT00000203oool000H0ooooD0000003051@
D080YZJV0`2WYjL30:2PX0<0Vi^K0P2/[:`30;6a/@<0Xj>S0`2MWId509ZJVP<0P8201@1/K6`306m_
K`<0N7Qh0`2<S8`209jNWP<0[jn_0`36a/H20<k>cP<0d];B1P3@d=020=GEe@<0d];B1P3Hf=P20=[J
fP<0fMWI0`3?cll30<G5a@80/k>c0`2MWId308F5Q@<0JVYZ0P1<C4`305EEE@<0QXJ60`2@T90208R8
R0<0KVi^0`16ATH302LW9`803`l?0`092@T303/k>`80KFe]0`1iNGT3061PH0<0=3@d0P0T92@304E5
A@<0Cdm?0`0/;2`200d=3BT00000203oool000H0ooooD0000003051@D080YZJV0`2WYjL30:2PX0<0
Vi^K0P2/[:`30;6a/@<0Xj>S0`2MWId509ZJVP<0P8201@1/K6`306m_K`<0N7Qh0`2<S8`209jNWP<0
[jn_0`36a/H20<k>cP<0d];B1P3@d=020=GEe@<0d];B1P3Hf=P20=[JfP<0fMWI0`3?cll30<G5a@80
/k>c0`2MWId308F5Q@<0JVYZ0P1<C4`305EEE@<0QXJ60`2@T90208R8R0<0KVi^0`16ATH302LW9`80
3`l?0`092@T303/k>`80KFe]0`1iNGT3061PH0<0=3@d0P0T92@304E5A@<0Cdm?0`0/;2`200d=3BT0
0000203oool000H0ooooD0000003055AD@80/[:b0`30`<030;bl_0<0]kNg0P37alL30=7Ad@<0c<c<
1@39bLT30<c<c0<0/;2`0`2DU9@208^;R`<0QXJ60`25QHD308b<S080UYJF0`2SXj<30;Jf]P80a/K6
0`3Bd]830<c<c0<0bl_;0P3?cll;0<G5a@<0alO70`2l_;`30:n_[`80UiNG0`1oOgl306MWI`<0CTi>
0P0e=CD304Q8B0<0QHF50`2IVIT209NGU`<0QXJ60`1OGel303Hf=P807QhN0`0L71`305EEE@80Q8B4
0`26QXH306MWI`<0>c/k0P0`<30304];B`<0CTi>0`0[:b/200d=3BT00000203oool000H0ooooD000
0003055AD@80/[:b0`30`<030;bl_0<0]kNg0P37alL30=7Ad@<0c<c<1@39bLT30<c<c0<0/;2`0`2D
U9@208^;R`<0QXJ60`25QHD308b<S080UYJF0`2SXj<30;Jf]P80a/K60`3Bd]830<c<c0<0bl_;0P3?
cll;0<G5a@<0alO70`2l_;`30:n_[`80UiNG0`1oOgl306MWI`<0CTi>0P0e=CD304Q8B0<0QHF50`2I
VIT209NGU`<0QXJ60`1OGel303Hf=P807QhN0`0L71`305EEE@80Q8B40`26QXH306MWI`<0>c/k0P0`
<30304];B`<0CTi>0`0[:b/200d=3BT00000203oool000H0ooooD0000003055AD@80/[:b0`30`<03
0;bl_0<0]kNg0P37alL30=7Ad@<0c<c<1@39bLT30<c<c0<0/;2`0`2DU9@208^;R`<0QXJ60`25QHD3
08b<S080UYJF0`2SXj<30;Jf]P80a/K60`3Bd]830<c<c0<0bl_;0P3?cll;0<G5a@<0alO70`2l_;`3
0:n_[`80UiNG0`1oOgl306MWI`<0CTi>0P0e=CD304Q8B0<0QHF50`2IVIT209NGU`<0QXJ60`1OGel3
03Hf=P807QhN0`0L71`305EEE@80Q8B40`26QXH306MWI`<0>c/k0P0`<30304];B`<0CTi>0`0[:b/2
00d=3BT00000203oool000H0ooooD0000003069RHP80fMWI0`3<c<`30:JVYP<0S8b<0P22PX8308F5
Q@<0Rh^;0`2=SHd209FEU@<0YZJV0`2LW9`30:>SX`80[:b/0`2ZZZX309nOW`<0V9RH0P2SXj<30:6Q
X@<0ZJVY0P2^[Zh30:n_[`<0[:b/0`2PX:020::RXP<0XJ6Q0`2KVi/30:JVYP80ZZZZ0`2][Jd309fM
W@<0QhN70P1YJFT304];B`<0?Cdm0`0`<30200/;2`<0820P0`1]KFd308Z:RP80R8R80`23Ph<306EU
I@<0>c/k0P0Z:RX301XJ6P<0Cdm?0P2=SHd309FEU@<0MgMg0`14A4@20410@0<0G5aL0`1HF5P3030`
<0803Ph>:@0000080?ooo`001P3ooom@000000<0HV9R0P3IfMT30<c<c0<0YZJV0`2<S8`208:2PP<0
QHF50`2;Rh/308f=S@80UIFE0`2VYZH309bLW0<0Xj>S0P2/[:`30:ZZZP<0WinO0`2HV9P20:>SX`<0
XJ6Q0`2YZJT20:j^[P<0[jn_0`2/[:`30:2PX080XZ:R0`2QXJ4309^KV`<0YZJV0P2ZZZX30:f][@<0
WIfM0`27QhL206UYJ@<0Bd];0`0m?Cd3030`<0802`/;0`0P820306e]K@<0RXZ:0P28R8P308>3P`<0
IFEU0`0k>c/202XZ:P<06QXJ0`1?Cdl208f=S@<0UIFE0`1gMgL304A4A080@4100`1LG5`305QHF0<0
<30`0P0>3PhY000000P0oooo00060?oooe0000000`1RHV820=WIf@<0c<c<0`2VYZH308b<S080PX:2
0`25QHD308^;R`<0SHf=0P2EUID30:JVYP<0W9bL0`2SXj<20:b/[0<0ZZZZ0`2OWil309RHV080Xj>S
0`2QXJ430:VYZ@80[Zj^0`2_[jl30:b/[0<0X:2P0P2RXZ830:6QX@<0Vi^K0`2VYZH20:ZZZP<0[Jf]
0`2MWId308N7Q`80JFUY0`1;Bd/303dm?@<0<30`0P0;2`/3020P80<0KFe]0`2:RXX208R8R0<0Ph>3
0`1UIFD303/k>`80:RXZ0`0J6QX304m?C`80SHf=0`2EUID307MgM`<0A4A40P10@40305aLG0<0F5QH
0`0`<30200h>3RT00000203oool000H0oooo?`00000300410@<00P8220030`<300410@<0;bl_0P2[
Zj/30<g=c@<0_[jn0`2XZ:P20::RXP<0[jn_0`2f][H50;>c/`<0`<300`32`/830>OWi`80jn_[0`3M
gMd30=KFeP<0dM7A0P32`/830;:b/P<0WinO0P26QXH307QhN0<0LW9b0`1PH60205=CD`<0FEUI0`1S
Hf<307IfMP80KFe]0`1QHF4305MGE`<0EUIF0P1GEeL3059BDP<0EEEE0`1KFe/203@d=0<0:BTY0`1Y
JFT30861P@80QXJ60`29RHT306QXJ0<0>CTi0P0K6a/300P820<0A4A41@1nOWh3069RHP<0@D510P1:
BTX304m?C`<0>SXj0`0L71`200P822T00000203oool000H0oooo?`00000300410@<00P8220030`<3
00410@<0;bl_0P2[Zj/30<g=c@<0_[jn0`2XZ:P20::RXP<0[jn_0`2f][H50;>c/`<0`<300`32`/83
0>OWi`80jn_[0`3MgMd30=KFeP<0dM7A0P32`/830;:b/P<0WinO0P26QXH307QhN0<0LW9b0`1PH602
05=CD`<0FEUI0`1SHf<307IfMP80KFe]0`1QHF4305MGE`<0EUIF0P1GEeL3059BDP<0EEEE0`1KFe/2
03@d=0<0:BTY0`1YJFT30861P@80QXJ60`29RHT306QXJ0<0>CTi0P0K6a/300P820<0A4A41@1nOWh3
069RHP<0@D510P1:BTX304m?C`<0>SXj0`0L71`200P822T00000203oool000H0oooo?@0000020041
0@<00P821P030`<200@410<01@D50`0410@301dM7@80Ph>30`2m_Kd30=7Ad@<0c/k>0P3De=@30>?S
h`<0k>c/0`3[jn/20>k^kP<0no_k1P3inOT20>WYj@<0gmoO0`3Lg=`30=SHf080aLG50`2m_Kd30:b/
[080Y:BT0`2[Zj/30:BTY0<0UYJF0P20P80307AdM0<0K6a/0`1RHV820410@0<09bLW0`0K6a/301XJ
6P808b<S0`0[:b/3038b<P<0?3`l0P0X:2P302d];@<0IVIV0`1nOWh208R8R0<0TY:B0`1cLg<30492
@P809RHV0`0_;bl306][J`80Rh^;0`1bLW8304i>CP<0=CDe0P10@40303Ti>@<08R8R0`0?3`l200@4
12T00000203oool000H0oooo?@00000200410@<00P821P030`<200@410<01@D50`0410@301dM7@80
Ph>30`2m_Kd30=7Ad@<0c/k>0P3De=@30>?Sh`<0k>c/0`3[jn/20>k^kP<0no_k1P3inOT20>WYj@<0
gmoO0`3Lg=`30=SHf080aLG50`2m_Kd30:b/[080Y:BT0`2[Zj/30:BTY0<0UYJF0P20P80307AdM0<0
K6a/0`1RHV820410@0<09bLW0`0K6a/301XJ6P808b<S0`0[:b/3038b<P<0?3`l0P0X:2P302d];@<0
IVIV0`1nOWh208R8R0<0TY:B0`1cLg<30492@P809RHV0`0_;bl306][J`80Rh^;0`1bLW8304i>CP<0
=CDe0P10@40303Ti>@<08R8R0`0?3`l200@412T00000203oool000H0oooo?@00000200410@<00P82
1P030`<200@410<01@D50`0410@301dM7@80Ph>30`2m_Kd30=7Ad@<0c/k>0P3De=@30>?Sh`<0k>c/
0`3[jn/20>k^kP<0no_k1P3inOT20>WYj@<0gmoO0`3Lg=`30=SHf080aLG50`2m_Kd30:b/[080Y:BT
0`2[Zj/30:BTY0<0UYJF0P20P80307AdM0<0K6a/0`1RHV820410@0<09bLW0`0K6a/301XJ6P808b<S
0`0[:b/3038b<P<0?3`l0P0X:2P302d];@<0IVIV0`1nOWh208R8R0<0TY:B0`1cLg<30492@P809RHV
0`0_;bl306][J`80Rh^;0`1bLW8304i>CP<0=CDe0P10@40303Ti>@<08R8R0`0?3`l200@412T00000
203oool000H0oooo?`00000300410@P00P820`030`<300@410<0<c<c0P27QhL30:b/[0<0/;2`0`2_
[jl20;fm_@<0e=CD0`3Rh^830>?Sh`80h^;R0`3Xj>P30=_Kf`<0emOG0P3De=@30<S8b0<0^;Rh0`2V
YZH209>CT`<0QXJ60`1jNWX208J6QP<0Ti>C0`27QhL308:2PP80Ph>30`1cLg<306i^KP<0MWIf0P1k
Ng/308B4Q0<0Ph>30`1mOGd206QXJ0<0EEEE0`0o?cl302d];@806QXJ0`0T92@305MGE`<0Kfm_0P1d
M7@307]kN`<0IfMW0`11@D4202h^;P<0=3@d0`1UIFD207YjNP<0IVIV0`1:BTX303<c<`80=SHf0`0h
>3P302LW9`<051@D0P061PHY000000P0oooo00060?ooocl000000`010@4800820P<00`<30`0410@3
03<c<`80QhN70`2/[:`30;2`/0<0[jn_0P2m_Kd30=CDe0<0h^;R0`3Shn<20>;RhP<0j>SX0`3Kfm/3
0=OGe`80e=CD0`38b<P30;Rh^0<0YZJV0P2CTi<308J6QP<0NWYj0P26QXH309>CT`<0QhN70`22PX82
08>3P`<0Lg=c0`1^KVh307IfMP80Ng]k0`24Q8@308>3P`<0OGem0P1XJ6P305EEE@<0?clo0`0];Bd2
01XJ6P<092@T0`1GEeL306m_K`80M7Ad0`1kNg/306MWI`<0@D510P0^;Rh303@d=0<0IFEU0P1jNWX3
06IVIP<0BTY:0`0c<c<203Hf=P<0>3Ph0`0W9bL301@D50801PH6:@0000080?ooo`001P3ooolo0000
00<00@4120020P8300<30`<010@40`0c<c<208N7Q`<0[:b/0`2`/;030:n_[`80_Kfm0`3De=@30>;R
hP<0hn?S0P3Rh^830>SXj0<0fm_K0`3GemL20=CDe0<0b<S80`2h^;P30:JVYP80Ti>C0`26QXH307Yj
NP80QXJ60`2CTi<308N7Q`<0PX:20P23Ph<307=cL`<0KVi^0`1fMWH207]kN`<0Q8B40`23Ph<307em
O@80J6QX0`1EEED303lo?`<0;Bd]0P0J6QX302@T90<0EeMG0`1_Kfl207AdM0<0Ng]k0`1WIfL30451
@@80;Rh^0`0d=3@306EUI@80NWYj0`1VIVH304Y:BP<0<c<c0P0f=SH303Ph>0<09bLW0`0D51@200H6
1RT00000203oool000H0oooo@P00000600410@800P820`030`<300H61P<09BDU0P1GEeL309BDU0<0
_Kfm0`3<c<`20>;RhPH0l?3`0`3/k>`50>OWi`<0iNGU0`32`/8208^;R`<0J6QX0`1OGel305]KF`80
De=C0`1NGUh306m_K`80Rh^;0`2RXZ8309NGU`<0Vi^K0P2DU9@30820P0<0N7Qh0`1XJ6P205mOG`<0
IFEU0`1dM7@308V9R@80Vi^K0`2VYZH309jNWP<0OGem0P1RHV8305]KF`<0Kfm_0`1iNGT207IfMP<0
OGem0`1cLg<305EEE@80A4A40`1YJFT309RHV080R8R80`1FEUH3038b<P<08b<S0P0O7al301LG5`<0
2`/;0`0410@200410BT00000203oool000H0oooo@P00000600410@800P820`030`<300H61P<09BDU
0P1GEeL309BDU0<0_Kfm0`3<c<`20>;RhPH0l?3`0`3/k>`50>OWi`<0iNGU0`32`/8208^;R`<0J6QX
0`1OGel305]KF`80De=C0`1NGUh306m_K`80Rh^;0`2RXZ8309NGU`<0Vi^K0P2DU9@30820P0<0N7Qh
0`1XJ6P205mOG`<0IFEU0`1dM7@308V9R@80Vi^K0`2VYZH309jNWP<0OGem0P1RHV8305]KF`<0Kfm_
0`1iNGT207IfMP<0OGem0`1cLg<305EEE@80A4A40`1YJFT309RHV080R8R80`1FEUH3038b<P<08b<S
0P0O7al301LG5`<02`/;0`0410@200410BT00000203oool000H0ooooBP00000300410@<00P820`0:
2PX202DU9@<0K6a/0`2_[jl30<W9b@80i>CT0`3]kNd30>KViP<0inOW0P3Zj^X30>WYj@<0eMGE0`1o
Ogl202/[:`<02@T90`0<30`301/K6`808B4Q0`14A4@306QXJ080U9BD0`2n_[h30;Vi^@<0`L710P2g
]kL30:VYZ@<0/k>c0`2EUID2075aL@<0FEUI0`1CDe<306EUI@80QhN70`2SXj<30:6QX@<0PH610P1]
KFd306IVIP<0Lg=c0`1mOGd50820P0<0Kfm_0`1DE5@203`l?0<0JFUY0`2@T90207MgM`<0ADE50`0Q
8B4301DE5@8030`<0`051@D300820PD00@41:@0000080?ooo`001P3ooom:000000<00@410`020P83
00X:2P809BDU0`1/K6`30:n_[`<0bLW90P3Ti>@30>g]k@<0i^KV0`3WinL20>[ZjP<0jNWY0`3EeMD3
07moO`80:b/[0`092@T300`<30<06a/K0P0Q8B4304A4A0<0J6QX0P2DU9@30;jn_P<0^KVi0`31`L42
0;Ng]`<0ZJVY0`2c/k<309FEU@80LG5a0`1IFET305=CD`<0IFEU0P27QhL30:>SX`<0XJ6Q0`21PH42
06e]K@<0IVIV0`1cLg<307emO@D0P8200`1_Kfl305ADE080?3`l0`1YJFT3092@T080MgMg0`15ADD3
024Q8@<05ADE0P0<30`300D51@<00P821@010@4Y000000P0oooo00060?ooodX000000`010@430082
0P<02PX:0P0U9BD306a/K0<0[jn_0`39bLT20>CTi0<0kNg]0`3Vi^H30>OWi`80j^[Z0`3YjNT30=GE
e@<0Ogmo0P0[:b/300T92@<030`<0`0K6a/2024Q8@<0A4A40`1XJ6P209BDU0<0_[jn0`2i^KT30<71
`@80]kNg0`2YZJT30;>c/`<0UIFE0P1aLG4305UIF@<0De=C0`1UIFD208N7Q`<0Xj>S0`2QXJ430861
P@80KFe]0`1VIVH307=cL`<0OGem1@20P80306m_K`<0E5AD0P0l?3`306UYJ@<0T92@0P1gMgL304E5
A@<08B4Q0`0E5AD200`<30<01@D50`020P8500410BT00000203oool000H0ooooD`00000200D51@<0
ATI60`27QhL30:FUY@80alO70`3Jf]X30>7Qh@<0jNWY0P3clo<30>o_k`<0bLW90`1XJ6P202PX:0<0
61PH0`0E5AD501LG5`<0=CDe0`1ADE4208j>SP<0b<S80`32`/830<W9b@80a<C40`2`/;030;Rh^0<0
WinO0P21PH4306i^KPH0GEeM0P1TI6@3075aL@<0HV9R0`1;Bd/205ADE0<0HF5Q0`1eMGD308F5Q@80
Rh^;0`22PX8306MWI`<0ATI60P0`<30305MGE`<0Kfm_0P1DE5@302l_;`<05QHF0`0?3`l200L71`<0
10@420020P8Y000000P0oooo00060?oooe<000000P051@D304I6AP<0QhN70`2UYJD20<O7a`<0f][J
0`3QhN430>WYj@80lo?c0`3_knl30<W9b@<0J6QX0P0X:2P301PH60<05ADE1@0G5aL303De=@<0DE5A
0P2>SXh30<S8b0<0`/;20`39bLT20<C4a0<0/;2`0`2h^;P309nOW`80PH610`1^KVh605eMG@80I6AT
0`1aLG43069RHP<0Bd];0P1DE5@3065QH@<0MGEe0`25QHD208^;R`<0PX:20`1WIfL304I6AP80<30`
0`1GEeL306m_K`80E5AD0`0_;bl301HF5P<03`l?0P071`L300@410P00P82:@0000080?ooo`001P3o
oomC000000801@D50`16ATH308N7Q`<0YJFU0P37alL30=[JfP<0hN7Q0`3YjNT20??cl`<0kno_0`39
bLT306QXJ080:2PX0`0H61P301DE5@D05aLG0`0e=CD3055AD@80SXj>0`38b<P30<;2`P<0bLW90P34
a<@30;2`/0<0^;Rh0`2OWil20861P@<0KVi^1P1MGEd206ATI0<0LG5a0`1RHV8304];B`80E5AD0`1Q
HF4307EeM@<0QHF50P2;Rh/308:2PP<0IfMW0`16ATH2030`<0<0EeMG0`1_Kfl205ADE0<0;bl_0`0F
5QH300l?3`801`L70`0410@800820RT00000203oool000H0ooooE@00000302DU9@<0G5aL0`21PH42
0:n_[`<0d=3@0`3UiND30>k^kP80lO7a0`3Vi^H30<G5a@<0QXJ60P1[Jf/306UYJ@<0FUYJ0`12@T82
02l_;`<0>3Ph0`12@T8208R8R0<0b<S80`2j^[X30<C4a080b<S80`2RXZ83092@T0<0OWin0P23Ph<3
09VIV@H0X:2P0P2:RXX308:2PP<0GemO0`13@d<206ATI0<0Ng]k0`22PX8308b<S080QXJ60`1eMGD3
05eMG@<0?Cdm0P0d=3@305eMG@<0I6AT0P0i>CT301<C4`<010@40`092@T200410C@00000203oool0
00H0ooooE@00000302DU9@<0G5aL0`21PH420:n_[`<0d=3@0`3UiND30>k^kP80lO7a0`3Vi^H30<G5
a@<0QXJ60P1[Jf/306UYJ@<0FUYJ0`12@T8202l_;`<0>3Ph0`12@T8208R8R0<0b<S80`2j^[X30<C4
a080b<S80`2RXZ83092@T0<0OWin0P23Ph<309VIV@H0X:2P0P2:RXX308:2PP<0GemO0`13@d<206AT
I0<0Ng]k0`22PX8308b<S080QXJ60`1eMGD305eMG@<0?Cdm0P0d=3@305eMG@<0I6AT0P0i>CT301<C
4`<010@40`092@T200410C@00000203oool000H0ooooE@00000302DU9@<0G5aL0`21PH420:n_[`<0
d=3@0`3UiND30>k^kP80lO7a0`3Vi^H30<G5a@<0QXJ60P1[Jf/306UYJ@<0FUYJ0`12@T8202l_;`<0
>3Ph0`12@T8208R8R0<0b<S80`2j^[X30<C4a080b<S80`2RXZ83092@T0<0OWin0P23Ph<309VIV@H0
X:2P0P2:RXX308:2PP<0GemO0`13@d<206ATI0<0Ng]k0`22PX8308b<S080QXJ60`1eMGD305eMG@<0
?Cdm0P0d=3@305eMG@<0I6AT0P0i>CT301<C4`<010@40`092@T200410C@00000203oool000H0oooo
C@00000300@410D000000`0;2`/303<c<`<0E5AD0P25QHD30;:b/P<0emOG0`3Vi^H20>c/k0<0inOW
0`3<c<`30;>c/`80a<C40`3Hf=P30<?3``<0VIVI0P1^KVh305UIF@<0?Cdm0P1iNGT30;bl_0<0/K6a
0`32`/820=WIf@<0^k^k0`2[Zj/30:VYZ@80]KFe0`3<c<`30<o?c`<0a/K60P2PX:0308f=S@<0IFEU
0`18B4P2075aL@<0R8R80`27QhL308b<S080PH610`1ZJVX3055AD@D0=CDe0`1DE5@304Q8B0805aLG
1P00000300410CH00000203oool000H0ooooC@00000300@410D000000`0;2`/303<c<`<0E5AD0P25
QHD30;:b/P<0emOG0`3Vi^H20>c/k0<0inOW0`3<c<`30;>c/`80a<C40`3Hf=P30<?3``<0VIVI0P1^
KVh305UIF@<0?Cdm0P1iNGT30;bl_0<0/K6a0`32`/820=WIf@<0^k^k0`2[Zj/30:VYZ@80]KFe0`3<
c<`30<o?c`<0a/K60P2PX:0308f=S@<0IFEU0`18B4P2075aL@<0R8R80`27QhL308b<S080PH610`1Z
JVX3055AD@D0=CDe0`1DE5@304Q8B0805aLG1P00000300410CH00000203oool000H0ooooF0000003
01<C4`<09RHV0P14A4@3079bLP<0YZJV0`2o_kl20=?Cd`<0emOG0`2n_[h30;^k^`80g=cL0`3kno/3
0>?Sh`<0/[:b0P27QhL306e]K@<0ADE50P1kNg/30<30`0<0^;Rh0`2c/k<20;Jf]PH0YJFU0`2b/[82
0;Jf]P<0_Kfm0`2/[:`309RHV080Kfm_0`1NGUh30451@@<0>c/k0P1QHF4306i^KP<0P8200`2CTi<2
08j>SP<0O7al0`1OGel303Ti>@80<S8b0`0j>SX302LW9`801`L71P00000300P82080410@0`030`<a
000000P0oooo00060?oooeP000000`0C4a<302HV9P80A4A40`1bLW830:JVYP<0_kno0P3Cdm<30=OG
e`<0_[jn0`2k^k/20=cLg0<0no_k0`3Shn<30;:b/P80QhN70`1]KFd304E5A@80Ng]k0`30`<030;Rh
^0<0/k>c0P2f][H60:FUY@<0/[:b0P2f][H30;fm_@<0[:b/0`2HV9P206m_K`<0GUiN0`11@D4303/k
>`80HF5Q0`1^KVh30820P0<0Ti>C0P2>SXh307alO0<0GemO0`0i>CT2038b<P<0>SXj0`0W9bL200L7
1`H000000`0820P2010@40<00`<3<@0000080?ooo`001P3ooomH000000<04a<C0`0V9RH204A4A0<0
LW9b0`2VYZH30;no_`80dm?C0`3GemL30;jn_P<0^k^k0P3Lg=`30?_kn`<0hn?S0`2b/[8208N7Q`<0
KFe]0`15ADD207]kN`<0`<300`2h^;P30;>c/`80][Jf1P2UYJD30;:b/P80][Jf0`2m_Kd30:b/[0<0
V9RH0P1_Kfl305iNGP<0@D510`0k>c/2065QH@<0KVi^0`20P80309>CT`80SXj>0`1lO7`305mOG`<0
>CTi0P0b<S8303Xj>P<09bLW0P071`L6000000<020P80P0@410300<30c400000203oool000H0oooo
F000000300820P<02@T90P0F5QH303@d=0<0IFEU0`22PX820::RXP<0]KFe0`2VYZH30:6QX@80_;bl
0`3QhN430<o?c`<0YJFU0P22PX8306UYJ@<0?clo0P1ZJVX30;6a/@<0][Jf0`2h^;P50<?3``<0`/;2
0`33`l<20:VYZ@<0TI6A0`1[Jf/3051@D080>3Ph0`0g=cL3038b<P<0>c/k0P1PH60307EeM@<0R8R8
0`2GUiL209:BTP<0O7al0`1HF5P303@d=080<c<c0`0j>SX301hN7P801PH61P00000300410@802`/;
0`020P8a000000P0oooo00060?oooeP000000`020P8300T92@805QHF0`0d=3@306EUI@<0PX:20P2R
XZ830;Fe]@<0YZJV0`2QXJ420;bl_0<0hN7Q0`3?cll30:FUY@80PX:20`1YJFT303lo?`80JVYZ0`2a
/K430;Jf]P<0^;Rh1@33`l<30<;2`P<0`l?30P2YZJT3096AT@<0Jf][0`1@D50203Ph>0<0=cLg0`0b
<S8303/k>`80H61P0`1eMGD308R8R0<0UiNG0P2BTY8307alO0<0F5QH0`0d=3@203<c<`<0>SXj0`0N
7Qh200H61PH000000`010@4200/;2`<00P82<@0000080?ooo`001P3ooomH000000<00P820`092@T2
01HF5P<0=3@d0`1UIFD308:2PP80XZ:R0`2e]KD30:JVYP<0XJ6Q0P2l_;`30>7Qh@<0clo?0`2UYJD2
08:2PP<0JFUY0`0o?cl206YZJP<0/K6a0`2f][H30;Rh^0D0`l?30`32`/830<?3``80ZJVY0`2ATI43
06][J`<0D51@0P0h>3P303Lg=`<0<S8b0`0k>c/2061PH0<0MGEe0`28R8P309NGU`80TY:B0`1lO7`3
05QHF0<0=3@d0P0c<c<303Xj>P<07QhN0P061PH6000000<00@410P0;2`/300820S400000203oool0
00H0ooooD000000300820P800@410`00000300820PP000000`0F5QH302h^;P80Cdm?0`1/K6`607=c
L`80NWYj0`2FUYH309FEU@<0QXJ60P1dM7@306MWI`<0B4Q80P1GEeL308V9R@<0WYjN0`2SXj<20:f]
[@<0`/;20`35aLD30;Ng]`80Ogmo0`16ATH301PH60<02@T90P0J6QX303Hf=P<0De=C0`1WIfL207Mg
M`<0OWin0`27QhL308Z:RP80PX:20`1YJFT304E5A@D0:b/[0`0b<S8301TI6@803@d=0`030`<60000
00801@D5=00000080?ooo`001P3ooom@000000<00P820P010@43000000<00P822000000301HF5P<0
;Rh^0P1?Cdl306a/K0H0Lg=c0P1jNWX309JFUP<0UIFE0`26QXH207AdM0<0IfMW0`18B4P205MGE`<0
RHV90`2NWYh30:>SX`80[Jf]0`32`/830<G5a@<0]kNg0P1oOgl304I6AP<061PH0`092@T201XJ6P<0
=SHf0`1CDe<306MWI`80MgMg0`1nOWh308N7Q`<0RXZ:0P22PX8306UYJ@<0ADE51@0[:b/3038b<P<0
6ATI0P0=3@d300<30`H000000P051@Dd000000P0oooo00060?ooodd000000`030`<301<C4`8030`<
3P00000300820P<02PX:0P0H61P302PX:0<0@T920`1UIFD207MgM`H0Shn?0`1oOgl206e]K@<0GEeM
0`16ATH204Y:BP<0HV9R0`1_Kfl307QhN0D0PH610`1LG5`30451@@80:2PX0`0J6QX301HF5P<061PH
0P0U9BD303Ph>0<0DE5A0`1YJFT208J6QP<0UYJF0`2>SXh30861P@80JFUY0`19BDT302HV9P<04Q8B
0P0M7Ad302PX:0<05ADE0P0;2`/300820S`00000203oool000H0ooooC@00000300<30`<04a<C0P0<
30`>000000<00P820`0:2PX201PH60<0:2PX0`12@T8306EUI@80MgMg1P2?Shl307moO`80KFe]0`1M
GEd304I6AP80BTY:0`1RHV8306m_K`<0N7Qh1@21PH4305aLG0<0@D510P0X:2P301XJ6P<05QHF0`0H
61P202DU9@<0>3Ph0`1ADE4306UYJ@80QXJ60`2FUYH308j>SP<0PH610P1YJFT304U9B@<09RHV0`0B
4Q8201dM7@<0:2PX0`0E5AD200/;2`<00P82?00000080?ooo`001P3ooom=000000<00`<30`0C4a<2
00`<30h000000`020P8300X:2P8061PH0`0X:2P30492@P<0IFEU0P1gMgL608n?S`<0Ogmo0P1]KFd3
05eMG@<0ATI60P1:BTX3069RHP<0Kfm_0`1hN7P50861P@<0G5aL0`11@D4202PX:0<06QXJ0`0F5QH3
01PH60809BDU0`0h>3P3055AD@<0JFUY0P26QXH309JFUP<0SXj>0`21PH4206UYJ@<0BDU90`0V9RH3
018B4P807AdM0`0X:2P301DE5@802`/;0`020P8l000000P0oooo00060?oooe<000000P0410@>0000
00<010@40`0820P200d=3@<04Q8B0`0Z:RX305MGE`80IFEU0`1`L70306][J`<0F5QH0P1<C4`30492
@P<0>CTi0P12@T8304m?C`<0E5AD0`1ADE4204U9B@<0@4100`0L71`500/;2`<05QHF0`0S8b<302d]
;@80=CDe0`0o?cl3051@D0<0JFUY0P24Q8@308b<S0<0QhN70`20P80206MWI`<0B4Q80`0Z:RX3014A
4@805aLG0`0J6QX300h>3P802PX:0`061PH300D51@<00`<30P051@D300@413400000203oool000H0
ooooD`00000200@410h000000`0410@300P820803@d=0`0B4Q8302XZ:P<0EeMG0P1UIFD3071`L0<0
Jf][0`1HF5P204a<C0<0@T920`0i>CT20492@P<0Cdm?0`1DE5@3055AD@80BDU90`10@40301`L70D0
2`/;0`0F5QH302<S8`<0;Bd]0P0e=CD303lo?`<0D51@0`1YJFT208B4Q0<0S8b<0`27QhL30820P080
IfMW0`18B4P302XZ:P<04A4A0P0G5aL301XJ6P<03Ph>0P0:2PX300H61P<01@D50`030`<200D51@<0
10@4<@0000080?ooo`001P3ooomC0000008010@43P00000300@410<020P80P0=3@d3018B4P<0:RXZ
0`1GEeL206EUI@<0L71`0`1[Jf/305QHF080C4a<0`12@T8303Ti>@80@T920`1?Cdl305ADE0<0DE5A
0P19BDT30410@0<071`L1@0;2`/301HF5P<08b<S0`0];Bd203De=@<0?clo0`1@D50306UYJ@80Q8B4
0`2<S8`308N7Q`<0P8200P1WIfL304Q8B0<0:RXZ0`0A4A4201LG5`<06QXJ0`0>3Ph200X:2P<01PH6
0`051@D300<30`801@D50`0410@a000000P0oooo00060?oooe<000000P051@D300T92@<00P822000
000300H61P<020P80P0;2`/300l?3`<09bLW0`1SHf<206m_K`<0L71`0`1XJ6P305IFEP80@d=30`0b
<S83020P80806ATI0`0J6QX301hN7P<06ATI0P0B4Q8301TI6@<03@d=0`0A4A4201DE5@<06a/K0`0T
92@303<c<`80@d=30`1ADE4306ATI0<0OWin0P2:RXX307alO0<0NWYj0`1eMGD206=SH`<0B4Q80`0Y
:BT3014A4@803@d=0`020P83000000800P820`0410@300L71`<020P80P0?3`l300X:2S400000203o
ool000H0ooooD`00000200D51@<02@T90`020P88000000<01PH60`0820P200/;2`<03`l?0`0W9bL3
06=SH`80Kfm_0`1`L70306QXJ0<0EUIF0P13@d<3038b<P<0820P0P0I6AT301XJ6P<07QhN0`0I6AT2
018B4P<06ATI0`0=3@d3014A4@805ADE0`0K6a/302@T90<0<c<c0P13@d<3055AD@<0I6AT0`1nOWh2
08Z:RP<0O7al0`1jNWX307EeM@80Hf=S0`18B4P302TY:@<04A4A0P0=3@d300820P<000000P020P83
00@410<01`L70`0820P200l?3`<02PX:<@0000080?ooo`001P3ooomC000000801@D50`092@T30082
0PP000000`061PH300P820802`/;0`0?3`l302LW9`<0Hf=S0P1_Kfl3071`L0<0J6QX0`1FEUH204=3
@`<0<S8b0`0P820201TI6@<06QXJ0`0N7Qh301TI6@804Q8B0`0I6AT300d=3@<04A4A0P0E5AD301/K
6`<092@T0`0c<c<204=3@`<0DE5A0`1TI6@307inOP80RXZ:0`1lO7`307YjNP<0MGEe0P1SHf<304Q8
B0<0:BTY0`0A4A4200d=3@<00P820`00000200820P<010@40`071`L300P820803`l?0`0:2PXa0000
00P0oooo00060?oooe<000000P092@T300X:2P<00@412000000300L71`<02@T90P0;2`/3010@40<0
:2PX0`1XJ6P207UiN@<0O7al0`1cLg<3061PH080BTY:0`0e=CD301lO7`D05ADE0`0J6QX301LG5`80
5ADE0`0M7Ad3018B4P<061PH0P0N7Qh302@T90<0;2`/0`0j>SX204M7A`<0De=C0`1UIFD307inOP80
Rh^;0`1nOWh307alO0<0MWIf0P1TI6@304M7A`<09RHV0`0?3`l200/;2`P000000`030`<300L71`<0
20P80P0?3`l300/;2c400000203oool000H0ooooD`00000200T92@<02PX:0`010@48000000<01`L7
0`092@T200/;2`<0410@0`0X:2P306QXJ080NGUi0`1lO7`307=cL`<0H61P0P1:BTX303De=@<07alO
1@0E5AD301XJ6P<05aLG0P0E5AD301dM7@<04Q8B0`0H61P201hN7P<092@T0`0/;2`303Xj>P80AdM7
0`1CDe<306EUI@<0OWin0P2;Rh/307inOP<0O7al0`1fMWH206ATI0<0AdM70`0V9RH300l?3`802`/;
2000000300<30`<01`L70`0820P200l?3`<02`/;<@0000080?ooo`001P3ooomC000000D02`/;0`01
0@48000000P01PH60`092@T3020P80<0GemO0P1bLW8307MgM`<0LW9b0`1TI6@2055AD@<0?Shn0`0Y
:BT201`L70<061PH0`0L71`301XJ6P8061PH0`0Q8B4301TI6@<08B4Q0P0X:2P302h^;P<0=cLg0`16
ATH205ADE0<0GUiN0`1]KFd30861P@80RHV90`1hN7P307=cL`<0Jf][0P1HF5P303`l?0<07QhN0`0;
2`/200L71`P000000`030`<300L71`<020P80P0=3@d300X:2P<00P82;P0000080?ooo`001P3ooomC
000000D02`/;0`010@48000000P01PH60`092@T3020P80<0GemO0P1bLW8307MgM`<0LW9b0`1TI6@2
055AD@<0?Shn0`0Y:BT201`L70<061PH0`0L71`301XJ6P8061PH0`0Q8B4301TI6@<08B4Q0P0X:2P3
02h^;P<0=cLg0`16ATH205ADE0<0GUiN0`1]KFd30861P@80RHV90`1hN7P307=cL`<0Jf][0P1HF5P3
03`l?0<07QhN0`0;2`/200L71`P000000`030`<300L71`<020P80P0=3@d300X:2P<00P82;P000008
0?ooo`001P3ooomC000000D02`/;0`010@48000000P01PH60`092@T3020P80<0GemO0P1bLW8307Mg
M`<0LW9b0`1TI6@2055AD@<0?Shn0`0Y:BT201`L70<061PH0`0L71`301XJ6P8061PH0`0Q8B4301TI
6@<08B4Q0P0X:2P302h^;P<0=cLg0`16ATH205ADE0<0GUiN0`1]KFd30861P@80RHV90`1hN7P307=c
L`<0Jf][0P1HF5P303`l?0<07QhN0`0;2`/200L71`P000000`030`<300L71`<020P80P0=3@d300X:
2P<00P82;P0000080?ooo`001P3ooom=000000<00@410`020P8200`<30<02@T92000000300410@<0
1`L70`0410@5000000<06QXJ0`1QHF420820P0<0RHV90`28R8P307moO`80JVYZ0`1CDe<303Ph>080
92@T0`0K6a/301dM7@<07QhN0P0O7al302HV9P<07AdM0`0U9BD2034a<@<0?3`l0`1=CDd305mOG`80
JVYZ0`1`L70307YjNP<0Ph>30P24Q8@306i^KP<0H61P0`1BDU8203dm?@<092@T0`0@410300H61P80
1@D52`00000300820P<010@40P0820P300D51C400000203oool000H0ooooC@00000300410@<00P82
0P0<30`300T92@P000000`010@4300L71`<010@41@00000301XJ6P<0HF5Q0P20P80308V9R@<0R8R8
0`1oOgl206YZJP<0De=C0`0h>3P202@T90<06a/K0`0M7Ad301hN7P807alO0`0V9RH301dM7@<09BDU
0P0a<C4303`l?0<0CDe=0`1OGel206YZJP<0L71`0`1jNWX308>3P`80Q8B40`1^KVh3061PH0<0DU9B
0P0m?Cd302@T90<0410@0`061PH200D51@/000000`020P8300@4108020P80`051@Da000000P0oooo
00060?ooodd000000`010@4300820P8030`<0`092@T8000000<00@410`071`L300@410D000000`0J
6QX3065QH@80P8200`29RHT308R8R0<0Ogmo0P1ZJVX305=CD`<0>3Ph0P0T92@301/K6`<07AdM0`0N
7Qh201lO7`<09RHV0`0M7Ad302DU9@80<C4a0`0l?3`304e=C@<0GemO0P1ZJVX3071`L0<0NWYj0`23
Ph<208B4Q0<0KVi^0`1PH603059BDP80?Cdm0`0T92@3010@40<01PH60P051@D;000000<00P820`04
10@200P820<01@D5<@0000080?ooo`001P3ooom5000000P00@410`020P8300@4108030`<0`0820P8
000000<010@40`0820P300@410D000000`0F5QH305iNGP80Q8B40`2?Shl309:BTP<0S8b<0P1gMgL3
061PH0<0@d=30P0/;2`;020P80<09bLW0`0R8R8302d];@80?3`l0`19BDT305]KF`<0K6a/0P1dM7@3
07IfMPH0NWYj0P1aLG4305IFEP<0ATI60`0f=SH202<S8`<04A4A0`071`L300@410801@D53P000003
00<30`801PH60`020P8a000000P0oooo00060?ooodD0000020010@4300820P<010@40P0<30`300P8
20P000000`0410@300P820<010@41@00000301HF5P<0GUiN0P24Q8@308n?S`<0TY:B0`2<S8`207Mg
M`<0H61P0`13@d<202`/;0/0820P0`0W9bL3028R8P<0;Bd]0P0l?3`304U9B@<0Fe]K0`1/K6`207Ad
M0<0MWIf1P1jNWX2075aL@<0EUIF0`16ATH303Hf=P808b<S0`0A4A4300L71`<010@40P051@D>0000
00<00`<30P061PH300820S400000203oool000H0oooo@P00000;00410@<00`<30`071`L200`<30<0
1PH62000000300@410<01`L70`0410@5000000<05aLG0`1FEUH207emO@<0RHV90`2=SHd308Z:RP80
N7Qh0`1QHF430492@P80:b/[0`0P8206024Q8@808b<S0`0^;Rh303<c<`<0@D510P1>CTh305IFEP<0
I6AT0`1cLg<207UiN@H0NWYj0`1`L70205iNGP<0?Shn0`0/;2`301hN7P803`l?1P030`<300L71`80
20P83P00000300410@8010@4=00000080?ooo`001P3ooom2000000/00@410`030`<300L71`8030`<
0`061PH8000000<010@40`071`L300@410D000000`0G5aL305IFEP80OGem0`29RHT308f=S@<0RXZ:
0P1hN7P3065QH@<0@T920P0[:b/3020P80H08B4Q0P0S8b<302h^;P<0<c<c0`11@D4204i>CP<0EUIF
0`1TI6@307=cL`80NGUi1P1jNWX3071`L080GUiN0`0n?Sh302`/;0<07QhN0P0?3`l600<30`<01`L7
0P0820P>000000<00@410P0410@d000000P0oooo00060?oood8000002`010@4300<30`<01`L70P0<
30`300H61PP000000`0410@300L71`<010@41@00000301LG5`<0EUIF0P1mOGd308V9R@<0SHf=0`2:
RXX207QhN0<0HF5Q0`12@T8202/[:`<0820P1P0Q8B4202<S8`<0;Rh^0`0c<c<30451@@80CTi>0`1F
EUH306ATI0<0Lg=c0P1iNGT607YjNP<0L71`0P1NGUh303hn?P<0;2`/0`0N7Qh200l?3`H00`<30`07
1`L200P820h000000`010@4200@413@00000203oool000H0ooooA@00000800410@<00`<30`0820P2
00/;2`<01@D52000000300<30`H01`L70P030`<300H61P<06ATI0`1@D50207MgM`<0Q8B40`28R8P3
08J6QP80MGEe0`1OGel30410@080:b/[2@0T92@202LW9`<0=CDe0`12@T8305EEE@80HF5Q0`1UIFD3
06e]K@<0NGUi0P1kNg/307YjNP<0MWIf0`1TI6@204U9B@<09RHV0`0F5QH300X:2PD000000`030`<3
00/;2`8030`<0`051@D>000000800`<3=00000080?ooo`001P3ooom5000000P00@410`030`<300P8
20802`/;0`051@D8000000<00`<31P071`L200<30`<01PH60`0I6AT3051@D080MgMg0`24Q8@308R8
R0<0QXJ60P1eMGD305mOG`<0@4100P0[:b/902@T90809bLW0`0e=CD30492@P<0EEEE0P1QHF4306EU
I@<0KFe]0`1iNGT207]kN`<0NWYj0`1fMWH306ATI080BDU90`0V9RH301HF5P<02PX:1@00000300<3
0`<02`/;0P0<30`300D51@h000000P030`<d000000P0oooo00060?ooodD0000020010@4300<30`<0
20P80P0;2`/300D51@P000000`030`<600L71`800`<30`061PH301TI6@<0D51@0P1gMgL308B4Q0<0
R8R80`26QXH207EeM@<0GemO0`10@40202/[:`T092@T0P0W9bL303De=@<0@T920`1EEED2065QH@<0
IFEU0`1]KFd307UiN@80Ng]k0`1jNWX307IfMP<0I6AT0P19BDT302HV9P<05QHF0`0:2PX5000000<0
0`<30`0;2`/200`<30<01@D53P00000200<30c@00000203oool000H0ooooBP00000300410@<00P82
0`0:2PX2010@40<01PH62`00000300L71`<02@T90P0820P300d=3@<06ATI0`17AdL2075aL@<0PH61
0`24Q8@30861P@80M7Ad0`1OGel30492@P80<C4a0`0^;Rh302d];@<0:b/[0P0];Bd303`l?0<0D51@
0`1WIfL207=cL`<0MGEe0`1hN7P307alO080MgMg0`1`L70306MWI`<0Cdm?0P0_;bl300h>3P<00`<3
2000000300@410<03Ph>0P0?3`l300H61P/000000`020P8200@413@00000203oool000H0ooooBP00
000300410@<00P820`0:2PX2010@40<01PH62`00000300L71`<02@T90P0820P300d=3@<06ATI0`17
AdL2075aL@<0PH610`24Q8@30861P@80M7Ad0`1OGel30492@P80<C4a0`0^;Rh302d];@<0:b/[0P0]
;Bd303`l?0<0D51@0`1WIfL207=cL`<0MGEe0`1hN7P307alO080MgMg0`1`L70306MWI`<0Cdm?0P0_
;bl300h>3P<00`<32000000300@410<03Ph>0P0?3`l300H61P/000000`020P8200@413@00000203o
ool000H0ooooBP00000300410@<00P820`0:2PX2010@40<01PH62`00000300L71`<02@T90P0820P3
00d=3@<06ATI0`17AdL2075aL@<0PH610`24Q8@30861P@80M7Ad0`1OGel30492@P80<C4a0`0^;Rh3
02d];@<0:b/[0P0];Bd303`l?0<0D51@0`1WIfL207=cL`<0MGEe0`1hN7P307alO080MgMg0`1`L703
06MWI`<0Cdm?0P0_;bl300h>3P<00`<32000000300@410<03Ph>0P0?3`l300H61P/000000`020P82
00@413@00000203oool000H0ooooC@00000300820P<051@D0P0E5AD300820PP000000`020P8300X:
2PD03Ph>0`0B4Q8301@D50<0=CDe0P1UIFD307]kN`<0O7al0`1eMGD206YZJP<0EUIF0`0l?3`203Hf
=P<0>SXj1P0h>3P20492@P<0BDU90`1EEED306][J`80O7al1P26QXH30861P@80Jf][0`1HF5P304E5
A@<0:RXZ0P0E5AD300@410h000000`0820P200d=3@<01@D52`00000300820P800@411P030`<30082
0P800@41:@0000080?ooo`001P3ooom=000000<00P820`0D51@201DE5@<00P822000000300820P<0
2PX:1@0>3Ph3018B4P<051@D0`0e=CD206EUI@<0Ng]k0`1lO7`307EeM@80JVYZ0`1FEUH303`l?080
=SHf0`0j>SX603Ph>080@T920`19BDT305EEE@<0Jf][0P1lO7`608J6QP<0PH610P1[Jf/305QHF0<0
ADE50`0Z:RX201DE5@<010@43P00000300P820803@d=0`051@D;000000<00P820P010@4600<30`<0
0P820P010@4Y000000P0oooo00060?ooodd000000`010@4301HF5P805ADE3P00000300T92@<03`l?
0P0A4A4301@D50<03Ph>0`0T92@205MGE`<0Lg=c0`1eMGD306i^KP80IfMW0`1GEeL30410@080@D51
0`1:BTX604U9B@80E5AD0`1EEED305]KF`<0Jf][0P1jNWX308>3P`<0P8200`1bLW8205ADE0<0?3`l
0`0T92@300d=3@8010@41P010@4;000000<00P820P071`L;000000H00@410P00000300D51@<02@T9
0`051@D200820RT00000203oool000H0ooooC@00000300410@<05QHF0P0E5AD>000000<02@T90`0?
3`l2014A4@<051@D0`0>3Ph302@T9080EeMG0`1cLg<307EeM@<0KVi^0P1WIfL305MGE`<0@4100P11
@D4304Y:BPH0BDU90P1DE5@305EEE@<0Fe]K0`1[Jf/207YjNP<0Ph>30`20P803079bLP80E5AD0`0l
?3`302@T90<03@d=0P0410@600410@/000000`020P8200L71`/000001P010@42000000<01@D50`09
2@T300D51@800P82:@0000080?ooo`001P3ooom=000000<00@410`0F5QH201DE5@h000000`092@T3
00l?3`804A4A0`0D51@300h>3P<092@T0P1GEeL307=cL`<0MGEe0`1^KVh206MWI`<0EeMG0`10@402
0451@@<0BTY:1P19BDT205ADE0<0EEEE0`1KFe/306][J`80NWYj0`23Ph<30820P0<0LW9b0P1DE5@3
03`l?0<092@T0`0=3@d200@410H00@412`00000300820P801`L72`00000600410@8000000`051@D3
00T92@<01@D50P020P8Y000000P0oooo00060?oooe0000000`0B4Q82010@40h000000`030`<300X:
2P803`l?0`0D51@300`<30<05QHF0P14A4@306EUI@<0KFe]0`1^KVh206][J`<0HF5Q0`1=CDd204a<
C0<0EeMG1P1HF5P2061PH0<0Hf=S0`1ZJVX5075aL@<0K6a/0`1OGel304i>CP80=CDe0`0T92@301<C
4`<00`<31@00000300410@h000000P010@4;000000<00@411@00000300@410<02PX:0`061PH20082
0RT00000203oool000H0ooooD0000003018B4P80410@3P00000300<30`<02PX:0P0?3`l301@D50<0
30`<0`0F5QH204A4A0<0IFEU0`1]KFd306i^KP80Jf][0`1QHF4304e=C@80C4a<0`1GEeL605QHF080
H61P0`1SHf<306YZJPD0LG5a0`1/K6`305mOG`<0CTi>0P0e=CD302@T90<04a<C0`030`<5000000<0
0@413P00000200410@/000000`010@45000000<010@40`0:2PX300H61P800P82:@0000080?ooo`00
1P3ooom@000000<04Q8B0P0@410>000000<00`<30`0:2PX200l?3`<051@D0`0<30`301HF5P80A4A4
0`1UIFD306e]K@<0KVi^0P1[Jf/3065QH@<0CDe=0P1<C4`305MGE`H0F5QH0P1PH60306=SH`<0JVYZ
1@1aLG4306a/K0<0GemO0`1>CTh203De=@<092@T0`0C4a<300<30`D000000`010@4>000000800@41
2`00000300410@D000000`0410@300X:2P<01PH60P020P8Y000000P0oooo00060?oooe0000001@0<
30`;000000<00P820`010@4300D51@802PX:0`0?3`l300D51@<01PH60P0Z:RX304U9B@<0F5QH0`1R
HV8206IVIP<0IFEU0`1JFUX205QHF0<0HF5Q0`1TI6@5065QH@<0HV9R0`1XJ6P306IVIP80GEeM0`1A
DE4304A4A0<0=CDe0P0U9BD301XJ6P<03`l?0`030`<5000000<00@416000000300410@<00P821@00
000300820P<02PX:0`061PH200410BT00000203oool000H0ooooD000000500`<30/000000`020P83
00410@<01@D50P0:2PX300l?3`<01@D50`061PH202XZ:P<0BDU90`1HF5P3069RHP80IVIV0`1UIFD3
05YJFP80F5QH0`1QHF4306ATI0D0HF5Q0`1RHV8306QXJ0<0IVIV0P1MGEd3055AD@<0A4A40`0e=CD2
02DU9@<06QXJ0`0?3`l300<30`D000000`010@4H000000<00@410`020P85000000<00P820`0:2PX3
00H61P800@41:@0000080?ooo`001P3ooom@000000D030`<2`00000300820P<00@410`051@D200X:
2P<03`l?0`051@D300H61P80:RXZ0`19BDT305QHF0<0HV9R0P1VIVH306EUI@<0FUYJ0P1HF5P3065Q
H@<0I6AT1@1QHF43069RHP<0J6QX0`1VIVH205eMG@<0DE5A0`14A4@303De=@809BDU0`0J6QX300l?
3`<00`<31@00000300410AP000000`010@4300820PD000000`020P8300X:2P<01PH60P010@4Y0000
00P0oooo00060?oooe0000000`0820P200T92@T000000P020P8300<30`<00@410`061PH200/;2`<0
3`l?0`0410@3000000806ATI0`0e=CD304=3@`<0CDe=0P1FEUH305]KF`<0F5QH0P1LG5`306MWI`<0
J6QX0`1TI6@205iNGP<0G5aL0`1OGel305UIF@80Cdm?0`15ADD303Ti>@<0:b/[0P0L71`301<C4`<0
20P82000000300820QP000001P051@D5000000<00P820`0;2`/300H61P800@41:@0000080?ooo`00
1P3ooom@000000<020P80P092@T9000000800P820`030`<300410@<01PH60P0;2`/300l?3`<010@4
0`00000201TI6@<0=CDe0`13@d<304e=C@80EUIF0`1KFe/305QHF080G5aL0`1WIfL306QXJ0<0I6AT
0P1NGUh305aLG0<0GemO0`1IFET204m?C`<0ADE50`0i>CT302/[:`8071`L0`0C4a<300P820P00000
0`020P8H000000H01@D51@00000300820P<02`/;0`061PH200410BT00000203oool000H0ooooD000
000300H61P801`L72`00000600410@<020P80P0?3`l301@D50<02@T90`00000201HF5P<0<30`0`0l
?3`304A4A080CDe=0`1BDU83051@D080F5QH0`1VIVH306QXJ0<0Hf=S0P1MGEd305YJFP<0GEeM0`1F
EUH204Y:BP<0?clo0`0a<C43028R8P8051@D0`0<30`300<30`P000000`030`<300@410800`<30`00
000300410@<00P820P030`<300D51@<000000P010@4300D51@<010@41@00000300820P<02@T90`06
1PH200410BT00000203oool000H0ooooD000000300H61P801`L72`00000600410@<020P80P0?3`l3
01@D50<02@T90`00000201HF5P<0<30`0`0l?3`304A4A080CDe=0`1BDU83051@D080F5QH0`1VIVH3
06QXJ0<0Hf=S0P1MGEd305YJFP<0GEeM0`1FEUH204Y:BP<0?clo0`0a<C43028R8P8051@D0`0<30`3
00<30`P000000`030`<300@410800`<30`00000300410@<00P820P030`<300D51@<000000P010@43
00D51@<010@41@00000300820P<02@T90`061PH200410BT00000203oool000H0ooooD000000300H6
1P801`L72`00000600410@<020P80P0?3`l301@D50<02@T90`00000201HF5P<0<30`0`0l?3`304A4
A080CDe=0`1BDU83051@D080F5QH0`1VIVH306QXJ0<0Hf=S0P1MGEd305YJFP<0GEeM0`1FEUH204Y:
BP<0?clo0`0a<C43028R8P8051@D0`0<30`300<30`P000000`030`<300@410800`<30`0000030041
0@<00P820P030`<300D51@<000000P010@4300D51@<010@41@00000300820P<02@T90`061PH20041
0BT00000203oool000H0ooooD`00000200@4114000000`071`L2014A4@<061PH0`0=3@d300000080
4A4A0`0Y:BT303De=@<0?clo0P19BDT3055AD@<0D51@0P1GEeL306IVIP<0JFUY0`1QHF4205MGE`<0
F5QH0`1OGel305UIF@80B4Q80`0f=SH302@T90<05ADE0P0<30`300P820<00`<32000000300410@<0
10@40P061PH300@410<01PH60`051@D200@410<01@D50`010@4200@410<01`L70`051@D5000000<0
0P820`0820P300D51@800@41:@0000080?ooo`001P3ooomC0000008010@44@00000300L71`804A4A
0`0H61P300d=3@<000000P0A4A4302TY:@<0=CDe0`0o?cl204U9B@<0DE5A0`1@D50205MGE`<0IVIV
0`1YJFT3065QH@80EeMG0`1HF5P305mOG`<0FEUI0P18B4P303Hf=P<092@T0`0E5AD200`<30<020P8
0`030`<8000000<00@410`0410@200H61P<010@40`061PH300D51@8010@40`051@D300410@8010@4
0`071`L300D51@D000000`020P8300P820<01@D50P010@4Y000000P0oooo00060?oooe<000000P04
10@A000000<01`L70P0A4A4301PH60<03@d=0`000002014A4@<0:BTY0`0e=CD303lo?`80BDU90`1A
DE43051@D080EeMG0`1VIVH306UYJ@<0HF5Q0P1GEeL305QHF0<0GemO0`1IFET204Q8B0<0=SHf0`0T
92@301DE5@8030`<0`0820P300<30`P000000`010@4300@410801PH60`0410@300H61P<01@D50P04
10@300D51@<00@410P0410@300L71`<01@D51@00000300820P<020P80`051@D200410BT00000203o
ool000H0ooooD`00000200410A4000000`092@T201@D50<07AdM0`0B4Q8300410@803Ph>0`0S8b<3
02d];@<0=SHf0P0o?cl304I6AP<0A4A40P1<C4`305iNGP<0HV9R0`1LG5`205ADE0<0F5QH0`1PH603
05YJFP80ADE50`0^;Rh301XJ6P<02`/;0P051@D300@410<00`<32000000300820P<01PH61@0820P3
00T92@<020P80P071`L300T92@D010@40`051@D300<30`D000000`010@4300D51@<00`<30P010@4Y
000000P0oooo00060?oooe<000000P010@4A000000<02@T90P0D51@301dM7@<04Q8B0`010@4200h>
3P<08b<S0`0];Bd303Hf=P80?clo0`16ATH304A4A080C4a<0`1NGUh3069RHP<0G5aL0P1DE5@305QH
F0<0H61P0`1JFUX204E5A@<0;Rh^0`0J6QX300/;2`801@D50`0410@300<30`P000000`020P8300H6
1PD020P80`092@T300P820801`L70`092@T500@410<01@D50`030`<5000000<00@410`051@D300<3
0`800@41:@0000080?ooo`001P3ooom@000000<00@410P020P8>000000<00@410`0:2PX201DE5@<0
7alO0`0I6AT300l?3`808R8R0`0k>c/304M7A`<0Cdm?0P1CDe<305EEE@<0Bd];0P1<C4`305aLG0<0
HV9R0`1MGEd205MGE`<0G5aL0`1RHV8305]KF`80@D510`0V9RH3014A4@<00`<30P00000300410@<0
0P822000000300<30`<010@43@061PH300P820<00`<31@020P8;000000<00P820`010@4[000000P0
oooo00060?oooe0000000`010@4200820Ph000000`010@4300X:2P805ADE0`0O7al301TI6@<03`l?
0P0R8R8303/k>`<0AdM70`1?Cdl205=CD`<0EEEE0`1;Bd/204a<C0<0G5aL0`1RHV8305eMG@80EeMG
0`1LG5`3069RHP<0Fe]K0P11@D4302HV9P<04A4A0`030`<2000000<00@410`020P88000000<00`<3
0`0410@=00H61P<020P80`030`<500820P/000000`020P8300410B/00000203oool000H0ooooD000
000300410@800P823P00000300410@<02PX:0P0E5AD301lO7`<06ATI0`0?3`l2028R8P<0>c/k0`17
AdL304m?C`80De=C0`1EEED304];B`80C4a<0`1LG5`3069RHP<0GEeM0P1GEeL305aLG0<0HV9R0`1K
Fe/20451@@<09RHV0`0A4A4300<30`8000000`010@4300820PP000000`030`<300@410d01PH60`08
20P300<30`D00P822`00000300820P<00@41:`0000080?ooo`001P3ooomC000000800P821P000003
00410@8010@40`030`<300820P<020P80P0A4A4301`L70H06QXJ0P0f=SH305EEE@<0J6QX0`1eMGD2
07UiN@<0NWYj0`1/K6`206ATI0<0KVi^0`1dM7@306][J`80GEeM0`1OGel3069RHP<0EEEE0P0g=cL3
01TI6@<01PH62000000300<30`<01PH61@00000300820P<000001@010@4600820P800@410`030`<3
00410@D00`<32`00000300410Bh00000203oool000H0ooooD`00000200820PH000000`010@4200@4
10<00`<30`020P8300P820804A4A0`0L71`601XJ6P80=SHf0`1EEED306QXJ0<0MGEe0P1iNGT307Yj
NP<0K6a/0P1TI6@306i^KP<0M7Ad0`1[Jf/205eMG@<0GemO0`1RHV8305EEE@80=cLg0`0I6AT300H6
1PP000000`030`<300H61PD000000`020P83000000D00@411P020P8200410@<00`<30`010@4500<3
0`/000000`010@4^000000P0oooo00060?oooe<000000P020P86000000<00@410P0410@300<30`<0
0P820`0820P2014A4@<071`L1P0J6QX203Hf=P<0EEEE0`1XJ6P307EeM@80NGUi0`1jNWX306a/K080
I6AT0`1^KVh307AdM0<0Jf][0P1MGEd305mOG`<0HV9R0`1EEED203Lg=`<06ATI0`061PH8000000<0
0`<30`061PH5000000<00P820`00000500410@H00P820P010@4300<30`<00@411@030`<;000000<0
0@41;P0000080?ooo`001P3ooomC000000800@410`00000300410@<01PH60P0820P300D51@<00`<3
0`0820P2010@40<06ATI0`0H61P301@D5080:BTY0`14A4@305MGE`<0IVIV0P1/K6`3071`L0<0IfMW
0P1QHF4306][J`<0L71`0`1XJ6P505UIF@<0FUYJ0`1:BTX202`/;0<0410@2`00000300@410<01PH6
1@00000300820PD000000`010@4800820P<01PH60`051@D200H61P<010@42`00000300410Bh00000
203oool000H0ooooD`00000200410@<000000`010@4300H61P8020P80`051@D300<30`<020P80P0@
410301TI6@<061PH0`0D51@202TY:@<0A4A40`1GEeL306IVIP80K6a/0`1`L70306MWI`80HF5Q0`1[
Jf/3071`L0<0J6QX1@1IFET305YJFP<0BTY:0P0/;2`3010@40/000000`0410@300H61PD000000`02
0P85000000<00@4120020P8300H61P<01@D50P061PH300@410/000000`010@4^000000P0oooo0006
0?oooe<000000P010@43000000<00@410`061PH200P820<01@D50`030`<300P82080410@0`0I6AT3
01PH60<051@D0P0Y:BT304A4A0<0EeMG0`1VIVH206a/K0<0L71`0`1WIfL2065QH@<0Jf][0`1`L703
06QXJ0D0FEUI0`1JFUX304Y:BP80;2`/0`0@410;000000<010@40`061PH5000000<00P821@000003
00410@P00P820`061PH300D51@801PH60`0410@;000000<00@41;P0000080?ooo`001P3ooom@0000
00<00`<31@00000300410@<020P80P0;2`/300L71`<010@40`0820P2010@40<06ATI0`0H61P300l?
3`80820P0`0j>SX304e=C@<0FUYJ0P1QHF4306MWI`<0HF5Q0P1PH60306e]K@<0LW9b0`1]KFd2069R
HP<0GUiN0`1GEeL30492@P8092@T0`0;2`/;000000<00@410`020P82000000H01`L70`030`<20041
0@<000000`010@4300820P801@D50`0?3`l300d=3@802@T90`0410@l000000P0oooo00060?oooe00
00000`030`<5000000<00@410`0820P200/;2`<01`L70`0410@300P82080410@0`0I6AT301PH60<0
3`l?0P0P820303Xj>P<0CDe=0`1JFUX2065QH@<0IfMW0`1QHF42061PH0<0KFe]0`1bLW8306e]K@80
HV9R0`1NGUh305MGE`<0@T920P0T92@300/;2`/000000`010@4300820P8000001P071`L300<30`80
0@410`00000300410@<00P820P051@D300l?3`<03@d=0P092@T300@413`00000203oool000H0oooo
D000000300<30`P000000`0820P200d=3@<020P80`051@D300P820803@d=0`0D51@301DE5@<03`l?
0P0S8b<303hn?P<0D51@0`1KFe/206ATI0<0Jf][0`1ZJVX206e]K@<0NGUi0`1lO7`307EeM@80IFEU
0`1HF5P304E5A@<0:RXZ0P0C4a<300D51@<00@414000000300`<30<02PX:0`051@D5000000H00@41
0P071`L301DE5@<04Q8B0P0=3@d300D51C`00000203oool000H0ooooD000000300<30`P000000`08
20P200d=3@<020P80`051@D300P820803@d=0`0D51@301DE5@<03`l?0P0S8b<303hn?P<0D51@0`1K
Fe/206ATI0<0Jf][0`1ZJVX206e]K@<0NGUi0`1lO7`307EeM@80IFEU0`1HF5P304E5A@<0:RXZ0P0C
4a<300D51@<00@414000000300`<30<02PX:0`051@D5000000H00@410P071`L301DE5@<04Q8B0P0=
3@d300D51C`00000203oool000H0ooooD000000300<30`P000000`0820P200d=3@<020P80`051@D3
00P820803@d=0`0D51@301DE5@<03`l?0P0S8b<303hn?P<0D51@0`1KFe/206ATI0<0Jf][0`1ZJVX2
06e]K@<0NGUi0`1lO7`307EeM@80IFEU0`1HF5P304E5A@<0:RXZ0P0C4a<300D51@<00@4140000003
00`<30<02PX:0`051@D5000000H00@410P071`L301DE5@<04Q8B0P0=3@d300D51C`00000203oool0
00H0ooooF`00000300X:2P80410@0`0=3@d300X:2P<02`/;0P0=3@d3014A4@<051@D0`0C4a<202XZ
:P<0A4A40`1EEED305iNGP80IfMW1P1_Kfl207AdM0<0OWin0`1mOGd3079bLP80GEeM0`1:BTX3038b
<P<05aLG0P061PH300410@<010@44000000300`<30<02PX:0`061PH5000000<00P820`010@4200L7
1`H051@D0P0>3Ph300H61P<00@41>@0000080?ooo`001P3ooomK000000<02PX:0P0@410300d=3@<0
2PX:0`0;2`/200d=3@<04A4A0`0D51@301<C4`80:RXZ0`14A4@305EEE@<0GUiN0P1WIfL606m_K`80
M7Ad0`1nOWh307emO@<0LW9b0P1MGEd304Y:BP<0<S8b0`0G5aL200H61P<00@410`0410@@000000<0
30`<0`0:2PX300H61PD000000`020P8300410@801`L71P0D51@200h>3P<01PH60`010@4i000000P0
oooo00060?oooe/000000`0:2PX2010@40<03@d=0`0:2PX300/;2`803@d=0`0A4A4301@D50<04a<C
0P0Z:RX304A4A0<0EEEE0`1NGUh206MWI`H0Kfm_0P1dM7@307inOP<0OGem0`1bLW8205eMG@<0BTY:
0`0b<S8301LG5`801PH60`010@4300@4110000000`0<30`300X:2P<01PH61@00000300820P<00@41
0P071`L601@D50803Ph>0`061PH300410CT00000203oool000H0ooooF000000300410@<03@d=0P0E
5AD301<C4`P04A4A0`0B4Q8301HF5P<06ATI0P0b<S8304];B`<0Fe]K0`1QHF4206QXJ0H0Kfm_0P1d
M7@307alO0<0N7Qh0`1[Jf/2059BDP<0?3`l0`0Q8B4300P820D000000`071`L300<30`d000000`0;
2`/300T92@<01PH61@00000300@410<000000P061PH3018B4P<04a<C0P0>3Ph300H61P<00@41>@00
00080?ooo`001P3ooomH000000<00@410`0=3@d201DE5@<04a<C200A4A43018B4P<05QHF0`0I6AT2
038b<P<0Bd];0`1KFe/3065QH@80J6QX1P1_Kfl207AdM0<0O7al0`1hN7P306][J`80DU9B0`0l?3`3
024Q8@<020P81@00000300L71`<00`<33@00000300/;2`<02@T90`061PH5000000<010@40`000002
00H61P<04Q8B0`0C4a<200h>3P<01PH60`010@4i000000P0oooo00060?oooeP000000`051@D3010@
40D061PH1P0G5aL201HF5P<05ADE0`0H61P301lO7`80>3Ph0`1>CTh305eMG@<0Hf=S0P1YJFT3071`
L0<0Kfm_0P1cLg<307MgM`<0LW9b0`1QHF420492@P<0;2`/0`0F5QH300410@D000000`071`L300D5
1@d000001P051@D300@4108000000`010@4300L71`<00P820P0410@300d=3@<04A4A0P0>3Ph300L7
1`<010@40`010@4f000000P0oooo00060?oooeP000000`051@D3010@40D061PH1P0G5aL201HF5P<0
5ADE0`0H61P301lO7`80>3Ph0`1>CTh305eMG@<0Hf=S0P1YJFT3071`L0<0Kfm_0P1cLg<307MgM`<0
LW9b0`1QHF420492@P<0;2`/0`0F5QH300410@D000000`071`L300D51@d000001P051@D300@41080
00000`010@4300L71`<00P820P0410@300d=3@<04A4A0P0>3Ph300L71`<010@40`010@4f000000P0
oooo00060?oooeP000000`051@D3010@40D061PH1P0G5aL201HF5P<05ADE0`0H61P301lO7`80>3Ph
0`1>CTh305eMG@<0Hf=S0P1YJFT3071`L0<0Kfm_0P1cLg<307MgM`<0LW9b0`1QHF420492@P<0;2`/
0`0F5QH300410@D000000`071`L300D51@d000001P051@D300@4108000000`010@4300L71`<00P82
0P0410@300d=3@<04A4A0P0>3Ph300L71`<010@40`010@4f000000P0oooo00060?oooeD000000`04
10@300P820<04Q8B0P0I6AT601`L70<06a/K0P0I6AT301PH60<06QXJ0`0W9bL20410@0<0E5AD0`1Q
HF4306MWI`80JVYZ0`1_Kfl506][J`<0K6a/0`1UIFD3055AD@80<30`0`0M7Ad300d=3@P000001P05
1@DC000000<00P820P00000300<30`<02@T90`030`<200410@<01PH60`0<30`200d=3@<01`L70`05
1@D500@413@00000203oool000H0ooooE@00000300@410<020P80`0B4Q8201TI6@H071`L0`0K6a/2
01TI6@<061PH0`0J6QX302LW9`80@4100`1DE5@3065QH@<0IfMW0P1ZJVX306m_K`D0Jf][0`1/K6`3
06EUI@<0DE5A0P0`<30301dM7@<03@d=2000000600D51A<000000`020P82000000<00`<30`092@T3
00<30`800@410`061PH300`<30803@d=0`071`L300D51@D010@4=00000080?ooo`001P3ooomE0000
00<010@40`0820P3018B4P806ATI1P0L71`301/K6`806ATI0`0H61P301XJ6P<09bLW0P10@40305AD
E0<0HF5Q0`1WIfL206YZJP<0Kfm_1@1[Jf/306a/K0<0IFEU0`1ADE42030`<0<07AdM0`0=3@d80000
00H01@D54`00000300820P8000000`030`<300T92@<00`<30P010@4300H61P<030`<0P0=3@d300L7
1`<01@D51@0410@d000000P0oooo00060?ooodP000000P010@4;000000<01`L70`0;2`/301<C4`80
6ATI0`0M7Ad301lO7`<07QhN0P0L71`301XJ6P<07AdM0`0];Bd204I6AP<0EUIF0`1SHf<306QXJ080
JFUY0`1/K6`306IVIP80Hf=S0`1QHF4305YJFP<0A4A40P0Q8B43014A4@<020P82000000300<30`<0
10@42000000300<30`d000000`051@D300/;2`<010@40P00000300410@<02@T90P0<30`300L71`H0
1PH60P071`L300820S400000203oool000H0ooooB000000200410@/000000`071`L300/;2`<04a<C
0P0I6AT301dM7@<07alO0`0N7Qh201`L70<06QXJ0`0M7Ad302d];@80ATI60`1FEUH306=SH`<0J6QX
0P1YJFT306a/K0<0IVIV0P1SHf<3065QH@<0FUYJ0`14A4@2024Q8@<04A4A0`0820P8000000<00`<3
0`0410@8000000<00`<33@00000300D51@<02`/;0`0410@2000000<00@410`092@T200`<30<01`L7
1P061PH200L71`<00P82<@0000080?ooo`001P3ooom8000000800@412`00000300L71`<02`/;0`0C
4a<201TI6@<07AdM0`0O7al301hN7P8071`L0`0J6QX301dM7@<0;Bd]0P16ATH305IFEP<0Hf=S0`1X
J6P206UYJ@<0K6a/0`1VIVH206=SH`<0HF5Q0`1JFUX304A4A0808B4Q0`0A4A4300P820P000000`03
0`<300@410P000000`030`<=000000<01@D50`0;2`/300@4108000000`010@4300T92@8030`<0`07
1`L600H61P801`L70`020P8a000000P0oooo00060?ooodD0000020010@48000000<030`<0`0>3Ph3
01<C4`8061PH0`0M7Ad3020P80<07alO0P0L71`301/K6`<07QhN0`0c<c<204];B`<0FEUI0`1TI6@3
06QXJ080IVIV0`1WIfL305eMG@80EeMG0`1CDe<304a<C0<0=cLg0P0G5aL300T92@<00`<320000003
00820P<010@40P010@46000000<01@D53@00000300H61P<02`/;0`0410@5000000<01`L70P0<30`3
00P820H01`L70P0:2PX300@413400000203oool000H0ooooA@00000800410@P000000`0<30`300h>
3P<04a<C0P0H61P301dM7@<0820P0`0O7al201`L70<06a/K0`0N7Qh303<c<`80Bd];0`1IFET306AT
I0<0J6QX0P1VIVH306MWI`<0GEeM0P1GEeL305=CD`<0C4a<0`0g=cL201LG5`<02@T90`030`<80000
00<00P820`0410@200410@H000000`051@D=000000<01PH60`0;2`/300@410D000000`071`L200`<
30<020P81P071`L200X:2P<010@4<@0000080?ooo`001P3ooom5000000P00@4120000006010@40<0
51@D0P0H61P301hN7P<0820P0`0N7Qh201/K6`<06QXJ0`0N7Qh303De=@80CDe=0`1IFET306=SH`<0
IVIV0P1RHV8305mOG`<0De=C0P19BDT304=3@`<0?Cdm0`0[:b/2010@40<01@D50`010@48000000<0
0P820`030`<200410@H000000`051@D=000000<01@D50`092@T300<30`D000000`051@D200/;2`<0
20P80`071`L300P820802`/;0`051@Da000000P0oooo00060?ooodD0000020010@48000000H0410@
0`0D51@201PH60<07QhN0`0P820301hN7P806a/K0`0J6QX301hN7P<0=CDe0P1=CDd305UIF@<0Hf=S
0`1VIVH2069RHP<0GemO0`1CDe<204U9B@<0@d=30`0m?Cd302/[:`80410@0`051@D300410@P00000
0`020P8300<30`800@411P00000300D51@d000000`051@D300T92@<00`<31@00000300D51@802`/;
0`0820P300L71`<020P80P0;2`/300D51C400000203oool000H0ooooA@00000800410@P000001P0@
410301@D508061PH0`0N7Qh3020P80<07QhN0P0K6a/301XJ6P<07QhN0`0e=CD204e=C@<0FEUI0`1S
Hf<306IVIP80HV9R0`1OGel305=CD`80BDU90`13@d<303dm?@<0:b/[0P0@410300D51@<00@412000
000300820P<00`<30P010@46000000<01@D53@00000300D51@<02@T90`030`<5000000<01@D50P0;
2`/300P820<01`L70`0820P200/;2`<01@D5<@0000080?ooo`001P3ooom2000000/00@411P000002
00D51@<04a<C0`0B4Q8301@D508061PH0`0M7Ad301lO7`<07AdM0P0I6AT301XJ6P<07alO0`0g=cL2
04i>CP<0FEUI0`1PH603065QH@80Fe]K0`1DE5@304I6AP80>CTi0`0a<C4302`/;0<07alO0P0;2`/3
00<30`/000000`010@4300<30`800@411P00000300D51@d000000`030`<300L71`<00P821@000003
00@410802PX:0`0820P600L71`802`/;0`051@Da000000P0oooo00060?oood8000002`010@460000
00801@D50`0C4a<3018B4P<051@D0P0H61P301dM7@<07alO0`0M7Ad201TI6@<06QXJ0`0O7al303Lg
=`80CTi>0`1IFET3061PH0<0HF5Q0P1KFe/305ADE0<0ATI60P0i>CT3034a<@<0;2`/0`0O7al200/;
2`<00`<32`00000300410@<00`<30P010@46000000<01@D53@00000300<30`<01`L70`020P850000
00<010@40P0:2PX300P820H01`L70P0;2`/300D51C400000203oool000H0oooo@P00000;00410@H0
00000P051@D301<C4`<04Q8B0`0D51@201PH60<07AdM0`0O7al301dM7@806ATI0`0J6QX301lO7`<0
=cLg0P1>CTh305UIF@<0H61P0`1QHF4205]KF`<0E5AD0`16ATH203Ti>@<0<C4a0`0/;2`301lO7`80
2`/;0`030`<;000000<00@410`030`<200410@H000000`051@D=000000<00`<30`071`L300820PD0
00000`0410@200X:2P<020P81P071`L200/;2`<01@D5<@0000080?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`1860\)], "Output"]
}, Open  ]],

Cell["Subjective answer:  (a) is 9 to 20, (b) is 5 to 7", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image Filtering", "Subsection"],

Cell["\<\
Suppose you attempted to download the matrix handMat from the WWW, your \
noisey modem
introduced error and provided you with the matrix handErr below:\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
handErr= handMat+
  Table[If[Random[]< 1/30,.5-Random[],0],{85},{100}];
showImage[handErr];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000000001010001030202080B151A
1D1E20232522201D195D10000C16151D232B2B001B100801
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000102550E18
1F1F2125282A2726211B140D0B0F171E2941515853381706
2A0000000000000000000000000000000000000000000000
000000330000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000100010710
1B1F22292D302F2D292319100C0F0D1726353231373B2A15
070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000005800
00000000
0000000000000000000000000000000000002C0000010105
0E1A212933333434332B211C1C1A151C1E181115171B151C
1F1608040404030100000000000000000000000000000000
000000000000000000000000000000007500000000000000
47000000
000000000000000000000000000000000000000000000001
030017253235363A35312C2C2F2A242C1F0F0A0D00120C0F
15191A181C21232216110A05010100000000000000000000
0000000000000000000C000000000000005E000000000000
00000000
000000000000000000000000000000000000000000000000
0001041329333539383534373500293E29190C091314151F
1A0A0E04070E171B171A191715130C070D081B0000010000
3F0000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000E242E3638393C3C342929443B290B081E1B163E
270E0876050002050209171500191A221C190F0701000000
000000000000000000000000000000000000000000000000
00000000
000000000000005D00000000000000000000003300000000
00000000000A213135393D3B32252F564C260D0351A12E3F
340B0F0604011B261B0406050406080D0E001C1B0C030100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000081E2D353A8E32262D4F491F15081A748246
1C07070B0115364A4F1E020001010507070B161D180C0502
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071D2E9937342C2B323A180D131F365247
040000001A3F382D252F22130A0405040B0A0E1114150D03
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000006A061B30343730322D2440526C8C9C8A74
53100B144D6B38392A2C001F1D0E03040A09070B13211401
00000000005F00000C000000000000000000000000000000
00000000
000000000000000000000000000043000000000000000000
000000000000001D00051D303431302E1F3FABD0D5CDB791
36010B4654565D6064554C3F260D09050503050D141D1001
0101000000000000000000000000000000004D0000000000
004C0000
000000000000000000000000000000000000000000190000
00000000000000000000051D32352F2A231858B0BEA57829
00063D606369605C5D584E4D50452B130301070E11130901
000001010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000031D33322C221B0E0B0C080100
00236369645A03504845414E595157001903050013110801
010101010000000000000000000000000000000000000000
00000000
0000000000000000000000000000004F0000000000000000
00000000000000000000000004213231231D120601000002
133A57564F453E3C362F333D41433D2E261D091121110601
000301010101000000000000000000002A00000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000720302B1F180C05010415
243947443F3B87373F55C78B8684775D3F26101C210A0303
000004010101000000000000000006000000000000000000
00000000
000000000000000000000000000000000000002C00000000
000000000000000000000000000006222F261B0D0907161D
1D2B3B403C3C414D6091BDCBFFBEAEAE9F6B1A1A12060605
080502010101000000000000000000000000000000000000
00000000
000000000000000D00000000000000000000000000000000
00000000000000000000510000000007282C0C0609111615
1A273039404B00CC7E7884ABB8E6DECEC5A53A1912140909
100B00010101017800001500000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000510060A0800050E111013
1D29333D4B5B72908D63374288C1DADCD0C153241F170D15
1D0900010101010000000000000000000000000600000000
00000000
000000000000000000000000000000000000005900000000
00000000000000000000000003212D100202050B0F0F1017
2333414A60718B939FAB763113366F98A8A66D563F26171E
180100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000051A181F190905090F0F101222
004560798699894A205EC0AD7A3A161F5B9599939C733617
070100000101000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000040
00000000000000000000001432180F0E0A0A111214732944
576D7F97A1A3947E52171F52A2C39C80ACACBFFFCBC78623
030503030302340000010100000000000000000000000000
00000013
00005A000000000000000000000000000000000000000000
00000000000000010005282B1C24660014131C223152667B
8C91A2A2AA9FAFB4B3976335296FB6D1C9BBB4B4A6A4650E
060505060704010000030300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B301D0902020D141E324F7189949B
A2A5AF9FA7B0A18A8DA7AAB1873500518CB7BAAC956B0A05
0404070806000100000A0900000000000000003800000000
00000000
000000000000000000000000000000003C00000000000000
000000000001000311217532302C180E2D365787A1A6A6AA
ACB3BBB0AA8E38142A6685A0B5957F976BADBCA78F591E1F
0C0F0D0A0704070409170600000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000031722232F393E3D2F1C386084A3A59B9899
A6BAB8B6A3707133081F62C0DDE1E79AB7FFB39274443A47
3227240F060512210F080000000000000000000000000006
00000000
000000000000000000000000000000000000000000000000
0000000000012737391A192221202A2B3C517F868D8A8C93
A3B2BDC5B0799372645089889CCDDBDACCAA8C6559394555
434E533A1E1A262F05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000011322E2A2613000714192D37454A445D5E5560
82ABC0C3BD87797B98989BA0AFB6C1D2C0973D2D3D2B3C62
3D6B8575533B3A1300010000000000000000000000000000
00000000
000000000000000000000000006000000000000000000000
00000000002031251F2C2818100D1A2B3322110A245B8290
858FB9B8B0947DA9C1A497D878B5CFD0BA52091224182867
6660A4B2884B1B0000000000000000120000000001000000
00000000
000000000000000000000000000000000000000000000000
0000000005322D2927222D2C160A0029391C161419316E7D
A19C99449583A1DEC9B4939BA6C7CCD192221814100B1200
7F646CA0882A010001010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000044E6C5722002A34332B15224F4C2E27497B5973
7D7470746E669BC4A9B2BCBFC6C8CCD3723432331B080628
6572503D2002000202000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000493AD431C1C171418241F2D669D7E5D657A6E51
4E363A1B3461A4ADA0B1C2CCC5FFB5C97D5956543D120210
3E6466461E09000404020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000009DFE313730210C090B1D3C76ABCCB79F816846
261B0F0904B7B6839CACA3ABB8BCBABE7F746D423F1E0402
204A625643210001060903000000000000000000006C0000
00000000
000000000000000000003100000000000000000000000000
000000002CD4825C662A192B512B1E3F78A8C6DDCABEA15B
2C130C1C7BD3BE83847C7888999B9BB5847C8C6022150A02
072A5655462D0F00040E0800000000000000610000000000
00000000
000000000047000000000000000000000000000000000000
000000000D48C0955B568293846D3C446895BBD7E2E5DED5
C1997EA1CED9B66D4B42608A97A9A6A9927C92924F200E08
06214F685A41220300131907000000000000000000000000
0E000000
000000000000000000000000000000000000000000000000
00000000004F9E2A197AA16528263737517BA7C2D6DDEDF1
EFE9DFD7CBC8B553213D4F83979DA3B5AD8491947143230F
051A47713C5A370E00183319010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
49000000002D6395934E1A41845B30863A71989FBACCDADB
DDE2E7D8CDD0D08626254F6E7A826F667C828D92855F4012
030F0067886E451802269525020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004C656B9BACABA678766E5F535B85A8B6C7D1DA
E0E5EBEBECE6DFCB81414F7A6C6B5A4A5569878D37674E26
060625537F7F531E052C492A040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000063CF8E7EC7CB69222F47B4473F588AB7C3FFD0
E1ECF3F1ECE7E2E4E4BE95949A97979B71475B8D866F5836
170611386C83622803214F2B060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000016EC9A6704E566E64523D3C2022354866A7C3CB
CDD2E9EBE6E0DEDEE0E5D5BCBEFFB8AA7A274A7B7E785C40
2610082660896833092D61320A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000006BAFB88E5289D4C0B3A7AA80667081706F94C7
D2C8D0D8D9DAD2D6D2D6F5B7BABDB4A06B3D5B8687486C44
2C17072759806B40174C6A3C1E01000A0000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000087B6AC9795CDCBBDE2EFD3C7BEA0786A84879D
D7D9D1D0C8D1CEC3BFBBB5A8A9A89670503342828C8E8659
00200B336A837542266E6246250000000000000000000000
00000000
000000000000000000000000000000000000000000001E00
000000000066C4B9B4B38F6568609ACDCABDAEA39B8CAA77
B9C6A9A19A9FA3A8A8969EA69C7C5D3512022A71868A855E
2F1A104782837B374479673E090000000000000064000000
00000000
000000000000000000000000000000000000000000000000
000000000029C2BED32D73B3EFD79DCDB4C3E0EBEDCFBEAC
919080715A535B6E266C635D4F4B435E69521F657C818869
361D134D937C602E66683706000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000005A7C8B8C9F1F8EFEAEEE7EAF6EFEBEBD2B3A7
979BB0B4B58D81685C412A25171017325F510E547F81826C
4E2C1C629874413A76470700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000066DAC3BAD4D8CEADC8D4DDD05FC4ACB6A28E
7E6C7D6F99B4C84C80989E8DB0633F34342F2D4777817D6F
22352B8995DD3B5C4E0D0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00005900000020D1D1CCD5DBE4E5EDEBDDE0AA5D3C53686E
67668DA49EC5B469445D6B748FA9B59C813C566B7A807D74
512D4F9A875F463E080001000000000000000000000D0000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E3CFD1DADAE6E9DADEB128060A091C58
7583D9BCC4AEB8D38E555D54779FAE9C624D6F7F8483846A
482A6192734D250200010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000012BFE0CFD1D6CDDDE9DC6326271F160B28
6CC6B5C9C8AA81D7BF967E7C59534E5E435E7882858A8364
3E31727C5C29000001010000000000180000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000002FC0E7D9DBDEDAD5BB82817A8F3E2B14
47AED6A4C7C97E7C90BD9F9C915D7D7E3A6B7B838E8B7E60
44386F673F06000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000001A4DEFE0DDE3DCB6A6C1DCDF866B4A
2C94D896A4D2CCBFACB1C1AAB2BDBE503E697989928F7A60
3F445E521A00000000000000000000000000000000000000
00000067
000000000000000000000000000000000000000000000000
000000000000000000000777BC9BE4D9ABA4CBECE2C49486
027CC7C4958F9FBEC898A5A4AB7D454648687D898F88775C
3D3E4D300200000000000009000000000000000000000000
00000000
004B0000000000000000000000000000000000000000006E
0000000000000000000000004BB1E8E89E81A8E6C9A7898A
3D55A9C2C2C0C6ABB496937E4E213A56525D7C918E7E6F55
2F2A38110001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000003DA99C736E989A817071
464A8DAFA5A4C8BFA987370F1636454A5F6983918B796747
212130050001000000000000000000000000000000000000
00000000
000F00000000000000000000000000000000000000000000
000070000000000000000000000000075F6C749598806955
43375F77808D8A743E0E0B191F3A4E4E5571888F16715A32
182C1E000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000386863676A605042
362A53626153361505101F271E3B4B565E728B8B7F724C2E
262C0500000000000000000000007D000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000038736B6B67574432
2F291B120B0C1413121A2E3129364F597B8F827978694834
2B0900010000000000430000000000000000000000000000
00000000
000000280000000000001000000000000000000000000000
000000000000000000000000000000002D897C2C6E5E482F
2B30120A10141B161D2635303BBF415F828C7C7C7B3F4E34
0C0000000000000000000000000000000000000000000000
00000000
000000550000000000000000000000000000000000000000
00000000000000000000000000000100128A766D6565D73A
352C121119161721233635314D5658697E7772826F605016
00000000000000000E000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000038196877A776951
492D121B1D1F19292B3C384700687480766C796958482100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000106899FF88817267
512D1B1E1C1A282600404355737B78786C6A5B4A49240000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000589092867A7567
47001F231F232E304F4C58D2727A79797253494017000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001D58878E88796B5D
4028282527372B4A595A6A787375797D6649310800000000
000000000000000000000000000000002100000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000001015159839186756556
40322F2B36314661606A757E79757D734B1C000000000000
000000000000000000000000000000000006000000000000
00000000
0000006A0000000000000041000000000000000000140000
2900000000000000000000000001040302467B897B6A5F4F
4036323A39475A3F68797F83807C6D460E00000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000480000000000000000000000000000000000
0000000000000000000000000002030200206F840B625D52
463C42484D695E6771798182756142140001000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001010102083C7E7B6A655D
4A4600575E63566D757A735D4B0000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000001500000000010101400304081645626E6E67
59085A5C5E65696C695C511D413409000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000007200000000000000000000
0000000000710000000000010101010A0D0A1B233C53605F
605F5D606265646057504D42391700000000004400000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010100030D19181D272B3D5256
585E626364675F5953504B43250000000000000000000000
000000000036000000000000000000000000000000000000
001B0000
000000000000000000000000000000000000000000000000
0000000000000000000000000102070E1B201E22262E4556
5D646664615D5B5858524D32030000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000011300000000000002050C0F0025262320212E3F
525B62655E5B5B5A59554310000000000000000000000000
000000000000000000000000000000000000000000000000
00000077
000000000000000000000000000000000000000000000000
000000000000000000000001030A0E101929363F44433E46
555D606263605D5E5B552C00000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000202080C0E121A293E5666717171
717271706963615F5D450800000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
006D00000000000000000000000000000000000000000000
000000000001010001020306080A0D121C2737434E5E6A6B
6F71706B615F5E705D1E0000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010003030404050B11150026313B454E555D
676E716D6A6D6B7145000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010102020201060C11174127313D474E5A68
2F757B7A7473715E0E3A0000000000000000000000000000
150000000000000000000000000000000000000000000000
00000000
00000000000000000000000000000000000000000000002A
0000000000010101010203050A0E131C2228323F4B54616E
777C7D7B756D672D00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000101000004000B0F141A21272D36434D596772
787978767C6E490300000000150000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000035000000000000000031000000000000000000
00000100010A0202040A0C1116671E232B313A45525C6776
777477776D5B1A0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020102020203070C1015191D21272E343E4A5A636B76
736F70685E37010100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020203020102560A0C10161D1F242E3235404E5C686D6F
6E6B695E4F0E000000000000000000000000000000000000
000000110000000000000000000000000000000000000000
00000000
000000000021000000000000000000000000000000000000
01050505030306080B1114171D20232C313C45536064666A
69675C56280000007F00000000000000000000000000006F
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
00052B0506092C0C101013161D222429303B48535B635E64
615E55410700000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
0000002A0000000000000000000000000000000000000003
0506090A0A0A0E0E101112171C1E2228313E4856595C5C5A
595348180000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooolT000000H00@410P00000300410@<00`<31@020P8300P820<0
2`/;0P0E5AD301XJ6P<07AdM0`0N7Qh2020P80<08b<S0`0U9BD3028R8P80820P0`0M7Ad301TI6@<0
GEeM0P0@4103000000<030`<0`0F5QH201DE5@<07AdM0`0S8b<502/[:`<000000`0K6a/3010@4080
20P80`010@6>000000P0oooo00060?ooob@000001P010@42000000<00@410`030`<500820P<020P8
0`0;2`/201DE5@<06QXJ0`0M7Ad301hN7P80820P0`0S8b<302DU9@<08R8R0P0P820301dM7@<06ATI
0`1MGEd2010@40<000000`0<30`301HF5P805ADE0`0M7Ad302<S8`D0:b/[0`00000301/K6`<0410@
0P0820P300410Hh00000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O
7al2024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?
3`l201LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`00
000303<c<d400000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O7al2
024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l2
01LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`000003
03<c<d400000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O7al2024Q
8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l201LG
5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`00000303<c
<d400000203oool000H0oooo=@00000200410@<000000`010@4200L71`<0410@0`0K6a/301lO7`80
8R8R0`0Y:BT302d];@<0<30`0P0_;bl302d];@<0:BTY0`0S8b<201TI6@<0410@0`0<30`300l?3`80
3@d=0`0G5aL302HV9P<0=CDe0P0b<S83034a<@<0=cLg0`0k>c/202XZ:P<05ADE0`071`Mk000000<0
F5QH3@0000080?ooo`001P3ooole000000800@410`00000300410@801`L70`0@410301/K6`<07alO
0P0R8R8302TY:@<0;Bd]0`0`<30202l_;`<0;Bd]0`0Y:BT302<S8`806ATI0`0@410300`<30<03`l?
0P0=3@d301LG5`<09RHV0`0e=CD2038b<P<0<C4a0`0g=cL303/k>`80:RXZ0`0E5AD300L71g/00000
0`1HF5P=000000P0oooo00060?ooocD000000P010@43000000<00@410P071`L3010@40<06a/K0`0O
7al2028R8P<0:BTY0`0];Bd3030`<080;bl_0`0];Bd302TY:@<08b<S0P0I6AT3010@40<030`<0`0?
3`l200d=3@<05aLG0`0V9RH303De=@80<S8b0`0a<C4303Lg=`<0>c/k0P0Z:RX301DE5@<01`L7N`00
000305QHF0d00000203oool000H0oooo<P00000302`/;0D000001@010@4300D51@<03Ph>0`0J6QX2
024Q8@<0:BTY1P0c<c<503@d=0<0<c<c0`0[:b/2024Q8@H071`L0`0J6QX201DE5@<071`L0`0N7Qh3
01PH60804A4A0`0E5AD301LG5`<06a/K0P0E5AD301`L70<07alO0P0F5QH300P820P010@40`030`<3
00410EP000000P1eMGDD00000080AdM7200000080?ooo`001P3ooolb000000<0;2`/1@0000050041
0@<01@D50`0>3Ph301XJ6P808B4Q0`0Y:BT603<c<`D0=3@d0`0c<c<302/[:`808B4Q1P0L71`301XJ
6P805ADE0`0L71`301hN7P<061PH0P0A4A4301DE5@<05aLG0`0K6a/201DE5@<071`L0`0O7al201HF
5P<020P8200410@300<30`<00@41F000000207EeMA@000000P17AdL8000000P0oooo00060?ooocl0
00000`010@4300<30`<000000P0G5aL302DU9@<0<S8b0`0e=CD203Hf=P<0>SXj0`0e=CD3034a<@D0
;2`/0`0_;bl302XZ:P8092@T0`0/;2`301lO7`<03`l?0P0:2PX300d=3@<000000`0B4Q8200`<30<0
3`l?0`0E5AD201TI6@<06QXJ0`0H61P301`L70808B4Q0`0S8b<3028R8P<05QHF0P0A4A4300X:2P<0
1@D51@010@4d000000<030`<4`00000305iNGQ/00000203oool000H0oooo?`00000300410@<00`<3
0`00000201LG5`<09BDU0`0b<S8303De=@80=SHf0`0j>SX303De=@<0<C4a1@0/;2`302l_;`<0:RXZ
0P0T92@302`/;0<07alO0`0?3`l200X:2P<03@d=0`000003018B4P8030`<0`0?3`l301DE5@806ATI
0`0J6QX301PH60<071`L0P0Q8B4302<S8`<08R8R0`0F5QH2014A4@<02PX:0`051@D500410C@00000
0`0<30`C000000<0GUiN6`0000080?ooo`001P3ooolo000000<00@410`030`<3000000805aLG0`0U
9BD3038b<P<0=CDe0P0f=SH303Xj>P<0=CDe0`0a<C4502`/;0<0;bl_0`0Z:RX202@T90<0;2`/0`0O
7al300l?3`802PX:0`0=3@d3000000<04Q8B0P0<30`300l?3`<05ADE0P0I6AT301XJ6P<061PH0`0L
71`2024Q8@<08b<S0`0R8R8301HF5P804A4A0`0:2PX300D51@D00@41=000000300`<31<000000`1N
GUhK000000P0oooo00060?ooodD000000`010@4200@410<04a<C0`0Y:BT303<c<`80=CDe0`0i>CT3
03Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0?Shn0`0Y:BT301TI6@8030`<0`092@T3
01<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<010@40`071`L200h>3P<05aLG0`0K6a/3
01LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<01`L70`0=3@d200P820<06a/K1P000002
00410@H000000`0o?cm9000000P0oooo00060?ooodD000000`010@4200@410<04a<C0`0Y:BT303<c
<`80=CDe0`0i>CT303Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0?Shn0`0Y:BT301TI
6@8030`<0`092@T301<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<010@40`071`L200h>
3P<05aLG0`0K6a/301LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<01`L70`0=3@d200P8
20<06a/K1P00000200410@H000000`0o?cm9000000P0oooo00060?ooodD000000`010@4200@410<0
4a<C0`0Y:BT303<c<`80=CDe0`0i>CT303Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0
?Shn0`0Y:BT301TI6@8030`<0`092@T301<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<0
10@40`071`L200h>3P<05aLG0`0K6a/301LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<0
1`L70`0=3@d200P820<06a/K1P00000200410@H000000`0o?cm9000000P0oooo00060?ooodd00000
0`0>3Ph302@T9080;Rh^0`0f=SH303Ph>0<0>CTi1@0l?3`303@d=0D0:BTY0`14A4@303/k>`<0:BTY
0P0;2`/300P820<07QhN0`0K6a/201HF5P<0?Shn0`0W9bL200h>3P<020P80`1fMWH300D51@800000
0`020P8300D51@<00P820P092@T301LG5`<05ADE0`00000201TI6@<06QXJ0`0R8R8301`L70806ATI
0`0?3`l300L71`<00@41E00000080?ooo`001P3ooom=000000<03Ph>0`0T92@202h^;P<0=SHf0`0h
>3P303Ti>@D0?3`l0`0d=3@502TY:@<0A4A40`0k>c/302TY:@802`/;0`0820P301hN7P<06a/K0P0F
5QH303hn?P<09bLW0P0>3Ph300P820<0MWIf0`051@D2000000<00P820`051@D300820P802@T90`0G
5aL301DE5@<000000P0I6AT301XJ6P<08R8R0`0L71`201TI6@<03`l?0`071`L300410E@00000203o
ool000H0ooooC@00000300h>3P<092@T0P0^;Rh303Hf=P<0>3Ph0`0i>CT503`l?0<0=3@d1@0Y:BT3
04A4A0<0>c/k0`0Y:BT200/;2`<020P80`0N7Qh301/K6`805QHF0`0n?Sh302LW9`803Ph>0`0820P3
07IfMP<01@D50P00000300820P<01@D50`020P8200T92@<05aLG0`0E5AD3000000806ATI0`0J6QX3
028R8P<071`L0P0I6AT300l?3`<01`L70`010@5D000000P0oooo00060?oooa@000000P1MGEdO0000
0080<c<c6@00000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0<S8b0`0U9BD202l_
;`<0EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0=3@d0P0;2`/300l?
3`<01PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<010@40P061PH300P8
20<03@d=0`0>3Ph2000000<071`L0`0K6a/300`<30800`<30`010@5?000000P0oooo00060?oooa@0
00000P1MGEdO00000080<c<c6@00000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0
<S8b0`0U9BD202l_;`<0EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0
=3@d0P0;2`/300l?3`<01PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<0
10@40P061PH300P820<03@d=0`0>3Ph2000000<071`L0`0K6a/300`<30800`<30`010@5?000000P0
oooo00060?oooe<000000P0820P301hN7P<0;Bd]0`0e=CD203Xj>P<0SXj>0`0b<S8302HV9P80;Bd]
0`1?Cdl304U9B@<07alO0P0E5AD300P820<06QXJ0`1dM7@208:2PP<0ATI60`0L71`500L71`<02`/;
0`010@4201DE5@<0=SHf0`1:BTX304m?C`807QhN0`020P83000000D00@410`051@D600L71`802`/;
0`0F5QH301dM7@<061PH0P0<30`300D51@<00P82C00000080?ooo`001P3ooomC0000008020P80`0N
7Qh302d];@<0=CDe0P0j>SX308j>SP<0<S8b0`0V9RH202d];@<0Cdm?0`19BDT301lO7`805ADE0`08
20P301XJ6P<0M7Ad0P22PX8304I6AP<071`L1@071`L300/;2`<00@410P0E5AD303Hf=P<0BTY:0`1?
Cdl201hN7P<00P820`00000500410@<01@D51P071`L200/;2`<05QHF0`0M7Ad301PH608030`<0`05
1@D300820T`00000203oool000H0ooooD`00000200P820<07QhN0`0];Bd303De=@80>SXj0`2>SXh3
038b<P<09RHV0P0];Bd304m?C`<0BDU90`0O7al201DE5@<020P80`0J6QX307AdM080PX:20`16ATH3
01`L70D01`L70`0;2`/300410@805ADE0`0f=SH304Y:BP<0Cdm?0P0N7Qh300820P<000001@010@43
00D51@H01`L70P0;2`/301HF5P<07AdM0`0H61P200`<30<01@D50`020P9<000000P0oooo00060?oo
oeD000000`071`L301dM7@<0;Rh^0P2IVIT303Lg=`<0=3@d0`0/;2`202/[:`<0<S8b0`0j>SX301PH
60803@d=0`0C4a<301lO7`<0=SHf0P1BDU8304M7A`<010@42000000301XJ6P80?clo0`0h>3P302d]
;@<09BDU0P0_;bl3028R8P<04a<C0`0:2PX200@410<01@D50`0410@300/;2`802PX:0`0>3Ph3014A
4@<051@D0P0E5AD300d=3@<00`<3C00000080?ooo`001P3ooomE000000<01`L70`0M7Ad302h^;P80
VIVI0`0g=cL303@d=0<0;2`/0P0[:b/3038b<P<0>SXj0`0H61P200d=3@<04a<C0`0O7al303Hf=P80
DU9B0`17AdL300@410P000000`0J6QX203lo?`<0>3Ph0`0];Bd302DU9@80;bl_0`0R8R8301<C4`<0
2PX:0P0410@300D51@<010@40`0;2`/200X:2P<03Ph>0`0A4A4301@D50805ADE0`0=3@d300<30d`0
0000203oool000H0ooooE@00000300L71`<07AdM0`0^;Rh209VIV@<0=cLg0`0d=3@302`/;080:b/[
0`0b<S8303Xj>P<061PH0P0=3@d301<C4`<07alO0`0f=SH2059BDP<0AdM70`0410@8000000<06QXJ
0P0o?cl303Ph>0<0;Bd]0`0U9BD202l_;`<08R8R0`0C4a<300X:2P8010@40`051@D300@410<02`/;
0P0:2PX300h>3P<04A4A0`0D51@201DE5@<03@d=0`030`=<000000P0oooo00060?oooeD000000`1Z
JVX300H61P<06a/K0P0`<30303@d=0<0=cLg0`0`<302038b<P<0;Bd]0`0T92@30410@080DU9B0`1/
K6`308b<S0<0W9bL0P2:RXX307AdM0<0De=C0P0@410300/;2`<051@D0`1=CDd206][J`<0>3Ph0`0i
>CT302XZ:P80;2`/0`00000301lO7`<07AdM0P0>3Ph300<30`<010@40`0:2PX200T92@<01`L70`0;
2`/301<C4`808B4Q0`0D51@300410@d000000`1OGel60000008030`<=00000080?ooo`001P3ooomE
000000<0JVYZ0`061PH301/K6`80<30`0`0d=3@303Lg=`<0<30`0P0b<S8302d];@<092@T0`10@402
059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1dM7@305=CD`80410@0`0;2`/301@D50<0CDe=0P1[Jf/3
03Ph>0<0>CTi0`0Z:RX202`/;0<000000`0O7al301dM7@803Ph>0`030`<300@410<02PX:0P092@T3
00L71`<02`/;0`0C4a<2024Q8@<051@D0`010@4=000000<0GemO1P00000200`<33@00000203oool0
00H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D50P0M7Ad3030`<0<0=3@d0`0a<C42030`
<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0=SHf0P010@4300/;
2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE0`1<C4`303lo?`<09RHV0P0=3@d300T9
2@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@20010@4/000000<0CDe=4000000304a<
C0D00000203oool000H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D50P0M7Ad3030`<0<0
=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0
=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE0`1<C4`303lo?`<0
9RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@20010@4/000000<0
CDe=4000000304a<C0D00000203oool000H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D5
0P0M7Ad3030`<0<0=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=
0P2g]kL3096AT@<0=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE
0`1<C4`303lo?`<09RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@
20010@4/000000<0CDe=4000000304a<C0D00000203oool000H0oooo>P00000301TI6B4000000P05
1@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn_P<0YJFU0P1h
N7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>
CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A4@804a<C0`09
2@T300410@D000001P010@51000000P0oooo00060?ooocX000000`0I6ATQ000000801@D50`0M7Ad3
038b<P<0=CDe0P0_;bl302XZ:P<08b<S0`0H61P205QHF0<0/;2`0`2n_[h30:FUY@80N7Qh0`0Y:BT3
000000801PH60`0m?Cd3061PH0<0Hf=S0P1YJFT3061PH0<0G5aL0`1MGEd205QHF0<0CTi>0`1=CDd3
051@D080ADE50`0[:b/301<C4`<00`<30P010@4300L71`<03Ph>0`0A4A4201<C4`<02@T90`010@45
000000H00@41@@0000080?ooo`001P3ooolj000000<06ATI8@00000200D51@<07AdM0`0b<S8303De
=@80;bl_0`0Z:RX302<S8`<061PH0P1HF5P30;2`/0<0_[jn0`2UYJD207QhN0<0:BTY0`00000200H6
1P<0?Cdm0`1PH60306=SH`80JFUY0`1PH60305aLG0<0GEeM0P1HF5P304i>CP<0CDe=0`1@D50204E5
A@<0:b/[0`0C4a<300<30`800@410`071`L300h>3P<04A4A0P0C4a<300T92@<00@411@0000060041
0D400000203oool000H0ooooH000000300<30`<07AdM0`0c<c<2038b<P<0;2`/0`0R8R8301/K6`80
3Ph>0`0;2`/300`<30<020P80P010@46000000808b<S0`1SHf<306UYJ@<0I6AT0P1JFUX300<30`<0
D51@0`18B4P204E5A@<0@D510`1>CTh305UIF@80DE5A0`1GEeL3000000<06ATI0P030`<300D51@<0
00000`0C4a<2014A4@<020P83P010@51000000P0oooo00060?ooof0000000`030`<301dM7@<0<c<c
0P0b<S8302`/;0<08R8R0`0K6a/200h>3P<02`/;0`0<30`300P820800@411P00000202<S8`<0Hf=S
0`1YJFT306ATI080FUYJ0`030`<3051@D0<0B4Q80P15ADD30451@@<0CTi>0`1IFET2055AD@<0EeMG
0`00000301TI6@800`<30`051@D3000000<04a<C0P0A4A4300P820h00@41@@0000080?ooo`001P3o
oomP000000<00`<30`0M7Ad303<c<`80<S8b0`0/;2`3028R8P<06a/K0P0>3Ph300/;2`<030`<0`08
20P200410@H000000P0S8b<306=SH`<0JFUY0`1TI6@205YJFP<00`<30`1@D50304Q8B080ADE50`11
@D4304i>CP<0FEUI0P1ADE4305MGE`<000000`0I6AT200<30`<01@D50`00000301<C4`804A4A0`08
20P>00410D400000203oool000H0oooo:P00000204m?CcL000000`0410@3024Q8@80<S8b0`0a<C43
02<S8`<07AdM0P0B4Q8300H61P<00@411@00000300820P<04a<C0P0j>SX305MGE`<0EUIF0`1?Cdl2
04E5A@<0?Shn0`0l?3`303Hf=P80;bl_0`0c<c<303dm?@<0@D510P13@d<303dm?@<0;Rh^0`0V9RH2
01dM7@<02@T90`0A4A43024Q8@804A4A0`061PH300410@<000000P030`<;00410A`000000P0Z:RXN
000000P0oooo00060?ooobX000000P1?Cdlg000000<010@40`0Q8B42038b<P<0<C4a0`0S8b<301dM
7@804Q8B0`061PH300410@D000000`020P8301<C4`80>SXj0`1GEeL305IFEP<0Cdm?0P15ADD303hn
?P<0?3`l0`0f=SH202l_;`<0<c<c0`0m?Cd30451@@80@d=30`0m?Cd302h^;P<09RHV0P0M7Ad300T9
2@<04A4A0`0Q8B42014A4@<01PH60`010@43000000800`<32`010@4L00000080:RXZ7P0000080?oo
o`001P3ooomV000000<01`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@80
10@40`0E5AD302@T9080>CTi0`17AdL304A4A0<0?clo0P0k>c/308N7Q`<0=cLg0`0o?cl205EEE@<0
alO70`2;Rh/308J6QP80Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH0
0`<31@00000300@410P00@415P00000300H61R<00000203oool000H0ooooIP00000300L71`80820P
0`0`<30302/[:`<07alO0P0H61P300`<30<01@D50`010@4200@410<05ADE0`0T92@203Ti>@<0AdM7
0`14A4@303lo?`80>c/k0`27QhL303Lg=`<0?clo0P1EEED30<O7a`<0Rh^;0`26QXH208B4Q0<0MgMg
0`1MGEd303lo?`809RHV0`0@410301`L70<08B4Q0P0:2PX600<30`D000000`0410@800410AH00000
0`061PHS000000P0oooo00060?ooofH000000`071`L2020P80<0<30`0`0[:b/301lO7`8061PH0`0<
30`300D51@<00@410P0410@301DE5@<092@T0P0i>CT304M7A`<0A4A40`0o?cl203/k>`<0QhN70`0g
=cL303lo?`80EEEE0`37alL308^;R`<0QXJ60P24Q8@307MgM`<0GEeM0`0o?cl202HV9P<0410@0`0L
71`3024Q8@802PX:1P030`<5000000<010@420010@4F000000<01PH68`0000080?ooo`001P3ooole
00000080;2`/<P00000200H61P<08R8R0`0_;bl302HV9P806a/K0`0=3@d300T92@<01`L70P0F5QH6
01dM7@80:b/[0`0k>c/30410@0D0?3`l0`11@D4304e=C@<0H61P0P2ATI430;fm_@<0bl_;0`3oool2
0;jn_PH0[Zj^0`2OWil206][J`H06QXJ0`0B4Q8500H61P<01@D50`0820P200D51@<00P8220010@4l
000000P0oooo00060?ooocD000000P0/;2`b000000801PH60`0R8R8302l_;`<09RHV0P0K6a/300d=
3@<02@T90`071`L201HF5PH07AdM0P0[:b/303/k>`<0@4101@0l?3`30451@@<0CDe=0`1PH602096A
T@<0_Kfm0`3;bl/30?ooo`80_[jn1P2^[Zh309nOW`80Jf][1P0J6QX3018B4PD01PH60`051@D300P8
20801@D50`020P8800410C`00000203oool000H0oooo=@00000202`/;38000000P061PH3028R8P<0
;bl_0`0V9RH201/K6`<03@d=0`092@T300L71`805QHF1P0M7Ad202/[:`<0>c/k0`10@40503`l?0<0
@D510`1=CDd3061PH080TI6A0`2m_Kd30<_;b`<0oooo0P2n_[h60:j^[P<0WinO0P1[Jf/601XJ6P<0
4Q8B1@061PH300D51@<020P80P051@D300820PP00@41?00000080?ooo`001P3ooolD000000803@d=
B0000002055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE
0`0J6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[
0`2h^;P20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@
0P0;2`/3000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooolD000000803@d=B000
0002055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE0`0J
6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[0`2h
^;P20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@0P0;
2`/3000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooolD000000803@d=B0000002
055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE0`0J6QX2
02LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[0`2h^;P2
0>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@0P0;2`/3
000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooomV000000<01@D50P0@410300H6
1P<02PX:0`0820P2000000<01@D50`0>3Ph3014A4@80410@0`0C4a<301dM7@80:BTY0`0c<c<303dm
?@<0Bd];0P1KFe/3079bLP<0T92@0`2=SHd206=SH`<0=cLg0`12@T8308R8R080`L710`3Jf]X30=cL
g0<0d=3@0P31`L4305=CD`<092@T0`0O7al201LG5`<03@d=0`0E5AD301dM7@802@T90`00000;0041
0B4000000`061PHE000000P0oooo00060?ooofH000000`051@D2010@40<01PH60`0:2PX300P82080
00000`051@D300h>3P<04A4A0P0@410301<C4`<07AdM0P0Y:BT303<c<`<0?Cdm0`1;Bd/205]KF`<0
LW9b0`2@T90308f=S@80Hf=S0`0g=cL30492@P<0R8R80P31`L430=[JfP<0g=cL0`3@d=020<71`@<0
De=C0`0T92@301lO7`805aLG0`0=3@d301DE5@<07AdM0P092@T3000000/00@418@00000300H61QD0
0000203oool000H0oooo=@00000205UIFB`000000`030`<3024Q8@80;Bd]0`0@410600820P801@D5
0`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C
0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF
0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@411P00000;00410CH00000203oool000H0oooo=@00
000205UIFB`000000`030`<3024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G
5aL302<S8`80<c<c0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a
<C4301<C4`80=SHf0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N
7Qh301PH60800@411P00000;00410CH00000203oool000H0oooo=@00000205UIFB`000000`030`<3
024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c0`11@D43
04Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf0`1_Kfl3
09RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@411P00000;
00410CH00000203oool000H0ooooH000000300D51@<06QXJ0`0H61P201lO7`<06ATI0`092@T300D5
1@802@T91P0?3`l3010@40804Q8B0`0R8R8300000080ADE50`1PH60307UiN@<0QXJ60P2IVIT308V9
R@<0BTY:0`0P820205iNGP<0`<300`2][Jd307YjNP80>SXj0`0F5QH301lO7`<0Fe]K0P2EUID309VI
V@<0Ti>C0`2LW9`207=cL`<0=SHf0`0G5aL300L71`800@411P00000500410@<000000`010@4f0000
00P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H0
3`l?0`0@4102018B4P<08R8R0`00000204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0
820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0
W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000001@010@43000000<00@41=P0000080?ooo`00
1P3ooomP000000<01@D50`0J6QX301PH60807alO0`0I6AT300T92@<01@D50P092@T600l?3`<0410@
0P0B4Q83028R8P<000000P15ADD3061PH0<0NGUi0`26QXH209VIV@<0RHV90`1:BTX3020P8080GUiN
0`30`<030:f][@<0NWYj0P0j>SX301HF5P<07alO0`1KFe/209FEU@<0VIVI0`2CTi<309bLW080Lg=c
0`0f=SH301LG5`<01`L70P010@46000000D00@410`00000300410CH00000203oool000H0oooo?`00
00030410@1h000000`0D51@3038b<P<061PH0P0?3`l300h>3PH02PX:0P0A4A43018B4P<051@D0`1c
Lg<202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2GUiL30:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G
5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20P8050:b/[0<0_kno0`3oool30<_;b`80alO70`26
QXH302<S8`<00`<30P051@D800<30`<00P820`0d=3@5000000H00@41;000000201<C4`P0oooo0006
0?ooocl000000`10@40N000000<051@D0`0b<S8301PH60803`l?0`0>3Ph600X:2P804A4A0`0B4Q83
01@D50<0Lg=c0P0Y:BT304A4A0<0EeMG0P1]KFd307moO`<0UiNG0`2QXJ420:>SX`<0U9BD0`1nOWh3
059BDP805aLG0`0O7al3059BDP<0XZ:R0P33`l<309bLW0<0P8201@2/[:`30;no_`<0oooo0`3;bl/2
0<O7a`<0QXJ60`0S8b<300<30`801@D520030`<300820P<0=3@d1@00000600410B`000000P0C4a<8
0?ooo`001P3oool6000000<0FUYJC000000300410@<000000`051@D202PX:0<0:b/[0`0L71`302@T
9080IVIV0`00000301@D50<04a<C0P0L71`3028R8P<0<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096A
T@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf
]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0IFEU0`0>3Ph300H61PD01@D50`061PH200L7
1`<010@40`010@45000000H00`<3;P0000080?ooo`001P3oool6000000<0FUYJC000000300410@<0
00000`051@D202PX:0<0:b/[0`0L71`302@T9080IVIV0`00000301@D50<04a<C0P0L71`3028R8P<0
<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80
UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0
IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@40`010@45000000H00`<3;P0000080?ooo`00
1P3oool6000000<0FUYJC000000300410@<000000`051@D202PX:0<0:b/[0`0L71`302@T9080IVIV
0`00000301@D50<04a<C0P0L71`3028R8P<0<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R
0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A
0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@4
0`010@45000000H00`<3;P0000080?ooo`001P3ooomH000000<01PH60`0K6a/2030`<0<07AdM0`09
2@T500820P<03@d=0`0D51@301hN7P80<S8b0`1?Cdl3075aL@<0RHV90P2DU9@309^KV`<0XZ:R0P2U
YJD30:n_[`<0WinO0`2WYjL20;2`/0<0XJ6Q0`2:RXX308f=S@80YjNW0`2ZZZX30;6a/@<0QhN70P0e
=CD3000000<0DE5A0`2<S8`20;Ng]`<0^[Zj0`2/[:`309FEU@80Jf][0`0:2PX300D51@D010@40`07
1`L300P820801PH60`00000300410@D000000`0:2PX300T92AH000000`0h>3PE000000P0oooo0006
0?oooeP000000`061PH301/K6`80<30`0`0M7Ad300T92@D00P820`0=3@d301@D50<07QhN0P0b<S83
04m?C`<0LG5a0`29RHT209BDU0<0Vi^K0`2RXZ820:FUY@<0[jn_0`2OWil30:NWY`80/;2`0`2QXJ43
08Z:RP<0SHf=0P2WYjL30:ZZZP<0/K6a0`27QhL203De=@<000000`1ADE4308b<S080]kNg0`2j^[X3
0:b/[0<0UIFE0P1[Jf/300X:2P<01@D51@0410@300L71`<020P80P061PH3000000<00@411@000003
00X:2P<02@T95P00000303Ph>1D00000203oool000H0ooooF000000300H61P<06a/K0P0`<30301dM
7@<02@T91@020P8300d=3@<051@D0`0N7Qh2038b<P<0Cdm?0`1aLG4308V9R@80U9BD0`2KVi/30::R
XP80YJFU0`2_[jl309nOW`<0YjNW0P2`/;030:6QX@<0RXZ:0`2=SHd20:NWY`<0ZZZZ0`2a/K4308N7
Q`80=CDe0`000003055AD@<0S8b<0P2g]kL30;Zj^P<0[:b/0`2EUID206][J`<02PX:0`051@D500@4
10<01`L70`0820P200H61P<000000`010@45000000<02PX:0`092@TF000000<0>3Ph5@0000080?oo
o`001P3oool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0
<30`0`0/;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080
/k>c0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80
UIFE0`1oOgl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<3080
3`l?0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`00
1P3oool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0<30`
0`0/;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c
0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE
0`1oOgl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?
0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3o
ool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0<30`0`0/
;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c0`2k
^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE0`1o
Ogl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?0`0=
3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3ooomC
000000800`<30`0G5aL3028R8P<08b<S0P0_;bl303Ti>@<0?Shn0`0m?Cd202l_;`<071`L0`0h>3P3
061PH080Q8B40`2SXj<30:FUY@<0Vi^K0P2HV9P309VIV@<0YZJV0P2j^[X30;Rh^0<0][Jf0`2SXj<2
071`L0<0LG5a0`0c<c<300P820807alO0`1RHV830<30`0<0gMgM0P3QhN430>OWi`<0VYZJ0`2g]kL2
0?ooo`<0/k>c0`2BTY8307AdM080A4A40`0j>SX304M7A`<0<S8b0P0W9bL302@T90<03`l?0P061PH3
00D51@<04Q8B0`0Q8B4200l?3`<020P89000000300H61PX00000203oool000H0ooooD`00000200<3
0`<05aLG0`0R8R8302<S8`80;bl_0`0i>CT303hn?P<0?Cdm0P0_;bl301`L70<0>3Ph0`1PH60208B4
Q0<0Xj>S0`2UYJD309^KV`80V9RH0`2IVIT30:JVYP80^[Zj0`2h^;P30;Jf]P<0Xj>S0P1`L703075a
L@<0<c<c0`0820P201lO7`<0HV9R0`30`<030=gMg@80hN7Q0`3WinL309ZJVP<0]kNg0P3oool30;>c
/`<0TY:B0`1dM7@204A4A0<0>SXj0`17AdL3038b<P809bLW0`0T92@300l?3`801PH60`051@D3018B
4P<08B4Q0P0?3`l300P822@000000`061PH:000000P0oooo00060?oooe0000000`010@4202LW9`<0
=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0
QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0
LW9b0`1TI6@2051@D0<0RHV90`28R8P309bLW080cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0
IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0
;bl_0P051@Dd000000P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI
0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<
0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@2051@D0<0RHV9
0`28R8P309bLW080cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE5
0`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo
00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z
:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m
_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@2051@D0<0RHV90`28R8P309bLW080cLg=0`3K
fm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1C
De<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe0000000`0A4A42
038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`00000300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD2
04Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL3
07UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd3
02d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX3
01<C4`8000000`010@4a000000P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV
9P804a<C0`00000300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iN
GP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^K
V`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l
?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a0000
00P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`00000300L71`<0
51@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80
Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0
`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0
QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?ooob@00000
0`1PH60Y000000<0820P0P0a<C4302DU9@<07alO0`0/;2`202PX:0<061PH0`0@410300d=3@806QXJ
0`0[:b/303<c<`<08R8R0P0A4A4300X:2P<092@T0`1KFe/208:2PP<0T92@0`25QHD208n?S`<0^KVi
0`2h^;P30;2`/080U9BD0`1mOGd30:VYZ@<0`L710P2TY:@309NGU`<0f=SH0`1hN7P20;Fe]@<0clo?
0`3@d=030;Zj^P80DU9B0`092@T3018B4P<092@T0P0H61P302PX:0<0IfMW0`1VIVH2061PH0<0Y:BT
0`2b/[8208R8R0<0Bd];0`0K6a/F000000<04Q8B2`00000200410A<00000203oool000H0oooo9000
0003061PH2T000000`0P8202034a<@<09BDU0`0O7al302`/;080:2PX0`0H61P3010@40<03@d=0P0J
6QX302/[:`<0<c<c0`0R8R82014A4@<02PX:0`0T92@305]KF`80PX:20`2@T90308F5Q@80Shn?0`2i
^KT30;Rh^0<0/;2`0P2DU9@307emO@<0ZJVY0`31`L420:BTY0<0UiNG0`3Hf=P307QhN080]KFe0`3?
cll30=3@d0<0^[Zj0P1BDU8300T92@<04Q8B0`0T92@201PH60<0:2PX0`1WIfL306IVIP80H61P0`2T
Y:@30;:b/P80R8R80`1;Bd/301/K6aH000000`0B4Q8;000000800@414`0000080?ooo`001P3ooom=
000000<01@D50`0b<S8202d];@<0:BTY0`0W9bL3028R8P80;Bd]0`0/;2`301HF5P<02PX:0P000003
02TY:@<0>CTi0`0L71`201HF5P<051@D0`0I6AT3034a<@80KVi^0`1mOGd30:6QX@80W9bL0`2IVIT3
04A4A0<0UIFE0P23Ph<30:6QX@<0g]kN0`39bLT20;Bd]0<0Ti>C0`2KVi/30:JVYP80alO70`3<c<`3
0=7Ad@<0TY:B0P0R8R8301PH60<051@D0`0@410200/;2`<04Q8B0`00000307moO`80I6AT0`1/K6`3
0:2PX080R8R80`0Z:RX300410@<000001@010@4a000000P0oooo00060?ooodd000000`051@D3038b
<P80;Bd]0`0Y:BT302LW9`<08R8R0P0];Bd302`/;0<05QHF0`0:2PX2000000<0:BTY0`0i>CT301`L
70805QHF0`0D51@301TI6@<0<C4a0P1^KVh307emO@<0XJ6Q0P2LW9`309VIV@<0A4A40`2EUID208>3
P`<0XJ6Q0`3Ng]h30<W9b@80];Bd0`2CTi<309^KV`<0YZJV0P37alL30<c<c0<0dM7A0`2BTY82028R
8P<061PH0`0D51@3010@40802`/;0`0B4Q83000000<0Ogmo0P1TI6@306a/K0<0X:2P0P28R8P302XZ
:P<00@410`00000500410C400000203oool000H0ooooC@00000300D51@<0<S8b0P0];Bd302TY:@<0
9bLW0`0R8R8202d];@<0;2`/0`0F5QH300X:2P8000000`0Y:BT303Ti>@<071`L0P0F5QH301@D50<0
6ATI0`0a<C4206i^KP<0OGem0`2QXJ4209bLW0<0VIVI0`14A4@309FEU@80Ph>30`2QXJ430=kNgP<0
bLW90P2d];@309>CT`<0Vi^K0`2VYZH20<O7a`<0c<c<0`3AdM4309:BTP808R8R0`0H61P301@D50<0
410@0P0;2`/3018B4P<000000`1oOgl206ATI0<0K6a/0`2PX:0208R8R0<0:RXZ0`010@43000000D0
0@41<@0000080?ooo`001P3ooom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8300000080:RXZ
0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT307]kN`80FEUI
0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl
0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH6
0`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3o
oom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8300000080:RXZ0`0d=3@303<c<`<0:b/[0P0E
5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT307]kN`80FEUI0`1cLg<307emO@80M7Ad0`1`
L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<
c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@
D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3ooom=000000<010@40`1>CTh2
06a/K0<0EeMG0`0R8R8300000080:RXZ0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`2
02h^;P<09bLW0`19BDT307]kN`80FEUI0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH3
09^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3
038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83
000000D00P82=00000080?ooo`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG
5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^
KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0K6a/303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2
`P<0c<c<0`35aLD20?ooo`<0]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q830082
0P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?oo
o`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T9080
7alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0
>SXj0`0K6a/303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20?ooo`<0
]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0
IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<010@4
0`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM
0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0K6a/303@d=080HF5Q
0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20?ooo`<0]KFe0`39bLT307emO@80FEUI
0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T9
0`00000500@410<00P82<@0000080?ooo`001P3ooom@000000<0WIfM0P3no_h3034a<@<0=cLg0`0`
<302024Q8@<030`<0`092@T300/;2`807AdM0`0l?3`307IfMP<0Zj^[0P3<c<`30;Ng]`<0WinO0`21
PH4206QXJ0<0ATI60`0V9RH201/K6`<03`l?0`092@T300@41080]kNg0`2f][H308>3P`<0W9bL0P2/
[:`30:>SX`<0Zj^[0`2h^;P20;bl_0<0^[Zj0`2n_[h307moO`80M7Ad0`1]KFd30492@P<0?clo0P0N
7Qh300@410<00P820`0P820204Y:BP<0HV9R0`1FEUH204=3@`<08B4Q0`00000300410@801PH60`09
2@T300<30a/000000`1/K6`@000000P0oooo00060?oooe0000000`2MWId20?knoP<0<C4a0`0g=cL3
030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2OWil3
0861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<010@40P2g]kL30;Jf]P<0Ph>30`2LW9`2
0:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o?cl2
01hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B43000000<00@410P061PH3
00T92@<00`<36`00000306a/K1000000203oool000H0oooo70000003034a<Bh000000`0/;2`30=CD
e080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A0`0[:b/201hN7P<0?clo0`1hN7P30:RX
Z080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/0P0C4a<300`<30<071`L0`1kNg/20=?C
d`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<
S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ0`1FEUH305EEE@80ATI60`0];Bd300l?
3`<000000P0410@300h>3P<020P84`000003065QHAP00000203oool000H0oooo70000003034a<Bh0
00000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A0`0[:b/201hN7P<0
?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/0P0C4a<300`<30<0
71`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI1@2KVi/30;Fe]@<0
Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ0`1FEUH305EEE@80
ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P84`000003065QHAP00000203oool000H0oooo
70000003034a<Bh000000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A
0`0[:b/201hN7P<0?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/
0P0C4a<300`<30<071`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI
1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ
0`1FEUH305EEE@80ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P84`000003065QHAP00000
203oool000H0oooo3P00000304M7Ac`000000`0=3@d304Q8B080`<300`2EUID305]KF`<0EUIF0P22
PX8309>CT`<0Q8B40`1]KFd203`l?0<0A4A40`1XJ6P309FEU@80^k^k0`3GemL30>;RhP<0iNGU0P3N
g]h30=GEe@<0`L710P2IVIT307inOP<0XJ6Q0`3>c/h20=WIf@<0][Jf0`1]KFd304];B`80@T920`1P
H60308Z:RP<0UiNG0P2YZJT30:JVYP<0ZJVY0`2BTY8207alO0H0TY:B0`1?Cdl2020P80<03Ph>0`08
20P300H61P808B4Q0`1?Cdl306QXJ080FUYJ0`11@D43028R8P<00`<30P00000301<C4`<06ATI0`07
1`LQ000000803Ph>200000080?ooo`001P3oool>000000<0AdM7?000000300d=3@<0B4Q80P30`<03
09FEU@<0Fe]K0`1FEUH208:2PP<0Ti>C0`24Q8@306e]K@80?3`l0`14A4@306QXJ0<0UIFE0P2k^k/3
0=OGe`<0h^;R0`3UiND20=kNgP<0eMGE0`31`L4209VIV@<0OWin0`2QXJ430<k>cP80fMWI0`2f][H3
06e]K@<0Bd];0P12@T83061PH0<0RXZ:0`2GUiL20:VYZ@<0YZJV0`2YZJT309:BTP80O7al1P2BTY83
04m?C`80820P0`0>3Ph300P820<01PH60P0Q8B4304m?C`<0J6QX0P1JFUX30451@@<08R8R0`030`<2
000000<04a<C0`0I6AT300L71b4000000P0>3Ph8000000P0oooo00060?ooo`h000000`17AdLl0000
00<03@d=0`18B4P20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`304A4
A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh30:6Q
X@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH30:VY
Z@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P205YJ
FP<0@D510`0R8R8300<30`8000000`0C4a<301TI6@<01`L78@00000200h>3PP00000203oool000H0
ooooD000000304m?C`80WYjN0`0Z:RX301TI6@<0NWYj0P2QXJ4306EUI@<0:2PX0`0V9RH503Lg=`<0
DE5A0`1kNg/20:NWY`<0`/;20`3Fe]H30=gMg@80kNg]0`3alO430>o_k`80jNWY0`3Ogml30=OGe`<0
bl_;0P38b<P30;Fe]@<0De=C0`0Q8B4203dm?@<0Cdm?0`23Ph<309NGU`80WIfM0`2SXj<30;Fe]@<0
[Jf]0P24Q8@3096AT@<0U9BD0`1aLG4204=3@`<08b<S0`0?3`l300D51@806QXJ0`17AdL3075aL@80
?3`l0`1JFUX303Lg=`<03Ph>0P00000301PH60<0<c<c0`0I6AT200410BT00000203oool000H0oooo
D000000304m?C`80WYjN0`0Z:RX301TI6@<0NWYj0P2QXJ4306EUI@<0:2PX0`0V9RH503Lg=`<0DE5A
0`1kNg/20:NWY`<0`/;20`3Fe]H30=gMg@80kNg]0`3alO430>o_k`80jNWY0`3Ogml30=OGe`<0bl_;
0P38b<P30;Fe]@<0De=C0`0Q8B4203dm?@<0Cdm?0`23Ph<309NGU`80WIfM0`2SXj<30;Fe]@<0[Jf]
0P24Q8@3096AT@<0U9BD0`1aLG4204=3@`<08b<S0`0?3`l300D51@806QXJ0`17AdL3075aL@80?3`l
0`1JFUX303Lg=`<03Ph>0P00000301PH60<0<c<c0`0I6AT200410BT00000203oool000H0oooo@P00
000304U9B@/000000`0];Bd206=SH`<0UIFE0`2CTi<304i>CP806QXJ0`11@D4308B4Q0<0Fe]K0P0`
<30308J6QP<0>SXj0`1aLG4209RHV0<0WinO0`2j^[X30<c<c080f][J0`3Kfm/30=gMg@80h^;R0`3W
inL30=SHf0<0cLg=1@3@d=0308J6QP<09RHV0P0U9BD304m?C`<0KVi^0`1jNWX208:2PP<0Kfm_0`1V
IVH307alO080PX:20`2=SHd309:BTP<0QHF50P1OGel30410@0<04Q8B0`030`<200l?3`<000000`1W
IfL208R8R0<0KVi^0`15ADD301PH60800P820`0V9RH309FEU@<09BDU0P020P8Y000000P0oooo0006
0?oood8000000`19BDT;000000<0;Bd]0P1SHf<309FEU@<0Ti>C0`1>CTh201XJ6P<0@D510`24Q8@3
05]KF`80<30`0`26QXH303Xj>P<0LG5a0P2HV9P309nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd2
0>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH302HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX83
06m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY8308F5Q@80GemO0`10@403018B4P<00`<30P0?3`l3
000000<0IfMW0P28R8P306i^KP<0ADE50`0H61P200820P<09RHV0`2EUID302DU9@800P82:@000008
0?ooo`001P3ooom2000000<0BDU92`00000302d];@80Hf=S0`2EUID309>CT`<0CTi>0P0J6QX30451
@@<0Q8B40`1KFe/2030`<0<0QXJ60`0j>SX3075aL@80V9RH0`2OWil30;Zj^P<0c<c<0P3Jf]X30=_K
f`<0gMgM0P3Rh^830>OWi`<0f=SH0`3=cLd50=3@d0<0QXJ60`0V9RH202DU9@<0Cdm?0`1^KVh307Yj
NP80PX:20`1_Kfl306IVIP<0O7al0P22PX8308f=S@<0TY:B0`25QHD205mOG`<0@4100`0B4Q8300<3
0`803`l?0`00000306MWI`80R8R80`1^KVh304E5A@<061PH0P020P8302HV9P<0UIFE0`0U9BD20082
0RT00000203oool000H0ooooD000000304a<C080IFEU0`1[Jf/309^KV`<0[:b/0P2[Zj/30:JVYP<0
N7Qh0`1fMWH206i^KP<0GemO0`1CDe<305]KF`80QHF50`2XZ:P30;Jf]P<0alO70P3AdM430=[JfP<0
h>3P0P3UiND60>_[j`<0k>c/0P3Vi^H30=oOg`<0bl_;0`21PH420451@@<0Cdm?0`1jNWX306a/K080
Jf][0`1JFUX304Y:BP<0EEEE0P1YJFT308N7Q`<0SHf=0`0g=cL206MWI`<0CTi>0`0V9RH500H61P<0
9BDU0`1CDe<507moO`<0De=C0`0N7Qh200D51@<0;2`/0`19BDT302XZ:P8010@4:@0000080?ooo`00
1P3ooom@000000<0C4a<0P1UIFD306][J`<0Vi^K0`2/[:`20:^[Z`<0YZJV0`1hN7P307IfMP80KVi^
0`1OGel305=CD`<0Fe]K0P25QHD30:RXZ0<0][Jf0`37alL20=7Ad@<0f][J0`3Ph>020>GUi@H0jn_[
0`3/k>`20>KViP<0gmoO0`3;bl/30861P@80@D510`1?Cdl307YjNP<0K6a/0P1[Jf/305YJFP<0BTY:
0`1EEED206UYJ@<0QhN70`2=SHd303Lg=`80IfMW0`1>CTh302HV9PD01PH60`0U9BD305=CD`D0Ogmo
0`1CDe<301hN7P801@D50`0/;2`304U9B@<0:RXZ0P0410@Y000000P0oooo00060?oooe0000000`1<
C4`206EUI@<0Jf][0`2KVi/30:b/[080Zj^[0`2VYZH307QhN0<0MWIf0P1^KVh305mOG`<0De=C0`1K
Fe/208F5Q@<0Z:RX0`2f][H30<O7a`80dM7A0`3Jf]X30>3Ph080iNGU1P3[jn/30>c/k080i^KV0`3O
gml30<_;b`<0PH610P11@D4304m?C`<0NWYj0`1/K6`206][J`<0FUYJ0`1:BTX305EEE@80JFUY0`27
QhL308f=S@<0=cLg0P1WIfL304i>CP<09RHV1@061PH302DU9@<0De=C1@1oOgl305=CD`<07QhN0P05
1@D302`/;0<0BDU90`0Z:RX200@412T00000203oool000H0ooooD000000306=SH`80clo?0`2>SXh3
07inOP<0alO70P3;bl/306UYJ@<08R8R0`0_;bl204M7A`<0];Bd0`17AdL303lo?`80F5QH0`2:RXX3
0;Ng]`<0`l?30P3oool30=3@d0<0hN7Q0P3/k>`30??cl`<0lO7a0`3/k>`20>OWi`<0h^;R1P3Ti>@2
0;jn_P<0UIFE0`2DU9@309ZJVPD0UiNG0`2KVi/3075aL@80AdM70`1KFe/308f=S@<0QXJ60P1_Kfl3
05QHF0<0=SHf0`0G5aL200H61P<04A4A0`0h>3P206a/K0<0Ph>30`1RHV8302PX:0800`<30`0Q8B43
04m?C`<0:b/[0P061PHY000000P0oooo00060?oooe0000000`1SHf<20<o?c`<0SXj>0`1nOWh30<O7
a`80bl_;0`1YJFT3028R8P<0;bl_0P17AdL30;Bd]0<0AdM70`0o?cl205QHF0<0RXZ:0`2g]kL30<?3
``80oooo0`3@d=030>7Qh@80k>c/0`3clo<30?7al@<0k>c/0P3WinL30>;RhPH0i>CT0P2n_[h309FE
U@<0U9BD0`2JVYX509NGU`<0Vi^K0`1aLG4204M7A`<0Fe]K0`2=SHd308J6QP80Kfm_0`1HF5P303Hf
=P<05aLG0P061PH3014A4@<0>3Ph0P1/K6`308>3P`<0HV9R0`0X:2P200<30`<08B4Q0`1?Cdl302/[
:`801PH6:@0000080?ooo`001P3ooom@000000<0Hf=S0P3?cll308j>SP<0OWin0`37alL20<_;b`<0
JFUY0`0R8R8302l_;`80AdM70`2d];@304M7A`<0?clo0P1HF5P308Z:RP<0]kNg0`33`l<20?ooo`<0
d=3@0`3QhN420>c/k0<0lo?c0`3alO430>c/k080inOW0`3Rh^860>CTi080_[jn0`2EUID309BDU0<0
VYZJ1@2GUiL309^KV`<0LG5a0P17AdL305]KF`<0SHf=0`26QXH206m_K`<0F5QH0`0f=SH301LG5`80
1PH60`0A4A4303Ph>080K6a/0`23Ph<3069RHP<0:2PX0P030`<3024Q8@<0Cdm?0`0[:b/200H61RT0
0000203oool000H0ooooC@00000300410@<0KVi^0P39bLT30:JVYP<0L71`0`1>CTh205IFEP<0KVi^
0`1TI6@3059BDP80?Cdm0`0l?3`3020P80<08R8R0P0e=CD304Q8B0<0IVIV0`2WYjL20<?3``<0bl_;
0`3=cLd20=;BdP<0jNWY0`3[jn/30>KViP80h>3P1P3Ng]h30>3Ph080iNGU0`3EeMD30;bl_0<0_[jn
0P3oool30;Rh^0<0ZZZZ0`1jNWX202LW9`<0BTY:0`1kNg/307inOP80N7Qh0`1LG5`30410@0<09RHV
0P0@410300P820<09RHV0P1PH60308V9R@<0J6QX0`0c<c<200T92@<0;Bd]0`1QHF43038b<P802PX:
:@0000080?ooo`001P3ooom=000000<00@410`1^KVh20<W9b@<0YZJV0`1`L70304i>CP80EUIF0`1^
KVh306ATI0<0DU9B0P0m?Cd303`l?0<0820P0`0R8R8203De=@<0B4Q80`1VIVH30:NWY`80`l?30`3;
bl/30<g=c@80d];B0`3YjNT30>_[j`<0i^KV0P3Ph>060=kNgP<0h>3P0P3UiND30=GEe@<0_;bl0`2n
_[h20?ooo`<0^;Rh0`2ZZZX307YjNP809bLW0`1:BTX307]kN`<0OWin0P1hN7P305aLG0<0@4100`0V
9RH2010@40<020P80`0V9RH2061PH0<0RHV90`1XJ6P303<c<`802@T90`0];Bd3065QH@<0<S8b0P0:
2PXY000000P0oooo00060?oooe0000000`1[Jf/20:n_[`<0^;Rh0`2>SXh3059BDP80RHV90`3De=@3
0<30`0<0/k>c0P2WYjL30:ZZZP<0P8200`1VIVH2071`L0<0PH610`1`L70306m_K`80U9BD0`37alL3
0=;BdP80b<S80`3@d=030=SHf0<0fMWI0P3Jf]X30=;BdP<0e]KF0`3Bd]820=KFeP<0mOGe0`2g]kL3
0;Zj^P80_Kfm0`2d];@30:2PX0<0Jf][0P0m?Cd305]KF`<0QXJ60`27QhL204Q8B0<0K6a/0`14A4@3
02`/;0805aLG0`071`L302LW9`80FEUI0`20P80306][J`<0@4100P0G5aL304a<C0<0JVYZ0`0l?3`2
01hN7P<00@410`00000300X:2R000000203oool000H0ooooD000000306][J`80[jn_0`2h^;P308j>
SP<0DU9B0P29RHT30=CDe0<0`<300`2c/k<20:NWY`<0ZZZZ0`20P80306IVIP80L71`0`21PH43071`
L0<0Kfm_0P2DU9@30<O7a`<0d];B0P38b<P30=3@d0<0f=SH0`3IfMT20=[JfP<0d];B0`3Fe]H30=;B
dP80e]KF0`3emOD30;Ng]`<0^[Zj0P2m_Kd30;Bd]0<0X:2P0`1[Jf/203dm?@<0Fe]K0`26QXH308N7
Q`80B4Q80`1/K6`304A4A0<0;2`/0P0G5aL300L71`<09bLW0P1IFET30820P0<0Jf][0`10@40201LG
5`<0C4a<0`1ZJVX303`l?0807QhN0`010@43000000<02PX:800000080?ooo`001P3ooom@000000<0
Jf][0P2_[jl30;Rh^0<0SXj>0`1BDU8208V9R@<0e=CD0`30`<030;>c/`80YjNW0`2ZZZX30820P0<0
IVIV0P1`L7030861P@<0L71`0`1_Kfl209BDU0<0alO70`3Bd]820<S8b0<0d=3@0`3Hf=P30=WIf@80
f][J0`3Bd]830=KFeP<0d];B0P3Fe]H30?Gem@<0]kNg0`2j^[X20;fm_@<0];Bd0`2PX:0306][J`80
?Cdm0`1KFe/308J6QP<0QhN70P18B4P306a/K0<0A4A40`0/;2`201LG5`<01`L70`0W9bL205UIF@<0
P8200`1[Jf/30410@0805aLG0`1<C4`306YZJP<0?3`l0P0N7Qh300410@<000000`0:2PXP000000P0
oooo00060?oooe0000000`27QhL20;Jf]P<0[:b/0`2GUiL309FEU@80cLg=0`3;bl/30;fm_@<0h^;R
0P3_knl30=?Cd`<0alO70`2n_[h20:2PX0<0N7Qh0`1ZJVX308B4Q080QhN70`2MWId30=OGe`80fMWI
0`3AdM430=3@d0<0b<S80P3AdM430<k>cP<0`l?30`2o_kl20;^k^`<0]KFe0`2XZ:P30:VYZ@80Z:RX
0`2FUYH3071`L0<0D51@0P0c<c<30492@P<0PX:20`2<S8`208j>SP<0QXJ60`1IFET300000080820P
0`0;2`/303<c<`80JVYZ0`23Ph<307EeM@<0@T920P0V9RH306i^KP<0HV9R0`16ATH202DU9BT00000
203oool000H0ooooD000000308N7Q`80][Jf0`2/[:`309NGU`<0UIFE0P3=cLd30<_;b`<0_Kfm0`3R
h^820>o_k`<0dm?C0`37alL30;jn_P80X:2P0`1hN7P306YZJP<0Q8B40P27QhL309fMW@<0emOG0P3I
fMT30=7Ad@<0d=3@0`38b<P20=7Ad@<0c/k>0`33`l<30;no_`80^k^k0`2e]KD30:RXZ0<0ZJVY0P2X
Z:P309JFUP<0L71`0`1@D50203<c<`<0@T920`22PX8308b<S080SXj>0`26QXH305UIF@<000000P0P
820300/;2`<0<c<c0P1ZJVX308>3P`<0MGEe0`12@T8202HV9P<0KVi^0`1RHV8304I6AP809BDU:@00
00080?ooo`001P3ooom@000000<0QhN70P2f][H30:b/[0<0UiNG0`2EUID20<g=c@<0bl_;0`2m_Kd3
0>;RhP80kno_0`3Cdm<30<O7a`<0_[jn0P2PX:0307QhN0<0JVYZ0`24Q8@208N7Q`<0WIfM0`3GemL2
0=WIf@<0dM7A0`3@d=030<S8b080dM7A0`3>c/h30<?3``<0_kno0P2k^k/30;Fe]@<0Z:RX0`2YZJT2
0:RXZ0<0UYJF0`1`L703051@D080<c<c0`12@T8308:2PP<0S8b<0P2>SXh308J6QP<0FEUI0`000002
020P80<02`/;0`0c<c<206YZJP<0Ph>30`1eMGD30492@P809RHV0`1^KVh3069RHP<0ATI60P0U9BDY
000000P0oooo00060?ooocd000000P0N7QhA000000<0IVIV0P34a<@30;Vi^@<0];Bd0`2c/k<208n?
S`<0IFEU0`1XJ6P3061PH080VYZJ0`3=cLd30<[:bP<0_Kfm0P2^[Zh30:>SX`<0Vi^K0`2<S8`20:ZZ
ZP<0MgMg0`2i^KT20<K6aP<0ZJVY0`2QXJ4309ZJVP80WinO0`2SXj<60:RXZ080UYJF0`2NWYh30:JV
YP<0W9bL0P1lO7`305eMG@<0=CDe0`0B4Q8200820P<0:RXZ0`1aLG4308J6QP80RXZ:0`25QHD305iN
GP<0;bl_0P0J6QX3010@40<0AdM70P22PX8308>3P`<0Ng]k0`0g=cL204A4A0<0NGUi0`1WIfL303hn
?P802@T95000000206ATI1<00000203oool000H0oooo?@00000201hN7Q4000000`1VIVH20<C4a0<0
^KVi0`2d];@30;>c/`80Shn?0`1UIFD306QXJ0<0H61P0P2JVYX30<g=c@<0b/[:0`2m_Kd20:j^[P<0
Xj>S0`2KVi/308b<S080ZZZZ0`1gMgL30;Vi^@80a/K60`2YZJT30:6QX@<0VYZJ0P2OWil30:>SX`H0
Z:RX0P2FUYH309jNWP<0YZJV0`2LW9`207alO0<0GEeM0`0e=CD3018B4P800P820`0Z:RX3075aL@<0
QXJ60P2:RXX308F5Q@<0GUiN0`0_;bl201XJ6P<0410@0`17AdL208:2PP<0Ph>30`1kNg/303Lg=`80
A4A40`1iNGT306MWI`<0?Shn0P092@TD00000080I6AT4`0000080?ooo`001P3ooolm000000807QhN
4@00000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0cLg=
0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX307MgM`<0^KVi0P36a/H30:VYZ@<0XJ6Q
0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<04Q8B
0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80PX:2
0`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92A@000000P1TI6@C000000P0oooo
00060?oooe0000000`0Y:BT20<;2`P<0_[jn0`3Cdm<302d];@80Lg=c0`2c/k<30>o_k`<0emOG0P2M
WId30<g=c@<0];Bd0`33`l<20>3Ph0<0jn_[0`3]kNd30<o?c`80_[jn0`2/[:`3096AT@80T92@0`20
P803075aL@<0FUYJ0P1CDe<305]KF`<0KVi^0`0V9RH206a/K0<0Hf=S0`1MGEd304m?C`80Bd];0`13
@d<305iNGP<0JFUY0P1BDU8301lO7`<0IFEU0`1lO7`20861P@<0R8R80`1YJFT303Hf=P807AdM0`0C
4a<304e=C@80Ti>C0`1lO7`3061PH0<0;Rh^0P1VIVH306QXJ0<0=cLg0`061PH[000000P0oooo0006
0?oooe0000000`0Y:BT20<;2`P<0_[jn0`3Cdm<302d];@80Lg=c0`2c/k<30>o_k`<0emOG0P2MWId3
0<g=c@<0];Bd0`33`l<20>3Ph0<0jn_[0`3]kNd30<o?c`80_[jn0`2/[:`3096AT@80T92@0`20P803
075aL@<0FUYJ0P1CDe<305]KF`<0KVi^0`0V9RH206a/K0<0Hf=S0`1MGEd304m?C`80Bd];0`13@d<3
05iNGP<0JFUY0P1BDU8301lO7`<0IFEU0`1lO7`20861P@<0R8R80`1YJFT303Hf=P807AdM0`0C4a<3
04e=C@80Ti>C0`1lO7`3061PH0<0;Rh^0P1VIVH306QXJ0<0=cLg0`061PH[000000P0oooo00060?oo
oe0000000`051@D20:NWY`<0b<S80`2h^;P30<W9b@80lO7a0`3hn?P30>o_k`<0j^[Z0P3^k^h30>OW
i`<0j^[Z0`3fm_H20>o_k`H0jn_[0`3Bd]820;>c/`<0YjNW0`2GUiL209^KV`<0/;2`0`2d];@30;Fe
]@80SHf=0`21PH4306QXJ0<0G5aL0P11@D4302XZ:P<09BDU0`0G5aL2010@40<05aLG0`0b<S8305mO
G`80DE5A0`0>3Ph305ADE0<0Ogmo0P21PH4308:2PP<0K6a/0`1>CTh202`/;0<071`L0`1RHV8209RH
V0<0M7Ad0`11@D4303Xj>P80MWIf0`17AdL300L71bh00000203oool000H0ooooD000000300D51@80
YjNW0`38b<P30;Rh^0<0bLW90P3alO430?Shn0<0kno_0`3Zj^X20>k^kP<0inOW0`3Zj^X30?KfmP80
kno_1P3[jn/30=;BdP80/k>c0`2WYjL309NGU`80Vi^K0`2`/;030;Bd]0<0]KFe0P2=SHd30861P@<0
J6QX0`1LG5`20451@@<0:RXZ0`0U9BD301LG5`80410@0`0G5aL3038b<P<0GemO0P1ADE4300h>3P<0
E5AD0`1oOgl20861P@<0PX:20`1/K6`304i>CP80;2`/0`0L71`3069RHP80V9RH0`1dM7@30451@@<0
>SXj0P1fMWH304M7A`<01`L7;P0000080?ooo`001P3ooom@000000<01@D50P2WYjL30<S8b0<0^;Rh
0`39bLT20?7al@<0n?Sh0`3_knl30>[ZjP80k^k^0`3WinL30>[ZjP<0m_Kf0P3_knl60>_[j`<0d];B
0P2c/k<30:NWY`<0UiNG0P2KVi/30;2`/0<0];Bd0`2e]KD208f=S@<0PH610`1XJ6P305aLG080@D51
0`0Z:RX302DU9@<05aLG0P0@410301LG5`<0<S8b0`1OGel2055AD@<03Ph>0`1DE5@307moO`80PH61
0`22PX8306a/K0<0CTi>0P0/;2`301`L70<0HV9R0P2HV9P307AdM0<0@D510`0j>SX207IfMP<0AdM7
0`071`L^000000P0oooo00060?oooe<000000P1VIVH30=[JfP<0`l?30`2j^[X20=CDe0<0f=SH0`3>
c/h30:f][@80b<S80`3De=@30=gMg@<0d=3@0P1OGel30<C4a0<0[:b/0`2f][H20::RXP<0SXj>0`1n
OWh206a/K0<0OGem0`1_Kfl309VIV@80];Bd0`38b<P304a<C0<0P8200P2HV9P309jNWP<0SHf=0`2`
/;0206=SH`<0?clo1P0d=3@202l_;`<0;Bd]0`17AdL307MgM`80PH610`1mOGd306m_K`<08R8R0P0e
=CD302/[:`<0RHV90P2EUID30=gMg@<0>c/k0`1LG5`204i>CP<03@d=<@0000080?ooo`001P3ooomC
00000080IVIV0`3Jf]X30<?3``<0^[Zj0P3De=@30=SHf0<0c/k>0`2][Jd20<S8b0<0e=CD0`3MgMd3
0=3@d080GemO0`34a<@30:b/[0<0][Jf0P2RXZ8308j>SP<0OWin0P1/K6`307emO@<0Kfm_0`2IVIT2
0;Bd]0<0b<S80`1<C4`30820P080V9RH0`2NWYh308f=S@<0/;2`0P1SHf<303lo?`H0=3@d0P0_;bl3
02d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl3028R8P80=CDe0`0[:b/308V9R@80UIFE0`3MgMd3
03/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj
^P80e=CD0`3Hf=P30<k>cP<0[Jf]0P38b<P30=CDe0<0gMgM0`3@d=0205mOG`<0a<C40`2/[:`30;Jf
]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@30<S8b0<0C4a<0`20P80209RH
V0<0WYjN0`2=SHd30;2`/080Hf=S0`0o?cl603@d=080;bl_0`0];Bd304M7A`<0MgMg0P21PH4307em
O@<0Kfm_0`0R8R8203De=@<0:b/[0`29RHT209FEU@<0gMgM0`0k>c/305aLG080CTi>0`0=3@da0000
00P0oooo00060?ooodP000000P1IFET900000080820P1P3AdM430<c<c080eMGE0`3Kfm/30>CTi0<0
iNGU0P3]kNd30>_[j`<0gMgM0`3Ph>020:ZZZP<0GEeM0`0l?3`305=CD`80J6QX0`1^KVh306MWI`80
IVIV0`2=SHd30:BTY0<0WYjN0P35aLD30;Bd]0<0JFUY0`14A4@205eMG@<0Jf][0`1dM7@308n?S`80
ZJVY0`2e]KD309bLW0<0PH610P0l?3`305IFEP<0Jf][0`1jNWX20820P0<0OGem0`1dM7@3055AD@80
;Bd]0`1?Cdl309ZJVP80QhN70`1OGel304I6AP<0?Shn0P0820P3000000<00@416`00000300d=3A00
0000203oool000H0ooooB000000205UIF@T000000P0P82060=7Ad@<0c<c<0P3EeMD30=_Kf`<0i>CT
0`3UiND20>g]k@<0jn_[0`3MgMd30>3Ph080ZZZZ0`1MGEd303`l?0<0De=C0P1XJ6P306i^KP<0IfMW
0P1VIVH308f=S@<0Y:BT0`2NWYh20<G5a@<0];Bd0`1YJFT304A4A080GEeM0`1[Jf/307AdM0<0Shn?
0P2YZJT30;Fe]@<0W9bL0`21PH4203`l?0<0EUIF0`1[Jf/307YjNP80P8200`1mOGd307AdM0<0DE5A
0P0];Bd304m?C`<0VYZJ0P27QhL305mOG`<0ATI60`0n?Sh200P820<000000`010@4K000000<03@d=
400000080?ooo`001P3ooomE000000<0Lg=c0`3Shn<30<o?c`80dM7A1P3Jf]X30>KViP80jNWY0`3J
f]X30=kNgP<0/K6a0P0X:2P300H61P<02PX:0`092@T201`L70<0F5QH0`1eMGD208>3P`<0fMWI0`2l
_;`30<C4a080[Zj^0`2h^;P30=?Cd`<0SXj>0P1EEED305eMG@<0E5AD0`1gMgL209nOW`<0[Zj^0`2L
W9`3069RHP80CDe=0`1_Kfl307moO`<0Q8B40P23Ph<308B4Q0<0JVYZ0`18B4P202XZ:P<0HF5Q0`2B
TY8207=cL`<0CDe=0`0U9BD300820P8000000`010@4a000000P0oooo00060?oooeD000000`1cLg<3
0>?Sh`<0clo?0P3AdM460=[JfP<0i^KV0P3YjNT30=[JfP<0g]kN0`2a/K4202PX:0<01PH60`0:2PX3
00T92@8071`L0`1HF5P307EeM@80Ph>30`3IfMT30;bl_0<0a<C40P2^[Zh30;Rh^0<0dm?C0`2>SXh2
05EEE@<0GEeM0`1DE5@307MgM`80WinO0`2^[Zh309bLW0<0HV9R0P1=CDd306m_K`<0Ogmo0`24Q8@2
08>3P`<0Q8B40`1ZJVX304Q8B080:RXZ0`1QHF4309:BTP80Lg=c0`1=CDd302DU9@<00P820P000003
00410C400000203oool000H0ooooE@00000307=cL`<0hn?S0`3?cll20=7Ad@H0f][J0`3Vi^H20>WY
j@<0f][J0`3Ng]h30;6a/@80:2PX0`061PH300X:2P<02@T90P0L71`305QHF0<0MGEe0P23Ph<30=WI
f@<0_;bl0`34a<@20:j^[P<0^;Rh0`3Cdm<308j>SP80EEEE0`1MGEd305ADE0<0MgMg0P2OWil30:j^
[P<0W9bL0`1RHV8204e=C@<0Kfm_0`1oOgl308B4Q080Ph>30`24Q8@306YZJP<0B4Q80P0Z:RX3065Q
H@<0TY:B0P1cLg<304e=C@<09BDU0`020P82000000<00@41<@0000080?ooo`001P3ooomE000000<0
4Q8B0`2o_kl30>3Ph080clo?0`3AdM430=KFeP<0cLg=0P3MgMd30>WYj@<0g=cL0`1SHf<202HV9P<0
9bLW0`0O7al301HF5P802`/;0`0X:2P306a/K080a/K60`2e]KD30<W9b@<0b<S80P2ZZZX30861P@<0
emOG0`2o_kl209JFUP<0OWin0`1lO7`305UIF@80De=C0`1>CTh305iNGP<0@d=30P1NGUh307QhN0<0
PX:20`25QHD208Z:RP<0Ph>30`1TI6@303hn?P80<C4a0`1bLW8307alO080G5aL0`0Y:BT6000000D0
0@413P00000301PH62000000203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A
0`3Fe]H30<g=c@80gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX
0`1/K6`20<K6aP<0]KFe0`39bLT30<S8b080ZZZZ0`21PH430=OGe`<0_kno0P2FUYH307inOP<0O7al
0`1IFET205=CD`<0CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT
0`0n?Sh2034a<@<0LW9b0`1lO7`205aLG0<0:BTY1P00000500410@h000000`0H61PP000000P0oooo
00060?oooeD000000`0B4Q830;no_`<0h>3P0P3?cll30=7Ad@<0e]KF0`3=cLd20=gMg@<0jNWY0`3L
g=`306=SH`809RHV0`0W9bL301lO7`<05QHF0P0;2`/302PX:0<0K6a/0P36a/H30;Fe]@<0bLW90`38
b<P20:ZZZP<0PH610`3GemL30;no_`80UYJF0`1nOWh307alO0<0FEUI0P1CDe<304i>CP<0GUiN0`13
@d<205iNGP<0N7Qh0`22PX8308F5Q@80RXZ:0`23Ph<306ATI0<0?Shn0P0a<C43079bLP<0O7al0P1L
G5`302TY:@H000001@010@4>000000<061PH800000080?ooo`001P3ooomH000000<0;bl_0`30`<02
0>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0PX:20P21PH4307YjNP<0Shn?0`0n?Sh2
02/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80bLW90`1nOWh307alO0<0T92@0P2m_Kd3
09nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80Jf][0`1kNg/308>3P`<0SXj>0P2;Rh/3
07inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<01PH6?00000080?ooo`001P3ooomH0000
00<0;bl_0`30`<020>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0PX:20P21PH4307Yj
NP<0Shn?0`0n?Sh202/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80bLW90`1nOWh307al
O0<0T92@0P2m_Kd309nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80Jf][0`1kNg/308>3
P`<0SXj>0P2;Rh/307inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<01PH6?00000080?oo
o`001P3ooomH000000<0;bl_0`30`<020>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0
PX:20P21PH4307YjNP<0Shn?0`0n?Sh202/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80
bLW90`1nOWh307alO0<0T92@0P2m_Kd309nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80
Jf][0`1kNg/308>3P`<0SXj>0P2;Rh/307inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<0
1PH6?00000080?ooo`001P3ooomK000000<06QXJ0P1=CDd30>o_k`<0h>3P0`3MgMd20>?Sh`<0g=cL
0`2f][H30:JVYP80`L710`3Lg=`30=oOg`<0QXJ60P1[Jf/304Y:BP<0;2`/0P2DU9@30=SHf0<0UYJF
0`2TY:@20=;BdP<0c<c<0`2o_kl30:b/[080/K6a0`31`L430:ZZZP<0/[:b0P2m_Kd30;jn_P<0D51@
0`0n?Sh206UYJ@<0NGUi0`29RHT309:BTP80Shn?0`1jNWX3061PH0<0?clo0P14A4@305iNGP<0DU9B
0P0J6QXm00000080IfMW203oool000H0ooooF`00000301XJ6P80CDe=0`3_knl30>3Ph0<0gMgM0P3S
hn<30=cLg0<0][Jf0`2VYZH20<71`@<0g=cL0`3Ogml308J6QP80Jf][0`1:BTX302`/;080U9BD0`3H
f=P309JFUP<0Y:BT0P3Bd]830<c<c0<0_kno0`2/[:`20;6a/@<0`L710`2ZZZX30;:b/P80_Kfm0`2n
_[h3051@D0<0?Shn0P1YJFT307UiN@<0RHV90`2BTY8208n?S`<0NWYj0`1PH60303lo?`80A4A40`1N
GUh3059BDP806QXJ?@00000206MWI`P0oooo00060?oooeh000000P071`L307MgM`<0_;bl0`2KVi/2
0>CTi0<0fMWI0`2[Zj/30:BTY080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<00P820P1lO7`3
0<O7a`<0a<C40`2EUID208n?S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd3
04E5A@<0ATI60`18B4P206QXJ0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh3
04e=C@<0<30`0P020P8A000000<02@T9:`0000080?ooo`001P3ooomN000000801`L70`1gMgL30;bl
_0<0Vi^K0P3Ti>@30=WIf@<0Zj^[0`2TY:@20<_;b`<0k>c/0`3Rh^830<C4a080U9BD0`26QXH30082
0P80O7al0`37alL30<C4a0<0UIFE0P2?Shl309nOW`<0_[jn0`38b<P209RHV0<0YJFU0`2TY:@30:^[
Z`80OGem0`15ADD304I6AP<0B4Q80P1XJ6P307emO@<0RHV90`2?Shl208R8R0<0MgMg0`1LG5`303dm
?@80?Shn0`1=CDd3030`<0800P824@00000300T92B/00000203oool000H0ooooGP00000200L71`<0
MgMg0`2l_;`309^KV`80i>CT0`3IfMT30:^[Z`<0Y:BT0P3;bl/30>c/k0<0h^;R0`34a<@209BDU0<0
QXJ60`020P8207alO0<0alO70`34a<@309FEU@80Shn?0`2OWil30;jn_P<0b<S80P2HV9P30:FUY@<0
Y:BT0`2[Zj/207emO@<0ADE50`16ATH304Q8B080J6QX0`1mOGd308V9R@<0Shn?0P28R8P307MgM`<0
G5aL0`0m?Cd203hn?P<0CDe=0`0`<30200820Q4000000`092@T[000000P0oooo00060?ooo`<00000
0`1;Bd/i000000<0KVi^8@00000304];B`<0/K6a1@3Xj>P309jNWP<0PH610P2XZ:P30>KViP<0bLW9
0`2WYjL208V9R@<0RXZ:0`0m?Cd205EEE@<0ZJVY1P32`/820<30`0<0a/K60`2[Zj/30;Bd]080UYJF
0`2CTi<307inOP<0CTi>0P0Q8B4303Xj>P<0EUIF0`1BDU8205eMG@<0O7al0`2ATI4308j>SP80OWin
0`1_Kfl305EEE@<0;bl_0P0Z:RX303Ph>0<04A4A0P00000300410C`00000203oool000H0oooo0`00
000304];BcT000000`1^KVhQ000000<0Bd];0`2a/K450>SXj0<0WYjN0`21PH420:RXZ0<0i^KV0`39
bLT30:NWY`80RHV90`2:RXX303dm?@80EEEE0`2YZJT60<;2`P80`<300`36a/H30:^[Z`<0];Bd0P2F
UYH309>CT`<0OWin0`1>CTh2024Q8@<0>SXj0`1FEUH3059BDP80GEeM0`1lO7`3096AT@<0SXj>0P1n
OWh306m_K`<0EEEE0`0_;bl202XZ:P<0>3Ph0`0A4A42000000<00@41?00000080?ooo`001P3oool3
000000<0Bd];>@00000306i^KR4000000`1;Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H3
0<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@2
09JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh2
07inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l000000P0oooo00060?oo
ofT000000P0m?Cd30:VYZ@<0W9bL0`1cLg<206i^KP<0V9RH0`2JVYX30861P@80L71`0`1aLG4304I6
AP80BTY:0`2=SHd30:n_[`<0YJFU0P2TY:@30<S8b0<0_kno0`2YZJT208N7Q`<0=cLg0`0?3`l301HF
5P80=SHf0`15ADD304Y:BP<0GemO0P1YJFT308>3P`<0TI6A0`2;Rh/207UiN@<0IfMW0`17AdL5024Q
8@<0<30`0`051@D2000000<00@41?00000080?ooo`001P3ooomY00000080?Cdm0`2YZJT309bLW0<0
Lg=c0P1^KVh309RHV0<0VYZJ0`21PH42071`L0<0LG5a0`16ATH204Y:BP<0SHf=0`2_[jl30:FUY@80
Y:BT0`38b<P30;no_`<0ZJVY0P27QhL303Lg=`<03`l?0`0F5QH203Hf=P<0ADE50`1:BTX305mOG`80
JFUY0`23Ph<3096AT@<0Rh^;0P1iNGT306MWI`<0AdM71@0Q8B43030`<0<01@D50P00000300410C`0
0000203oool000H0oooo0`00000300l?3d8000000P1`L70Q000000<01`L70`1OGel306a/K080M7Ad
0`2EUID309RHV0<0P8200P1YJFT305EEE@<0@d=30P0g=cL305mOG`<0MgMg0`20P80208f=S@<0RXZ:
0`1dM7@303hn?P803Ph>0`0;2`/301TI6@<07alO0P0j>SX604i>CP<0EEEE0P1aLG4308R8R0<0Shn?
0`0F5QH2075aL@<0FUYJ0`0b<S8301PH6080;2`/0`0N7Qi4000000P0oooo00060?ooo`<000000`0?
3`m200000080L71`8@00000300L71`<0GemO0`1/K6`207AdM0<0UIFE0`2HV9P30820P080JFUY0`1E
EED304=3@`80=cLg0`1OGel307MgM`<0P8200P2=SHd308Z:RP<0M7Ad0`0n?Sh200h>3P<02`/;0`0I
6AT301lO7`80>SXj1P1>CTh305EEE@80LG5a0`28R8P308n?S`<05QHF0P1aLG4305YJFP<0<S8b0`0H
61P202`/;0<07QhNA00000080?ooo`001P3oool3000000<03`l?@P000002071`L24000000`071`L3
05mOG`<0K6a/0P1dM7@309FEU@<0V9RH0`20P80206UYJ@<0EEEE0`13@d<203Lg=`<0GemO0`1gMgL3
0820P080SHf=0`2:RXX307AdM0<0?Shn0P0>3Ph300/;2`<06ATI0`0O7al203Xj>PH0CTi>0`1EEED2
075aL@<0R8R80`2?Shl301HF5P80LG5a0`1JFUX3038b<P<061PH0P0/;2`301hN7T@00000203oool0
00H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ
:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<01@D50P0@410301lO7`<09bLW0`0N7Qh203/k
>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D5
1Ah000000`1mOGdS000000P0oooo00060?ooofh000000`0h>3P306QXJ080Hf=S0`1WIfL306YZJP<0
H61P0P1@D5030492@P<0=SHf0P0Z:RX305=CD`<0HV9R0`1QHF4205=CD`<0=SHf0`0E5AD300D51@80
410@0`0O7al302LW9`<07QhN0P0k>c/304];B`<0EUIF0`1NGUh2079bLPH0Rh^;0`1oOgl2079bLP<0
C4a<0`0^;Rh302HV9P80;2`/0`051@DN000000<0OGem8`0000080?ooo`001P3ooom^000000<0>3Ph
0`1XJ6P206=SH`<0IfMW0`1ZJVX3061PH080D51@0`12@T8303Hf=P80:RXZ0`1CDe<3069RHP<0HF5Q
0P1CDe<303Hf=P<05ADE0`051@D2010@40<07alO0`0W9bL301hN7P80>c/k0`1;Bd/305IFEP<0GUiN
0P1bLW8608^;R`<0Ogmo0P1bLW8304a<C0<0;Rh^0`0V9RH202`/;0<01@D57P00000307emOB<00000
203oool000H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y
:BT301/K6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f
=SH304m?C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P09
2@T3000000<00@413@00000304=3@c400000203oool000H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/3
06MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3
018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT3
07QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T3000000<00@413@00000304=3@c400000203oool0
00H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K
6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?
C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T30000
00<00@413@00000304=3@c400000203oool000H0oooo2@00000202PX:14000000`0@411?000000<0
;Bd]0`29RHT207alO0<0;2`/0`1^KVh305iNGP80B4Q80`0_;bl302/[:`80<30`0`0B4Q8300X:2P<0
410@0P0D51@301/K6`<05QHF0`0M7Ad202HV9P<0=CDe0`0`<30303/k>`80_kno0`11@D4305mOG`<0
PX:20P2<S8`607alO0<0Ng]k0P0o?cl304i>CP<0=3@d0`0<30a9000000P0oooo00060?ooo`T00000
0P0X:2PA000000<0410@C`00000302d];@<0RHV90P1lO7`302`/;0<0KVi^0`1NGUh204Q8B0<0;bl_
0`0[:b/2030`<0<04Q8B0`0:2PX3010@408051@D0`0K6a/301HF5P<07AdM0P0V9RH303De=@<0<30`
0`0k>c/20;no_`<0@D510`1OGel308:2PP80S8b<1P1lO7`307]kN`80?clo0`1>CTh303@d=0<030`<
B@0000080?ooo`001P3oool900000080EEEEGP00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]
KFd606EUI@80emOG0`0j>SX303De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S
8b<203Hf=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_
Kfl2061PH0<0D51@0`0F5QHF000000803Ph>=00000080?ooo`001P3oool900000080EEEEGP000002
00410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EUI@80emOG0`0j>SX303De=@80;2`/0`0B4Q83
014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P3
06UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061PH0<0D51@0`0F5QHF000000803Ph>=0000008
0?ooo`001P3oool900000080EEEEGP00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EU
I@80emOG0`0j>SX303De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf
=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061P
H0<0D51@0`0F5QHF000000803Ph>=00000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0
QhN70`1jNWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0
:BTY0`0[:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0
JFUY0`1HF5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0QhN7
0`1jNWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0:BTY
0`0[:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0JFUY
0`1HF5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0QhN70`1j
NWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0:BTY0`0[
:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0JFUY0`1H
F5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<0410@0`1XJ6P209VIV@<0oooo0`28R8P3
0861P@80LW9b0`1WIfL3055AD@80;Bd]0`0K6a/301hN7P<071`L0P0J6QX302PX:0<09RHV0`000002
0410@0<0@d=30`1EEED307=cL`80Ng]k1P1hN7P306a/K080JVYZ0`1KFe/304Y:BP<0BDU90P0T92AB
000000P0oooo00060?ooofh000000`0@410306QXJ080VIVI0`3oool308R8R0<0PH610P1bLW8306MW
I`<0DE5A0P0];Bd301/K6`<07QhN0`0L71`201XJ6P<0:2PX0`0V9RH300000080@4100`13@d<305EE
E@<0Lg=c0P1kNg/607QhN0<0K6a/0P1ZJVX305]KF`<0BTY:0`19BDT202@T95800000203oool000H0
ooooL@00000305QHF080T92@0`2BTY8308J6QP<0NWYj0P1eMGD306MWI`<0AdM70P00000301lO7`<0
8b<S0`0O7al202<S8`<0;Rh^0`0`<30304m?C`80C4a<0`1HF5P30=;BdP<0LW9b0P1jNWX607UiN@<0
LW9b0P1CDe<304U9B@<0@4100`0G5aMD000000P0oooo00060?ooog4000000`1HF5P2092@T0<0TY:B
0`26QXH307YjNP80MGEe0`1WIfL304M7A`8000000`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`
0`1?Cdl204a<C0<0F5QH0`3Bd]83079bLP80NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLG
E00000080?ooo`001P3oooma000000<0F5QH0P2@T90309:BTP<0QXJ60`1jNWX207EeM@<0IfMW0`17
AdL2000000<07alO0`0S8b<301lO7`808b<S0`0^;Rh3030`<0<0Cdm?0P1<C4`305QHF0<0d];B0`1b
LW8207YjNPH0NGUi0`1bLW8205=CD`<0BDU90`10@40301LG5e@00000203oool000H0ooooKP000003
01dM7@<0F5QH0P27QhL308j>SP<0R8R80`1iNGT206][J`<0GEeM0`10@40502PX:0<09BDU0`0W9bL2
03Lg=`<0:b/[0`1:BTX305UIF@80FUYJ0`1ZJVX307QhN0<0Lg=c0P1eMGD307UiN@<0OGem0`1VIVH2
04U9B@<0<C4a0`0820Pg000000808B4Q7P0000080?ooo`001P3ooom^000000<07AdM0`1HF5P208N7
Q`<0SXj>0`28R8P307UiN@80Jf][0`1MGEd30410@0D0:2PX0`0U9BD302LW9`80=cLg0`0[:b/304Y:
BP<0FEUI0P1JFUX306YZJP<0N7Qh0`1cLg<207EeM@<0NGUi0`1mOGd306IVIP80BDU90`0a<C4300P8
23L000000P0Q8B4N000000P0oooo00060?ooofh000000`0M7Ad305QHF080QhN70`2>SXh308R8R0<0
NGUi0P1[Jf/305eMG@<0@4101@0X:2P302DU9@<09bLW0P0g=cL302/[:`<0BTY:0`1IFET205YJFP<0
JVYZ0`1hN7P307=cL`80MGEe0`1iNGT307emO@<0IVIV0P19BDT3034a<@<020P8=`000002024Q8Ah0
0000203oool000H0ooooJ@00000500410@<0DE5A0`1IFET208>3P`<0TI6A0`26QXH307EeM@80IFEU
0`1FEUH30410@080<S8b0`0_;bl302/[:`<0=SHf0P0a<C4304I6AP<0HF5Q0`1PH60206YZJP<0MGEe
0`1nOWh307UiN@80MGEe0`1mOGd307=cL`<0Bd];0P0L71`o000000<01PH66`0000080?ooo`001P3o
oomY000000D00@410`1ADE4305UIF@80Ph>30`2ATI4308J6QP<0MGEe0P1UIFD305IFEP<0@4100P0b
<S8302l_;`<0:b/[0`0f=SH2034a<@<0ATI60`1QHF43061PH080JVYZ0`1eMGD307inOP<0NGUi0P1e
MGD307emO@<0Lg=c0`1;Bd/201`L73l000000`061PHK000000P0oooo00060?ooofT000001@010@43
055AD@<0FEUI0P23Ph<3096AT@<0QXJ60`1eMGD206EUI@<0EUIF0`10@402038b<P<0;bl_0`0[:b/3
03Hf=P80<C4a0`16ATH3065QH@<0H61P0P1ZJVX307EeM@<0OWin0`1iNGT207EeM@<0OGem0`1cLg<3
04];B`8071`L?`00000300H61Q/00000203oool000H0oooo2@00000206YZJQ@000000P11@D4I0000
00<051@D1@00000302TY:B4000000`010@4200@410<00`<30`020P8304I6AP80Ng]k0`29RHT307]k
N`<0JVYZ0P1OGel304m?C`<0@4100P0f=SH3038b<P<0>SXj0`0i>CT204M7A`<0FUYJ0`0o?cl306QX
J080NGUi0`1oOgl308>3P`<0P8200P1lO7`306e]K@<0ATI60`0>3PiO000000P0oooo00060?ooo`T0
00000P1ZJVXD00000080@D516@00000301@D50D000000`0Y:BTQ000000<00@410P0410@300<30`<0
0P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410@080=SHf0`0b<S8303Xj>P<0
>CTi0P17AdL305YJFP<0?clo0`1XJ6P207UiN@<0Ogmo0`23Ph<30820P080O7al0`1]KFd304I6AP<0
3Ph>G`0000080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P
0P1_Kfl308B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY
0`1NGUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41
G@0000080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P0P1_
Kfl308B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY0`1N
GUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41G@00
00080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P0P1_Kfl3
08B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY0`1NGUh3
06MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41G@000008
0?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l0`1nOWh307]kN`<0JVYZ0P1UIFD305eM
G@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF0`1]KFd307EeM@80NWYj0`1cLg<305eM
G@<0Bd];JP0000080?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l0`1nOWh307]kN`<0
JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF0`1]KFd307EeM@80
NWYj0`1cLg<305eMG@<0Bd];JP0000080?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l
0`1nOWh307]kN`<0JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF
0`1]KFd307EeM@80NWYj0`1cLg<305eMG@<0Bd];JP0000080?ooo`001P3ooomC000000805ADE2`00
000900410@80@4100`030`<300@410<020P80P0F5QH304E5A@<0HV9R1@1^KVh306MWI`<0FEUI0P08
20P305YJFP<0G5aL0`1NGUh206EUI@<0JFUY0`1/K6`306UYJ@80G5aL0`1ADE4301dM7@<0@D510P0d
=3@300T92FD00000203oool000H0ooooD`00000201DE5@/000002@010@420410@0<00`<30`0410@3
00P820805QHF0`15ADD3069RHPD0KVi^0`1WIfL305UIF@8020P80`1JFUX305aLG0<0GUiN0P1UIFD3
06UYJ@<0K6a/0`1YJFT205aLG0<0DE5A0`0M7Ad30451@@80=3@d0`092@UU000000P0oooo00060?oo
oe<000000P0E5AD;000000T00@410P10@40300<30`<010@40`0820P201HF5P<0ADE50`1RHV8506i^
KP<0IfMW0`1IFET200P820<0FUYJ0`1LG5`305iNGP80IFEU0`1YJFT306a/K0<0JFUY0P1LG5`3055A
D@<07AdM0`11@D4203@d=0<02@T9I@0000080?ooo`001P3ooolT000000<0LW9b:@000003075aL@d0
00002`010@4300X:2P<03@d=0`0:2PX201/K6`<08b<S0`0l?3`305=CD`80H61P0`1OGel3061PH080
GemO0`1MGEd3061PH0<0HV9R0P1UIFD306ATI0<0H61P0`1GEeL2051@D0<0CDe=0`12@T8303Ti>@80
5aLG3P00000304A4A5L00000203oool000H0oooo90000003079bLRT000000`1aLG4=000000/00@41
0`0:2PX300d=3@<02PX:0P0K6a/302<S8`<0?3`l0`1CDe<2061PH0<0GemO0`1PH60205mOG`<0GEeM
0`1PH603069RHP80IFEU0`1TI6@3061PH0<0EeMG0P1@D50304e=C@<0@T920`0i>CT201LG5`h00000
0`14A4AG000000P0oooo00060?ooof0000001P010@43000000800`<30`0=3@d301TI6@<061PH0P0M
7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306ATI080IfMW0`1O
Gel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BD[000000<0=SHf=000000301/K6`D00000203o
ool000H0ooooH000000600410@<000000P030`<300d=3@<06ATI0`0H61P201dM7@<09bLW0`0[:b/3
03dm?@80DU9B0`1FEUH305QHF080GUiN0`1RHV8306=SH`<0I6AT0P1WIfL305mOG`<0FEUI0`1CDe<2
051@D0<0Bd];0`13@d<302DU9B/000000`0f=SHd000000<06a/K1@0000080?ooo`001P3ooomP0000
00H00@410`00000200<30`<03@d=0`0I6AT301PH60807AdM0`0W9bL302/[:`<0?Cdm0P1BDU8305IF
EP<0F5QH0P1NGUh3069RHP<0Hf=S0`1TI6@206MWI`<0GemO0`1IFET305=CD`80D51@0`1;Bd/304=3
@`<09BDU:`00000303Hf=S@000000`0K6a/5000000P0oooo00060?ooof<000000`010@4300820P80
1`L70`0>3Ph301/K6`<0820P0P0N7Qh3028R8P<09RHV0`0^;Rh204E5A@<0EUIF0`1MGEd206ATI0<0
IVIV0`1TI6@3065QH@80GEeM0`1KFe/605QHF080DU9B0`1=CDd3038b<P<00`<3JP0000080?ooo`00
1P3ooomS000000<00@410`020P8200L71`<03Ph>0`0K6a/3020P80807QhN0`0R8R8302HV9P<0;Rh^
0P15ADD305IFEP<0GEeM0P1TI6@306IVIP<0I6AT0`1QHF4205eMG@<0Fe]K1P1HF5P2059BDP<0CDe=
0`0b<S8300<30fX00000203oool000H0ooooH`00000300410@<00P820P071`L300h>3P<06a/K0`0P
820201hN7P<08R8R0`0V9RH302h^;P80ADE50`1FEUH305eMG@80I6AT0`1VIVH306ATI0<0HF5Q0P1M
GEd305]KF`H0F5QH0P1BDU8304e=C@<0<S8b0`030`=Z000000P0oooo00060?ooodd000000`010@43
01<C4a0000000`020P8300D51@8030`<0`0?3`l3000000<09BDU0P0V9RH302<S8`<0820P0`0Q8B42
02h^;P<0?clo0`1BDU8205]KF`<0HV9R0`1UIFD305iNGPD0Fe]K0`1JFUX305UIF@80EEEE0`13@d<3
010@46/000000P1gMgL80?ooo`001P3ooom=000000<00@410`0C4a<@000000<00P820`051@D200`<
30<03`l?0`00000302DU9@809RHV0`0S8b<3020P80<08B4Q0P0^;Rh303lo?`<0DU9B0P1KFe/3069R
HP<0IFEU0`1NGUh505]KF`<0FUYJ0`1IFET205EEE@<0@d=30`0@411[00000080MgMg203oool000H0
ooooH000000300410@<00`<30`0:2PX200h>3P<0410@0`0I6AT302TY:@80=SHf0`0o?cl304A4A0<0
@d=30P0n?Sh304I6AP<0EEEE0P1MGEd3061PH0<0HV9R0`1SHf<2061PH0<0GEeM0`1NGUh305]KF`80
EEEE0`0/;2a`000000P0oooo00060?ooof0000000`010@4300<30`<02PX:0P0>3Ph3010@40<06ATI
0`0Y:BT203Hf=P<0?clo0`14A4@304=3@`80?Shn0`16ATH305EEE@80GEeM0`1PH603069RHP<0Hf=S
0P1PH60305eMG@<0GUiN0`1KFe/205EEE@<0;2`/L00000080?ooo`001P3ooomP000000<00@410`03
0`<300X:2P803Ph>0`0@410301TI6@<0:BTY0P0f=SH303lo?`<0A4A40`13@d<203hn?P<0ATI60`1E
EED205eMG@<0H61P0`1RHV8306=SH`80H61P0`1MGEd305iNGP<0Fe]K0P1EEED302`/;7000000203o
ool000H0ooooGP00000500820P<020P80`0<30`200h>3P<04Q8B0`0J6QX302TY:@80?Shn0`1FEUH3
06IVIP/0LG5a0P1bLW83075aL@<0L71`0`1YJFT206=SH`<0HF5Q0`1OGel305eMG@80ADE50`0820Q`
000000P0oooo00060?oooeh000001@020P8300P820<030`<0P0>3Ph3018B4P<06QXJ0`0Y:BT203hn
?P<0EUIF0`1VIVH;075aL@80LW9b0`1aLG43071`L0<0JFUY0P1SHf<3065QH@<0GemO0`1MGEd204E5
A@<020P8L00000080?ooo`001P3ooomN000000D00P820`0820P300`<30803Ph>0`0B4Q8301XJ6P<0
:BTY0P0n?Sh305IFEP<0IVIV2`1aLG42079bLP<0LG5a0`1`L70306UYJ@80Hf=S0`1QHF4305mOG`<0
GEeM0P15ADD300P827000000203oool000H0oooo0`00000306e]KDX000001@010@43000000<00@41
0`020P8200<30`<01PH60`0820P300X:2P803@d=0`0B4Q8301`L70<09bLW0P0g=cL304=3@`<0CTi>
0`1NGUh206YZJP<0Jf][0`1_Kfl2075aL@<0L71`0`1[Jf/3065QH@80GemO0`1NGUh3071`L0<0GEeM
0P0N7Qic000000P0oooo00060?ooo`<000000`1]KFe:000000D00@410`00000300410@<00P820P03
0`<300H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1Z
JVX306][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1`L70305eMG@807QhNL`00
00080?ooo`001P3oool3000000<0KFe]BP00000500410@<000000`010@4300820P800`<30`061PH3
00P820<02PX:0P0=3@d3018B4P<071`L0`0W9bL203Lg=`<0@d=30`1>CTh305iNGP80JVYZ0`1[Jf/3
06m_K`80LG5a0`1`L70306][J`<0HF5Q0P1OGel305iNGP<0L71`0`1MGEd201hN7W<00000203oool0
00H0ooooD000000500410@<000001P030`<500@410<01@D50`0;2`/2014A4@<05ADE0`00000302HV
9P80<C4a0`0k>c/304E5A@<0CTi>0P1EEED305eMG@<0IfMW0P1^KVh3075aL@<0KFe]0`1ZJVX206e]
K@<0Jf][0`1aLG4304E5AGD00000203oool000H0ooooD000000500410@<000001P030`<500@410<0
1@D50`0;2`/2014A4@<05ADE0`00000302HV9P80<C4a0`0k>c/304E5A@<0CTi>0P1EEED305eMG@<0
IfMW0P1^KVh3075aL@<0KFe]0`1ZJVX206e]K@<0Jf][0`1aLG4304E5AGD00000203oool000H0oooo
D000000800410@P00P820`010@4300H61P<030`<0P0A4A4301LG5`<0@D510`0W9bL2034a<@<0?Cdm
0`17AdL304i>CP80FUYJ0`1XJ6P302l_;`80MGEe0`1kNg/307YjNP<0M7Ad0P1cLg<3075aL@<0GUiN
0`0>3Ph203Xj>RL000000`0E5AE9000000P0oooo00060?oooe00000020010@4800820P<00@410`06
1PH300`<30804A4A0`0G5aL30451@@<09bLW0P0a<C4303dm?@<0AdM70`1>CTh205YJFP<0J6QX0`0_
;bl207EeM@<0Ng]k0`1jNWX307AdM080Lg=c0`1aLG4305iNGP<03Ph>0P0j>SXW000000<05ADEB@00
00080?ooo`001P3ooom@000000P00@4120020P8300410@<01PH60`0<30`2014A4@<05aLG0`11@D43
02LW9`80<C4a0`0m?Cd304M7A`<0CTi>0P1JFUX306QXJ0<0;bl_0P1eMGD307]kN`<0NWYj0`1dM7@2
07=cL`<0LG5a0`1NGUh300h>3P80>SXj9`00000301DE5DT00000203oool000H0oooo?`00000302XZ
:Ph000002`010@4300820P800`<30`051@D300X:2P<03Ph>0P0C4a<301`L70<08R8R0`0X:2P2038b
<P<0?clo0`1;Bd/305ADE080HF5Q0`1^KVh307MgM`80O7al0`1mOGd307]kN`<0MGEe0P1]KFd306MW
I`<0;Bd]N00000080?ooo`001P3ooolo000000<0:RXZ3P00000;00410@<00P820P030`<300D51@<0
2PX:0`0>3Ph201<C4`<071`L0`0R8R8302PX:080<S8b0`0o?cl304];B`<0E5AD0P1QHF4306i^KP<0
MgMg0P1lO7`307emO@<0Ng]k0`1eMGD206e]K@<0IfMW0`0];Beh000000P0oooo00060?ooocl00000
0`0Z:RX>000000/00@410`020P8200<30`<01@D50`0:2PX300h>3P804a<C0`0L71`3028R8P<0:2PX
0P0b<S8303lo?`<0Bd];0`1DE5@2065QH@<0KVi^0`1gMgL207alO0<0OGem0`1kNg/307EeM@80KFe]
0`1WIfL302d];GP00000203oool000H0ooooD000000500410@H000000`0410@2000000<02`/;0`0?
3`l301@D50806QXJ0`0Q8B4302LW9`<0;Bd]0P0f=SH304=3@`<0CDe=0`1IFET206MWI`<0LW9b0`1h
N7P207UiN@<0N7Qh0`1fMWH307alO080KVi^0`19BDT300<30`/000000`0E5AEZ000000P0oooo0006
0?oooe0000001@010@46000000<010@40P00000300/;2`<03`l?0`0D51@201XJ6P<08B4Q0`0W9bL3
02d];@80=SHf0`13@d<304e=C@<0FEUI0P1WIfL3079bLP<0N7Qh0P1iNGT307QhN0<0MWIf0`1lO7`2
06i^KP<0BDU90`030`<;000000<05ADEJP0000080?ooo`001P3oool>000000<0=CDe5P000003034a
<Ah000000P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MW
I`807QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207Ad
M0H0MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3oool>000000<0=CDe5P000003034a<Ah0
00000P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MWI`80
7QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0
MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3oool>000000<0=CDe5P000003034a<Ah00000
0P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MWI`807QhN
0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0MgMg
0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`03
0`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:
BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N000
00080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@4103
01DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/3
07IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooom50000
00<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q
8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`
L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooolo000000H00@411@020P8300<30`<0
0P820`010@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0
<S8b0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0
Cdm?0P0>3Phj000000<04A4A@@0000080?ooo`001P3ooolo000000H00@411@020P8300<30`<00P82
0`010@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b
0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?
0P0>3Phj000000<04A4A@@0000080?ooo`001P3ooolo000000H00@411@020P8300<30`<00P820`01
0@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b0`0e
=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?0P0>
3Phj000000<04A4A@@0000080?ooo`001P3oool>000000<08B4Q<@00000300410@P01@D51P030`<2
00H61P<020P80`0;2`/3014A4@8051@D0`0G5aL301dM7@<0820P0P0S8b<302`/;0<0<C4a0`0l?3`2
04E5A@<0De=C0`1PH60306ATI080IVIV0`1ZJVX306UYJ@80IfMW0`1LG5`305IFEP<0:2PX20000003
07moObH000000`1_Kfm<000000P0oooo00060?ooo`h000000`0Q8B4a000000<00@4120051@D600<3
0`801PH60`0820P300/;2`<04A4A0P0D51@301LG5`<07AdM0`0P820202<S8`<0;2`/0`0a<C4303`l
?080ADE50`1CDe<3061PH0<0I6AT0P1VIVH306YZJP<0JFUY0P1WIfL305aLG0<0EUIF0`0X:2P80000
00<0Ogmo9P00000306m_Kd`00000203oool000H0oooo?`00000300410@<000000`051@D202/[:`<0
1@D50`061PH300T92@80;2`/0`0<30`6010@40804a<C0`0F5QH301dM7@<08R8R0P0T92@302TY:@<0
<30`0`0k>c/204Q8B0<0De=C0`1KFe/306=SH`80GUiN0`1TI6@3065QH@80GUiN0`1EEED30451@@<0
1`L7P00000080?ooo`001P3ooolo000000<00@410`00000300D51@80:b/[0`051@D300H61P<02@T9
0P0/;2`300`<30H0410@0P0C4a<301HF5P<07AdM0`0R8R8202@T90<0:BTY0`0`<30303/k>`80B4Q8
0`1CDe<305]KF`<0Hf=S0P1NGUh306ATI0<0HF5Q0P1NGUh305EEE@<0@D510`071`N0000000P0oooo
00060?ooocl000000`010@43000000<01@D50P0[:b/300D51@<01PH60`092@T202`/;0<030`<1P0@
410201<C4`<05QHF0`0M7Ad3028R8P8092@T0`0Y:BT3030`<0<0>c/k0P18B4P305=CD`<0Fe]K0`1S
Hf<205iNGP<0I6AT0`1QHF4205iNGP<0EEEE0`11@D4300L71h000000203oool000H0oooo2@000002
02XZ:S@000000`030`<300D51@<01PH60P092@T900X:2PD03Ph>0`0@4103014A4@804Q8B0`0G5aL3
01`L70<07QhN0P0R8R8302PX:0<0<C4a0`0n?Sh204Q8B0<0EUIF0`1IFET505aLG0<0FUYJ0`1IFET2
05=CD`<0B4Q80`0H61R3000000P0oooo00060?ooo`T000000P0Z:RXd000000<00`<30`051@D300H6
1P802@T92@0:2PX500h>3P<0410@0`0A4A42018B4P<05aLG0`0L71`301hN7P808R8R0`0X:2P3034a
<@<0?Shn0P18B4P305IFEP<0FEUI1@1LG5`305YJFP<0FEUI0P1CDe<304Q8B0<061PHP`0000080?oo
o`001P3oool900000080:RXZ=000000300<30`<01@D50`061PH200T92@T02PX:1@0>3Ph3010@40<0
4A4A0P0B4Q8301LG5`<071`L0`0N7Qh2028R8P<0:2PX0`0a<C4303hn?P80B4Q80`1FEUH305UIF@D0
G5aL0`1JFUX305UIF@80De=C0`18B4P301PH68<00000203oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]],

Cell["As you can see the image has become speckled with noise.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Question 6:  How did introducing the noise change the size of the reduced \
SVD?  Specifically,\
\>", "Subsubsection"],

Cell["\<\
Compare the following answers with those for the original.  Do these numbers \
ring a bell?\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Clear[Ur,UrT,VrT]
{UrT, sings, VrT} = SingularValues[handErr];
Length[sings]\
\>", "Input"],

Cell[BoxData[
    \(TraditionalForm\`85\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[Flatten[{UrT, sings, VrT}]]", "Input"],

Cell[BoxData[
    \(TraditionalForm\`15810\)], "Output"]
}, Open  ]],

Cell["\<\
Ans:  Noise changed reduced SVD up to maximum possible: 85 nonzero singular \
values for 15810 entries (the answers to questions 3 and 4).  This is up from \
67 nonzero singular values for the original image.  (Actually, this number is \
also controlled by a Tolerance option in SingularValues (see Help) that sets \
very small values to zero.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Maybe compressing to the important singular values will remove the spots.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
numToKeep = 15;
bigSings = Take[sings,numToKeep];
UaT = Take[UrT,numToKeep];
VaT = Take[VrT,numToKeep];
newHand = Transpose[UaT].DiagonalMatrix[bigSings].VaT;
showImage[handErr];  (* noisy image on top *)
showImage[newHand];  (* filtered on bottom *)
Length[Flatten[{UaT,bigSings,VaT}]]\
\>", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000000001010001030202080B151A
1D1E20232522201D195D10000C16151D232B2B001B100801
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000102550E18
1F1F2125282A2726211B140D0B0F171E2941515853381706
2A0000000000000000000000000000000000000000000000
000000330000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000100010710
1B1F22292D302F2D292319100C0F0D1726353231373B2A15
070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000005800
00000000
0000000000000000000000000000000000002C0000010105
0E1A212933333434332B211C1C1A151C1E181115171B151C
1F1608040404030100000000000000000000000000000000
000000000000000000000000000000007500000000000000
47000000
000000000000000000000000000000000000000000000001
030017253235363A35312C2C2F2A242C1F0F0A0D00120C0F
15191A181C21232216110A05010100000000000000000000
0000000000000000000C000000000000005E000000000000
00000000
000000000000000000000000000000000000000000000000
0001041329333539383534373500293E29190C091314151F
1A0A0E04070E171B171A191715130C070D081B0000010000
3F0000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000E242E3638393C3C342929443B290B081E1B163E
270E0876050002050209171500191A221C190F0701000000
000000000000000000000000000000000000000000000000
00000000
000000000000005D00000000000000000000003300000000
00000000000A213135393D3B32252F564C260D0351A12E3F
340B0F0604011B261B0406050406080D0E001C1B0C030100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000081E2D353A8E32262D4F491F15081A748246
1C07070B0115364A4F1E020001010507070B161D180C0502
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071D2E9937342C2B323A180D131F365247
040000001A3F382D252F22130A0405040B0A0E1114150D03
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000006A061B30343730322D2440526C8C9C8A74
53100B144D6B38392A2C001F1D0E03040A09070B13211401
00000000005F00000C000000000000000000000000000000
00000000
000000000000000000000000000043000000000000000000
000000000000001D00051D303431302E1F3FABD0D5CDB791
36010B4654565D6064554C3F260D09050503050D141D1001
0101000000000000000000000000000000004D0000000000
004C0000
000000000000000000000000000000000000000000190000
00000000000000000000051D32352F2A231858B0BEA57829
00063D606369605C5D584E4D50452B130301070E11130901
000001010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000031D33322C221B0E0B0C080100
00236369645A03504845414E595157001903050013110801
010101010000000000000000000000000000000000000000
00000000
0000000000000000000000000000004F0000000000000000
00000000000000000000000004213231231D120601000002
133A57564F453E3C362F333D41433D2E261D091121110601
000301010101000000000000000000002A00000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000720302B1F180C05010415
243947443F3B87373F55C78B8684775D3F26101C210A0303
000004010101000000000000000006000000000000000000
00000000
000000000000000000000000000000000000002C00000000
000000000000000000000000000006222F261B0D0907161D
1D2B3B403C3C414D6091BDCBFFBEAEAE9F6B1A1A12060605
080502010101000000000000000000000000000000000000
00000000
000000000000000D00000000000000000000000000000000
00000000000000000000510000000007282C0C0609111615
1A273039404B00CC7E7884ABB8E6DECEC5A53A1912140909
100B00010101017800001500000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000510060A0800050E111013
1D29333D4B5B72908D63374288C1DADCD0C153241F170D15
1D0900010101010000000000000000000000000600000000
00000000
000000000000000000000000000000000000005900000000
00000000000000000000000003212D100202050B0F0F1017
2333414A60718B939FAB763113366F98A8A66D563F26171E
180100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000051A181F190905090F0F101222
004560798699894A205EC0AD7A3A161F5B9599939C733617
070100000101000100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000040
00000000000000000000001432180F0E0A0A111214732944
576D7F97A1A3947E52171F52A2C39C80ACACBFFFCBC78623
030503030302340000010100000000000000000000000000
00000013
00005A000000000000000000000000000000000000000000
00000000000000010005282B1C24660014131C223152667B
8C91A2A2AA9FAFB4B3976335296FB6D1C9BBB4B4A6A4650E
060505060704010000030300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B301D0902020D141E324F7189949B
A2A5AF9FA7B0A18A8DA7AAB1873500518CB7BAAC956B0A05
0404070806000100000A0900000000000000003800000000
00000000
000000000000000000000000000000003C00000000000000
000000000001000311217532302C180E2D365787A1A6A6AA
ACB3BBB0AA8E38142A6685A0B5957F976BADBCA78F591E1F
0C0F0D0A0704070409170600000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000031722232F393E3D2F1C386084A3A59B9899
A6BAB8B6A3707133081F62C0DDE1E79AB7FFB39274443A47
3227240F060512210F080000000000000000000000000006
00000000
000000000000000000000000000000000000000000000000
0000000000012737391A192221202A2B3C517F868D8A8C93
A3B2BDC5B0799372645089889CCDDBDACCAA8C6559394555
434E533A1E1A262F05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000011322E2A2613000714192D37454A445D5E5560
82ABC0C3BD87797B98989BA0AFB6C1D2C0973D2D3D2B3C62
3D6B8575533B3A1300010000000000000000000000000000
00000000
000000000000000000000000006000000000000000000000
00000000002031251F2C2818100D1A2B3322110A245B8290
858FB9B8B0947DA9C1A497D878B5CFD0BA52091224182867
6660A4B2884B1B0000000000000000120000000001000000
00000000
000000000000000000000000000000000000000000000000
0000000005322D2927222D2C160A0029391C161419316E7D
A19C99449583A1DEC9B4939BA6C7CCD192221814100B1200
7F646CA0882A010001010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000044E6C5722002A34332B15224F4C2E27497B5973
7D7470746E669BC4A9B2BCBFC6C8CCD3723432331B080628
6572503D2002000202000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000493AD431C1C171418241F2D669D7E5D657A6E51
4E363A1B3461A4ADA0B1C2CCC5FFB5C97D5956543D120210
3E6466461E09000404020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000009DFE313730210C090B1D3C76ABCCB79F816846
261B0F0904B7B6839CACA3ABB8BCBABE7F746D423F1E0402
204A625643210001060903000000000000000000006C0000
00000000
000000000000000000003100000000000000000000000000
000000002CD4825C662A192B512B1E3F78A8C6DDCABEA15B
2C130C1C7BD3BE83847C7888999B9BB5847C8C6022150A02
072A5655462D0F00040E0800000000000000610000000000
00000000
000000000047000000000000000000000000000000000000
000000000D48C0955B568293846D3C446895BBD7E2E5DED5
C1997EA1CED9B66D4B42608A97A9A6A9927C92924F200E08
06214F685A41220300131907000000000000000000000000
0E000000
000000000000000000000000000000000000000000000000
00000000004F9E2A197AA16528263737517BA7C2D6DDEDF1
EFE9DFD7CBC8B553213D4F83979DA3B5AD8491947143230F
051A47713C5A370E00183319010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
49000000002D6395934E1A41845B30863A71989FBACCDADB
DDE2E7D8CDD0D08626254F6E7A826F667C828D92855F4012
030F0067886E451802269525020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004C656B9BACABA678766E5F535B85A8B6C7D1DA
E0E5EBEBECE6DFCB81414F7A6C6B5A4A5569878D37674E26
060625537F7F531E052C492A040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000063CF8E7EC7CB69222F47B4473F588AB7C3FFD0
E1ECF3F1ECE7E2E4E4BE95949A97979B71475B8D866F5836
170611386C83622803214F2B060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000016EC9A6704E566E64523D3C2022354866A7C3CB
CDD2E9EBE6E0DEDEE0E5D5BCBEFFB8AA7A274A7B7E785C40
2610082660896833092D61320A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000006BAFB88E5289D4C0B3A7AA80667081706F94C7
D2C8D0D8D9DAD2D6D2D6F5B7BABDB4A06B3D5B8687486C44
2C17072759806B40174C6A3C1E01000A0000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000087B6AC9795CDCBBDE2EFD3C7BEA0786A84879D
D7D9D1D0C8D1CEC3BFBBB5A8A9A89670503342828C8E8659
00200B336A837542266E6246250000000000000000000000
00000000
000000000000000000000000000000000000000000001E00
000000000066C4B9B4B38F6568609ACDCABDAEA39B8CAA77
B9C6A9A19A9FA3A8A8969EA69C7C5D3512022A71868A855E
2F1A104782837B374479673E090000000000000064000000
00000000
000000000000000000000000000000000000000000000000
000000000029C2BED32D73B3EFD79DCDB4C3E0EBEDCFBEAC
919080715A535B6E266C635D4F4B435E69521F657C818869
361D134D937C602E66683706000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000005A7C8B8C9F1F8EFEAEEE7EAF6EFEBEBD2B3A7
979BB0B4B58D81685C412A25171017325F510E547F81826C
4E2C1C629874413A76470700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000066DAC3BAD4D8CEADC8D4DDD05FC4ACB6A28E
7E6C7D6F99B4C84C80989E8DB0633F34342F2D4777817D6F
22352B8995DD3B5C4E0D0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00005900000020D1D1CCD5DBE4E5EDEBDDE0AA5D3C53686E
67668DA49EC5B469445D6B748FA9B59C813C566B7A807D74
512D4F9A875F463E080001000000000000000000000D0000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E3CFD1DADAE6E9DADEB128060A091C58
7583D9BCC4AEB8D38E555D54779FAE9C624D6F7F8483846A
482A6192734D250200010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000012BFE0CFD1D6CDDDE9DC6326271F160B28
6CC6B5C9C8AA81D7BF967E7C59534E5E435E7882858A8364
3E31727C5C29000001010000000000180000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000002FC0E7D9DBDEDAD5BB82817A8F3E2B14
47AED6A4C7C97E7C90BD9F9C915D7D7E3A6B7B838E8B7E60
44386F673F06000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000001A4DEFE0DDE3DCB6A6C1DCDF866B4A
2C94D896A4D2CCBFACB1C1AAB2BDBE503E697989928F7A60
3F445E521A00000000000000000000000000000000000000
00000067
000000000000000000000000000000000000000000000000
000000000000000000000777BC9BE4D9ABA4CBECE2C49486
027CC7C4958F9FBEC898A5A4AB7D454648687D898F88775C
3D3E4D300200000000000009000000000000000000000000
00000000
004B0000000000000000000000000000000000000000006E
0000000000000000000000004BB1E8E89E81A8E6C9A7898A
3D55A9C2C2C0C6ABB496937E4E213A56525D7C918E7E6F55
2F2A38110001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000003DA99C736E989A817071
464A8DAFA5A4C8BFA987370F1636454A5F6983918B796747
212130050001000000000000000000000000000000000000
00000000
000F00000000000000000000000000000000000000000000
000070000000000000000000000000075F6C749598806955
43375F77808D8A743E0E0B191F3A4E4E5571888F16715A32
182C1E000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000386863676A605042
362A53626153361505101F271E3B4B565E728B8B7F724C2E
262C0500000000000000000000007D000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000038736B6B67574432
2F291B120B0C1413121A2E3129364F597B8F827978694834
2B0900010000000000430000000000000000000000000000
00000000
000000280000000000001000000000000000000000000000
000000000000000000000000000000002D897C2C6E5E482F
2B30120A10141B161D2635303BBF415F828C7C7C7B3F4E34
0C0000000000000000000000000000000000000000000000
00000000
000000550000000000000000000000000000000000000000
00000000000000000000000000000100128A766D6565D73A
352C121119161721233635314D5658697E7772826F605016
00000000000000000E000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000038196877A776951
492D121B1D1F19292B3C384700687480766C796958482100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000106899FF88817267
512D1B1E1C1A282600404355737B78786C6A5B4A49240000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000589092867A7567
47001F231F232E304F4C58D2727A79797253494017000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001D58878E88796B5D
4028282527372B4A595A6A787375797D6649310800000000
000000000000000000000000000000002100000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000001015159839186756556
40322F2B36314661606A757E79757D734B1C000000000000
000000000000000000000000000000000006000000000000
00000000
0000006A0000000000000041000000000000000000140000
2900000000000000000000000001040302467B897B6A5F4F
4036323A39475A3F68797F83807C6D460E00000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000480000000000000000000000000000000000
0000000000000000000000000002030200206F840B625D52
463C42484D695E6771798182756142140001000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001010102083C7E7B6A655D
4A4600575E63566D757A735D4B0000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000001500000000010101400304081645626E6E67
59085A5C5E65696C695C511D413409000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000007200000000000000000000
0000000000710000000000010101010A0D0A1B233C53605F
605F5D606265646057504D42391700000000004400000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010100030D19181D272B3D5256
585E626364675F5953504B43250000000000000000000000
000000000036000000000000000000000000000000000000
001B0000
000000000000000000000000000000000000000000000000
0000000000000000000000000102070E1B201E22262E4556
5D646664615D5B5858524D32030000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000011300000000000002050C0F0025262320212E3F
525B62655E5B5B5A59554310000000000000000000000000
000000000000000000000000000000000000000000000000
00000077
000000000000000000000000000000000000000000000000
000000000000000000000001030A0E101929363F44433E46
555D606263605D5E5B552C00000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000202080C0E121A293E5666717171
717271706963615F5D450800000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
006D00000000000000000000000000000000000000000000
000000000001010001020306080A0D121C2737434E5E6A6B
6F71706B615F5E705D1E0000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010003030404050B11150026313B454E555D
676E716D6A6D6B7145000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010102020201060C11174127313D474E5A68
2F757B7A7473715E0E3A0000000000000000000000000000
150000000000000000000000000000000000000000000000
00000000
00000000000000000000000000000000000000000000002A
0000000000010101010203050A0E131C2228323F4B54616E
777C7D7B756D672D00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000101000004000B0F141A21272D36434D596772
787978767C6E490300000000150000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000035000000000000000031000000000000000000
00000100010A0202040A0C1116671E232B313A45525C6776
777477776D5B1A0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020102020203070C1015191D21272E343E4A5A636B76
736F70685E37010100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020203020102560A0C10161D1F242E3235404E5C686D6F
6E6B695E4F0E000000000000000000000000000000000000
000000110000000000000000000000000000000000000000
00000000
000000000021000000000000000000000000000000000000
01050505030306080B1114171D20232C313C45536064666A
69675C56280000007F00000000000000000000000000006F
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
00052B0506092C0C101013161D222429303B48535B635E64
615E55410700000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
0000002A0000000000000000000000000000000000000003
0506090A0A0A0E0E101112171C1E2228313E4856595C5C5A
595348180000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooolT000000H00@410P00000300410@<00`<31@020P8300P820<0
2`/;0P0E5AD301XJ6P<07AdM0`0N7Qh2020P80<08b<S0`0U9BD3028R8P80820P0`0M7Ad301TI6@<0
GEeM0P0@4103000000<030`<0`0F5QH201DE5@<07AdM0`0S8b<502/[:`<000000`0K6a/3010@4080
20P80`010@6>000000P0oooo00060?ooob@000001P010@42000000<00@410`030`<500820P<020P8
0`0;2`/201DE5@<06QXJ0`0M7Ad301hN7P80820P0`0S8b<302DU9@<08R8R0P0P820301dM7@<06ATI
0`1MGEd2010@40<000000`0<30`301HF5P805ADE0`0M7Ad302<S8`D0:b/[0`00000301/K6`<0410@
0P0820P300410Hh00000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O
7al2024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?
3`l201LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`00
000303<c<d400000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O7al2
024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l2
01LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`000003
03<c<d400000203oool000H0oooo=@00000200410@<00P820`1EEED200h>3P<061PH1P0O7al2024Q
8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l201LG
5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P305=CD`<0>3Ph0P0G5aL300H61P<0:RXZA`00000303<c
<d400000203oool000H0oooo=@00000200410@<000000`010@4200L71`<0410@0`0K6a/301lO7`80
8R8R0`0Y:BT302d];@<0<30`0P0_;bl302d];@<0:BTY0`0S8b<201TI6@<0410@0`0<30`300l?3`80
3@d=0`0G5aL302HV9P<0=CDe0P0b<S83034a<@<0=cLg0`0k>c/202XZ:P<05ADE0`071`Mk000000<0
F5QH3@0000080?ooo`001P3ooole000000800@410`00000300410@801`L70`0@410301/K6`<07alO
0P0R8R8302TY:@<0;Bd]0`0`<30202l_;`<0;Bd]0`0Y:BT302<S8`806ATI0`0@410300`<30<03`l?
0P0=3@d301LG5`<09RHV0`0e=CD2038b<P<0<C4a0`0g=cL303/k>`80:RXZ0`0E5AD300L71g/00000
0`1HF5P=000000P0oooo00060?ooocD000000P010@43000000<00@410P071`L3010@40<06a/K0`0O
7al2028R8P<0:BTY0`0];Bd3030`<080;bl_0`0];Bd302TY:@<08b<S0P0I6AT3010@40<030`<0`0?
3`l200d=3@<05aLG0`0V9RH303De=@80<S8b0`0a<C4303Lg=`<0>c/k0P0Z:RX301DE5@<01`L7N`00
000305QHF0d00000203oool000H0oooo<P00000302`/;0D000001@010@4300D51@<03Ph>0`0J6QX2
024Q8@<0:BTY1P0c<c<503@d=0<0<c<c0`0[:b/2024Q8@H071`L0`0J6QX201DE5@<071`L0`0N7Qh3
01PH60804A4A0`0E5AD301LG5`<06a/K0P0E5AD301`L70<07alO0P0F5QH300P820P010@40`030`<3
00410EP000000P1eMGDD00000080AdM7200000080?ooo`001P3ooolb000000<0;2`/1@0000050041
0@<01@D50`0>3Ph301XJ6P808B4Q0`0Y:BT603<c<`D0=3@d0`0c<c<302/[:`808B4Q1P0L71`301XJ
6P805ADE0`0L71`301hN7P<061PH0P0A4A4301DE5@<05aLG0`0K6a/201DE5@<071`L0`0O7al201HF
5P<020P8200410@300<30`<00@41F000000207EeMA@000000P17AdL8000000P0oooo00060?ooocl0
00000`010@4300<30`<000000P0G5aL302DU9@<0<S8b0`0e=CD203Hf=P<0>SXj0`0e=CD3034a<@D0
;2`/0`0_;bl302XZ:P8092@T0`0/;2`301lO7`<03`l?0P0:2PX300d=3@<000000`0B4Q8200`<30<0
3`l?0`0E5AD201TI6@<06QXJ0`0H61P301`L70808B4Q0`0S8b<3028R8P<05QHF0P0A4A4300X:2P<0
1@D51@010@4d000000<030`<4`00000305iNGQ/00000203oool000H0oooo?`00000300410@<00`<3
0`00000201LG5`<09BDU0`0b<S8303De=@80=SHf0`0j>SX303De=@<0<C4a1@0/;2`302l_;`<0:RXZ
0P0T92@302`/;0<07alO0`0?3`l200X:2P<03@d=0`000003018B4P8030`<0`0?3`l301DE5@806ATI
0`0J6QX301PH60<071`L0P0Q8B4302<S8`<08R8R0`0F5QH2014A4@<02PX:0`051@D500410C@00000
0`0<30`C000000<0GUiN6`0000080?ooo`001P3ooolo000000<00@410`030`<3000000805aLG0`0U
9BD3038b<P<0=CDe0P0f=SH303Xj>P<0=CDe0`0a<C4502`/;0<0;bl_0`0Z:RX202@T90<0;2`/0`0O
7al300l?3`802PX:0`0=3@d3000000<04Q8B0P0<30`300l?3`<05ADE0P0I6AT301XJ6P<061PH0`0L
71`2024Q8@<08b<S0`0R8R8301HF5P804A4A0`0:2PX300D51@D00@41=000000300`<31<000000`1N
GUhK000000P0oooo00060?ooodD000000`010@4200@410<04a<C0`0Y:BT303<c<`80=CDe0`0i>CT3
03Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0?Shn0`0Y:BT301TI6@8030`<0`092@T3
01<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<010@40`071`L200h>3P<05aLG0`0K6a/3
01LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<01`L70`0=3@d200P820<06a/K1P000002
00410@H000000`0o?cm9000000P0oooo00060?ooodD000000`010@4200@410<04a<C0`0Y:BT303<c
<`80=CDe0`0i>CT303Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0?Shn0`0Y:BT301TI
6@8030`<0`092@T301<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<010@40`071`L200h>
3P<05aLG0`0K6a/301LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<01`L70`0=3@d200P8
20<06a/K1P00000200410@H000000`0o?cm9000000P0oooo00060?ooodD000000`010@4200@410<0
4a<C0`0Y:BT303<c<`80=CDe0`0i>CT303Ph>0<0=CDe0P0d=3@303Lg=`<0=CDe0`00000202TY:@<0
?Shn0`0Y:BT301TI6@8030`<0`092@T301<C4`<051@D0P0E5AD301lO7`<06QXJ0P0:2PX300h>3P<0
10@40`071`L200h>3P<05aLG0`0K6a/301LG5`806QXJ0`0I6AT301LG5`<05ADE0P0C4a<300`<30<0
1`L70`0=3@d200P820<06a/K1P00000200410@H000000`0o?cm9000000P0oooo00060?ooodd00000
0`0>3Ph302@T9080;Rh^0`0f=SH303Ph>0<0>CTi1@0l?3`303@d=0D0:BTY0`14A4@303/k>`<0:BTY
0P0;2`/300P820<07QhN0`0K6a/201HF5P<0?Shn0`0W9bL200h>3P<020P80`1fMWH300D51@800000
0`020P8300D51@<00P820P092@T301LG5`<05ADE0`00000201TI6@<06QXJ0`0R8R8301`L70806ATI
0`0?3`l300L71`<00@41E00000080?ooo`001P3ooom=000000<03Ph>0`0T92@202h^;P<0=SHf0`0h
>3P303Ti>@D0?3`l0`0d=3@502TY:@<0A4A40`0k>c/302TY:@802`/;0`0820P301hN7P<06a/K0P0F
5QH303hn?P<09bLW0P0>3Ph300P820<0MWIf0`051@D2000000<00P820`051@D300820P802@T90`0G
5aL301DE5@<000000P0I6AT301XJ6P<08R8R0`0L71`201TI6@<03`l?0`071`L300410E@00000203o
ool000H0ooooC@00000300h>3P<092@T0P0^;Rh303Hf=P<0>3Ph0`0i>CT503`l?0<0=3@d1@0Y:BT3
04A4A0<0>c/k0`0Y:BT200/;2`<020P80`0N7Qh301/K6`805QHF0`0n?Sh302LW9`803Ph>0`0820P3
07IfMP<01@D50P00000300820P<01@D50`020P8200T92@<05aLG0`0E5AD3000000806ATI0`0J6QX3
028R8P<071`L0P0I6AT300l?3`<01`L70`010@5D000000P0oooo00060?oooa@000000P1MGEdO0000
0080<c<c6@00000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0<S8b0`0U9BD202l_
;`<0EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0=3@d0P0;2`/300l?
3`<01PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<010@40P061PH300P8
20<03@d=0`0>3Ph2000000<071`L0`0K6a/300`<30800`<30`010@5?000000P0oooo00060?oooa@0
00000P1MGEdO00000080<c<c6@00000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0
<S8b0`0U9BD202l_;`<0EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0
=3@d0P0;2`/300l?3`<01PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<0
10@40P061PH300P820<03@d=0`0>3Ph2000000<071`L0`0K6a/300`<30800`<30`010@5?000000P0
oooo00060?oooe<000000P0820P301hN7P<0;Bd]0`0e=CD203Xj>P<0SXj>0`0b<S8302HV9P80;Bd]
0`1?Cdl304U9B@<07alO0P0E5AD300P820<06QXJ0`1dM7@208:2PP<0ATI60`0L71`500L71`<02`/;
0`010@4201DE5@<0=SHf0`1:BTX304m?C`807QhN0`020P83000000D00@410`051@D600L71`802`/;
0`0F5QH301dM7@<061PH0P0<30`300D51@<00P82C00000080?ooo`001P3ooomC0000008020P80`0N
7Qh302d];@<0=CDe0P0j>SX308j>SP<0<S8b0`0V9RH202d];@<0Cdm?0`19BDT301lO7`805ADE0`08
20P301XJ6P<0M7Ad0P22PX8304I6AP<071`L1@071`L300/;2`<00@410P0E5AD303Hf=P<0BTY:0`1?
Cdl201hN7P<00P820`00000500410@<01@D51P071`L200/;2`<05QHF0`0M7Ad301PH608030`<0`05
1@D300820T`00000203oool000H0ooooD`00000200P820<07QhN0`0];Bd303De=@80>SXj0`2>SXh3
038b<P<09RHV0P0];Bd304m?C`<0BDU90`0O7al201DE5@<020P80`0J6QX307AdM080PX:20`16ATH3
01`L70D01`L70`0;2`/300410@805ADE0`0f=SH304Y:BP<0Cdm?0P0N7Qh300820P<000001@010@43
00D51@H01`L70P0;2`/301HF5P<07AdM0`0H61P200`<30<01@D50`020P9<000000P0oooo00060?oo
oeD000000`071`L301dM7@<0;Rh^0P2IVIT303Lg=`<0=3@d0`0/;2`202/[:`<0<S8b0`0j>SX301PH
60803@d=0`0C4a<301lO7`<0=SHf0P1BDU8304M7A`<010@42000000301XJ6P80?clo0`0h>3P302d]
;@<09BDU0P0_;bl3028R8P<04a<C0`0:2PX200@410<01@D50`0410@300/;2`802PX:0`0>3Ph3014A
4@<051@D0P0E5AD300d=3@<00`<3C00000080?ooo`001P3ooomE000000<01`L70`0M7Ad302h^;P80
VIVI0`0g=cL303@d=0<0;2`/0P0[:b/3038b<P<0>SXj0`0H61P200d=3@<04a<C0`0O7al303Hf=P80
DU9B0`17AdL300@410P000000`0J6QX203lo?`<0>3Ph0`0];Bd302DU9@80;bl_0`0R8R8301<C4`<0
2PX:0P0410@300D51@<010@40`0;2`/200X:2P<03Ph>0`0A4A4301@D50805ADE0`0=3@d300<30d`0
0000203oool000H0ooooE@00000300L71`<07AdM0`0^;Rh209VIV@<0=cLg0`0d=3@302`/;080:b/[
0`0b<S8303Xj>P<061PH0P0=3@d301<C4`<07alO0`0f=SH2059BDP<0AdM70`0410@8000000<06QXJ
0P0o?cl303Ph>0<0;Bd]0`0U9BD202l_;`<08R8R0`0C4a<300X:2P8010@40`051@D300@410<02`/;
0P0:2PX300h>3P<04A4A0`0D51@201DE5@<03@d=0`030`=<000000P0oooo00060?oooeD000000`1Z
JVX300H61P<06a/K0P0`<30303@d=0<0=cLg0`0`<302038b<P<0;Bd]0`0T92@30410@080DU9B0`1/
K6`308b<S0<0W9bL0P2:RXX307AdM0<0De=C0P0@410300/;2`<051@D0`1=CDd206][J`<0>3Ph0`0i
>CT302XZ:P80;2`/0`00000301lO7`<07AdM0P0>3Ph300<30`<010@40`0:2PX200T92@<01`L70`0;
2`/301<C4`808B4Q0`0D51@300410@d000000`1OGel60000008030`<=00000080?ooo`001P3ooomE
000000<0JVYZ0`061PH301/K6`80<30`0`0d=3@303Lg=`<0<30`0P0b<S8302d];@<092@T0`10@402
059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1dM7@305=CD`80410@0`0;2`/301@D50<0CDe=0P1[Jf/3
03Ph>0<0>CTi0`0Z:RX202`/;0<000000`0O7al301dM7@803Ph>0`030`<300@410<02PX:0P092@T3
00L71`<02`/;0`0C4a<2024Q8@<051@D0`010@4=000000<0GemO1P00000200`<33@00000203oool0
00H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D50P0M7Ad3030`<0<0=3@d0`0a<C42030`
<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0=SHf0P010@4300/;
2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE0`1<C4`303lo?`<09RHV0P0=3@d300T9
2@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@20010@4/000000<0CDe=4000000304a<
C0D00000203oool000H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D50P0M7Ad3030`<0<0
=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0
=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE0`1<C4`303lo?`<0
9RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@20010@4/000000<0
CDe=4000000304a<C0D00000203oool000H0oooo9`00000304=3@b/000000`0M7Ad3000000<01@D5
0P0M7Ad3030`<0<0=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[0`3@d=030=GEe@<0cLg=
0P2g]kL3096AT@<0=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM0`1PH60306ATI080EEEE
0`1<C4`303lo?`<09RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=0`0D51@201dM7@<0410@
20010@4/000000<0CDe=4000000304a<C0D00000203oool000H0oooo>P00000301TI6B4000000P05
1@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn_P<0YJFU0P1h
N7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>
CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A4@804a<C0`09
2@T300410@D000001P010@51000000P0oooo00060?ooocX000000`0I6ATQ000000801@D50`0M7Ad3
038b<P<0=CDe0P0_;bl302XZ:P<08b<S0`0H61P205QHF0<0/;2`0`2n_[h30:FUY@80N7Qh0`0Y:BT3
000000801PH60`0m?Cd3061PH0<0Hf=S0P1YJFT3061PH0<0G5aL0`1MGEd205QHF0<0CTi>0`1=CDd3
051@D080ADE50`0[:b/301<C4`<00`<30P010@4300L71`<03Ph>0`0A4A4201<C4`<02@T90`010@45
000000H00@41@@0000080?ooo`001P3ooolj000000<06ATI8@00000200D51@<07AdM0`0b<S8303De
=@80;bl_0`0Z:RX302<S8`<061PH0P1HF5P30;2`/0<0_[jn0`2UYJD207QhN0<0:BTY0`00000200H6
1P<0?Cdm0`1PH60306=SH`80JFUY0`1PH60305aLG0<0GEeM0P1HF5P304i>CP<0CDe=0`1@D50204E5
A@<0:b/[0`0C4a<300<30`800@410`071`L300h>3P<04A4A0P0C4a<300T92@<00@411@0000060041
0D400000203oool000H0ooooH000000300<30`<07AdM0`0c<c<2038b<P<0;2`/0`0R8R8301/K6`80
3Ph>0`0;2`/300`<30<020P80P010@46000000808b<S0`1SHf<306UYJ@<0I6AT0P1JFUX300<30`<0
D51@0`18B4P204E5A@<0@D510`1>CTh305UIF@80DE5A0`1GEeL3000000<06ATI0P030`<300D51@<0
00000`0C4a<2014A4@<020P83P010@51000000P0oooo00060?ooof0000000`030`<301dM7@<0<c<c
0P0b<S8302`/;0<08R8R0`0K6a/200h>3P<02`/;0`0<30`300P820800@411P00000202<S8`<0Hf=S
0`1YJFT306ATI080FUYJ0`030`<3051@D0<0B4Q80P15ADD30451@@<0CTi>0`1IFET2055AD@<0EeMG
0`00000301TI6@800`<30`051@D3000000<04a<C0P0A4A4300P820h00@41@@0000080?ooo`001P3o
oomP000000<00`<30`0M7Ad303<c<`80<S8b0`0/;2`3028R8P<06a/K0P0>3Ph300/;2`<030`<0`08
20P200410@H000000P0S8b<306=SH`<0JFUY0`1TI6@205YJFP<00`<30`1@D50304Q8B080ADE50`11
@D4304i>CP<0FEUI0P1ADE4305MGE`<000000`0I6AT200<30`<01@D50`00000301<C4`804A4A0`08
20P>00410D400000203oool000H0oooo:P00000204m?CcL000000`0410@3024Q8@80<S8b0`0a<C43
02<S8`<07AdM0P0B4Q8300H61P<00@411@00000300820P<04a<C0P0j>SX305MGE`<0EUIF0`1?Cdl2
04E5A@<0?Shn0`0l?3`303Hf=P80;bl_0`0c<c<303dm?@<0@D510P13@d<303dm?@<0;Rh^0`0V9RH2
01dM7@<02@T90`0A4A43024Q8@804A4A0`061PH300410@<000000P030`<;00410A`000000P0Z:RXN
000000P0oooo00060?ooobX000000P1?Cdlg000000<010@40`0Q8B42038b<P<0<C4a0`0S8b<301dM
7@804Q8B0`061PH300410@D000000`020P8301<C4`80>SXj0`1GEeL305IFEP<0Cdm?0P15ADD303hn
?P<0?3`l0`0f=SH202l_;`<0<c<c0`0m?Cd30451@@80@d=30`0m?Cd302h^;P<09RHV0P0M7Ad300T9
2@<04A4A0`0Q8B42014A4@<01PH60`010@43000000800`<32`010@4L00000080:RXZ7P0000080?oo
o`001P3ooomV000000<01`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@80
10@40`0E5AD302@T9080>CTi0`17AdL304A4A0<0?clo0P0k>c/308N7Q`<0=cLg0`0o?cl205EEE@<0
alO70`2;Rh/308J6QP80Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH0
0`<31@00000300@410P00@415P00000300H61R<00000203oool000H0ooooIP00000300L71`80820P
0`0`<30302/[:`<07alO0P0H61P300`<30<01@D50`010@4200@410<05ADE0`0T92@203Ti>@<0AdM7
0`14A4@303lo?`80>c/k0`27QhL303Lg=`<0?clo0P1EEED30<O7a`<0Rh^;0`26QXH208B4Q0<0MgMg
0`1MGEd303lo?`809RHV0`0@410301`L70<08B4Q0P0:2PX600<30`D000000`0410@800410AH00000
0`061PHS000000P0oooo00060?ooofH000000`071`L2020P80<0<30`0`0[:b/301lO7`8061PH0`0<
30`300D51@<00@410P0410@301DE5@<092@T0P0i>CT304M7A`<0A4A40`0o?cl203/k>`<0QhN70`0g
=cL303lo?`80EEEE0`37alL308^;R`<0QXJ60P24Q8@307MgM`<0GEeM0`0o?cl202HV9P<0410@0`0L
71`3024Q8@802PX:1P030`<5000000<010@420010@4F000000<01PH68`0000080?ooo`001P3ooole
00000080;2`/<P00000200H61P<08R8R0`0_;bl302HV9P806a/K0`0=3@d300T92@<01`L70P0F5QH6
01dM7@80:b/[0`0k>c/30410@0D0?3`l0`11@D4304e=C@<0H61P0P2ATI430;fm_@<0bl_;0`3oool2
0;jn_PH0[Zj^0`2OWil206][J`H06QXJ0`0B4Q8500H61P<01@D50`0820P200D51@<00P8220010@4l
000000P0oooo00060?ooocD000000P0/;2`b000000801PH60`0R8R8302l_;`<09RHV0P0K6a/300d=
3@<02@T90`071`L201HF5PH07AdM0P0[:b/303/k>`<0@4101@0l?3`30451@@<0CDe=0`1PH602096A
T@<0_Kfm0`3;bl/30?ooo`80_[jn1P2^[Zh309nOW`80Jf][1P0J6QX3018B4PD01PH60`051@D300P8
20801@D50`020P8800410C`00000203oool000H0oooo=@00000202`/;38000000P061PH3028R8P<0
;bl_0`0V9RH201/K6`<03@d=0`092@T300L71`805QHF1P0M7Ad202/[:`<0>c/k0`10@40503`l?0<0
@D510`1=CDd3061PH080TI6A0`2m_Kd30<_;b`<0oooo0P2n_[h60:j^[P<0WinO0P1[Jf/601XJ6P<0
4Q8B1@061PH300D51@<020P80P051@D300820PP00@41?00000080?ooo`001P3ooolD000000803@d=
B0000002055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE
0`0J6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[
0`2h^;P20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@
0P0;2`/3000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooolD000000803@d=B000
0002055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE0`0J
6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[0`2h
^;P20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@0P0;
2`/3000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooolD000000803@d=B0000002
055AD@/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A4201HF5P<05ADE0`0J6QX2
02LW9`<0<30`0`0i>CT30410@080Bd];0`0000030<c<c0<0OWin0P1hN7P308B4Q0<0Zj^[0`2h^;P2
0>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@600T92@<0410@0P0;2`/3
000000/00@410`1hN7P5000000<05ADE;P0000080?ooo`001P3ooomV000000<01@D50P0@410300H6
1P<02PX:0`0820P2000000<01@D50`0>3Ph3014A4@80410@0`0C4a<301dM7@80:BTY0`0c<c<303dm
?@<0Bd];0P1KFe/3079bLP<0T92@0`2=SHd206=SH`<0=cLg0`12@T8308R8R080`L710`3Jf]X30=cL
g0<0d=3@0P31`L4305=CD`<092@T0`0O7al201LG5`<03@d=0`0E5AD301dM7@802@T90`00000;0041
0B4000000`061PHE000000P0oooo00060?ooofH000000`051@D2010@40<01PH60`0:2PX300P82080
00000`051@D300h>3P<04A4A0P0@410301<C4`<07AdM0P0Y:BT303<c<`<0?Cdm0`1;Bd/205]KF`<0
LW9b0`2@T90308f=S@80Hf=S0`0g=cL30492@P<0R8R80P31`L430=[JfP<0g=cL0`3@d=020<71`@<0
De=C0`0T92@301lO7`805aLG0`0=3@d301DE5@<07AdM0P092@T3000000/00@418@00000300H61QD0
0000203oool000H0oooo=@00000205UIFB`000000`030`<3024Q8@80;Bd]0`0@410600820P801@D5
0`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C
0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF
0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@411P00000;00410CH00000203oool000H0oooo=@00
000205UIFB`000000`030`<3024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G
5aL302<S8`80<c<c0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a
<C4301<C4`80=SHf0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N
7Qh301PH60800@411P00000;00410CH00000203oool000H0oooo=@00000205UIFB`000000`030`<3
024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c0`11@D43
04Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf0`1_Kfl3
09RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@411P00000;
00410CH00000203oool000H0ooooH000000300D51@<06QXJ0`0H61P201lO7`<06ATI0`092@T300D5
1@802@T91P0?3`l3010@40804Q8B0`0R8R8300000080ADE50`1PH60307UiN@<0QXJ60P2IVIT308V9
R@<0BTY:0`0P820205iNGP<0`<300`2][Jd307YjNP80>SXj0`0F5QH301lO7`<0Fe]K0P2EUID309VI
V@<0Ti>C0`2LW9`207=cL`<0=SHf0`0G5aL300L71`800@411P00000500410@<000000`010@4f0000
00P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H0
3`l?0`0@4102018B4P<08R8R0`00000204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0
820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0
W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000001@010@43000000<00@41=P0000080?ooo`00
1P3ooomP000000<01@D50`0J6QX301PH60807alO0`0I6AT300T92@<01@D50P092@T600l?3`<0410@
0P0B4Q83028R8P<000000P15ADD3061PH0<0NGUi0`26QXH209VIV@<0RHV90`1:BTX3020P8080GUiN
0`30`<030:f][@<0NWYj0P0j>SX301HF5P<07alO0`1KFe/209FEU@<0VIVI0`2CTi<309bLW080Lg=c
0`0f=SH301LG5`<01`L70P010@46000000D00@410`00000300410CH00000203oool000H0oooo?`00
00030410@1h000000`0D51@3038b<P<061PH0P0?3`l300h>3PH02PX:0P0A4A43018B4P<051@D0`1c
Lg<202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2GUiL30:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G
5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20P8050:b/[0<0_kno0`3oool30<_;b`80alO70`26
QXH302<S8`<00`<30P051@D800<30`<00P820`0d=3@5000000H00@41;000000201<C4`P0oooo0006
0?ooocl000000`10@40N000000<051@D0`0b<S8301PH60803`l?0`0>3Ph600X:2P804A4A0`0B4Q83
01@D50<0Lg=c0P0Y:BT304A4A0<0EeMG0P1]KFd307moO`<0UiNG0`2QXJ420:>SX`<0U9BD0`1nOWh3
059BDP805aLG0`0O7al3059BDP<0XZ:R0P33`l<309bLW0<0P8201@2/[:`30;no_`<0oooo0`3;bl/2
0<O7a`<0QXJ60`0S8b<300<30`801@D520030`<300820P<0=3@d1@00000600410B`000000P0C4a<8
0?ooo`001P3oool6000000<0FUYJC000000300410@<000000`051@D202PX:0<0:b/[0`0L71`302@T
9080IVIV0`00000301@D50<04a<C0P0L71`3028R8P<0<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096A
T@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf
]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0IFEU0`0>3Ph300H61PD01@D50`061PH200L7
1`<010@40`010@45000000H00`<3;P0000080?ooo`001P3oool6000000<0FUYJC000000300410@<0
00000`051@D202PX:0<0:b/[0`0L71`302@T9080IVIV0`00000301@D50<04a<C0P0L71`3028R8P<0
<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80
UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0
IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@40`010@45000000H00`<3;P0000080?ooo`00
1P3oool6000000<0FUYJC000000300410@<000000`051@D202PX:0<0:b/[0`0L71`302@T9080IVIV
0`00000301@D50<04a<C0P0L71`3028R8P<0<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R
0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A
0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@4
0`010@45000000H00`<3;P0000080?ooo`001P3ooomH000000<01PH60`0K6a/2030`<0<07AdM0`09
2@T500820P<03@d=0`0D51@301hN7P80<S8b0`1?Cdl3075aL@<0RHV90P2DU9@309^KV`<0XZ:R0P2U
YJD30:n_[`<0WinO0`2WYjL20;2`/0<0XJ6Q0`2:RXX308f=S@80YjNW0`2ZZZX30;6a/@<0QhN70P0e
=CD3000000<0DE5A0`2<S8`20;Ng]`<0^[Zj0`2/[:`309FEU@80Jf][0`0:2PX300D51@D010@40`07
1`L300P820801PH60`00000300410@D000000`0:2PX300T92AH000000`0h>3PE000000P0oooo0006
0?oooeP000000`061PH301/K6`80<30`0`0M7Ad300T92@D00P820`0=3@d301@D50<07QhN0P0b<S83
04m?C`<0LG5a0`29RHT209BDU0<0Vi^K0`2RXZ820:FUY@<0[jn_0`2OWil30:NWY`80/;2`0`2QXJ43
08Z:RP<0SHf=0P2WYjL30:ZZZP<0/K6a0`27QhL203De=@<000000`1ADE4308b<S080]kNg0`2j^[X3
0:b/[0<0UIFE0P1[Jf/300X:2P<01@D51@0410@300L71`<020P80P061PH3000000<00@411@000003
00X:2P<02@T95P00000303Ph>1D00000203oool000H0ooooF000000300H61P<06a/K0P0`<30301dM
7@<02@T91@020P8300d=3@<051@D0`0N7Qh2038b<P<0Cdm?0`1aLG4308V9R@80U9BD0`2KVi/30::R
XP80YJFU0`2_[jl309nOW`<0YjNW0P2`/;030:6QX@<0RXZ:0`2=SHd20:NWY`<0ZZZZ0`2a/K4308N7
Q`80=CDe0`000003055AD@<0S8b<0P2g]kL30;Zj^P<0[:b/0`2EUID206][J`<02PX:0`051@D500@4
10<01`L70`0820P200H61P<000000`010@45000000<02PX:0`092@TF000000<0>3Ph5@0000080?oo
o`001P3oool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0
<30`0`0/;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080
/k>c0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80
UIFE0`1oOgl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<3080
3`l?0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`00
1P3oool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0<30`
0`0/;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c
0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE
0`1oOgl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?
0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3o
ool/000000<0?3`l8@00000300410@8000000`030`<3014A4@<08B4Q0P1eMGD3038b<P<0<30`0`0/
;2`201PH60<03Ph>0`0];Bd303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c0`2k
^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE0`1o
Ogl309NGU`<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?0`0=
3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3ooomC
000000800`<30`0G5aL3028R8P<08b<S0P0_;bl303Ti>@<0?Shn0`0m?Cd202l_;`<071`L0`0h>3P3
061PH080Q8B40`2SXj<30:FUY@<0Vi^K0P2HV9P309VIV@<0YZJV0P2j^[X30;Rh^0<0][Jf0`2SXj<2
071`L0<0LG5a0`0c<c<300P820807alO0`1RHV830<30`0<0gMgM0P3QhN430>OWi`<0VYZJ0`2g]kL2
0?ooo`<0/k>c0`2BTY8307AdM080A4A40`0j>SX304M7A`<0<S8b0P0W9bL302@T90<03`l?0P061PH3
00D51@<04Q8B0`0Q8B4200l?3`<020P89000000300H61PX00000203oool000H0ooooD`00000200<3
0`<05aLG0`0R8R8302<S8`80;bl_0`0i>CT303hn?P<0?Cdm0P0_;bl301`L70<0>3Ph0`1PH60208B4
Q0<0Xj>S0`2UYJD309^KV`80V9RH0`2IVIT30:JVYP80^[Zj0`2h^;P30;Jf]P<0Xj>S0P1`L703075a
L@<0<c<c0`0820P201lO7`<0HV9R0`30`<030=gMg@80hN7Q0`3WinL309ZJVP<0]kNg0P3oool30;>c
/`<0TY:B0`1dM7@204A4A0<0>SXj0`17AdL3038b<P809bLW0`0T92@300l?3`801PH60`051@D3018B
4P<08B4Q0P0?3`l300P822@000000`061PH:000000P0oooo00060?oooe0000000`010@4202LW9`<0
=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0
QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0
LW9b0`1TI6@2051@D0<0RHV90`28R8P309bLW080cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0
IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0
;bl_0P051@Dd000000P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI
0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<
0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@2051@D0<0RHV9
0`28R8P309bLW080cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE5
0`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo
00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z
:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m
_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@2051@D0<0RHV90`28R8P309bLW080cLg=0`3K
fm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1C
De<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe0000000`0A4A42
038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`00000300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD2
04Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL3
07UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd3
02d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX3
01<C4`8000000`010@4a000000P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV
9P804a<C0`00000300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iN
GP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^K
V`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l
?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a0000
00P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`00000300L71`<0
51@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80
Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0
`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0
QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?ooob@00000
0`1PH60Y000000<0820P0P0a<C4302DU9@<07alO0`0/;2`202PX:0<061PH0`0@410300d=3@806QXJ
0`0[:b/303<c<`<08R8R0P0A4A4300X:2P<092@T0`1KFe/208:2PP<0T92@0`25QHD208n?S`<0^KVi
0`2h^;P30;2`/080U9BD0`1mOGd30:VYZ@<0`L710P2TY:@309NGU`<0f=SH0`1hN7P20;Fe]@<0clo?
0`3@d=030;Zj^P80DU9B0`092@T3018B4P<092@T0P0H61P302PX:0<0IfMW0`1VIVH2061PH0<0Y:BT
0`2b/[8208R8R0<0Bd];0`0K6a/F000000<04Q8B2`00000200410A<00000203oool000H0oooo9000
0003061PH2T000000`0P8202034a<@<09BDU0`0O7al302`/;080:2PX0`0H61P3010@40<03@d=0P0J
6QX302/[:`<0<c<c0`0R8R82014A4@<02PX:0`0T92@305]KF`80PX:20`2@T90308F5Q@80Shn?0`2i
^KT30;Rh^0<0/;2`0P2DU9@307emO@<0ZJVY0`31`L420:BTY0<0UiNG0`3Hf=P307QhN080]KFe0`3?
cll30=3@d0<0^[Zj0P1BDU8300T92@<04Q8B0`0T92@201PH60<0:2PX0`1WIfL306IVIP80H61P0`2T
Y:@30;:b/P80R8R80`1;Bd/301/K6aH000000`0B4Q8;000000800@414`0000080?ooo`001P3ooom=
000000<01@D50`0b<S8202d];@<0:BTY0`0W9bL3028R8P80;Bd]0`0/;2`301HF5P<02PX:0P000003
02TY:@<0>CTi0`0L71`201HF5P<051@D0`0I6AT3034a<@80KVi^0`1mOGd30:6QX@80W9bL0`2IVIT3
04A4A0<0UIFE0P23Ph<30:6QX@<0g]kN0`39bLT20;Bd]0<0Ti>C0`2KVi/30:JVYP80alO70`3<c<`3
0=7Ad@<0TY:B0P0R8R8301PH60<051@D0`0@410200/;2`<04Q8B0`00000307moO`80I6AT0`1/K6`3
0:2PX080R8R80`0Z:RX300410@<000001@010@4a000000P0oooo00060?ooodd000000`051@D3038b
<P80;Bd]0`0Y:BT302LW9`<08R8R0P0];Bd302`/;0<05QHF0`0:2PX2000000<0:BTY0`0i>CT301`L
70805QHF0`0D51@301TI6@<0<C4a0P1^KVh307emO@<0XJ6Q0P2LW9`309VIV@<0A4A40`2EUID208>3
P`<0XJ6Q0`3Ng]h30<W9b@80];Bd0`2CTi<309^KV`<0YZJV0P37alL30<c<c0<0dM7A0`2BTY82028R
8P<061PH0`0D51@3010@40802`/;0`0B4Q83000000<0Ogmo0P1TI6@306a/K0<0X:2P0P28R8P302XZ
:P<00@410`00000500410C400000203oool000H0ooooC@00000300D51@<0<S8b0P0];Bd302TY:@<0
9bLW0`0R8R8202d];@<0;2`/0`0F5QH300X:2P8000000`0Y:BT303Ti>@<071`L0P0F5QH301@D50<0
6ATI0`0a<C4206i^KP<0OGem0`2QXJ4209bLW0<0VIVI0`14A4@309FEU@80Ph>30`2QXJ430=kNgP<0
bLW90P2d];@309>CT`<0Vi^K0`2VYZH20<O7a`<0c<c<0`3AdM4309:BTP808R8R0`0H61P301@D50<0
410@0P0;2`/3018B4P<000000`1oOgl206ATI0<0K6a/0`2PX:0208R8R0<0:RXZ0`010@43000000D0
0@41<@0000080?ooo`001P3ooom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8300000080:RXZ
0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT307]kN`80FEUI
0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl
0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH6
0`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3o
oom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8300000080:RXZ0`0d=3@303<c<`<0:b/[0P0E
5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT307]kN`80FEUI0`1cLg<307emO@80M7Ad0`1`
L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<
c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@
D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3ooom=000000<010@40`1>CTh2
06a/K0<0EeMG0`0R8R8300000080:RXZ0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`2
02h^;P<09bLW0`19BDT307]kN`80FEUI0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH3
09^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3
038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83
000000D00P82=00000080?ooo`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG
5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^
KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0K6a/303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2
`P<0c<c<0`35aLD20?ooo`<0]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q830082
0P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?oo
o`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T9080
7alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0
>SXj0`0K6a/303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20?ooo`<0
]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0
IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<010@4
0`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM
0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0K6a/303@d=080HF5Q
0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20?ooo`<0]KFe0`39bLT307emO@80FEUI
0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T9
0`00000500@410<00P82<@0000080?ooo`001P3ooom@000000<0WIfM0P3no_h3034a<@<0=cLg0`0`
<302024Q8@<030`<0`092@T300/;2`807AdM0`0l?3`307IfMP<0Zj^[0P3<c<`30;Ng]`<0WinO0`21
PH4206QXJ0<0ATI60`0V9RH201/K6`<03`l?0`092@T300@41080]kNg0`2f][H308>3P`<0W9bL0P2/
[:`30:>SX`<0Zj^[0`2h^;P20;bl_0<0^[Zj0`2n_[h307moO`80M7Ad0`1]KFd30492@P<0?clo0P0N
7Qh300@410<00P820`0P820204Y:BP<0HV9R0`1FEUH204=3@`<08B4Q0`00000300410@801PH60`09
2@T300<30a/000000`1/K6`@000000P0oooo00060?oooe0000000`2MWId20?knoP<0<C4a0`0g=cL3
030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2OWil3
0861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<010@40P2g]kL30;Jf]P<0Ph>30`2LW9`2
0:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o?cl2
01hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B43000000<00@410P061PH3
00T92@<00`<36`00000306a/K1000000203oool000H0oooo70000003034a<Bh000000`0/;2`30=CD
e080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A0`0[:b/201hN7P<0?clo0`1hN7P30:RX
Z080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/0P0C4a<300`<30<071`L0`1kNg/20=?C
d`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<
S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ0`1FEUH305EEE@80ATI60`0];Bd300l?
3`<000000P0410@300h>3P<020P84`000003065QHAP00000203oool000H0oooo70000003034a<Bh0
00000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A0`0[:b/201hN7P<0
?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/0P0C4a<300`<30<0
71`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI1@2KVi/30;Fe]@<0
Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ0`1FEUH305EEE@80
ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P84`000003065QHAP00000203oool000H0oooo
70000003034a<Bh000000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0DE5A
0`0[:b/201hN7P<0?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/
0P0C4a<300`<30<071`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI
1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ
0`1FEUH305EEE@80ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P84`000003065QHAP00000
203oool000H0oooo3P00000304M7Ac`000000`0=3@d304Q8B080`<300`2EUID305]KF`<0EUIF0P22
PX8309>CT`<0Q8B40`1]KFd203`l?0<0A4A40`1XJ6P309FEU@80^k^k0`3GemL30>;RhP<0iNGU0P3N
g]h30=GEe@<0`L710P2IVIT307inOP<0XJ6Q0`3>c/h20=WIf@<0][Jf0`1]KFd304];B`80@T920`1P
H60308Z:RP<0UiNG0P2YZJT30:JVYP<0ZJVY0`2BTY8207alO0H0TY:B0`1?Cdl2020P80<03Ph>0`08
20P300H61P808B4Q0`1?Cdl306QXJ080FUYJ0`11@D43028R8P<00`<30P00000301<C4`<06ATI0`07
1`LQ000000803Ph>200000080?ooo`001P3oool>000000<0AdM7?000000300d=3@<0B4Q80P30`<03
09FEU@<0Fe]K0`1FEUH208:2PP<0Ti>C0`24Q8@306e]K@80?3`l0`14A4@306QXJ0<0UIFE0P2k^k/3
0=OGe`<0h^;R0`3UiND20=kNgP<0eMGE0`31`L4209VIV@<0OWin0`2QXJ430<k>cP80fMWI0`2f][H3
06e]K@<0Bd];0P12@T83061PH0<0RXZ:0`2GUiL20:VYZ@<0YZJV0`2YZJT309:BTP80O7al1P2BTY83
04m?C`80820P0`0>3Ph300P820<01PH60P0Q8B4304m?C`<0J6QX0P1JFUX30451@@<08R8R0`030`<2
000000<04a<C0`0I6AT300L71b4000000P0>3Ph8000000P0oooo00060?ooo`h000000`17AdLl0000
00<03@d=0`18B4P20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`304A4
A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh30:6Q
X@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH30:VY
Z@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P205YJ
FP<0@D510`0R8R8300<30`8000000`0C4a<301TI6@<01`L78@00000200h>3PP00000203oool000H0
ooooD000000304m?C`80WYjN0`0Z:RX301TI6@<0NWYj0P2QXJ4306EUI@<0:2PX0`0V9RH503Lg=`<0
DE5A0`1kNg/20:NWY`<0`/;20`3Fe]H30=gMg@80kNg]0`3alO430>o_k`80jNWY0`3Ogml30=OGe`<0
bl_;0P38b<P30;Fe]@<0De=C0`0Q8B4203dm?@<0Cdm?0`23Ph<309NGU`80WIfM0`2SXj<30;Fe]@<0
[Jf]0P24Q8@3096AT@<0U9BD0`1aLG4204=3@`<08b<S0`0?3`l300D51@806QXJ0`17AdL3075aL@80
?3`l0`1JFUX303Lg=`<03Ph>0P00000301PH60<0<c<c0`0I6AT200410BT00000203oool000H0oooo
D000000304m?C`80WYjN0`0Z:RX301TI6@<0NWYj0P2QXJ4306EUI@<0:2PX0`0V9RH503Lg=`<0DE5A
0`1kNg/20:NWY`<0`/;20`3Fe]H30=gMg@80kNg]0`3alO430>o_k`80jNWY0`3Ogml30=OGe`<0bl_;
0P38b<P30;Fe]@<0De=C0`0Q8B4203dm?@<0Cdm?0`23Ph<309NGU`80WIfM0`2SXj<30;Fe]@<0[Jf]
0P24Q8@3096AT@<0U9BD0`1aLG4204=3@`<08b<S0`0?3`l300D51@806QXJ0`17AdL3075aL@80?3`l
0`1JFUX303Lg=`<03Ph>0P00000301PH60<0<c<c0`0I6AT200410BT00000203oool000H0oooo@P00
000304U9B@/000000`0];Bd206=SH`<0UIFE0`2CTi<304i>CP806QXJ0`11@D4308B4Q0<0Fe]K0P0`
<30308J6QP<0>SXj0`1aLG4209RHV0<0WinO0`2j^[X30<c<c080f][J0`3Kfm/30=gMg@80h^;R0`3W
inL30=SHf0<0cLg=1@3@d=0308J6QP<09RHV0P0U9BD304m?C`<0KVi^0`1jNWX208:2PP<0Kfm_0`1V
IVH307alO080PX:20`2=SHd309:BTP<0QHF50P1OGel30410@0<04Q8B0`030`<200l?3`<000000`1W
IfL208R8R0<0KVi^0`15ADD301PH60800P820`0V9RH309FEU@<09BDU0P020P8Y000000P0oooo0006
0?oood8000000`19BDT;000000<0;Bd]0P1SHf<309FEU@<0Ti>C0`1>CTh201XJ6P<0@D510`24Q8@3
05]KF`80<30`0`26QXH303Xj>P<0LG5a0P2HV9P309nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd2
0>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH302HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX83
06m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY8308F5Q@80GemO0`10@403018B4P<00`<30P0?3`l3
000000<0IfMW0P28R8P306i^KP<0ADE50`0H61P200820P<09RHV0`2EUID302DU9@800P82:@000008
0?ooo`001P3ooom2000000<0BDU92`00000302d];@80Hf=S0`2EUID309>CT`<0CTi>0P0J6QX30451
@@<0Q8B40`1KFe/2030`<0<0QXJ60`0j>SX3075aL@80V9RH0`2OWil30;Zj^P<0c<c<0P3Jf]X30=_K
f`<0gMgM0P3Rh^830>OWi`<0f=SH0`3=cLd50=3@d0<0QXJ60`0V9RH202DU9@<0Cdm?0`1^KVh307Yj
NP80PX:20`1_Kfl306IVIP<0O7al0P22PX8308f=S@<0TY:B0`25QHD205mOG`<0@4100`0B4Q8300<3
0`803`l?0`00000306MWI`80R8R80`1^KVh304E5A@<061PH0P020P8302HV9P<0UIFE0`0U9BD20082
0RT00000203oool000H0ooooD000000304a<C080IFEU0`1[Jf/309^KV`<0[:b/0P2[Zj/30:JVYP<0
N7Qh0`1fMWH206i^KP<0GemO0`1CDe<305]KF`80QHF50`2XZ:P30;Jf]P<0alO70P3AdM430=[JfP<0
h>3P0P3UiND60>_[j`<0k>c/0P3Vi^H30=oOg`<0bl_;0`21PH420451@@<0Cdm?0`1jNWX306a/K080
Jf][0`1JFUX304Y:BP<0EEEE0P1YJFT308N7Q`<0SHf=0`0g=cL206MWI`<0CTi>0`0V9RH500H61P<0
9BDU0`1CDe<507moO`<0De=C0`0N7Qh200D51@<0;2`/0`19BDT302XZ:P8010@4:@0000080?ooo`00
1P3ooom@000000<0C4a<0P1UIFD306][J`<0Vi^K0`2/[:`20:^[Z`<0YZJV0`1hN7P307IfMP80KVi^
0`1OGel305=CD`<0Fe]K0P25QHD30:RXZ0<0][Jf0`37alL20=7Ad@<0f][J0`3Ph>020>GUi@H0jn_[
0`3/k>`20>KViP<0gmoO0`3;bl/30861P@80@D510`1?Cdl307YjNP<0K6a/0P1[Jf/305YJFP<0BTY:
0`1EEED206UYJ@<0QhN70`2=SHd303Lg=`80IfMW0`1>CTh302HV9PD01PH60`0U9BD305=CD`D0Ogmo
0`1CDe<301hN7P801@D50`0/;2`304U9B@<0:RXZ0P0410@Y000000P0oooo00060?oooe0000000`1<
C4`206EUI@<0Jf][0`2KVi/30:b/[080Zj^[0`2VYZH307QhN0<0MWIf0P1^KVh305mOG`<0De=C0`1K
Fe/208F5Q@<0Z:RX0`2f][H30<O7a`80dM7A0`3Jf]X30>3Ph080iNGU1P3[jn/30>c/k080i^KV0`3O
gml30<_;b`<0PH610P11@D4304m?C`<0NWYj0`1/K6`206][J`<0FUYJ0`1:BTX305EEE@80JFUY0`27
QhL308f=S@<0=cLg0P1WIfL304i>CP<09RHV1@061PH302DU9@<0De=C1@1oOgl305=CD`<07QhN0P05
1@D302`/;0<0BDU90`0Z:RX200@412T00000203oool000H0ooooD000000306=SH`80clo?0`2>SXh3
07inOP<0alO70P3;bl/306UYJ@<08R8R0`0_;bl204M7A`<0];Bd0`17AdL303lo?`80F5QH0`2:RXX3
0;Ng]`<0`l?30P3oool30=3@d0<0hN7Q0P3/k>`30??cl`<0lO7a0`3/k>`20>OWi`<0h^;R1P3Ti>@2
0;jn_P<0UIFE0`2DU9@309ZJVPD0UiNG0`2KVi/3075aL@80AdM70`1KFe/308f=S@<0QXJ60P1_Kfl3
05QHF0<0=SHf0`0G5aL200H61P<04A4A0`0h>3P206a/K0<0Ph>30`1RHV8302PX:0800`<30`0Q8B43
04m?C`<0:b/[0P061PHY000000P0oooo00060?oooe0000000`1SHf<20<o?c`<0SXj>0`1nOWh30<O7
a`80bl_;0`1YJFT3028R8P<0;bl_0P17AdL30;Bd]0<0AdM70`0o?cl205QHF0<0RXZ:0`2g]kL30<?3
``80oooo0`3@d=030>7Qh@80k>c/0`3clo<30?7al@<0k>c/0P3WinL30>;RhPH0i>CT0P2n_[h309FE
U@<0U9BD0`2JVYX509NGU`<0Vi^K0`1aLG4204M7A`<0Fe]K0`2=SHd308J6QP80Kfm_0`1HF5P303Hf
=P<05aLG0P061PH3014A4@<0>3Ph0P1/K6`308>3P`<0HV9R0`0X:2P200<30`<08B4Q0`1?Cdl302/[
:`801PH6:@0000080?ooo`001P3ooom@000000<0Hf=S0P3?cll308j>SP<0OWin0`37alL20<_;b`<0
JFUY0`0R8R8302l_;`80AdM70`2d];@304M7A`<0?clo0P1HF5P308Z:RP<0]kNg0`33`l<20?ooo`<0
d=3@0`3QhN420>c/k0<0lo?c0`3alO430>c/k080inOW0`3Rh^860>CTi080_[jn0`2EUID309BDU0<0
VYZJ1@2GUiL309^KV`<0LG5a0P17AdL305]KF`<0SHf=0`26QXH206m_K`<0F5QH0`0f=SH301LG5`80
1PH60`0A4A4303Ph>080K6a/0`23Ph<3069RHP<0:2PX0P030`<3024Q8@<0Cdm?0`0[:b/200H61RT0
0000203oool000H0ooooC@00000300410@<0KVi^0P39bLT30:JVYP<0L71`0`1>CTh205IFEP<0KVi^
0`1TI6@3059BDP80?Cdm0`0l?3`3020P80<08R8R0P0e=CD304Q8B0<0IVIV0`2WYjL20<?3``<0bl_;
0`3=cLd20=;BdP<0jNWY0`3[jn/30>KViP80h>3P1P3Ng]h30>3Ph080iNGU0`3EeMD30;bl_0<0_[jn
0P3oool30;Rh^0<0ZZZZ0`1jNWX202LW9`<0BTY:0`1kNg/307inOP80N7Qh0`1LG5`30410@0<09RHV
0P0@410300P820<09RHV0P1PH60308V9R@<0J6QX0`0c<c<200T92@<0;Bd]0`1QHF43038b<P802PX:
:@0000080?ooo`001P3ooom=000000<00@410`1^KVh20<W9b@<0YZJV0`1`L70304i>CP80EUIF0`1^
KVh306ATI0<0DU9B0P0m?Cd303`l?0<0820P0`0R8R8203De=@<0B4Q80`1VIVH30:NWY`80`l?30`3;
bl/30<g=c@80d];B0`3YjNT30>_[j`<0i^KV0P3Ph>060=kNgP<0h>3P0P3UiND30=GEe@<0_;bl0`2n
_[h20?ooo`<0^;Rh0`2ZZZX307YjNP809bLW0`1:BTX307]kN`<0OWin0P1hN7P305aLG0<0@4100`0V
9RH2010@40<020P80`0V9RH2061PH0<0RHV90`1XJ6P303<c<`802@T90`0];Bd3065QH@<0<S8b0P0:
2PXY000000P0oooo00060?oooe0000000`1[Jf/20:n_[`<0^;Rh0`2>SXh3059BDP80RHV90`3De=@3
0<30`0<0/k>c0P2WYjL30:ZZZP<0P8200`1VIVH2071`L0<0PH610`1`L70306m_K`80U9BD0`37alL3
0=;BdP80b<S80`3@d=030=SHf0<0fMWI0P3Jf]X30=;BdP<0e]KF0`3Bd]820=KFeP<0mOGe0`2g]kL3
0;Zj^P80_Kfm0`2d];@30:2PX0<0Jf][0P0m?Cd305]KF`<0QXJ60`27QhL204Q8B0<0K6a/0`14A4@3
02`/;0805aLG0`071`L302LW9`80FEUI0`20P80306][J`<0@4100P0G5aL304a<C0<0JVYZ0`0l?3`2
01hN7P<00@410`00000300X:2R000000203oool000H0ooooD000000306][J`80[jn_0`2h^;P308j>
SP<0DU9B0P29RHT30=CDe0<0`<300`2c/k<20:NWY`<0ZZZZ0`20P80306IVIP80L71`0`21PH43071`
L0<0Kfm_0P2DU9@30<O7a`<0d];B0P38b<P30=3@d0<0f=SH0`3IfMT20=[JfP<0d];B0`3Fe]H30=;B
dP80e]KF0`3emOD30;Ng]`<0^[Zj0P2m_Kd30;Bd]0<0X:2P0`1[Jf/203dm?@<0Fe]K0`26QXH308N7
Q`80B4Q80`1/K6`304A4A0<0;2`/0P0G5aL300L71`<09bLW0P1IFET30820P0<0Jf][0`10@40201LG
5`<0C4a<0`1ZJVX303`l?0807QhN0`010@43000000<02PX:800000080?ooo`001P3ooom@000000<0
Jf][0P2_[jl30;Rh^0<0SXj>0`1BDU8208V9R@<0e=CD0`30`<030;>c/`80YjNW0`2ZZZX30820P0<0
IVIV0P1`L7030861P@<0L71`0`1_Kfl209BDU0<0alO70`3Bd]820<S8b0<0d=3@0`3Hf=P30=WIf@80
f][J0`3Bd]830=KFeP<0d];B0P3Fe]H30?Gem@<0]kNg0`2j^[X20;fm_@<0];Bd0`2PX:0306][J`80
?Cdm0`1KFe/308J6QP<0QhN70P18B4P306a/K0<0A4A40`0/;2`201LG5`<01`L70`0W9bL205UIF@<0
P8200`1[Jf/30410@0805aLG0`1<C4`306YZJP<0?3`l0P0N7Qh300410@<000000`0:2PXP000000P0
oooo00060?oooe0000000`27QhL20;Jf]P<0[:b/0`2GUiL309FEU@80cLg=0`3;bl/30;fm_@<0h^;R
0P3_knl30=?Cd`<0alO70`2n_[h20:2PX0<0N7Qh0`1ZJVX308B4Q080QhN70`2MWId30=OGe`80fMWI
0`3AdM430=3@d0<0b<S80P3AdM430<k>cP<0`l?30`2o_kl20;^k^`<0]KFe0`2XZ:P30:VYZ@80Z:RX
0`2FUYH3071`L0<0D51@0P0c<c<30492@P<0PX:20`2<S8`208j>SP<0QXJ60`1IFET300000080820P
0`0;2`/303<c<`80JVYZ0`23Ph<307EeM@<0@T920P0V9RH306i^KP<0HV9R0`16ATH202DU9BT00000
203oool000H0ooooD000000308N7Q`80][Jf0`2/[:`309NGU`<0UIFE0P3=cLd30<_;b`<0_Kfm0`3R
h^820>o_k`<0dm?C0`37alL30;jn_P80X:2P0`1hN7P306YZJP<0Q8B40P27QhL309fMW@<0emOG0P3I
fMT30=7Ad@<0d=3@0`38b<P20=7Ad@<0c/k>0`33`l<30;no_`80^k^k0`2e]KD30:RXZ0<0ZJVY0P2X
Z:P309JFUP<0L71`0`1@D50203<c<`<0@T920`22PX8308b<S080SXj>0`26QXH305UIF@<000000P0P
820300/;2`<0<c<c0P1ZJVX308>3P`<0MGEe0`12@T8202HV9P<0KVi^0`1RHV8304I6AP809BDU:@00
00080?ooo`001P3ooom@000000<0QhN70P2f][H30:b/[0<0UiNG0`2EUID20<g=c@<0bl_;0`2m_Kd3
0>;RhP80kno_0`3Cdm<30<O7a`<0_[jn0P2PX:0307QhN0<0JVYZ0`24Q8@208N7Q`<0WIfM0`3GemL2
0=WIf@<0dM7A0`3@d=030<S8b080dM7A0`3>c/h30<?3``<0_kno0P2k^k/30;Fe]@<0Z:RX0`2YZJT2
0:RXZ0<0UYJF0`1`L703051@D080<c<c0`12@T8308:2PP<0S8b<0P2>SXh308J6QP<0FEUI0`000002
020P80<02`/;0`0c<c<206YZJP<0Ph>30`1eMGD30492@P809RHV0`1^KVh3069RHP<0ATI60P0U9BDY
000000P0oooo00060?ooocd000000P0N7QhA000000<0IVIV0P34a<@30;Vi^@<0];Bd0`2c/k<208n?
S`<0IFEU0`1XJ6P3061PH080VYZJ0`3=cLd30<[:bP<0_Kfm0P2^[Zh30:>SX`<0Vi^K0`2<S8`20:ZZ
ZP<0MgMg0`2i^KT20<K6aP<0ZJVY0`2QXJ4309ZJVP80WinO0`2SXj<60:RXZ080UYJF0`2NWYh30:JV
YP<0W9bL0P1lO7`305eMG@<0=CDe0`0B4Q8200820P<0:RXZ0`1aLG4308J6QP80RXZ:0`25QHD305iN
GP<0;bl_0P0J6QX3010@40<0AdM70P22PX8308>3P`<0Ng]k0`0g=cL204A4A0<0NGUi0`1WIfL303hn
?P802@T95000000206ATI1<00000203oool000H0oooo?@00000201hN7Q4000000`1VIVH20<C4a0<0
^KVi0`2d];@30;>c/`80Shn?0`1UIFD306QXJ0<0H61P0P2JVYX30<g=c@<0b/[:0`2m_Kd20:j^[P<0
Xj>S0`2KVi/308b<S080ZZZZ0`1gMgL30;Vi^@80a/K60`2YZJT30:6QX@<0VYZJ0P2OWil30:>SX`H0
Z:RX0P2FUYH309jNWP<0YZJV0`2LW9`207alO0<0GEeM0`0e=CD3018B4P800P820`0Z:RX3075aL@<0
QXJ60P2:RXX308F5Q@<0GUiN0`0_;bl201XJ6P<0410@0`17AdL208:2PP<0Ph>30`1kNg/303Lg=`80
A4A40`1iNGT306MWI`<0?Shn0P092@TD00000080I6AT4`0000080?ooo`001P3ooolm000000807QhN
4@00000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0cLg=
0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX307MgM`<0^KVi0P36a/H30:VYZ@<0XJ6Q
0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<04Q8B
0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80PX:2
0`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92A@000000P1TI6@C000000P0oooo
00060?oooe0000000`0Y:BT20<;2`P<0_[jn0`3Cdm<302d];@80Lg=c0`2c/k<30>o_k`<0emOG0P2M
WId30<g=c@<0];Bd0`33`l<20>3Ph0<0jn_[0`3]kNd30<o?c`80_[jn0`2/[:`3096AT@80T92@0`20
P803075aL@<0FUYJ0P1CDe<305]KF`<0KVi^0`0V9RH206a/K0<0Hf=S0`1MGEd304m?C`80Bd];0`13
@d<305iNGP<0JFUY0P1BDU8301lO7`<0IFEU0`1lO7`20861P@<0R8R80`1YJFT303Hf=P807AdM0`0C
4a<304e=C@80Ti>C0`1lO7`3061PH0<0;Rh^0P1VIVH306QXJ0<0=cLg0`061PH[000000P0oooo0006
0?oooe0000000`0Y:BT20<;2`P<0_[jn0`3Cdm<302d];@80Lg=c0`2c/k<30>o_k`<0emOG0P2MWId3
0<g=c@<0];Bd0`33`l<20>3Ph0<0jn_[0`3]kNd30<o?c`80_[jn0`2/[:`3096AT@80T92@0`20P803
075aL@<0FUYJ0P1CDe<305]KF`<0KVi^0`0V9RH206a/K0<0Hf=S0`1MGEd304m?C`80Bd];0`13@d<3
05iNGP<0JFUY0P1BDU8301lO7`<0IFEU0`1lO7`20861P@<0R8R80`1YJFT303Hf=P807AdM0`0C4a<3
04e=C@80Ti>C0`1lO7`3061PH0<0;Rh^0P1VIVH306QXJ0<0=cLg0`061PH[000000P0oooo00060?oo
oe0000000`051@D20:NWY`<0b<S80`2h^;P30<W9b@80lO7a0`3hn?P30>o_k`<0j^[Z0P3^k^h30>OW
i`<0j^[Z0`3fm_H20>o_k`H0jn_[0`3Bd]820;>c/`<0YjNW0`2GUiL209^KV`<0/;2`0`2d];@30;Fe
]@80SHf=0`21PH4306QXJ0<0G5aL0P11@D4302XZ:P<09BDU0`0G5aL2010@40<05aLG0`0b<S8305mO
G`80DE5A0`0>3Ph305ADE0<0Ogmo0P21PH4308:2PP<0K6a/0`1>CTh202`/;0<071`L0`1RHV8209RH
V0<0M7Ad0`11@D4303Xj>P80MWIf0`17AdL300L71bh00000203oool000H0ooooD000000300D51@80
YjNW0`38b<P30;Rh^0<0bLW90P3alO430?Shn0<0kno_0`3Zj^X20>k^kP<0inOW0`3Zj^X30?KfmP80
kno_1P3[jn/30=;BdP80/k>c0`2WYjL309NGU`80Vi^K0`2`/;030;Bd]0<0]KFe0P2=SHd30861P@<0
J6QX0`1LG5`20451@@<0:RXZ0`0U9BD301LG5`80410@0`0G5aL3038b<P<0GemO0P1ADE4300h>3P<0
E5AD0`1oOgl20861P@<0PX:20`1/K6`304i>CP80;2`/0`0L71`3069RHP80V9RH0`1dM7@30451@@<0
>SXj0P1fMWH304M7A`<01`L7;P0000080?ooo`001P3ooom@000000<01@D50P2WYjL30<S8b0<0^;Rh
0`39bLT20?7al@<0n?Sh0`3_knl30>[ZjP80k^k^0`3WinL30>[ZjP<0m_Kf0P3_knl60>_[j`<0d];B
0P2c/k<30:NWY`<0UiNG0P2KVi/30;2`/0<0];Bd0`2e]KD208f=S@<0PH610`1XJ6P305aLG080@D51
0`0Z:RX302DU9@<05aLG0P0@410301LG5`<0<S8b0`1OGel2055AD@<03Ph>0`1DE5@307moO`80PH61
0`22PX8306a/K0<0CTi>0P0/;2`301`L70<0HV9R0P2HV9P307AdM0<0@D510`0j>SX207IfMP<0AdM7
0`071`L^000000P0oooo00060?oooe<000000P1VIVH30=[JfP<0`l?30`2j^[X20=CDe0<0f=SH0`3>
c/h30:f][@80b<S80`3De=@30=gMg@<0d=3@0P1OGel30<C4a0<0[:b/0`2f][H20::RXP<0SXj>0`1n
OWh206a/K0<0OGem0`1_Kfl309VIV@80];Bd0`38b<P304a<C0<0P8200P2HV9P309jNWP<0SHf=0`2`
/;0206=SH`<0?clo1P0d=3@202l_;`<0;Bd]0`17AdL307MgM`80PH610`1mOGd306m_K`<08R8R0P0e
=CD302/[:`<0RHV90P2EUID30=gMg@<0>c/k0`1LG5`204i>CP<03@d=<@0000080?ooo`001P3ooomC
00000080IVIV0`3Jf]X30<?3``<0^[Zj0P3De=@30=SHf0<0c/k>0`2][Jd20<S8b0<0e=CD0`3MgMd3
0=3@d080GemO0`34a<@30:b/[0<0][Jf0P2RXZ8308j>SP<0OWin0P1/K6`307emO@<0Kfm_0`2IVIT2
0;Bd]0<0b<S80`1<C4`30820P080V9RH0`2NWYh308f=S@<0/;2`0P1SHf<303lo?`H0=3@d0P0_;bl3
02d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl3028R8P80=CDe0`0[:b/308V9R@80UIFE0`3MgMd3
03/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj
^P80e=CD0`3Hf=P30<k>cP<0[Jf]0P38b<P30=CDe0<0gMgM0`3@d=0205mOG`<0a<C40`2/[:`30;Jf
]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@30<S8b0<0C4a<0`20P80209RH
V0<0WYjN0`2=SHd30;2`/080Hf=S0`0o?cl603@d=080;bl_0`0];Bd304M7A`<0MgMg0P21PH4307em
O@<0Kfm_0`0R8R8203De=@<0:b/[0`29RHT209FEU@<0gMgM0`0k>c/305aLG080CTi>0`0=3@da0000
00P0oooo00060?ooodP000000P1IFET900000080820P1P3AdM430<c<c080eMGE0`3Kfm/30>CTi0<0
iNGU0P3]kNd30>_[j`<0gMgM0`3Ph>020:ZZZP<0GEeM0`0l?3`305=CD`80J6QX0`1^KVh306MWI`80
IVIV0`2=SHd30:BTY0<0WYjN0P35aLD30;Bd]0<0JFUY0`14A4@205eMG@<0Jf][0`1dM7@308n?S`80
ZJVY0`2e]KD309bLW0<0PH610P0l?3`305IFEP<0Jf][0`1jNWX20820P0<0OGem0`1dM7@3055AD@80
;Bd]0`1?Cdl309ZJVP80QhN70`1OGel304I6AP<0?Shn0P0820P3000000<00@416`00000300d=3A00
0000203oool000H0ooooB000000205UIF@T000000P0P82060=7Ad@<0c<c<0P3EeMD30=_Kf`<0i>CT
0`3UiND20>g]k@<0jn_[0`3MgMd30>3Ph080ZZZZ0`1MGEd303`l?0<0De=C0P1XJ6P306i^KP<0IfMW
0P1VIVH308f=S@<0Y:BT0`2NWYh20<G5a@<0];Bd0`1YJFT304A4A080GEeM0`1[Jf/307AdM0<0Shn?
0P2YZJT30;Fe]@<0W9bL0`21PH4203`l?0<0EUIF0`1[Jf/307YjNP80P8200`1mOGd307AdM0<0DE5A
0P0];Bd304m?C`<0VYZJ0P27QhL305mOG`<0ATI60`0n?Sh200P820<000000`010@4K000000<03@d=
400000080?ooo`001P3ooomE000000<0Lg=c0`3Shn<30<o?c`80dM7A1P3Jf]X30>KViP80jNWY0`3J
f]X30=kNgP<0/K6a0P0X:2P300H61P<02PX:0`092@T201`L70<0F5QH0`1eMGD208>3P`<0fMWI0`2l
_;`30<C4a080[Zj^0`2h^;P30=?Cd`<0SXj>0P1EEED305eMG@<0E5AD0`1gMgL209nOW`<0[Zj^0`2L
W9`3069RHP80CDe=0`1_Kfl307moO`<0Q8B40P23Ph<308B4Q0<0JVYZ0`18B4P202XZ:P<0HF5Q0`2B
TY8207=cL`<0CDe=0`0U9BD300820P8000000`010@4a000000P0oooo00060?oooeD000000`1cLg<3
0>?Sh`<0clo?0P3AdM460=[JfP<0i^KV0P3YjNT30=[JfP<0g]kN0`2a/K4202PX:0<01PH60`0:2PX3
00T92@8071`L0`1HF5P307EeM@80Ph>30`3IfMT30;bl_0<0a<C40P2^[Zh30;Rh^0<0dm?C0`2>SXh2
05EEE@<0GEeM0`1DE5@307MgM`80WinO0`2^[Zh309bLW0<0HV9R0P1=CDd306m_K`<0Ogmo0`24Q8@2
08>3P`<0Q8B40`1ZJVX304Q8B080:RXZ0`1QHF4309:BTP80Lg=c0`1=CDd302DU9@<00P820P000003
00410C400000203oool000H0ooooE@00000307=cL`<0hn?S0`3?cll20=7Ad@H0f][J0`3Vi^H20>WY
j@<0f][J0`3Ng]h30;6a/@80:2PX0`061PH300X:2P<02@T90P0L71`305QHF0<0MGEe0P23Ph<30=WI
f@<0_;bl0`34a<@20:j^[P<0^;Rh0`3Cdm<308j>SP80EEEE0`1MGEd305ADE0<0MgMg0P2OWil30:j^
[P<0W9bL0`1RHV8204e=C@<0Kfm_0`1oOgl308B4Q080Ph>30`24Q8@306YZJP<0B4Q80P0Z:RX3065Q
H@<0TY:B0P1cLg<304e=C@<09BDU0`020P82000000<00@41<@0000080?ooo`001P3ooomE000000<0
4Q8B0`2o_kl30>3Ph080clo?0`3AdM430=KFeP<0cLg=0P3MgMd30>WYj@<0g=cL0`1SHf<202HV9P<0
9bLW0`0O7al301HF5P802`/;0`0X:2P306a/K080a/K60`2e]KD30<W9b@<0b<S80P2ZZZX30861P@<0
emOG0`2o_kl209JFUP<0OWin0`1lO7`305UIF@80De=C0`1>CTh305iNGP<0@d=30P1NGUh307QhN0<0
PX:20`25QHD208Z:RP<0Ph>30`1TI6@303hn?P80<C4a0`1bLW8307alO080G5aL0`0Y:BT6000000D0
0@413P00000301PH62000000203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A
0`3Fe]H30<g=c@80gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX
0`1/K6`20<K6aP<0]KFe0`39bLT30<S8b080ZZZZ0`21PH430=OGe`<0_kno0P2FUYH307inOP<0O7al
0`1IFET205=CD`<0CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT
0`0n?Sh2034a<@<0LW9b0`1lO7`205aLG0<0:BTY1P00000500410@h000000`0H61PP000000P0oooo
00060?oooeD000000`0B4Q830;no_`<0h>3P0P3?cll30=7Ad@<0e]KF0`3=cLd20=gMg@<0jNWY0`3L
g=`306=SH`809RHV0`0W9bL301lO7`<05QHF0P0;2`/302PX:0<0K6a/0P36a/H30;Fe]@<0bLW90`38
b<P20:ZZZP<0PH610`3GemL30;no_`80UYJF0`1nOWh307alO0<0FEUI0P1CDe<304i>CP<0GUiN0`13
@d<205iNGP<0N7Qh0`22PX8308F5Q@80RXZ:0`23Ph<306ATI0<0?Shn0P0a<C43079bLP<0O7al0P1L
G5`302TY:@H000001@010@4>000000<061PH800000080?ooo`001P3ooomH000000<0;bl_0`30`<02
0>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0PX:20P21PH4307YjNP<0Shn?0`0n?Sh2
02/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80bLW90`1nOWh307alO0<0T92@0P2m_Kd3
09nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80Jf][0`1kNg/308>3P`<0SXj>0P2;Rh/3
07inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<01PH6?00000080?ooo`001P3ooomH0000
00<0;bl_0`30`<020>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0PX:20P21PH4307Yj
NP<0Shn?0`0n?Sh202/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80bLW90`1nOWh307al
O0<0T92@0P2m_Kd309nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80Jf][0`1kNg/308>3
P`<0SXj>0P2;Rh/307inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<01PH6?00000080?oo
o`001P3ooomH000000<0;bl_0`30`<020>OWi`<0fMWI0`3Kfm/30=kNgP80f][J0`3EeMD30;^k^`<0
PX:20P21PH4307YjNP<0Shn?0`0n?Sh202/[:`<051@D0`17AdL20:j^[P<0e]KF0`2TY:@30<O7a`80
bLW90`1nOWh307alO0<0T92@0P2m_Kd309nOW`<0W9bL0`2ATI4205eMG@<0OGem0`1nOWh303Xj>P80
Jf][0`1kNg/308>3P`<0SXj>0P2;Rh/307inOP<0H61P0`14A4@203Ph>0<0Kfm_0`1WIfL203lo?`<0
1PH6?00000080?ooo`001P3ooomK000000<06QXJ0P1=CDd30>o_k`<0h>3P0`3MgMd20>?Sh`<0g=cL
0`2f][H30:JVYP80`L710`3Lg=`30=oOg`<0QXJ60P1[Jf/304Y:BP<0;2`/0P2DU9@30=SHf0<0UYJF
0`2TY:@20=;BdP<0c<c<0`2o_kl30:b/[080/K6a0`31`L430:ZZZP<0/[:b0P2m_Kd30;jn_P<0D51@
0`0n?Sh206UYJ@<0NGUi0`29RHT309:BTP80Shn?0`1jNWX3061PH0<0?clo0P14A4@305iNGP<0DU9B
0P0J6QXm00000080IfMW203oool000H0ooooF`00000301XJ6P80CDe=0`3_knl30>3Ph0<0gMgM0P3S
hn<30=cLg0<0][Jf0`2VYZH20<71`@<0g=cL0`3Ogml308J6QP80Jf][0`1:BTX302`/;080U9BD0`3H
f=P309JFUP<0Y:BT0P3Bd]830<c<c0<0_kno0`2/[:`20;6a/@<0`L710`2ZZZX30;:b/P80_Kfm0`2n
_[h3051@D0<0?Shn0P1YJFT307UiN@<0RHV90`2BTY8208n?S`<0NWYj0`1PH60303lo?`80A4A40`1N
GUh3059BDP806QXJ?@00000206MWI`P0oooo00060?oooeh000000P071`L307MgM`<0_;bl0`2KVi/2
0>CTi0<0fMWI0`2[Zj/30:BTY080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<00P820P1lO7`3
0<O7a`<0a<C40`2EUID208n?S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd3
04E5A@<0ATI60`18B4P206QXJ0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh3
04e=C@<0<30`0P020P8A000000<02@T9:`0000080?ooo`001P3ooomN000000801`L70`1gMgL30;bl
_0<0Vi^K0P3Ti>@30=WIf@<0Zj^[0`2TY:@20<_;b`<0k>c/0`3Rh^830<C4a080U9BD0`26QXH30082
0P80O7al0`37alL30<C4a0<0UIFE0P2?Shl309nOW`<0_[jn0`38b<P209RHV0<0YJFU0`2TY:@30:^[
Z`80OGem0`15ADD304I6AP<0B4Q80P1XJ6P307emO@<0RHV90`2?Shl208R8R0<0MgMg0`1LG5`303dm
?@80?Shn0`1=CDd3030`<0800P824@00000300T92B/00000203oool000H0ooooGP00000200L71`<0
MgMg0`2l_;`309^KV`80i>CT0`3IfMT30:^[Z`<0Y:BT0P3;bl/30>c/k0<0h^;R0`34a<@209BDU0<0
QXJ60`020P8207alO0<0alO70`34a<@309FEU@80Shn?0`2OWil30;jn_P<0b<S80P2HV9P30:FUY@<0
Y:BT0`2[Zj/207emO@<0ADE50`16ATH304Q8B080J6QX0`1mOGd308V9R@<0Shn?0P28R8P307MgM`<0
G5aL0`0m?Cd203hn?P<0CDe=0`0`<30200820Q4000000`092@T[000000P0oooo00060?ooo`<00000
0`1;Bd/i000000<0KVi^8@00000304];B`<0/K6a1@3Xj>P309jNWP<0PH610P2XZ:P30>KViP<0bLW9
0`2WYjL208V9R@<0RXZ:0`0m?Cd205EEE@<0ZJVY1P32`/820<30`0<0a/K60`2[Zj/30;Bd]080UYJF
0`2CTi<307inOP<0CTi>0P0Q8B4303Xj>P<0EUIF0`1BDU8205eMG@<0O7al0`2ATI4308j>SP80OWin
0`1_Kfl305EEE@<0;bl_0P0Z:RX303Ph>0<04A4A0P00000300410C`00000203oool000H0oooo0`00
000304];BcT000000`1^KVhQ000000<0Bd];0`2a/K450>SXj0<0WYjN0`21PH420:RXZ0<0i^KV0`39
bLT30:NWY`80RHV90`2:RXX303dm?@80EEEE0`2YZJT60<;2`P80`<300`36a/H30:^[Z`<0];Bd0P2F
UYH309>CT`<0OWin0`1>CTh2024Q8@<0>SXj0`1FEUH3059BDP80GEeM0`1lO7`3096AT@<0SXj>0P1n
OWh306m_K`<0EEEE0`0_;bl202XZ:P<0>3Ph0`0A4A42000000<00@41?00000080?ooo`001P3oool3
000000<0Bd];>@00000306i^KR4000000`1;Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H3
0<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@2
09JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh2
07inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l000000P0oooo00060?oo
ofT000000P0m?Cd30:VYZ@<0W9bL0`1cLg<206i^KP<0V9RH0`2JVYX30861P@80L71`0`1aLG4304I6
AP80BTY:0`2=SHd30:n_[`<0YJFU0P2TY:@30<S8b0<0_kno0`2YZJT208N7Q`<0=cLg0`0?3`l301HF
5P80=SHf0`15ADD304Y:BP<0GemO0P1YJFT308>3P`<0TI6A0`2;Rh/207UiN@<0IfMW0`17AdL5024Q
8@<0<30`0`051@D2000000<00@41?00000080?ooo`001P3ooomY00000080?Cdm0`2YZJT309bLW0<0
Lg=c0P1^KVh309RHV0<0VYZJ0`21PH42071`L0<0LG5a0`16ATH204Y:BP<0SHf=0`2_[jl30:FUY@80
Y:BT0`38b<P30;no_`<0ZJVY0P27QhL303Lg=`<03`l?0`0F5QH203Hf=P<0ADE50`1:BTX305mOG`80
JFUY0`23Ph<3096AT@<0Rh^;0P1iNGT306MWI`<0AdM71@0Q8B43030`<0<01@D50P00000300410C`0
0000203oool000H0oooo0`00000300l?3d8000000P1`L70Q000000<01`L70`1OGel306a/K080M7Ad
0`2EUID309RHV0<0P8200P1YJFT305EEE@<0@d=30P0g=cL305mOG`<0MgMg0`20P80208f=S@<0RXZ:
0`1dM7@303hn?P803Ph>0`0;2`/301TI6@<07alO0P0j>SX604i>CP<0EEEE0P1aLG4308R8R0<0Shn?
0`0F5QH2075aL@<0FUYJ0`0b<S8301PH6080;2`/0`0N7Qi4000000P0oooo00060?ooo`<000000`0?
3`m200000080L71`8@00000300L71`<0GemO0`1/K6`207AdM0<0UIFE0`2HV9P30820P080JFUY0`1E
EED304=3@`80=cLg0`1OGel307MgM`<0P8200P2=SHd308Z:RP<0M7Ad0`0n?Sh200h>3P<02`/;0`0I
6AT301lO7`80>SXj1P1>CTh305EEE@80LG5a0`28R8P308n?S`<05QHF0P1aLG4305YJFP<0<S8b0`0H
61P202`/;0<07QhNA00000080?ooo`001P3oool3000000<03`l?@P000002071`L24000000`071`L3
05mOG`<0K6a/0P1dM7@309FEU@<0V9RH0`20P80206UYJ@<0EEEE0`13@d<203Lg=`<0GemO0`1gMgL3
0820P080SHf=0`2:RXX307AdM0<0?Shn0P0>3Ph300/;2`<06ATI0`0O7al203Xj>PH0CTi>0`1EEED2
075aL@<0R8R80`2?Shl301HF5P80LG5a0`1JFUX3038b<P<061PH0P0/;2`301hN7T@00000203oool0
00H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ
:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<01@D50P0@410301lO7`<09bLW0`0N7Qh203/k
>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D5
1Ah000000`1mOGdS000000P0oooo00060?ooofh000000`0h>3P306QXJ080Hf=S0`1WIfL306YZJP<0
H61P0P1@D5030492@P<0=SHf0P0Z:RX305=CD`<0HV9R0`1QHF4205=CD`<0=SHf0`0E5AD300D51@80
410@0`0O7al302LW9`<07QhN0P0k>c/304];B`<0EUIF0`1NGUh2079bLPH0Rh^;0`1oOgl2079bLP<0
C4a<0`0^;Rh302HV9P80;2`/0`051@DN000000<0OGem8`0000080?ooo`001P3ooom^000000<0>3Ph
0`1XJ6P206=SH`<0IfMW0`1ZJVX3061PH080D51@0`12@T8303Hf=P80:RXZ0`1CDe<3069RHP<0HF5Q
0P1CDe<303Hf=P<05ADE0`051@D2010@40<07alO0`0W9bL301hN7P80>c/k0`1;Bd/305IFEP<0GUiN
0P1bLW8608^;R`<0Ogmo0P1bLW8304a<C0<0;Rh^0`0V9RH202`/;0<01@D57P00000307emOB<00000
203oool000H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y
:BT301/K6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f
=SH304m?C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P09
2@T3000000<00@413@00000304=3@c400000203oool000H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/3
06MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3
018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT3
07QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T3000000<00@413@00000304=3@c400000203oool0
00H0ooooKP00000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K
6`<04Q8B0`0;2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?
C`<0FEUI0`1kNg/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T30000
00<00@413@00000304=3@c400000203oool000H0oooo2@00000202PX:14000000`0@411?000000<0
;Bd]0`29RHT207alO0<0;2`/0`1^KVh305iNGP80B4Q80`0_;bl302/[:`80<30`0`0B4Q8300X:2P<0
410@0P0D51@301/K6`<05QHF0`0M7Ad202HV9P<0=CDe0`0`<30303/k>`80_kno0`11@D4305mOG`<0
PX:20P2<S8`607alO0<0Ng]k0P0o?cl304i>CP<0=3@d0`0<30a9000000P0oooo00060?ooo`T00000
0P0X:2PA000000<0410@C`00000302d];@<0RHV90P1lO7`302`/;0<0KVi^0`1NGUh204Q8B0<0;bl_
0`0[:b/2030`<0<04Q8B0`0:2PX3010@408051@D0`0K6a/301HF5P<07AdM0P0V9RH303De=@<0<30`
0`0k>c/20;no_`<0@D510`1OGel308:2PP80S8b<1P1lO7`307]kN`80?clo0`1>CTh303@d=0<030`<
B@0000080?ooo`001P3oool900000080EEEEGP00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]
KFd606EUI@80emOG0`0j>SX303De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S
8b<203Hf=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_
Kfl2061PH0<0D51@0`0F5QHF000000803Ph>=00000080?ooo`001P3oool900000080EEEEGP000002
00410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EUI@80emOG0`0j>SX303De=@80;2`/0`0B4Q83
014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P3
06UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061PH0<0D51@0`0F5QHF000000803Ph>=0000008
0?ooo`001P3oool900000080EEEEGP00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EU
I@80emOG0`0j>SX303De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf
=P<0=CDe0`0a<C4304e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061P
H0<0D51@0`0F5QHF000000803Ph>=00000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0
QhN70`1jNWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0
:BTY0`0[:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0
JFUY0`1HF5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0QhN7
0`1jNWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0:BTY
0`0[:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0JFUY
0`1HF5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<00`<30`21PH4209JFUP<0QhN70`1j
NWX307MgM`80JFUY0`1ADE4304U9B@80;Bd]0`0B4Q8301/K6`<07AdM0P0O7al301TI6@<0:BTY0`0[
:b/203`l?0<0>3Ph0`17AdL300000080J6QX0`1dM7@30820P0<0MWIf0P1/K6`307UiN@<0JFUY0`1H
F5P204Q8B0<08B4QC`0000080?ooo`001P3ooom^000000<0410@0`1XJ6P209VIV@<0oooo0`28R8P3
0861P@80LW9b0`1WIfL3055AD@80;Bd]0`0K6a/301hN7P<071`L0P0J6QX302PX:0<09RHV0`000002
0410@0<0@d=30`1EEED307=cL`80Ng]k1P1hN7P306a/K080JVYZ0`1KFe/304Y:BP<0BDU90P0T92AB
000000P0oooo00060?ooofh000000`0@410306QXJ080VIVI0`3oool308R8R0<0PH610P1bLW8306MW
I`<0DE5A0P0];Bd301/K6`<07QhN0`0L71`201XJ6P<0:2PX0`0V9RH300000080@4100`13@d<305EE
E@<0Lg=c0P1kNg/607QhN0<0K6a/0P1ZJVX305]KF`<0BTY:0`19BDT202@T95800000203oool000H0
ooooL@00000305QHF080T92@0`2BTY8308J6QP<0NWYj0P1eMGD306MWI`<0AdM70P00000301lO7`<0
8b<S0`0O7al202<S8`<0;Rh^0`0`<30304m?C`80C4a<0`1HF5P30=;BdP<0LW9b0P1jNWX607UiN@<0
LW9b0P1CDe<304U9B@<0@4100`0G5aMD000000P0oooo00060?ooog4000000`1HF5P2092@T0<0TY:B
0`26QXH307YjNP80MGEe0`1WIfL304M7A`8000000`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`
0`1?Cdl204a<C0<0F5QH0`3Bd]83079bLP80NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLG
E00000080?ooo`001P3oooma000000<0F5QH0P2@T90309:BTP<0QXJ60`1jNWX207EeM@<0IfMW0`17
AdL2000000<07alO0`0S8b<301lO7`808b<S0`0^;Rh3030`<0<0Cdm?0P1<C4`305QHF0<0d];B0`1b
LW8207YjNPH0NGUi0`1bLW8205=CD`<0BDU90`10@40301LG5e@00000203oool000H0ooooKP000003
01dM7@<0F5QH0P27QhL308j>SP<0R8R80`1iNGT206][J`<0GEeM0`10@40502PX:0<09BDU0`0W9bL2
03Lg=`<0:b/[0`1:BTX305UIF@80FUYJ0`1ZJVX307QhN0<0Lg=c0P1eMGD307UiN@<0OGem0`1VIVH2
04U9B@<0<C4a0`0820Pg000000808B4Q7P0000080?ooo`001P3ooom^000000<07AdM0`1HF5P208N7
Q`<0SXj>0`28R8P307UiN@80Jf][0`1MGEd30410@0D0:2PX0`0U9BD302LW9`80=cLg0`0[:b/304Y:
BP<0FEUI0P1JFUX306YZJP<0N7Qh0`1cLg<207EeM@<0NGUi0`1mOGd306IVIP80BDU90`0a<C4300P8
23L000000P0Q8B4N000000P0oooo00060?ooofh000000`0M7Ad305QHF080QhN70`2>SXh308R8R0<0
NGUi0P1[Jf/305eMG@<0@4101@0X:2P302DU9@<09bLW0P0g=cL302/[:`<0BTY:0`1IFET205YJFP<0
JVYZ0`1hN7P307=cL`80MGEe0`1iNGT307emO@<0IVIV0P19BDT3034a<@<020P8=`000002024Q8Ah0
0000203oool000H0ooooJ@00000500410@<0DE5A0`1IFET208>3P`<0TI6A0`26QXH307EeM@80IFEU
0`1FEUH30410@080<S8b0`0_;bl302/[:`<0=SHf0P0a<C4304I6AP<0HF5Q0`1PH60206YZJP<0MGEe
0`1nOWh307UiN@80MGEe0`1mOGd307=cL`<0Bd];0P0L71`o000000<01PH66`0000080?ooo`001P3o
oomY000000D00@410`1ADE4305UIF@80Ph>30`2ATI4308J6QP<0MGEe0P1UIFD305IFEP<0@4100P0b
<S8302l_;`<0:b/[0`0f=SH2034a<@<0ATI60`1QHF43061PH080JVYZ0`1eMGD307inOP<0NGUi0P1e
MGD307emO@<0Lg=c0`1;Bd/201`L73l000000`061PHK000000P0oooo00060?ooofT000001@010@43
055AD@<0FEUI0P23Ph<3096AT@<0QXJ60`1eMGD206EUI@<0EUIF0`10@402038b<P<0;bl_0`0[:b/3
03Hf=P80<C4a0`16ATH3065QH@<0H61P0P1ZJVX307EeM@<0OWin0`1iNGT207EeM@<0OGem0`1cLg<3
04];B`8071`L?`00000300H61Q/00000203oool000H0oooo2@00000206YZJQ@000000P11@D4I0000
00<051@D1@00000302TY:B4000000`010@4200@410<00`<30`020P8304I6AP80Ng]k0`29RHT307]k
N`<0JVYZ0P1OGel304m?C`<0@4100P0f=SH3038b<P<0>SXj0`0i>CT204M7A`<0FUYJ0`0o?cl306QX
J080NGUi0`1oOgl308>3P`<0P8200P1lO7`306e]K@<0ATI60`0>3PiO000000P0oooo00060?ooo`T0
00000P1ZJVXD00000080@D516@00000301@D50D000000`0Y:BTQ000000<00@410P0410@300<30`<0
0P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410@080=SHf0`0b<S8303Xj>P<0
>CTi0P17AdL305YJFP<0?clo0`1XJ6P207UiN@<0Ogmo0`23Ph<30820P080O7al0`1]KFd304I6AP<0
3Ph>G`0000080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P
0P1_Kfl308B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY
0`1NGUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41
G@0000080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P0P1_
Kfl308B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY0`1N
GUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41G@00
00080?ooo`001P3ooolA000000<0B4Q8DP00000300820P800`<30`020P83000000<0820P0P1_Kfl3
08B4Q0<02`/;0`1RHV8205eMG@<0DU9B0`16ATH203`l?0<0@T920`18B4P304e=C@80JFUY0`1NGUh3
06MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2065QH@<0@T920`0D51@3000000800@41G@000008
0?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l0`1nOWh307]kN`<0JVYZ0P1UIFD305eM
G@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF0`1]KFd307EeM@80NWYj0`1cLg<305eM
G@<0Bd];JP0000080?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l0`1nOWh307]kN`<0
JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF0`1]KFd307EeM@80
NWYj0`1cLg<305eMG@<0Bd];JP0000080?ooo`001P3ooomV000000P00@410`020P8300P82080?3`l
0`1nOWh307]kN`<0JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3000000<0EeMG0`1NGUh206=SH`<0EUIF
0`1]KFd307EeM@80NWYj0`1cLg<305eMG@<0Bd];JP0000080?ooo`001P3ooomC000000805ADE2`00
000900410@80@4100`030`<300@410<020P80P0F5QH304E5A@<0HV9R1@1^KVh306MWI`<0FEUI0P08
20P305YJFP<0G5aL0`1NGUh206EUI@<0JFUY0`1/K6`306UYJ@80G5aL0`1ADE4301dM7@<0@D510P0d
=3@300T92FD00000203oool000H0ooooD`00000201DE5@/000002@010@420410@0<00`<30`0410@3
00P820805QHF0`15ADD3069RHPD0KVi^0`1WIfL305UIF@8020P80`1JFUX305aLG0<0GUiN0P1UIFD3
06UYJ@<0K6a/0`1YJFT205aLG0<0DE5A0`0M7Ad30451@@80=3@d0`092@UU000000P0oooo00060?oo
oe<000000P0E5AD;000000T00@410P10@40300<30`<010@40`0820P201HF5P<0ADE50`1RHV8506i^
KP<0IfMW0`1IFET200P820<0FUYJ0`1LG5`305iNGP80IFEU0`1YJFT306a/K0<0JFUY0P1LG5`3055A
D@<07AdM0`11@D4203@d=0<02@T9I@0000080?ooo`001P3ooolT000000<0LW9b:@000003075aL@d0
00002`010@4300X:2P<03@d=0`0:2PX201/K6`<08b<S0`0l?3`305=CD`80H61P0`1OGel3061PH080
GemO0`1MGEd3061PH0<0HV9R0P1UIFD306ATI0<0H61P0`1GEeL2051@D0<0CDe=0`12@T8303Ti>@80
5aLG3P00000304A4A5L00000203oool000H0oooo90000003079bLRT000000`1aLG4=000000/00@41
0`0:2PX300d=3@<02PX:0P0K6a/302<S8`<0?3`l0`1CDe<2061PH0<0GemO0`1PH60205mOG`<0GEeM
0`1PH603069RHP80IFEU0`1TI6@3061PH0<0EeMG0P1@D50304e=C@<0@T920`0i>CT201LG5`h00000
0`14A4AG000000P0oooo00060?ooof0000001P010@43000000800`<30`0=3@d301TI6@<061PH0P0M
7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306ATI080IfMW0`1O
Gel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BD[000000<0=SHf=000000301/K6`D00000203o
ool000H0ooooH000000600410@<000000P030`<300d=3@<06ATI0`0H61P201dM7@<09bLW0`0[:b/3
03dm?@80DU9B0`1FEUH305QHF080GUiN0`1RHV8306=SH`<0I6AT0P1WIfL305mOG`<0FEUI0`1CDe<2
051@D0<0Bd];0`13@d<302DU9B/000000`0f=SHd000000<06a/K1@0000080?ooo`001P3ooomP0000
00H00@410`00000200<30`<03@d=0`0I6AT301PH60807AdM0`0W9bL302/[:`<0?Cdm0P1BDU8305IF
EP<0F5QH0P1NGUh3069RHP<0Hf=S0`1TI6@206MWI`<0GemO0`1IFET305=CD`80D51@0`1;Bd/304=3
@`<09BDU:`00000303Hf=S@000000`0K6a/5000000P0oooo00060?ooof<000000`010@4300820P80
1`L70`0>3Ph301/K6`<0820P0P0N7Qh3028R8P<09RHV0`0^;Rh204E5A@<0EUIF0`1MGEd206ATI0<0
IVIV0`1TI6@3065QH@80GEeM0`1KFe/605QHF080DU9B0`1=CDd3038b<P<00`<3JP0000080?ooo`00
1P3ooomS000000<00@410`020P8200L71`<03Ph>0`0K6a/3020P80807QhN0`0R8R8302HV9P<0;Rh^
0P15ADD305IFEP<0GEeM0P1TI6@306IVIP<0I6AT0`1QHF4205eMG@<0Fe]K1P1HF5P2059BDP<0CDe=
0`0b<S8300<30fX00000203oool000H0ooooH`00000300410@<00P820P071`L300h>3P<06a/K0`0P
820201hN7P<08R8R0`0V9RH302h^;P80ADE50`1FEUH305eMG@80I6AT0`1VIVH306ATI0<0HF5Q0P1M
GEd305]KF`H0F5QH0P1BDU8304e=C@<0<S8b0`030`=Z000000P0oooo00060?ooodd000000`010@43
01<C4a0000000`020P8300D51@8030`<0`0?3`l3000000<09BDU0P0V9RH302<S8`<0820P0`0Q8B42
02h^;P<0?clo0`1BDU8205]KF`<0HV9R0`1UIFD305iNGPD0Fe]K0`1JFUX305UIF@80EEEE0`13@d<3
010@46/000000P1gMgL80?ooo`001P3ooom=000000<00@410`0C4a<@000000<00P820`051@D200`<
30<03`l?0`00000302DU9@809RHV0`0S8b<3020P80<08B4Q0P0^;Rh303lo?`<0DU9B0P1KFe/3069R
HP<0IFEU0`1NGUh505]KF`<0FUYJ0`1IFET205EEE@<0@d=30`0@411[00000080MgMg203oool000H0
ooooH000000300410@<00`<30`0:2PX200h>3P<0410@0`0I6AT302TY:@80=SHf0`0o?cl304A4A0<0
@d=30P0n?Sh304I6AP<0EEEE0P1MGEd3061PH0<0HV9R0`1SHf<2061PH0<0GEeM0`1NGUh305]KF`80
EEEE0`0/;2a`000000P0oooo00060?ooof0000000`010@4300<30`<02PX:0P0>3Ph3010@40<06ATI
0`0Y:BT203Hf=P<0?clo0`14A4@304=3@`80?Shn0`16ATH305EEE@80GEeM0`1PH603069RHP<0Hf=S
0P1PH60305eMG@<0GUiN0`1KFe/205EEE@<0;2`/L00000080?ooo`001P3ooomP000000<00@410`03
0`<300X:2P803Ph>0`0@410301TI6@<0:BTY0P0f=SH303lo?`<0A4A40`13@d<203hn?P<0ATI60`1E
EED205eMG@<0H61P0`1RHV8306=SH`80H61P0`1MGEd305iNGP<0Fe]K0P1EEED302`/;7000000203o
ool000H0ooooGP00000500820P<020P80`0<30`200h>3P<04Q8B0`0J6QX302TY:@80?Shn0`1FEUH3
06IVIP/0LG5a0P1bLW83075aL@<0L71`0`1YJFT206=SH`<0HF5Q0`1OGel305eMG@80ADE50`0820Q`
000000P0oooo00060?oooeh000001@020P8300P820<030`<0P0>3Ph3018B4P<06QXJ0`0Y:BT203hn
?P<0EUIF0`1VIVH;075aL@80LW9b0`1aLG43071`L0<0JFUY0P1SHf<3065QH@<0GemO0`1MGEd204E5
A@<020P8L00000080?ooo`001P3ooomN000000D00P820`0820P300`<30803Ph>0`0B4Q8301XJ6P<0
:BTY0P0n?Sh305IFEP<0IVIV2`1aLG42079bLP<0LG5a0`1`L70306UYJ@80Hf=S0`1QHF4305mOG`<0
GEeM0P15ADD300P827000000203oool000H0oooo0`00000306e]KDX000001@010@43000000<00@41
0`020P8200<30`<01PH60`0820P300X:2P803@d=0`0B4Q8301`L70<09bLW0P0g=cL304=3@`<0CTi>
0`1NGUh206YZJP<0Jf][0`1_Kfl2075aL@<0L71`0`1[Jf/3065QH@80GemO0`1NGUh3071`L0<0GEeM
0P0N7Qic000000P0oooo00060?ooo`<000000`1]KFe:000000D00@410`00000300410@<00P820P03
0`<300H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1Z
JVX306][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1`L70305eMG@807QhNL`00
00080?ooo`001P3oool3000000<0KFe]BP00000500410@<000000`010@4300820P800`<30`061PH3
00P820<02PX:0P0=3@d3018B4P<071`L0`0W9bL203Lg=`<0@d=30`1>CTh305iNGP80JVYZ0`1[Jf/3
06m_K`80LG5a0`1`L70306][J`<0HF5Q0P1OGel305iNGP<0L71`0`1MGEd201hN7W<00000203oool0
00H0ooooD000000500410@<000001P030`<500@410<01@D50`0;2`/2014A4@<05ADE0`00000302HV
9P80<C4a0`0k>c/304E5A@<0CTi>0P1EEED305eMG@<0IfMW0P1^KVh3075aL@<0KFe]0`1ZJVX206e]
K@<0Jf][0`1aLG4304E5AGD00000203oool000H0ooooD000000500410@<000001P030`<500@410<0
1@D50`0;2`/2014A4@<05ADE0`00000302HV9P80<C4a0`0k>c/304E5A@<0CTi>0P1EEED305eMG@<0
IfMW0P1^KVh3075aL@<0KFe]0`1ZJVX206e]K@<0Jf][0`1aLG4304E5AGD00000203oool000H0oooo
D000000800410@P00P820`010@4300H61P<030`<0P0A4A4301LG5`<0@D510`0W9bL2034a<@<0?Cdm
0`17AdL304i>CP80FUYJ0`1XJ6P302l_;`80MGEe0`1kNg/307YjNP<0M7Ad0P1cLg<3075aL@<0GUiN
0`0>3Ph203Xj>RL000000`0E5AE9000000P0oooo00060?oooe00000020010@4800820P<00@410`06
1PH300`<30804A4A0`0G5aL30451@@<09bLW0P0a<C4303dm?@<0AdM70`1>CTh205YJFP<0J6QX0`0_
;bl207EeM@<0Ng]k0`1jNWX307AdM080Lg=c0`1aLG4305iNGP<03Ph>0P0j>SXW000000<05ADEB@00
00080?ooo`001P3ooom@000000P00@4120020P8300410@<01PH60`0<30`2014A4@<05aLG0`11@D43
02LW9`80<C4a0`0m?Cd304M7A`<0CTi>0P1JFUX306QXJ0<0;bl_0P1eMGD307]kN`<0NWYj0`1dM7@2
07=cL`<0LG5a0`1NGUh300h>3P80>SXj9`00000301DE5DT00000203oool000H0oooo?`00000302XZ
:Ph000002`010@4300820P800`<30`051@D300X:2P<03Ph>0P0C4a<301`L70<08R8R0`0X:2P2038b
<P<0?clo0`1;Bd/305ADE080HF5Q0`1^KVh307MgM`80O7al0`1mOGd307]kN`<0MGEe0P1]KFd306MW
I`<0;Bd]N00000080?ooo`001P3ooolo000000<0:RXZ3P00000;00410@<00P820P030`<300D51@<0
2PX:0`0>3Ph201<C4`<071`L0`0R8R8302PX:080<S8b0`0o?cl304];B`<0E5AD0P1QHF4306i^KP<0
MgMg0P1lO7`307emO@<0Ng]k0`1eMGD206e]K@<0IfMW0`0];Beh000000P0oooo00060?ooocl00000
0`0Z:RX>000000/00@410`020P8200<30`<01@D50`0:2PX300h>3P804a<C0`0L71`3028R8P<0:2PX
0P0b<S8303lo?`<0Bd];0`1DE5@2065QH@<0KVi^0`1gMgL207alO0<0OGem0`1kNg/307EeM@80KFe]
0`1WIfL302d];GP00000203oool000H0ooooD000000500410@H000000`0410@2000000<02`/;0`0?
3`l301@D50806QXJ0`0Q8B4302LW9`<0;Bd]0P0f=SH304=3@`<0CDe=0`1IFET206MWI`<0LW9b0`1h
N7P207UiN@<0N7Qh0`1fMWH307alO080KVi^0`19BDT300<30`/000000`0E5AEZ000000P0oooo0006
0?oooe0000001@010@46000000<010@40P00000300/;2`<03`l?0`0D51@201XJ6P<08B4Q0`0W9bL3
02d];@80=SHf0`13@d<304e=C@<0FEUI0P1WIfL3079bLP<0N7Qh0P1iNGT307QhN0<0MWIf0`1lO7`2
06i^KP<0BDU90`030`<;000000<05ADEJP0000080?ooo`001P3oool>000000<0=CDe5P000003034a
<Ah000000P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MW
I`807QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207Ad
M0H0MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3oool>000000<0=CDe5P000003034a<Ah0
00000P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MWI`80
7QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0
MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3oool>000000<0=CDe5P000003034a<Ah00000
0P010@43000000<00@410`0:2PX500820P<010@40`0:2PX200`<30<04A4A0`0F5QH306MWI`807QhN
0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0MgMg
0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`03
0`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:
BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N000
00080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@4103
01DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/3
07IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooom50000
00<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q
8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`
L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooolo000000H00@411@020P8300<30`<0
0P820`010@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0
<S8b0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0
Cdm?0P0>3Phj000000<04A4A@@0000080?ooo`001P3ooolo000000H00@411@020P8300<30`<00P82
0`010@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b
0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?
0P0>3Phj000000<04A4A@@0000080?ooo`001P3ooolo000000H00@411@020P8300<30`<00P820`01
0@4200820P<0EUIF0`0:2PX300`<3080410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b0`0e
=CD20410@0<0CTi>0`1LG5`306QXJ080KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?0P0>
3Phj000000<04A4A@@0000080?ooo`001P3oool>000000<08B4Q<@00000300410@P01@D51P030`<2
00H61P<020P80`0;2`/3014A4@8051@D0`0G5aL301dM7@<0820P0P0S8b<302`/;0<0<C4a0`0l?3`2
04E5A@<0De=C0`1PH60306ATI080IVIV0`1ZJVX306UYJ@80IfMW0`1LG5`305IFEP<0:2PX20000003
07moObH000000`1_Kfm<000000P0oooo00060?ooo`h000000`0Q8B4a000000<00@4120051@D600<3
0`801PH60`0820P300/;2`<04A4A0P0D51@301LG5`<07AdM0`0P820202<S8`<0;2`/0`0a<C4303`l
?080ADE50`1CDe<3061PH0<0I6AT0P1VIVH306YZJP<0JFUY0P1WIfL305aLG0<0EUIF0`0X:2P80000
00<0Ogmo9P00000306m_Kd`00000203oool000H0oooo?`00000300410@<000000`051@D202/[:`<0
1@D50`061PH300T92@80;2`/0`0<30`6010@40804a<C0`0F5QH301dM7@<08R8R0P0T92@302TY:@<0
<30`0`0k>c/204Q8B0<0De=C0`1KFe/306=SH`80GUiN0`1TI6@3065QH@80GUiN0`1EEED30451@@<0
1`L7P00000080?ooo`001P3ooolo000000<00@410`00000300D51@80:b/[0`051@D300H61P<02@T9
0P0/;2`300`<30H0410@0P0C4a<301HF5P<07AdM0`0R8R8202@T90<0:BTY0`0`<30303/k>`80B4Q8
0`1CDe<305]KF`<0Hf=S0P1NGUh306ATI0<0HF5Q0P1NGUh305EEE@<0@D510`071`N0000000P0oooo
00060?ooocl000000`010@43000000<01@D50P0[:b/300D51@<01PH60`092@T202`/;0<030`<1P0@
410201<C4`<05QHF0`0M7Ad3028R8P8092@T0`0Y:BT3030`<0<0>c/k0P18B4P305=CD`<0Fe]K0`1S
Hf<205iNGP<0I6AT0`1QHF4205iNGP<0EEEE0`11@D4300L71h000000203oool000H0oooo2@000002
02XZ:S@000000`030`<300D51@<01PH60P092@T900X:2PD03Ph>0`0@4103014A4@804Q8B0`0G5aL3
01`L70<07QhN0P0R8R8302PX:0<0<C4a0`0n?Sh204Q8B0<0EUIF0`1IFET505aLG0<0FUYJ0`1IFET2
05=CD`<0B4Q80`0H61R3000000P0oooo00060?ooo`T000000P0Z:RXd000000<00`<30`051@D300H6
1P802@T92@0:2PX500h>3P<0410@0`0A4A42018B4P<05aLG0`0L71`301hN7P808R8R0`0X:2P3034a
<@<0?Shn0P18B4P305IFEP<0FEUI1@1LG5`305YJFP<0FEUI0P1CDe<304Q8B0<061PHP`0000080?oo
o`001P3oool900000080:RXZ=000000300<30`<01@D50`061PH200T92@T02PX:1@0>3Ph3010@40<0
4A4A0P0B4Q8301LG5`<071`L0`0N7Qh2028R8P<0:2PX0`0a<C4303hn?P80B4Q80`1FEUH305UIF@D0
G5aL0`1JFUX305UIF@80De=C0`18B4P301PH68<00000203oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000A0002000000020200000203050700000002000004050D
0003150C1425201C21371B000000122A3A32130000060600
0600000B0005040000000000000400000000020000000208
000004010000000B00020001000000030806030004020401
03000000
030400050002000000000004000002000000010000040303
00000D0608252C1A1C2617070B0F11243750544B43322D18
16060000000D0B0000000001000304020000010000000000
00020B0F0900000101020000000000000303040004070202
03000100
020400020002010302000002010003000000020000030206
00010E080D272F261C231E09090A13243137322931362D1D
120000000006090000000000010800000000040400000000
000001010000000600050101000000020504030000020400
03000000
000200000003000401000002010005000000020000020309
00040C09123137251F2C271814141F2D2C1E130514221C19
170E0C0F020A0A0000000000010000000000020801000000
000000000000040500070B08000000020704000100000400
06000200
000400000002000300000200010004000000010000010106
000009060D2F372A2D33322820232D302B1401000006060E
1713141917272525170D0700010907000000040300000000
000000040908060800050D07020000000606000200020500
06000000
010100000001000602000100010403000000020000010105
00020A070E29342A26323E2519131F2D301906000F25201B
1505060A0710141A1C141216161B0D0E06000B0F07020105
040A0F0D0A07040500020404000000050505000000000400
02010000
010500000005000702000100000000000100010600000003
000509080619312F3030422C2C323A3A3E24100319271D2D
2B20222C160D041102050506040C141B1F1A0C040500000B
000300030500051200070400000000040801000200000700
05000000
040100000005021106000500000703000200020900000009
00050C0A13192D3B2323504535293C44441A0D1745735550
2100081C0C050E211F0A0003010A000A110714180A02000C
060E070000000208000000000000000A0804000000000800
02060000
0B0003020002010D03000300000006010000010600000005
00020605130D12271F2C5F6D402D3A3B33150D1B3C695D48
2500070E1115234F54260000000E050B0400142712181105
040002000000090000000002000000060207020000000500
010A0000
00030000000100090300020002010A000100000300010003
000006040E0102172545694E2E24312F2D130A1D2B403C28
1000000D1C2C2430392C1B1B14000008090C19190F130600
00000204040B000700000000000000050205040000000300
00090000
020300020003080601000301000006010000000000010003
0700050006000D4A271B2E3E3426272C24365082859A8E6F
39071631464F50362C1D0D171B0C08050D02081409151206
0000000C183B150D0A030300000000010000080000000000
00090000
0200000A0002060400000004000009000000000200040005
0200000002000019000017392E242D342F5490D6D0D0BB86
39091A334860645B685B413F320B020403040A1409140A01
0000000000140000080000000000000000010E0000000000
000E0004
000000040001050200000205000009010000000000020007
050000000000000F00000029302C36322738689F9391775D
1D103043556C6C58585858565630200D05090F110D110A03
04030300000C0000000000000000000000000A0000000000
0007000B
000100000000050000000004010006060000000000010004
0102020100000008030000021C3240342814100F02000013
153353584E4537453A44574D5644441E0E0100000000020E
050000010000010E00000000000000000200000002000004
00000002
000200000000010000000000010004030000000000000106
0101040201040002050500001122302923160E0500000012
1A374F5349443C3F30323F3740403F29221F130C15111210
050103010000030900000302010000000200000103000002
03000001
000000050000040000000006030008030100000000020203
0502020100110100020B03000515231B191C1C170200070E
1A33454C4B56474D4C6891909D866F4B38321A111D100905
000000000002031500000C0904000000020002000A010007
00000003
000000030000040201000004000101040300000900000000
00040000000306020000100004101509161B1D1C0D0B0C18
1A2939433F3F31556293CAD7E0C9B9A78D73260B20020012
110B0D050001002000000001030000030000000000010007
00000000
030605090000070702000000010004050100000D00000000
000504020000000C13143C03000C1302202C1300000D1C21
321D2839332D2383868D99A1B2DBEBE6CB9A36181E0C090F
0B0000000000062A00000000030000040200000300000300
00020000
04080A000001060600000600000001030000000B00000000
010003000000000B07000100000B0A000D1C0D00000E0E21
24193244535E609B7B6554526BB7DDDFCDA25935221A1408
170B0E070100001100000000030000000000010400020100
03000000
000A10000000000400000600000000000000001E00000003
0000000000000A00080009000416260D1003020C0D0C0E23
1F2D3958647778A9A18E653C2836669BA49D644B4338210F
0E0907000600000D0E060000050001000004040A00080000
00020000
000001000000000201060600010402020600000B00000010
090000000009030000060800151A35240E00001F1E150313
003A5A7A889E86342F66A49E94371A2B5293A3978E693316
000507000009000E0000090405000A020200010002050008
00000202
0000070500000003010006000300060A030000000000000F
0B000B001006000A0000001F20111B1209160D0C21504A4A
466391929D949F7545263F4F7EC59C849DB2E6FFC7B27B2E
1506050000152A03000C2110070012010000000400000000
03000011
000615000000000200000500000000040000001600000001
00000000000000000E0825341E2528100F181B24364F6270
7F8F9EA8AFA6A6D4B3835439387B9BC2D0CFBBBB94855922
140302000D011507030C1607050008000000001200000000
07000008
00000B010000000000000000010704000A00001C00000002
00040000000F0A000025461400000D0B090735637E80938C
8FB6AAB2AFAB8B8092A8ADA5732E1F5C72AEBAB49367220B
000010000000000000000706000006000000001600020000
04040400
000001060006000103000000000703030C00000500000000
0007000000000D000C325F3F31271917213C5E819AA7ACA9
A8B5B2AE9F7A532D1F5088B6B191737F8EB3AAA4885A2A20
08060C150B000F0E00000F06000007050100000700000002
00000300
00000004000A000002000200000100040900000000000000
0001080000000419121331314543291E3A6C8899A2A293A2
9CAEC0BAA87E5828002E77B7D0E0D4C4CCDEB29980543531
1B191A2B1305131700000900000008040100000100000008
01000000
010002000005000000000000000900020200000000000000
000002000005232E23101B162E30212B46667279888E8E9F
A3AEC1B8AE867D7A5B6273969FCED7DBCEAF776B5D443B42
3D3B404D39211C0E01080700000006020000000000000003
00000000
000700000000000000010000001C00010000000000000200
03000200000D2E2D2A1C0000000310365253423F4F4E5D75
88A7BFBEB4888786888E9CB4A5B3C0D4C28B3E30412E355A
595B6B705739170F0907000000000604000000000B050010
00000000
010000000000000201050000002700020000000000000000
00000000000D3236312D360312060730421F061037576E85
93A2BCA8B2818EB1C3A898B49FB8BFD8A750171521162656
797D989A744A1C0004000000000005080000000000000004
00010000
0C0000020000000000020001011600000000000000000000
000000000038451C232F3731110000071D1D1A16243E6669
9095976A8E8B9FD0DBAE889A94D1D2D68027151506030F23
61678F926B36120000000101000000000000000204050000
00020010
040000000003040701000200001000000000000A00000000
000000000055723C19001C2E3025253A463034314F736776
676980706D6F89B5B9ADB0B9BBE6C9C185422A271E010924
4659604B2F110B0000030905010000040200000500020200
06010002
040000040001010401000204010C00000000020100040303
000009050498AB4123151B181C0F1541687E83666E7B674D
40353C29336B919FADAABACAD4FFD8CA844F565336141017
3653684828050000000D0F0B050000030505050900110300
0C000003
000100000003000000000B02000100000000010900060302
0200050000B8E1393A2A1D081A16103972AED0C2A7775F37
261A0202299EB28A93B2B7B8A8B0A7C78C7972502D0B0000
234F6C5C421100000D120B030600000003090E090A2A0302
09000002
000600000006000200001101010005000000010000060009
0D0013010793AB6548362A2D372924416DABCEDDC7B89567
33080E2560D0DE91747A768793A6A1A8827282632D1F0B00
17364C533D350000000308000300000003061200001D0200
00030003
010000000011000401000F00000000000300000000010000
03000900036AA9836A5D81988269404B618CB5D2E0F1E0DB
C29E9798B0D2BF73374B5C8797AEA7AA9087927F492B1406
173035615645170A000D22080000000103000000000B0300
04000000
00030002000D000000000500000402000700010000010000
020009030951824F58737F5C4535132E4B83A5B8CFDFF2EB
FFEFD7C9CEC7A65D2E445B9090A196A49697A19966442216
1623325F55362207000C250D000001010200000400060002
05000200
000402000008060000030200000000020100000000000000
11000400003B819872483A56655E454F3F7494B2B1C3D1D9
E0DCDDE7EBE0CF6A22304B5F7689796876717D967B6C552A
0605003D627E5628133D4C1D04000600000000000A010000
00000002
000502000008000000000200000004000200000000000000
0A0004000A3C737C899CA9A78273606B5A6C7C9DA6C0E2DC
F0E6DFDFF8FCE0A574665963666461615650738A6A664A1F
0C0711586F7243160E193919030000000000000004000000
00000002
000903080000050400000000010905000200010200000503
040405071168AA9193ACB86C423446756768617296D7FFF2
FFEADBE5ECE9EAE7E4C0A7A5959B7688764763947C705432
140B1444707C592516344828080000030208000009000100
00050200
000004020000110300000000000000070000000200000100
09010000006DB2A36D3F55715A4542572F2D354157A3C8CD
E1D8E0DADDD7EEF3DEC6D1C8DDFFC2A17A354C887962552E
1E1A063364846F2611496134110003000000000008000000
0000000B
000006000004090300000000000000040000000A00000000
010200000063BEAD945C8BCBBDB7B1AA79656970728F9DB2
C0D1D9D5CDD6DBEBCECFDAB9C5D2AE916F484B798169623A
1412002E64735F37244E5D2F120000000102000203000200
0200000E
000000040001020000000000000000000000020000010606
010703060070C6B8BCA6B6CEC8CFDAE5BEAF987F767C9298
C2DEDDD4BFCCC9D1B8B7C29EA8B38F6B4D35498294857F4E
0A0200336B7163412A545F34110000000507000213020300
05000006
000000130000030000040009000200000000020000050D0A
0A0909070070C6B3B4AE8B616F728ECDB6CCB49C8D84B086
B7C4B2A39299A795AAA5AE998F884E381F001E728F8C8B65
190E124A84916D393A615A350E000000010A04002E050003
00000800
060005000005010000030000000000000000000C00000000
000100000027C6CDA93C71BEDED2B8C3ABC7DFFAF0C6B0AB
92907D795D4C5A4E46646657454549636A55295F85727F73
3237114F8C8C5D415C71451A070002000000000006060000
00010106
060400000006000000000000000000000000000000000100
00010701000F86C1D4BBDEE8F2F2EFFFF1ECDCF0EEC8C0B4
A9A4A1A79C8D7C6853523128100026424B463256737B8374
2F28287091844738473B220B000000030001000001030300
00030000
000000000000000504000008000A00010100000000010201
12000A0000025DD9CCC6E5C4D1B7C8E1C3A88ABFB3B1AE8A
61506E8BAFB7AB6A738598AAA753443D3C25234E727D7F6E
3B2A3787A1CA51413E251B0D0400010A00000A0005000000
000C0400
060400020001000103000004020006020000000000030202
0E002606100B2EBCC8D9DDD4E1DDE5EEF1D88B72615A5251
5D6DA09CB2B6A07F4F4352709CB8C48D705454616E7F896D
422D509181823F3212010C05010000070200010003000100
00000001
070300000000000100000000030004040000000000000002
02001A0413061378ADD2DFE0D8DBEAE6DB93350A0F131C39
679DD2BDCABEACBE936451506D9EB893705764727B8A8E6C
4B3661897153331B06000806030000050202000000000100
00000007
000000000000000000000000010300000100000000000102
0005070205000D2189D1EDD6C4CDE8E4D1752D161F081930
61B5D4BCC0B699BABAA0856D58425B644A596B7A8E8F8069
443668775E24120B0F000004010000050106000205000000
00000007
000000020001000000000002020105000400000000010000
000205000000000059B3DCE8D5D8DECFCB967B7C6F353036
4EABCBA6B6BE909093A0A8A998606D66417289838C836855
3E38777A4200000002000000000000030000000503060005
00010315
030000070002000000050204000000010000000000000003
00000000000200051A1A41E2ECE7E4CBB2ACCBE3C48D5D59
338BCBA2AEC5C5C2B4B0BCAEBEBCA36738577E94958D7E55
42415D4B1E00000000000001030002000000010500030000
03010134
000000020000000200090002000500030100000100000014
000000000000000903000F7DAAAFD3D1B9A2C0E7E9C8877C
2E71BBB3A09CABA9B3ACB6A2997F5C433C5A718F9C8C7C6A
41444B210000000006000000000006010000050000000000
00030419
000501000000000500060100000400010000000900020225
00000B040000000E110300196482C5CBBA9BA8CDD3B67C79
2C62AFD5C0C5CCB6B2A1946D562E2E355374757E8B84705F
292A2C080000000B070200000000050005020D0000020000
00000000
000C06030000000300030000010704000000000400010320
000011040F0E00010A0D0000132660797C7975809396816B
43568AA29EA3BDBFBA763F1F1032394F64697E927E856C49
28202D0B00000000000200000000070003080D0101000000
01010000
000A02060000000000000500020109000000000000030110
09001501120A0004040D000003081728406E7C898B88785D
413C5A697A898E60401C030E18434E53636F827F565B411E
141020190505000000000000000007000000090001040000
00000001
000002060000000000010200000500000200000000000107
04000900000000000002000008060A172B5460686D615541
35424F504E45461A0B0913272A423D4D67838D94776A4A2E
16131A14090205000107000000000B000000000105010003
00000101
020005100000000001000000000100000200000000000101
0000060000000000000005000101050F2B646D6F69534E29
211F1E1E160A0E0F17181B2C2B484A60788A778273684E33
120308000100080B11110000000009010000020208000002
00010000
060002130000000002000000000000000200000000010303
00000D0303090400000205000000000E2F6B6E5C5B57502A
281F1F160B09161B1D18263D4D877371767C7A886D5D4427
0E040B0000000C0702110704000006020000010606000000
04000001
0701051C0000000000000000000002000200000000030300
020009010200000003151E02000000001C7084877C768246
4422141515171A28332B283B42695C647079718469624219
00000000000113100D140C0801000500000005030A000000
00050000
090007150000000000000000000000000100000000020100
000002000005070000000700000000000D698D90826E7848
4B31180E1520232D302C1F333363687C797D6B6C4B41270C
05000603040001000A0B0501000003000000030909060000
03020005
040001130003000000000004000000000200000000030000
0300020000000300000000080A0800001677ADC4A88A8358
442A1E1D24302516113045656C7574716D76524633251206
000000020000000908050100000001000000030005060006
00020005
0000000E0001030202000005000104000300000300030000
010001000002060500000F0000000000145079988B877D55
300A0B1722312D313E586E8B8E8677756A613A2D200F0102
040003000001000C02000000000000010000060000010000
00070000
0402000E0002040000000004000004000000000300040000
000001000004070200000700000300001E597F9281757457
432422292D38314A505E627272787C78624D190601000000
040004020000000A02000000000000000000050000040000
00040000
080100130000080000000009000005000000000000050200
000201000000000C00000000000809172C6384917A6C7454
482E31312F30315E71747179777D78623F1900000000000D
0B0005040104040D06000000000000000000080007010002
00040001
03000016000005000000000C02000B000000000000050200
06000000000900000000000500000007104C788F70647149
4134362E3B4B4852646E7B868B7D613D1805000001020100
00000204000A04010000050601000000000008000E010005
0004010D
0000000D000007000000000902000B010000000000030100
06000000000D0000000000030002050B04254D6952505F48
403D444553645F6370767E7B7A5C43250900000001020000
00000000000E050200000A0802000000000007000B000003
0003000C
000303010000030000010002000304000100000F00010002
0100000000000B0000010C000000080E00093B7B746D755B
372A274253665D58757E6D5A330000000006000002010000
00000000071300000E0000000000000000030A0001030000
000A0200
00020100000108040001000101030A030000000500000008
00000000080D070B0000000B0606171C0C042148546F6C64
4132495A6064686B6C57463B321E100B0400000600010000
020200000009020000000101000000000002060000000000
00050000
000100000001020100060002020808000100010400010108
000100030D302C00000C0300000004160A0016293E57605D
575A6163606365585B4F4A42342103030000162112090000
00090C030000030000000D09000000000203010500000000
04000300
000500000000030000020002010307020000000300000003
0200000001000000010F040000030F150803183638405051
4E535D676C645A5456504439270404070400000000040003
020002090C12050000000302000000000000030004000001
00010000
000501000000010000020000010104010000000600000103
0001000000090700000D0000000814190D081A2D3132444B
5361656A655C5257584F3E2B160000070300000002030003
000000010601020000000604000000000002010305000000
01000000
000104020000020000050000000000000000000200000000
03000000000C070000000000000F0B080007283626192D36
4862635A5E6260635949301207050C050000000001090700
000000020A0306000003110802000000000201080E040002
05000010
000403000000030000040000000000000000000500000004
010000000007060000000000001016170B18374B443A434A
4A5A6264615F5E625945270B000006070100000000060804
020100000400020000030803000000000002030508030000
03000007
03070203000301000001000001000A000000000000020003
000001010C000000000D000A020C111916203E5A646C7773
6B666F7272665E6256371109000006080100000000000000
020007080000000000000000000000000001020200000000
03010000
030803020003030000000000010007010000000100010004
000002020B060000020E0004000B121A151F3547515C6B6B
6C666D716C5F5962523009000000090A0600000100040301
000000020300070000000401000000000002020300000000
04000000
020604010004030000010000010006010000000000000000
03000000050200000001001006100703000B2C4441475961
68696D6D736D62583B22030000000D060100050600030000
0000000308090A0000000D04000000000000000402000000
04000007
000900000004010000040100010008010000000000010007
010006020B060005030A0000081820251F2031434C50515E
575F727B776C614C301B0500000006010403080100020204
0304060D0400000000000000000000000100010000000000
03000000
000A00000006010000030000010006010000000000010005
000007040C05050C0A1200000314191F1C20314151595E70
70737D8678604E3311030000000000000608090100000003
000000090400060000000300000000000300000100000000
05000000
000600000006040000050002000005030000000000020005
040005020602000B00000000071A18180F25465656525367
67778588765E4B2100000002070508000002030000000001
0000000000000C0000010C02000000000200000104000005
06000000
00050000000A010000000000000004030200000000010000
00040504050002160F10091B25372E221927435458575770
72787C826748260600000003070003000011050000000000
0000000000000E0E00020E03000000000400000200000102
06000000
020300010007000000000001000202010200000000010000
00060405070002080714111216201D24252D414F61636570
7070716C5129160C0000000800000000010500000000000E
000100070100090000000000000000000300000200000100
05000200
02020000000A000201010003000304020300010000010000
00060C080C02102810120F14222822292C31404A616E6172
67616A69491F0A00000000070D0D0600000302000000000D
0004000A00000E0600000300000000020600000000000200
05000200
090000080001000000000000000700010100000300010200
000B01050200040608101714131A2337383C464B62676D65
655F5D512D0001283520070600000006040000010B0C1525
100B09030300110005080001000000010100000400000100
04000200
060100030008000200000000000000000300020800020201
000C070B0A1C290002121D191422242F3B41514761625A60
625D50451600000300010003000000000008050300000005
000000000000000000030101000000010800001000000600
11000200
080000080004000000000002000000000100000000020100
000604040406140A0B15181D171B14212A4255565D57594E
51483B2D160000010000000400050200000000020200030C
000000030100090001060402000000000100000501000100
06000200
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool3000000<02PX:0`00000200820PT000001@020P8600000080
0P820`030`<300D51@<01`L72000000300820PD000000`0410@200D51@<03@d=0`00000300<30`80
5ADE0`0<30`301@D50<09BDU0P0P820301`L70<08B4Q0`0g=cL201/K6`T000000P0B4Q8302XZ:P<0
>SXj0`0b<S8201<C4`H000001@061PH3000000<01PH61@00000300/;2`<000000P051@D300@41140
00000P0410@;000000<00P822000000300820P<020P81@00000300@410<00@412000000300/;2`80
00000`020P83000000<00@412000000300<30`8020P80`061PH300<30`<000000P0410@300820P<0
10@40`010@4200<30`P00000203oool000H0oooo0`00000300X:2P<000000P020P89000000D00P82
1P00000200820P<00`<30`051@D300L71`P000000`020P85000000<010@40P051@D300d=3@<00000
0`030`<201DE5@<030`<0`0D51@302DU9@80820P0`0L71`3024Q8@<0=cLg0P0K6a/9000000804Q8B
0`0Z:RX303Xj>P<0<S8b0P0C4a<6000000D01PH60`00000300H61PD000000`0;2`/3000000801@D5
0`0410@A0000008010@42`00000300820PP000000`020P8300P820D000000`0410@300410@P00000
0`0;2`/2000000<00P820`00000300410@P000000`030`<200P820<01PH60`030`<30000008010@4
0`020P8300@410<00@410P030`<8000000P0oooo00060?ooo`<00`<30`0410@3000000801@D50`00
000300820Ph000000P0410@6000000<00P822000000300410@D000000`0410@500<30`H000000P0=
3@d300H61P<020P80`0U9BD202`/;0<06QXJ0`0L71`302HV9P805aLG0`071`L300/;2`<03`l?0P0A
4A4302@T90<0=cLg0`1@D50205ADE0<0Bd];0`13@d<3038b<P80;Bd]0`0H61P301HF5P801PH62@00
000200d=3@<02`/;2`00000300410@<000000P030`<300@410<00P821@00000300410A4000000P02
0P8300/;2`<03`l?0P092@T6000000D00@410`020P8A000000D00`<30`0410@30000008010@40`07
1`L600820P800`<30`00000300410@800000203oool000H0oooo0`030`<300@410<000000P051@D3
000000<00P823P00000200@410H000000`020P88000000<00@411@00000300@410D00`<31P000002
00d=3@<01PH60`0820P302DU9@80;2`/0`0J6QX301`L70<09RHV0P0G5aL300L71`<02`/;0`0?3`l2
014A4@<092@T0`0g=cL3051@D080E5AD0`1;Bd/304=3@`<0<S8b0P0];Bd301PH60<05QHF0P061PH9
000000803@d=0`0;2`/;000000<00@410`00000200<30`<010@40`020P85000000<00@414@000002
00820P<02`/;0`0?3`l200T92@H000001@010@4300820Q4000001@030`<300@410<000000P0410@3
00L71`H00P820P030`<3000000<00@410P0000080?ooo`001P3oool300<30`<010@40`00000200D5
1@<000000`020P8>0000008010@41P00000300820PP000000`010@45000000<010@41@030`<60000
00803@d=0`061PH300P820<09BDU0P0/;2`301XJ6P<071`L0`0V9RH201LG5`<01`L70`0;2`/300l?
3`804A4A0`0T92@303Lg=`<0D51@0P1DE5@304];B`<0@d=30`0b<S8202d];@<061PH0`0F5QH200H6
1PT000000P0=3@d300/;2`/000000`010@43000000800`<30`0410@300820PD000000`010@4A0000
00800P820`0;2`/300l?3`802@T91P00000500410@<00P824@00000500<30`<010@40`00000200@4
10<01`L71P020P8200<30`<000000`010@42000000P0oooo00060?ooo`<00P820`0410@300000080
0P820`00000300820P<00@410P030`<300820PH000000P020P8300410@<000000`030`<8000000<0
0P821@00000300<30`800P820`061PH3000000<00@410P0>3Ph300P820<03@d=0`0W9bL202l_;`<0
9RHV0`0L71`302<S8`807QhN1P092@T300X:2P804a<C0`0T92@3034a<@<0=cLg0P0b<S8302TY:@<0
<C4a0`0f=SH202d];@<07AdM0`0B4Q8;000000801PH60`092@T>000000<00@410P0820P;000000H0
10@44000000600410@P000000`061PH2000000<01@D51P010@48000000<00P820P051@D300@410<0
0`<31@00000300820P<010@40`00000200<30`P00000203oool000H0oooo0`020P8300@410<00000
0P020P83000000<00P820`010@4200<30`<00P821P00000200820P<00@410`00000300<30`P00000
0`020P85000000<00`<30P020P8300H61P<000000`010@4200h>3P<020P80`0=3@d302LW9`80;bl_
0`0V9RH301`L70<08b<S0P0N7Qh600T92@<02PX:0P0C4a<302@T90<0<C4a0`0g=cL2038b<P<0:BTY
0`0a<C4303Hf=P80;Bd]0`0M7Ad3018B4P/000000P061PH300T92@h000000`010@4200P820/00000
1P0410@@000000H00@412000000300H61P8000000`051@D600410@P000000`020P8200D51@<010@4
0`030`<5000000<00P820`0410@3000000800`<3200000080?ooo`001P3oool300820P<010@40`00
000200820P<000000`020P8300410@800`<30`020P86000000800P820`010@43000000<00`<32000
000300820PD000000`030`<200820P<01PH60`00000300410@803Ph>0`0820P300d=3@<09bLW0P0_
;bl302HV9P<071`L0`0S8b<201hN7PH02@T90`0:2PX201<C4`<092@T0`0a<C4303Lg=`80<S8b0`0Y
:BT3034a<@<0=SHf0P0];Bd301dM7@<04Q8B2`00000200H61P<02@T93P00000300410@8020P82`00
000600@4110000001P010@48000000<01PH60P00000300D51@H00@412000000300820P801@D50`04
10@300<30`D000000`020P8300@410<000000P030`<8000000P0oooo00060?ooo`<000000`020P88
000000<00`<30`00000200@410<00@411P00000200820P<00@410`00000300D51@P000000`020P85
000000<00P820P030`<300T92@<000000`0410@200`<30<02@T90`0B4Q83034a<@80=cLg0`0U9BD3
01lO7`<0;2`/0P0W9bL301PH60H051@D0P0O7al302d];@<0;2`/0`0N7Qh201<C4`<01@D50`0D51@3
028R8P8071`L0`0I6AT301LG5`803Ph>0`0<30`300l?3`<00P821@0:2PX>000000<00@413@000003
00820P<020P80`010@4H000000<010@40`051@D2000000<01`L70`0;2`/300P820P000000`020P82
00L71`<010@40`00000300410@D000000`0410@3000000801PH60`00000300820P800000203oool0
00H0oooo0`00000300820PP000000`030`<30000008010@40`010@46000000800P820`010@430000
00<01@D52000000300820PD000000`020P8200<30`<02@T90`00000300@4108030`<0`092@T3018B
4P<0<C4a0P0g=cL302DU9@<07alO0`0/;2`202LW9`<061PH1P0D51@201lO7`<0;Bd]0`0/;2`301hN
7P804a<C0`051@D301@D50<08R8R0P0L71`301TI6@<05aLG0P0>3Ph300`<30<03`l?0`020P8500X:
2Ph000000`010@4=000000<00P820`0820P300410AP000000`0410@300D51@8000000`071`L300/;
2`<020P82000000300820P801`L70`0410@3000000<00@411@00000300@410<000000P061PH30000
00<00P820P0000080?ooo`001P3oool3000000<010@42000000300820P<000000P030`<6000000<0
0P820P00000300410@<000000`0410@8000000<00@411@00000500410@<01PH61P00000200T92@<0
1PH60`0=3@d302l_;`80=cLg0`0Z:RX302d];@<0<c<c0P0b<S8302PX:0<0820P0`0S8b<202d];@<0
<30`0`0[:b/301@D50800@411P00000500H61P<03Ph>0`0G5aL201<C4`<051@D0`0I6AT301LG5`80
9bLW1P0U9BD301LG5`803@d=0`071`L3000000<00@410P092@T300L71`P000000`0410@300<30a<0
00000`0410@200T92@<020P80`061PH300P8208000000`051@D300d=3@<01`L70P020P89000000D0
1PH60`00000300820P8000000`020P8300D51@<000000P061PH8000000P0oooo00060?ooo`<00000
0`0410@8000000<00P820`00000200<30`H000000`020P82000000<00@410`00000300@410P00000
0`010@45000000D00@410`061PH6000000802@T90`061PH300d=3@<0;bl_0P0g=cL302XZ:P<0;Bd]
0`0c<c<2038b<P<0:2PX0`0P820302<S8`80;Bd]0`0`<30302/[:`<051@D0P010@46000000D01PH6
0`0>3Ph301LG5`804a<C0`0D51@301TI6@<05aLG0P0W9bL602DU9@<05aLG0P0=3@d300L71`<00000
0`010@4200T92@<01`L72000000300@410<00`<34`00000300@410802@T90`0820P300H61P<020P8
0P00000300D51@<03@d=0`071`L200820PT000001@061PH3000000<00P820P00000300820P<01@D5
0`00000200H61PP00000203oool000H0oooo0`00000300@410P000000`020P83000000800`<31P00
000300820P8000000`010@43000000<010@42000000300410@D000001@010@4300H61PH000000P09
2@T300H61P<03@d=0`0_;bl203Lg=`<0:RXZ0`0];Bd303<c<`80<S8b0`0X:2P3020P80<08b<S0P0]
;Bd3030`<0<0:b/[0`0D51@200410@H000001@061PH300h>3P<05aLG0P0C4a<301@D50<06ATI0`0G
5aL202LW9`H09BDU0`0G5aL200d=3@<01`L70`00000300410@802@T90`071`L8000000<010@40`03
0`<C000000<010@40P092@T300P820<01PH60`0820P2000000<01@D50`0=3@d300L71`800P822@00
000500H61P<000000`020P82000000<00P820`051@D3000000801PH6200000080?ooo`001P3oool6
00410@P000000`010@43000000801PH60`020P83000000<00@410P00000300410@<010@40`030`<8
000000<00P821@00000500410@<01@D50`00000300820P802PX:0`071`L300h>3P<0:BTY0P0d=3@3
02XZ:P<09RHV0`0b<S8203hn?P<09BDU0`0I6AT301<C4`807alO0`0];Bd3030`<0<06ATI0P061PH3
000000<03`l?0`0U9BD2020P80<06a/K0`0E5AD200D51@<01PH60`0:2PX300L71`80410@0`0D51@3
01XJ6P<071`L0P0D51@3018B4PH05QHF0P0K6a/300d=3@<03Ph>0`061PH2000000<02`/;0`0?3`l3
00L71`800P820`010@4300D51@<010@40P0:2PX300l?3`<03@d=0P0:2PX300L71`<010@40`051@D2
000000<00P821P0410@8000000P01@D52`00000300@410<000000P020P8300410@D00000203oool0
00H0oooo1P010@48000000<00@410`00000200H61P<00P820`00000300410@8000000`010@4300@4
10<00`<32000000300820PD000001@010@4300D51@<000000`020P8200X:2P<01`L70`0>3Ph302TY
:@80=3@d0`0Z:RX302HV9P<0<S8b0P0n?Sh302DU9@<06ATI0`0C4a<201lO7`<0;Bd]0`0`<30301TI
6@801PH60`00000300l?3`<09BDU0P0P820301/K6`<05ADE0P051@D300H61P<02PX:0`071`L2010@
40<051@D0`0J6QX301`L708051@D0`0B4Q8601HF5P806a/K0`0=3@d300h>3P<01PH60P00000300/;
2`<03`l?0`071`L200820P<00@410`051@D300@410802PX:0`0?3`l300d=3@802PX:0`071`L300@4
10<01@D50P00000300820PH010@42000000800D51@/000000`0410@3000000800P820`010@450000
00P0oooo00060?ooo`H00@412000000300410@<000000P061PH300820P<000000`010@42000000<0
0@410`0410@300<30`P000000`020P85000000D00@410`051@D3000000<00P820P0:2PX300L71`<0
3Ph>0`0Y:BT203@d=0<0:RXZ0`0V9RH3038b<P80?Shn0`0U9BD301TI6@<04a<C0P0O7al302d];@<0
<30`0`0I6AT200H61P<000000`0?3`l302DU9@80820P0`0K6a/301DE5@801@D50`061PH300X:2P<0
1`L70P0@410301@D50<06QXJ0`0L71`201@D50<04Q8B1P0F5QH201/K6`<03@d=0`0>3Ph300H61P80
00000`0;2`/300l?3`<01`L70P020P8300410@<01@D50`0410@200X:2P<03`l?0`0=3@d200X:2P<0
1`L70`0410@300D51@8000000`020P8600@410P0000020051@D;000000<010@40`00000200820P<0
0@411@0000080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<00000
0`010@4=000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P8
0`061PH301TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@
0`030`<301TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@4
0`0A4A4300820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@4
0`051@D5000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P800000
0`071`L300@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D5
200000080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<000000`01
0@4=000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P80`06
1PH301TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@0`03
0`<301TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@40`0A
4A4300820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@40`05
1@D5000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P8000000`07
1`L300@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D52000
00080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<000000`010@4=
000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P80`061PH3
01TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@0`030`<3
01TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@40`0A4A43
00820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@40`051@D5
000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P8000000`071`L3
00@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D520000008
0?ooo`001P3oool300@410<00@412000000300D51@<00P820P0A4A4300H61P<000000`051@D50000
00<01`L70`030`<2000000<00P820`00000300820P802@T92000000300T92@<000000`051@D200`<
30<02PX:0`0C4a<301TI6@80;Bd]0`0k>c/602<S8`80D51@0`15ADD303De=@<0:BTY0P0l?3`604A4
A0<06QXJ0P0=3@d301LG5`<0ADE50`1cLg<205EEE@<0D51@0`0Q8B42000000<020P80`0L71`300`<
30801@D50`0>3Ph3024Q8@<07alO0P0:2PX3000000<00`<30`010@4200X:2P<000000`0:2PX3014A
4@801`L70`0D51@301PH60<02PX:0P020P83000000<030`<0`061PH200h>3P<01`L7200000030082
0P<020P84`00000300X:2P8020P80`0410@;000000<020P80`00000200820P<01PH61@0000080?oo
o`001P3oool300@410<00@412000000300D51@<00P820P0A4A4300H61P<000000`051@D5000000<0
1`L70`030`<2000000<00P820`00000300820P802@T92000000300T92@<000000`051@D200`<30<0
2PX:0`0C4a<301TI6@80;Bd]0`0k>c/602<S8`80D51@0`15ADD303De=@<0:BTY0P0l?3`604A4A0<0
6QXJ0P0=3@d301LG5`<0ADE50`1cLg<205EEE@<0D51@0`0Q8B42000000<020P80`0L71`300`<3080
1@D50`0>3Ph3024Q8@<07alO0P0:2PX3000000<00`<30`010@4200X:2P<000000`0:2PX3014A4@80
1`L70`0D51@301PH60<02PX:0P020P83000000<030`<0`061PH200h>3P<01`L72000000300820P<0
20P84`00000300X:2P8020P80`0410@;000000<020P80`00000200820P<01PH61@0000080?ooo`00
1P3oool300/;2`<000000`030`<200820P<000000`020P8300410@803@d=0`030`<3000000<00`<3
2000000300H61P800@411P00000300410@801PH62000000300D51@<000000`020P8200H61P<01@D5
0`0C4a<300d=3@804Q8B0`0W9bL301lO7`<0;2`/0P1OGel306e]K@<0@4100`0];Bd203Xj>P<0>c/k
0`0c<c<301DE5@803@d=0`0K6a/303`l?0<0JFUY0P1MGEd304Q8B0<09BDU0P00000300L71`<03Ph>
0`0A4A4201DE5@<08b<S0`1?Cdl305ADE0809RHV2@00000200h>3P<01@D50`0;2`/300@410800000
0`0D51@302LW9`<04Q8B0P0H61P3014A4@<01@D50`0410@2000000<00P822000000300T92@/00000
0`020P88000000<01PH60P020P8300L71`<00P822000000300D51@<000000P010@4300X:2PD00000
203oool000H0oooo0`0;2`/3000000<00`<30P020P83000000<00P820`010@4200d=3@<00`<30`00
000300<30`P000000`061PH200410@H000000`010@4200H61PP000000`051@D3000000<00P820P06
1PH300D51@<04a<C0`0=3@d2018B4P<09bLW0`0O7al302`/;080GemO0`1]KFd30410@0<0;Bd]0P0j
>SX303/k>`<0<c<c0`0E5AD200d=3@<06a/K0`0l?3`306UYJ@80GEeM0`18B4P302DU9@8000000`07
1`L300h>3P<04A4A0P0E5AD302<S8`<0Cdm?0`1DE5@202HV9PT000000P0>3Ph300D51@<02`/;0`04
10@2000000<051@D0`0W9bL3018B4P8061PH0`0A4A4300D51@<010@40P00000300820PP000000`09
2@T;000000<00P822000000300H61P800P820`071`L300820PP000000`051@D3000000800@410`0:
2PX5000000P0oooo00060?ooo`<02`/;0`00000300<30`800P820`00000300820P<00@410P0=3@d3
00<30`<000000`030`<8000000<01PH60P010@46000000<00@410P061PH8000000<01@D50`000003
00820P801PH60`051@D301<C4`<03@d=0P0B4Q8302LW9`<07alO0`0/;2`205mOG`<0KFe]0`10@403
02d];@80>SXj0`0k>c/303<c<`<05ADE0P0=3@d301/K6`<0?3`l0`1YJFT205eMG@<0B4Q80`0U9BD2
000000<01`L70`0>3Ph3014A4@805ADE0`0S8b<304m?C`<0E5AD0P0V9RH9000000803Ph>0`051@D3
00/;2`<010@40P00000301@D50<09bLW0`0B4Q8201PH60<04A4A0`051@D300@4108000000`020P88
000000<02@T92`00000300820PP000000`061PH200820P<01`L70`020P88000000<01@D50`000002
00410@<02PX:1@0000080?ooo`001P3oool3000000<00`<32000000300410@<000000P092@T300<3
0`<000000`020P82000000<00P820`010@4300X:2P8000000`010@46000000800`<30`0000030041
0@8000000`030`<6000000801PH60`0410@300h>3P<00@410P020P8301LG5`<09BDU0`15ADD206UY
J@<0CTi>0`0^;Rh302@T9080<C4a0`0_;bl302d];@<04a<C0P0:2PX301dM7@<0:b/[0`10@40203`l
?0<0:2PX0`0@4105000000<03@d=0`0L71`202`/;0<092@T0`0`<30303Ti>@80;2`/1P0K6a/301@D
50D000000`0820P300T92@8030`<1P0I6AT300l?3`804a<C0`061PH8000000<00P821@0410@300/;
2`<000000`071`LC000000<01@D50P020P8300D51@<010@42000000300<30`D000000`092@T50000
00P0oooo00060?ooo`<000000`030`<8000000<00@410`00000200T92@<00`<30`00000300820P80
00000`020P8300410@<02PX:0P00000300410@H000000P030`<3000000<00@410P00000300<30`H0
00000P061PH300@410<03Ph>0`010@4200820P<05aLG0`0U9BD304E5A@80JFUY0`1>CTh302h^;P<0
92@T0P0a<C4302l_;`<0;Bd]0`0C4a<200X:2P<07AdM0`0[:b/30410@080?3`l0`0X:2P3010@40D0
00000`0=3@d301`L7080;2`/0`0T92@3030`<0<0>CTi0P0/;2`601/K6`<051@D1@00000300P820<0
2@T90P0<30`601TI6@<03`l?0P0C4a<300H61PP000000`020P8500@410<02`/;0`00000300L71a<0
00000`051@D200820P<01@D50`0410@8000000<00`<31@00000300T92@D00000203oool000H0oooo
0`00000300<30`P000000`010@43000000802@T90`030`<3000000<00P820P00000300820P<00@41
0`0:2PX2000000<00@411P00000200<30`<000000`010@42000000<00`<31P00000200H61P<010@4
0`0>3Ph300410@800P820`0G5aL302DU9@<0ADE50P1YJFT304i>CP<0;Rh^0`0T92@2034a<@<0;bl_
0`0];Bd301<C4`802PX:0`0M7Ad302/[:`<0@4100P0l?3`302PX:0<0410@1@00000300d=3@<071`L
0P0/;2`302@T90<0<30`0`0i>CT202`/;0H06a/K0`0D51@5000000<020P80`092@T200`<30H06ATI
0`0?3`l201<C4`<01PH62000000300820PD010@40`0;2`/3000000<01`L74`00000300D51@800P82
0`051@D300@410P000000`030`<5000000<02@T91@0000080?ooo`001P3oool300820P<00`<30`00
000200820P<000000`030`<300P820801PH60`010@43000000<00`<30P010@46000000<01PH60P01
0@4>000000<00@410P00000300<30`<01`L70`00000200D51@<000000`061PH3000000803@d=0`1:
BTX302LW9`<06a/K0P0^;Rh303hn?P<0=3@d0`0V9RH202LW9`<0;2`/0`0T92@303Hf=P80D51@0`22
PX8308F5Q@<0VYZJ0P2>SXh306m_K`<0>CTi0P071`L301HF5P<0<C4a0`16ATH204m?C`<0D51@0`0f
=SH302`/;0807AdM0`0=3@d301LG5`<06a/K0P0<30`300P820<01@D50`0=3@d200820P<020P80`0D
51@300T92@805ADE0`0B4Q8300H61PP000000`0<30`201PH60<0>c/k0`0E5AD300d=3@802PX:1P03
0`<;000000<00@411@00000300P8210000000`092@T5000000P0oooo00060?ooo`<00P820`030`<3
000000800P820`00000300<30`<020P80P061PH300410@<000000`030`<200410@H000000`061PH2
00410@h000000`010@42000000<00`<30`071`L3000000801@D50`00000300H61P<000000P0=3@d3
04Y:BP<09bLW0`0K6a/202h^;P<0?Shn0`0d=3@302HV9P809bLW0`0/;2`302@T90<0=SHf0P1@D503
08:2PP<0QHF50`2JVYX208j>SP<0Kfm_0`0i>CT200L71`<05QHF0`0a<C4304I6AP80Cdm?0`1@D503
03Hf=P<0;2`/0P0M7Ad300d=3@<05aLG0`0K6a/200`<30<020P80`051@D300d=3@800P820`0820P3
01@D50<02@T90P0E5AD3018B4P<01PH62000000300`<308061PH0`0k>c/301DE5@<03@d=0P0:2PX6
00<30`/000000`010@45000000<020P84000000300T92@D00000203oool000H0oooo0`020P860000
00802PX:0`00000300820P<01PH60P0410@90000008010@41P00000300T92@/000000P020P830000
00<010@40P00000300D51@<00P822000000300820PD000000`0I6AT6000000805aLG0`0i>CT302h^
;P<092@T0P0];Bd303@d=0<0;bl_0`1DE5@2092@T0<0e]KF1P3@d=020;^k^`<0QXJ60`0i>CT200T9
2@<06QXJ0`0c<c<304Q8B080H61P0`1TI6@305]KF`<0J6QX0P1KFe/30451@@<0?clo0`0b<S8200/;
2`<00P820`0410@300<30`8010@40`0:2PX301@D50<02@T90P0D51@300X:2P<00@413@00000301@D
50H000000P0820PF000000<00@410`0>3Ph@000000<03Ph>0`00000200@410P0oooo00060?ooo`<0
0P821P00000200X:2P<000000`020P8300H61P8010@42@00000200@410H000000`092@T;00000080
0P820`00000300@4108000000`051@D300820PP000000`020P85000000<06ATI1P00000201LG5`<0
>CTi0`0^;Rh302@T9080;Bd]0`0d=3@302l_;`<0E5AD0P2@T9030=KFePH0d=3@0P2k^k/308J6QP<0
>CTi0P092@T301XJ6P<0<c<c0`18B4P2061PH0<0I6AT0`1KFe/306QXJ080Fe]K0`11@D4303lo?`<0
<S8b0P0;2`/300820P<010@40`030`<200@410<02PX:0`0D51@300T92@8051@D0`0:2PX300410@d0
00000`0D51@60000008020P85P00000300410@<03Ph>4000000300h>3P<000000P0410@80?ooo`00
1P3oool300820PH000000P0:2PX3000000<00P820`061PH200@410T000000P0410@6000000<02@T9
2`00000200820P<000000`0410@2000000<01@D50`020P88000000<00P821@00000301TI6@H00000
0P0G5aL303Ti>@<0;Rh^0`0T92@202d];@<0=3@d0`0_;bl305ADE080T92@0`3Fe]H60=3@d080^k^k
0`26QXH303Ti>@802@T90`0J6QX303<c<`<0B4Q80P1PH60306ATI0<0Fe]K0`1XJ6P205]KF`<0@D51
0`0o?cl3038b<P802`/;0`020P8300@410<00`<30P0410@300X:2P<051@D0`092@T201@D50<02PX:
0`010@4=000000<051@D1P00000200P821H000000`010@4300h>3Q0000000`0>3Ph30000008010@4
203oool000H0oooo2@00000200@410<000000`010@4300D51@800P821P00000300820P801@D51P00
000300T92@800@413P00000300820P8000000`071`L300D51A0000000`0?3`l8000000<0:BTY0`0`
<30302`/;080=SHf0`0b<S8302LW9`<0>3Ph0P1XJ6P309nOW`<0Ti>C0`2ATI4207MgM`<0GEeM0`0M
7Ad2010@40<0<30`0`13@d<305EEE@D0K6a/2`1HF5P605IFEP80<30`0`0P820300d=3@<01@D50P09
2@T300l?3`<04A4A0`0=3@d2014A4@<02PX:0`030`<300@410D00`<31@00000300`<324000000`0:
2PX@000000<01`L70`00000200/;2`P0oooo00060?ooo`T000000P0410@3000000<00@410`051@D2
00820PH000000`020P8200D51@H000000`092@T200410@h000000`020P82000000<01`L70`051@D@
000000<03`l?2000000302TY:@<0<30`0`0/;2`203Hf=P<0<S8b0`0W9bL303Ph>080J6QX0`2OWil3
09>CT`<0TI6A0P1gMgL305eMG@<07AdM0P0@4103030`<0<0@d=30`1EEED506a/K0/0F5QH1P1FEUH2
030`<0<0820P0`0=3@d300D51@802@T90`0?3`l3014A4@<03@d=0P0A4A4300X:2P<00`<30`0410@5
00<30`D000000`0<30`Q000000<02PX:4000000300L71`<000000P0;2`/80?ooo`001P3oool90000
008010@40`00000300410@<01@D50P020P86000000<00P820P051@D6000000<02@T90P010@4>0000
00<00P820P00000300L71`<01@D54000000300l?3`P000000`0Y:BT3030`<0<0;2`/0P0f=SH3038b
<P<09bLW0`0h>3P206QXJ0<0WinO0`2CTi<3096AT@80MgMg0`1MGEd301dM7@80410@0`0`<30304=3
@`<0EEEE1@1/K6`;05QHF0H0EUIF0P0`<303020P80<03@d=0`051@D200T92@<03`l?0`0A4A4300d=
3@804A4A0`0:2PX300<30`<010@41@030`<5000000<030`<8@00000300X:2Q0000000`071`L30000
00802`/;203oool000H0oooo0`00000300410@/000000`051@D;0000008010@40`010@43000000D0
1PH63P00000300410@8000000`0410@300410@D00P820`010@48000000<020P80`030`<5000000<0
0P820`0L71`3038b<P80@4100`0d=3@302PX:0<051@D0P0@410300l?3`<00P821@00000301<C4`<0
5ADE0P0c<c<305=CD`<0F5QH0`1>CTh204E5A@<0=cLg0`15ADD303Xj>P80A4A40`1GEeL304e=C@<0
EUIF1@14A4@301hN7P<03Ph>0P010@4;000000<00P820`0>3Ph300D51@D000000`010@45000000<0
0@410`0>3PhF000000800P822@00000200820PH000000`0410@8000000800P82203oool000H0oooo
0`00000300410@/000000`051@D;0000008010@40`010@43000000D01PH63P00000300410@800000
0`0410@300410@D00P820`010@48000000<020P80`030`<5000000<00P820`0L71`3038b<P80@410
0`0d=3@302PX:0<051@D0P0@410300l?3`<00P821@00000301<C4`<05ADE0P0c<c<305=CD`<0F5QH
0`1>CTh204E5A@<0=cLg0`15ADD303Xj>P80A4A40`1GEeL304e=C@<0EUIF1@14A4@301hN7P<03Ph>
0P010@4;000000<00P820`0>3Ph300D51@D000000`010@45000000<00@410`0>3PhF000000800P82
2@00000200820PH000000`0410@8000000800P82203oool000H0oooo0`00000300410@/000000`05
1@D;0000008010@40`010@43000000D01PH63P00000300410@8000000`0410@300410@D00P820`01
0@48000000<020P80`030`<5000000<00P820`0L71`3038b<P80@4100`0d=3@302PX:0<051@D0P0@
410300l?3`<00P821@00000301<C4`<05ADE0P0c<c<305=CD`<0F5QH0`1>CTh204E5A@<0=cLg0`15
ADD303Xj>P80A4A40`1GEeL304e=C@<0EUIF1@14A4@301hN7P<03Ph>0P010@4;000000<00P820`0>
3Ph300D51@D000000`010@45000000<00@410`0>3PhF000000800P822@00000200820PH000000`04
10@8000000800P82203oool000H0oooo0`00000300820P/000000`010@4=000000<00@410`000003
00@410800`<34@00000200410@<01PH61P010@4200@410<00P820`010@4300@4108000000`020P86
00D51@D000000`0A4A43028R8P80<30`0`0Y:BT302<S8`<05QHF0P0>3Ph300D51@P000000`0B4Q83
01XJ6P80=cLg0`1?Cdl305=CD`<0BDU90P14A4@303`l?0<0?clo0`0`<302038b<P<0?clo0`0g=cL5
0410@0<0?clo0`0Y:BT3028R8P807alO0`0C4a<300`<30<05ADE0P0A4A43018B4P<0410@0`051@D2
00410@<00`<30`010@45000000<00`<30`092@T5000000<00`<30`020P8200410@T000000P020P86
000000<00@410P030`<6000000<00P820P030`<6000000800@41203oool000H0oooo0`0000030082
0P/000000`010@4=000000<00@410`00000300@410800`<34@00000200410@<01PH61P010@4200@4
10<00P820`010@4300@4108000000`020P8600D51@D000000`0A4A43028R8P80<30`0`0Y:BT302<S
8`<05QHF0P0>3Ph300D51@P000000`0B4Q8301XJ6P80=cLg0`1?Cdl305=CD`<0BDU90P14A4@303`l
?0<0?clo0`0`<302038b<P<0?clo0`0g=cL50410@0<0?clo0`0Y:BT3028R8P807alO0`0C4a<300`<
30<05ADE0P0A4A43018B4P<0410@0`051@D200410@<00`<30`010@45000000<00`<30`092@T50000
00<00`<30`020P8200410@T000000P020P86000000<00@410P030`<6000000<00P820P030`<60000
00800@41203oool000H0oooo2@00000200D51@H000000`0410@;000000801PH60`030`<3000000<0
20P80P030`<300410@/000001@020P8300<30`<01@D51@020P8300410@<000000`0A4A4200410@<0
00000`020P8300/;2`800`<30`00000300D51@<05ADE0P0S8b<301/K6`<06ATI1@0L71`301LG5`<0
0P820`00000200L71`<03Ph>0`0J6QX203<c<`<0ADE50`1<C4`304];B`80EUIF0`17AdL304e=C@<0
C4a<0P1XJ6P3096AT@<0T92@0`2MWId208J6QP<0Kfm_0`1;Bd/303Ph>080<S8b0`0J6QX3014A4@<0
7AdM0P0@410300T92@<01@D53@00000300820P<00`<30`0E5AD5000000<030`<0`092@T200@410T0
00000P020P83000000<00P820`00000200X:2P<00@410`00000300L71`P000000P030`<80?ooo`00
1P3oool9000000801@D51P00000300@410/000000P061PH300<30`<000000`0820P200<30`<00@41
2`00000500820P<00`<30`051@D500820P<00@410`000003014A4@800@410`00000300820P<02`/;
0P030`<3000000<01@D50`0E5AD202<S8`<06a/K0`0I6AT501`L70<05aLG0`020P83000000801`L7
0`0>3Ph301XJ6P80<c<c0`15ADD304a<C0<0Bd];0P1FEUH304M7A`<0CDe=0`1<C4`206QXJ0<0TI6A
0`2@T90309fMW@80QXJ60`1_Kfl304];B`<0>3Ph0P0b<S8301XJ6P<04A4A0`0M7Ad2010@40<02@T9
0`051@D=000000<00P820`030`<301DE5@D000000`0<30`300T92@8010@42@00000200820P<00000
0`020P83000000802PX:0`010@43000000<01`L72000000200<30`P0oooo00060?ooo`T000000P05
1@D6000000<010@42`00000200H61P<00`<30`00000300P820800`<30`010@4;000000D00P820`03
0`<300D51@D00P820`010@43000000<04A4A0P010@43000000<00P820`0;2`/200<30`<000000`05
1@D301DE5@808b<S0`0K6a/301TI6@D071`L0`0G5aL300820P<000000P071`L300h>3P<06QXJ0P0c
<c<304E5A@<0C4a<0`1;Bd/205IFEP<0AdM70`1=CDd304a<C080J6QX0`2ATI43092@T0<0WIfM0P26
QXH306m_K`<0Bd];0`0h>3P2038b<P<06QXJ0`0A4A4301dM7@80410@0`092@T300D51@d000000`02
0P8300<30`<05ADE1@00000300`<30<02@T90P0410@9000000800P820`00000300820P<000000P0:
2PX300410@<000000`071`L8000000800`<3203oool000H0oooo2@00000200<30`H000000`0410@2
00820P<00@411P00000200@410<000001P010@4200@410<00`<31P00000200T92@h000000`0410@8
000000<00`<30P061PH300820PH000000P0@4103000000<010@40`0@410201DE5@<02@T90`0F5QH3
01/K6`807AdM0`0L71`300d=3@<02`/;0P0<30`301PH60<06QXJ0P0Y:BT303Ti>@<0@d=31@0o?cl3
034a<@<0EEEE0`1RHV8209>CT`<0b/[:0`3GemL30>3Ph080bLW90`2i^KT30:NWY`<0SHf=0P1cLg<3
02HV9P<02`/;0`0P820200820P<000000`0B4Q83014A4@802`/;0`0=3@d300D51@8000000`010@43
000000<0820P2000000300410@800`<31P00000300<30`d000000`010@43000000<01`L72P000008
0?ooo`001P3oool9000000800`<31P00000300@410800P820`010@460000008010@40`0000060041
0@8010@40`030`<6000000802@T93P00000300@410P000000`030`<200H61P<00P821P000002010@
40<000000`0410@3010@40805ADE0`092@T301HF5P<06a/K0P0M7Ad301`L70<03@d=0`0;2`/200`<
30<061PH0`0J6QX202TY:@<0>CTi0`13@d<503lo?`<0<C4a0`1EEED3069RHP80Ti>C0`3:b/X30=OG
e`<0h>3P0P39bLT30;Vi^@<0YjNW0`2=SHd207=cL`<09RHV0`0;2`/3020P80800P820`000003018B
4P<04A4A0P0;2`/300d=3@<01@D50P00000300410@<000000`0P8208000000<00@410P030`<60000
00<00`<33@00000300410@<000000`071`L:000000P0oooo00060?ooo`T000000P030`<6000000<0
10@40P020P8300410@H000000P0410@3000000H00@410P0410@300<30`H000000P092@T>000000<0
10@42000000300<30`801PH60`020P8600000080410@0`00000300@410<0410@0P0E5AD300T92@<0
5QHF0`0K6a/201dM7@<071`L0`0=3@d300/;2`8030`<0`0H61P301XJ6P80:BTY0`0i>CT304=3@`D0
?clo0`0a<C4305EEE@<0HV9R0P2CTi<30<[:bP<0emOG0`3Ph>020<W9b@<0^KVi0`2WYjL308f=S@80
Lg=c0`0V9RH300/;2`<0820P0P020P83000000<04Q8B0`0A4A4200/;2`<03@d=0`051@D2000000<0
0@410`000003020P80P000000`010@4200<30`H000000`030`<=000000<00@410`00000300L71`X0
0000203oool000H0oooo0`030`<300H61P<01@D50P092@T6000000D01`L70`020P88000000<00@41
0`00000300@410801@D50`010@46000000803@d=3P00000300D51@8010@40`020P88000000<030`<
0`0C4a<301@D5080?3`l0`030`<3000000<030`<0P0C4a<300820P<0820P0`0/;2`201<C4`H00000
0`0=3@d201`L70<08B4Q0`0b<S8201dM7@<0:2PX0`0i>CT303<c<`80;Bd]0`0S8b<308>3P`<0QXJ6
0P2=SHd309VIV@<0XJ6Q0`2b/[820=_Kf`<0jn_[0`3Vi^H30<_;b`80VYZJ0`0f=SH301PH60<07QhN
0P0<30`300T92@<03`l?0`0;2`/=000000<01PH60`0Z:RX;000000800`<31P00000300@410800P82
1P00000300<30`D000000`030`<5000000<00P821@0000080?ooo`001P3oool300<30`<01PH60`05
1@D200T92@H000001@071`L300820PP000000`010@43000000<010@40P051@D300410@H000000P0=
3@d>000000<01@D50P0410@300820PP000000`0<30`301<C4`<051@D0P0l?3`300<30`<000000`0<
30`201<C4`<00P820`0P820302`/;0804a<C1P00000300d=3@8071`L0`0Q8B43038b<P807AdM0`0X
:2P303Ti>@<0<c<c0P0];Bd302<S8`<0Ph>30`26QXH208f=S@<0VIVI0`2QXJ430;:b/P80fm_K0`3[
jn/30>KViP<0bl_;0P2JVYX303Hf=P<061PH0`0N7Qh200`<30<02@T90`0?3`l300/;2`d000000`06
1PH302XZ:P/000000P030`<6000000<010@40P020P86000000<00`<31@00000300<30`D000000`02
0P85000000P0oooo00060?ooo`<00`<30`061PH300D51@802@T91P00000500L71`<00P8220000003
00410@<000000`0410@200D51@<00@411P00000200d=3@h000000`051@D200@410<00P8220000003
00`<30<04a<C0`0D51@203`l?0<00`<30`00000300`<30804a<C0`020P83020P80<0;2`/0P0C4a<6
000000<03@d=0P0L71`3024Q8@<0<S8b0P0M7Ad302PX:0<0>CTi0`0c<c<202d];@<08b<S0`23Ph<3
08J6QP80SHf=0`2IVIT30:6QX@<0/[:b0P3Kfm/30>_[j`<0i^KV0`3;bl/209ZJVP<0=SHf0`0H61P3
01hN7P8030`<0`092@T300l?3`<02`/;3@00000300H61P<0:RXZ2`00000200<30`H000000`0410@2
00820PH000000`030`<5000000<00`<31@00000300820PD00000203oool000H0oooo0`0410@300P8
20<02PX:1@00000300410@D01PH61P00000300H61PP000000`010@4200<30`T000000P0;2`/;0000
00<00@410`00000200<30`/000000`0;2`/300L71`<000000P010@46000000<02`/;0P0:2PX30000
00<03@d=0`0L71`200d=3@H000001@0>3Ph3024Q8@<092@T0P0I6AT3038b<P<0A4A40`1CDe<205iN
GP<0H61P0`2KVi/307]kN`80IFEU0`1DE5@3059BDP<0Jf][0P2g]kL30=gMg@<0gmoO0`3=cLd20::R
XP<0FEUI0`0e=CD3028R8P806QXJ0`0D51@300P820<05aLG0P0;2`/300h>3P<01`L70P010@460000
00<04A4A2`00000200<30`h000000`010@4300@4108000000`020P8300410@<000000P030`<80000
00P0oooo00060?ooo`<010@40`0820P300X:2PD000000`010@4500H61PH000000`061PH8000000<0
0@410P030`<9000000802`/;2`00000300410@<000000P030`<;000000<02`/;0`071`L300000080
0@411P00000300/;2`802PX:0`00000300d=3@<071`L0P0=3@d6000000D03Ph>0`0Q8B4302@T9080
6ATI0`0b<S8304A4A0<0De=C0P1NGUh3061PH0<0Vi^K0`1kNg/206EUI@<0E5AD0`1BDU8306][J`80
]kNg0`3MgMd30=oOg`<0cLg=0P2RXZ8305UIF@<0=CDe0`0R8R8201XJ6P<051@D0`0820P301LG5`80
2`/;0`0>3Ph300L71`800@411P000003014A4@/000000P030`<>000000<00@410`0410@2000000<0
0P820`010@43000000800`<3200000080?ooo`001P3oool3000000<02PX:0`0@410;0000008010@4
1P00000300H61QH000000P0N7Qh8000000<00`<34@00000200X:2P<000000`0820P3000000802@T9
0`00000300@410<05QHF0P0V9RH300d=3@<0410@0`030`<200820P<030`<0`0=3@d300`<30803Ph>
0`0S8b<301lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1gMgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU
0`0l?3`302PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2MWId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q
0`0?3`l300h>3P802@T90`071`L3000000801PH61P00000300d=3@803Ph>0`061PH6000000801@D5
0`00000300410@D000001P0410@300X:2P8000000`0820P8000000<00P821@0000080?ooo`001P3o
ool3000000<02PX:0`0@410;0000008010@41P00000300H61QH000000P0N7Qh8000000<00`<34@00
000200X:2P<000000`0820P3000000802@T90`00000300@410<05QHF0P0V9RH300d=3@<0410@0`03
0`<200820P<030`<0`0=3@d300`<30803Ph>0`0S8b<301lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1g
MgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU0`0l?3`302PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2M
WId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q0`0?3`l300h>3P802@T90`071`L3000000801PH61P00
000300d=3@803Ph>0`061PH6000000801@D50`00000300410@D000001P0410@300X:2P8000000`08
20P8000000<00P821@0000080?ooo`001P3oool3000000<02PX:0`0@410;0000008010@41P000003
00H61QH000000P0N7Qh8000000<00`<34@00000200X:2P<000000`0820P3000000802@T90`000003
00@410<05QHF0P0V9RH300d=3@<0410@0`030`<200820P<030`<0`0=3@d300`<30803Ph>0`0S8b<3
01lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1gMgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU0`0l?3`3
02PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2MWId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q0`0?3`l3
00h>3P802@T90`071`L3000000801PH61P00000300d=3@803Ph>0`061PH6000000801@D50`000003
00410@D000001P0410@300X:2P8000000`0820P8000000<00P821@0000080?ooo`001P3oool60000
00<00@412`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;
2`P000000`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ
6P80=CDe0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJ
FP<0NWYj0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ
6P<0:b/[0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L7
1`D000000`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P830000
00<00@410`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<0
0@412`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;2`P0
00000`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ6P80
=CDe0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJFP<0
NWYj0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ6P<0
:b/[0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L71`D0
00000`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P83000000<0
0@410`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<00@41
2`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;2`P00000
0`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ6P80=CDe
0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJFP<0NWYj
0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ6P<0:b/[
0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L71`D00000
0`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P83000000<00@41
0`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<01`L70P05
1@D9000000800`<30`010@43000000<01PH60P00000300<30`<000000`061PH200X:2P<00`<34000
000300l?3`<02`/;0`00000200/;2`<000000`0@410300H61P8000000`0:2PX8000000<07alO0`0P
8203014A4@806a/K0`0B4Q8300T92@<05QHF0P0=3@d300`<30<08B4Q0`1@D50504Y:BP<0ATI60P1S
Hf<3096AT@<0TY:B0`2MWId209BDU0<0WinO0`1eMGD304E5A@809RHV0`0o?cl304m?C`<0OWin0P35
aLD309bLW0<0Q8B40`2MWId20;:b/P<0i^KV0`3oool30<O7a`80/[:b0`1kNg/302h^;P<05ADE0P06
1PH300D51@D000000`0E5AD302XZ:P<00`<30P00000300`<30<08B4Q0`0@410200L71`<000000`0B
4Q8300410@P000000`0410@;000000800`<31P000002014A4@P0oooo00060?ooo`H000000`071`L2
00D51@T000000P030`<300410@<000000`061PH2000000<00`<30`00000300H61P802PX:0`030`<@
000000<03`l?0`0;2`/3000000802`/;0`000003010@40<01PH60P00000300X:2PP000000`0O7al3
020P80<04A4A0P0K6a/3018B4P<02@T90`0F5QH200d=3@<030`<0`0Q8B43051@D0D0BTY:0`16ATH2
06=SH`<0TI6A0`2BTY8309fMW@80U9BD0`2OWil307EeM@<0ADE50P0V9RH303lo?`<0Cdm?0`1nOWh2
0<G5a@<0W9bL0`24Q8@309fMW@80/[:b0`3Vi^H30?ooo`<0alO70P2b/[8307]kN`<0;Rh^0`0E5AD2
00H61P<01@D51@00000301DE5@<0:RXZ0`030`<2000000<030`<0`0Q8B43010@40801`L70`000003
018B4P<00@412000000300@410/000000P030`<6000000804A4A203oool000H0oooo0`00000300H6
1P<05ADE2`00000200820PH000000`051@D;0000008010@42@00000201HF5PP000000`010@4F0000
00<03Ph>0`0820P202DU9@<0=3@d0`0N7Qh302DU9@80:2PX0`0@410300l?3`<061PH0P0K6a/302@T
90<0=SHf0`1?Cdl2069RHP<0L71`0`1oOgl208n?S`<0WYjN0`2XZ:P30:n_[`D0YZJV0`3De=@30;>c
/`80Ph>30`1DE5@303Ti>@<0>3Ph0P1kNg/309^KV`<0`/;20`3@d=020<o?c`H0^k^k0`2DU9@208F5
Q@<0FEUI0`0R8R8301@D50800`<30`020P83000000803@d=0`010@4301DE5@<01`L70P030`<300`<
30<05QHF0`071`L200D51@<000000`0820P;000000<04Q8B2`00000200L71`H000000P0820P80?oo
o`001P3oool3000000<01PH60`0E5AD;000000800P821P00000300D51@/000000P0410@900000080
5QHF2000000300410AH000000`0>3Ph300P820809BDU0`0d=3@301hN7P<09BDU0P0X:2P3010@40<0
3`l?0`0H61P201/K6`<092@T0`0f=SH304m?C`80HV9R0`1`L70307moO`80Shn?0`2NWYh30:RXZ0<0
[jn_1@2VYZH30=CDe0<0/k>c0P23Ph<305ADE0<0>CTi0`0h>3P207]kN`<0Vi^K0`32`/830=3@d080
clo?1P2k^k/309BDU080QHF50`1IFET3028R8P<051@D0P030`<300820P<000000P0=3@d300410@<0
5ADE0`071`L200<30`<030`<0`0F5QH300L71`801@D50`00000300P820/000000`0B4Q8;00000080
1`L71P00000200P820P0oooo00060?ooo`<000000`061PH301DE5@/000000P020P86000000<01@D5
2`00000200@410T000000P0F5QH8000000<00@415P00000300h>3P<020P80P0U9BD303@d=0<07QhN
0`0U9BD202PX:0<0410@0`0?3`l301PH60806a/K0`0T92@303Hf=P<0Cdm?0P1RHV83071`L0<0Ogmo
0P2?Shl309jNWP<0Z:RX0`2_[jl50:JVYP<0e=CD0`2c/k<208>3P`<0E5AD0`0i>CT303Ph>080Ng]k
0`2KVi/30<;2`P<0d=3@0P3?cll60;^k^`<0U9BD0P25QHD305UIF@<08R8R0`0D51@200<30`<00P82
0`00000200d=3@<00@410`0E5AD300L71`800`<30`0<30`301HF5P<01`L70P051@D3000000<020P8
2`000003018B4P/000000P071`L60000008020P8203oool000H0oooo1P00000300/;2`800@415P00
000300410@<01`L70`0410@2000000<02PX:1P00000201`L70P000000`020P83000000<010@42000
000300l?3`802PX:1P00000302DU9@80ATI60`0D51@6000000803@d=0`0;2`/300T92@<01`L70P0e
=CD306=SH`<0OWin0`20P80209>CT`<0S8b<0`2?Shl20;Jf]P<0ZZZZ0`2b/[830:n_[`80Zj^[0`2;
Rh/30820P0<0TY:B0P2XZ:P30:f][@<0YJFU0`1cLg<202h^;P<07alO0`1LG5`3079bLP80[Zj^0`2j
^[X30;Bd]0<0Ti>C0P1WIfL3028R8P<02`/;1@000003010@41<000000`071`L300H61PD000000`06
1PH;000000<05QHF0P00000300820PH00000200410@2000000P0oooo00060?ooo`H000000`0;2`/2
00410AH000000`010@4300L71`<010@40P00000300X:2PH000000P0L71`8000000<00P820`000003
00@410P000000`0?3`l200X:2PH000000`0U9BD204I6AP<051@D1P00000200d=3@<02`/;0`092@T3
00L71`80=CDe0`1SHf<307inOP<0P8200P2CTi<308b<S0<0Shn?0P2f][H30:ZZZP<0/[:b0`2_[jl2
0:^[Z`<0Rh^;0`20P80309:BTP80Z:RX0`2][Jd30:FUY@<0Lg=c0P0^;Rh301lO7`<0G5aL0`1bLW82
0:j^[P<0^[Zj0`2d];@309>CT`80IfMW0`0R8R8300/;2`D000000`0@410C000000<01`L70`061PH5
000000<01PH62`00000301HF5P8000000`020P86000000P010@40P0000080?ooo`001P3oool60000
00<02`/;0P010@4F000000<00@410`071`L300@4108000000`0:2PX60000008071`L200000030082
0P<000000`0410@8000000<03`l?0P0:2PX6000000<09BDU0P16ATH301@D50H000000P0=3@d300/;
2`<02@T90`071`L203De=@<0Hf=S0`1nOWh30820P080Ti>C0`2<S8`308n?S`80][Jf0`2ZZZX30;:b
/P<0[jn_0P2[Zj/308^;R`<0P8200`2BTY820:RXZ0<0[Jf]0`2UYJD307=cL`80;Rh^0`0O7al305aL
G0<0LW9b0P2^[Zh30;Zj^P<0];Bd0`2CTi<206MWI`<08R8R0`0;2`/5000000<0410@4`00000300L7
1`<01PH61@00000300H61P/000000`0F5QH2000000<00P821P00000800@410800000203oool000H0
oooo1P00000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<0
30`<1P00000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0
<C4a0`0W9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0
Z:RX0P2e]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0
/K6a0P2ATI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<0
20P80P061PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<0
1`L70`051@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo
1P00000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<030`<
1P00000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0<C4a
0`0W9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0Z:RX
0P2e]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0/K6a
0P2ATI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<020P8
0P061PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<01`L7
0`051@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo1P00
000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<030`<1P00
000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0<C4a0`0W
9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0Z:RX0P2e
]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0/K6a0P2A
TI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<020P80P06
1PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<01`L70`05
1@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo2@000002
00@410<000000`0:2PX5000000<00P820`00000300820PD000000`010@430000008010@40`092@TF
000000<00@410P0820P90000008010@40`0I6AT3018B4P<04a<C1@0a<C4304E5A@<0@d=30P0Y:BT3
01hN7P<0>SXj0`1/K6`208R8R0<0VIVI1P2RXZ8209>CT`<0XZ:R0`2LW9`20:j^[P<0`<300`2j^[X3
0:RXZ080OWin0`1HF5P302PX:0<000000P0^;Rh307MgM`<0]kNg0`3@d=020>3Ph0<0e=CD0`34a<@3
0<c<c080g]kN0`2b/[8309VIV@<0P8200P1DE5@303De=@<0<C4a0`0K6a/201TI6@<06QXJ0`0[:b/2
01<C4`<01@D50`0C4a<301LG5`D000000`092@T8000000<020P80`0410@200410@H000000`010@48
000000<020P80P010@48000000P0oooo00060?ooo`T000000P0410@3000000<02PX:1@0000030082
0P<000000`020P85000000<00@410`00000200@410<02@T95P00000300410@8020P82@00000200@4
10<06ATI0`0B4Q8301<C4`D0<C4a0`15ADD304=3@`80:BTY0`0N7Qh303Xj>P<0K6a/0P28R8P309VI
V@H0XZ:R0P2CTi<30::RXP<0W9bL0P2^[Zh30<30`0<0^[Zj0`2XZ:P207inOP<0F5QH0`0X:2P30000
0080;Rh^0`1gMgL30;Ng]`<0d=3@0P3Ph>030=CDe0<0a<C40`3<c<`20=kNgP<0/[:b0`2IVIT30820
P080E5AD0`0e=CD3034a<@<06a/K0P0I6AT301XJ6P<0:b/[0P0C4a<300D51@<04a<C0`0G5aL50000
00<02@T92000000300P820<010@40P010@46000000<00@412000000300P820800@41200000080?oo
o`001P3oool300410@<000000`020P85000000<01@D54`00000300T92@<000001@020P8I00000080
0P821P00000300D51@808b<S0`0^;Rh302<S8`<0410@0P0K6a/301HF5P<0;Rh^0`0`<302024Q8@<0
:b/[0`16ATH306IVIP80LW9b0`1iNGT308R8R0D0SXj>0`2OWil30:>SX`80[Zj^0`31`L430;Rh^0<0
[Zj^0P26QXH307emO@<0NWYj0`1KFe/2069RHP<0Lg=c0`2FUYH309nOW`80c/k>0`3GemL30=_Kf`<0
c/k>0P2_[jl307MgM`<0Jf][0`1MGEd204A4A0<0>c/k0`12@T8303dm?@80>c/k0`10@40304e=C@80
>CTi0`0Q8B4301`L70<03Ph>0P010@4300P820<01`L72000000300H61P<00P824`00000300<30`X0
0000203oool000H0oooo0`010@43000000<00P821@00000300D51A<000000`092@T3000000D00P82
6@00000200820PH000000`051@D202<S8`<0;Rh^0`0S8b<3010@40806a/K0`0F5QH302h^;P<0<30`
0P0Q8B4302/[:`<0ATI60`1VIVH2079bLP<0NGUi0`28R8P508j>SP<0WinO0`2SXj<20:j^[P<0`L71
0`2h^;P30:j^[P80QXJ60`1mOGd307YjNP<0Fe]K0P1RHV8307=cL`<0UYJF0`2OWil20<k>cP<0emOG
0`3Kfm/30<k>cP80[jn_0`1gMgL306][J`<0GEeM0P14A4@303/k>`<0@T920`0m?Cd203/k>`<0@410
0`1=CDd203Ti>@<08B4Q0`0L71`300h>3P800@410`0820P300L71`P000000`061PH300820Q<00000
0`030`<:000000P0oooo00060?ooo`<00@410`00000300820PD000000`051@DC000000<02@T90`00
000500820QT000000P020P86000000<01@D50P0S8b<302h^;P<08b<S0`0@410201/K6`<05QHF0`0^
;Rh3030`<0808B4Q0`0[:b/304I6AP<0IVIV0P1bLW8307UiN@<0R8R81@2>SXh309nOW`<0Xj>S0P2^
[Zh30<71`@<0^;Rh0`2^[Zh208J6QP<0OGem0`1jNWX305]KF`80HV9R0`1cLg<309JFUP<0WinO0P3>
c/h30=OGe`<0fm_K0`3>c/h20:n_[`<0MgMg0`1[Jf/305eMG@80A4A40`0k>c/30492@P<0?Cdm0P0k
>c/30410@0<0CDe=0P0i>CT3024Q8@<071`L0`0>3Ph200410@<020P80`071`L8000000<01PH60`02
0P8C000000<00`<32P0000080?ooo`001P3oool3000000<01`L74`00000300410@P000000`0L71`3
000000800@414@00000200820P<000000`030`<3000000800P821P00000300d=3@80;Rh^0`0];Bd3
02XZ:P<071`L2000000300<30`80410@0`0f=SH3059BDP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh2
05eMG@<0MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd]080R8R80`27QhL308J6QP<0R8R80P2>SXh3
09bLW0<0];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh3
03De=@<0FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MGE`<0>CTi0`0G5aL300l?3`802@T90`071`L;
000000<01PH60`0410@;000000802`/;0`051@D3000000<0410@2P0000080?ooo`001P3oool30000
00<01`L74`00000300410@P000000`0L71`3000000800@414@00000200820P<000000`030`<30000
00800P821P00000300d=3@80;Rh^0`0];Bd302XZ:P<071`L2000000300<30`80410@0`0f=SH3059B
DP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh205eMG@<0MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd
]080R8R80`27QhL308J6QP<0R8R80P2>SXh309bLW0<0];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2
`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh303De=@<0FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MG
E`<0>CTi0`0G5aL300l?3`802@T90`071`L;000000<01PH60`0410@;000000802`/;0`051@D30000
00<0410@2P0000080?ooo`001P3oool3000000<01`L74`00000300410@P000000`0L71`300000080
0@414@00000200820P<000000`030`<3000000800P821P00000300d=3@80;Rh^0`0];Bd302XZ:P<0
71`L2000000300<30`80410@0`0f=SH3059BDP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh205eMG@<0
MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd]080R8R80`27QhL308J6QP<0R8R80P2>SXh309bLW0<0
];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh303De=@<0
FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MGE`<0>CTi0`0G5aL300l?3`802@T90`071`L;000000<0
1PH60`0410@;000000802`/;0`051@D3000000<0410@2P0000080?ooo`001P3oool300410A400000
0P020P8300410@<01@D52000000302LW9`<000000P020P8T000000<03@d=0P0b<S8303Hf=P<0<C4a
0`0];Bd203Hf=P<00`<30`0B4Q8300H61P801`L70`0`<3030492@P<07alO0P061PH3010@40<0=cLg
0`1GEeL206i^KP<0QHF50`2CTi<20::RXP<0_;bl0`2XZ:P30;:b/P80PH610`2>SXh30;6a/@<0`l?3
0P2XZ:P309RHV0<0];Bd0`2OWil20;Rh^0<0_kno0`3Hf=P30:NWY`80D51@0`0G5aL301DE5@<08B4Q
0P0F5QH302HV9P<0EUIF0`1iNGT207emO@<0V9RH0`2JVYX207AdM0<0BTY:0`0L71`30000008010@4
3P00000300D51@<020P84`00000300@4108000000`010@45000000P0oooo00060?ooo`<00@414@00
000200820P<00@410`051@D8000000<09bLW0`00000200820R@000000`0=3@d2038b<P<0=SHf0`0a
<C4302d];@80=SHf0`030`<3018B4P<01PH60P071`L3030`<0<0@T920`0O7al200H61P<0410@0`0g
=cL305MGE`80KVi^0`25QHD309>CT`80XZ:R0`2l_;`30:RXZ0<0/[:b0P21PH4308j>SP<0/K6a0`33
`l<20:RXZ0<0V9RH0`2d];@309nOW`80^;Rh0`2o_kl30=SHf0<0YjNW0P1@D50301LG5`<05ADE0`0Q
8B4201HF5P<09RHV0`1FEUH307UiN@80OGem0`2HV9P309ZJVP80M7Ad0`1:BTX301`L70<000000P04
10@>000000<01@D50`0820PC000000<010@40P00000300410@D00000203oool000H0oooo0`0<30`6
000000800P823P00000300820P<000001@010@4301HF5RT000000`0h>3P204E5A@<071`L0`0S8b<3
02l_;`80=cLg0`0a<C43014A4@D000000`071`L601dM7@806QXJ0`0F5QH302@T90<0?Shn0P1VIVH3
06UYJ@<0T92@0P2EUID309NGU`<0JVYZ0`2>SXh208^;R`<0WinO0`3@d=030=_Kf`80[Zj^0`28R8P3
09ZJVP<0U9BD0P3AdM430=;BdP<0e]KF0`20P80202LW9`H05ADE0`061PH200<30`<03`l?0`0S8b<3
065QH@80IfMW0`2?Shl309:BTP80Jf][0`0f=SH3018B4PP000001P010@4C000000<00P820P0410@3
00D51@P000000`020P8300000080410@203oool000H0oooo0`0<30`6000000800P823P0000030082
0P<000001@010@4301HF5RT000000`0h>3P204E5A@<071`L0`0S8b<302l_;`80=cLg0`0a<C43014A
4@D000000`071`L601dM7@806QXJ0`0F5QH302@T90<0?Shn0P1VIVH306UYJ@<0T92@0P2EUID309NG
U`<0JVYZ0`2>SXh208^;R`<0WinO0`3@d=030=_Kf`80[Zj^0`28R8P309ZJVP<0U9BD0P3AdM430=;B
dP<0e]KF0`20P80202LW9`H05ADE0`061PH200<30`<03`l?0`0S8b<3065QH@80IfMW0`2?Shl309:B
TP80Jf][0`0f=SH3018B4PP000001P010@4C000000<00P820P0410@300D51@P000000`020P830000
0080410@203oool000H0oooo0`0<30`6000000800P823P00000300820P<000001@010@4301HF5RT0
00000`0h>3P204E5A@<071`L0`0S8b<302l_;`80=cLg0`0a<C43014A4@D000000`071`L601dM7@80
6QXJ0`0F5QH302@T90<0?Shn0P1VIVH306UYJ@<0T92@0P2EUID309NGU`<0JVYZ0`2>SXh208^;R`<0
WinO0`3@d=030=_Kf`80[Zj^0`28R8P309ZJVP<0U9BD0P3AdM430=;BdP<0e]KF0`20P80202LW9`H0
5ADE0`061PH200<30`<03`l?0`0S8b<3065QH@80IfMW0`2?Shl309:BTP80Jf][0`0f=SH3018B4PP0
00001P010@4C000000<00P820P0410@300D51@P000000`020P8300000080410@203oool000H0oooo
0`0410@;000000<00`<30`0410@200L71`<00@410`00000300820PD000000`0@410>000000802PX:
6@00000305EEE@80LW9b0`0l?3`301TI6@<000000P0L71`302h^;P<0<30`1@0U9BD303Xj>P<0ATI6
0`0`<30203@d=0<0<C4a0`1?Cdl307=cL`80IfMW0`1fMWH306MWI`80JFUY0`20P803071`L0<0KFe]
0P1_Kfl308V9R@<0]KFe0`2i^KT20:f][@<0/;2`0`2i^KT30;^k^`80i^KV0`39bLT30<71`@<0QHF5
0P12@T8302XZ:P<09bLW0`0N7Qh200410@<02@T90`0T92@304I6AP80FEUI0`1PH60304];B`80;bl_
0`0A4A4300/;2`D000000`030`<300T92@<01@D50P010@46000000<010@40P020P86000000<01@D5
0P00000600820P<000000P061PH300410@<000000P020P880?ooo`001P3oool300@410/000000`03
0`<300@410801`L70`010@43000000<00P821@000003010@40h000000P0:2PXI000000<0EEEE0P1b
LW8303`l?0<06ATI0`00000201`L70<0;Rh^0`0`<30502DU9@<0>SXj0`16ATH3030`<080=3@d0`0a
<C4304m?C`<0Lg=c0P1WIfL307IfMP<0IfMW0P1YJFT30820P0<0L71`0`1]KFd206m_K`<0RHV90`2e
]KD30;Vi^@80[Jf]0`2`/;030;Vi^@<0^k^k0P3Vi^H30<W9b@<0`L710`25QHD20492@P<0:RXZ0`0W
9bL301hN7P800@410`092@T302@T90<0ATI60P1IFET3061PH0<0Bd];0P0_;bl3014A4@<02`/;1@00
000300<30`<02@T90`051@D200410@H000000`0410@200820PH000000`051@D2000000H00P820`00
000200H61P<00@410`00000200820PP0oooo00060?ooo`<010@42`00000300<30`<010@40P071`L3
00410@<000000`020P85000000<0410@3P00000200X:2QT000000`1EEED2079bLP<0?3`l0`0I6AT3
0000008071`L0`0^;Rh3030`<0D09BDU0`0j>SX304I6AP<0<30`0P0d=3@3034a<@<0Cdm?0`1cLg<2
06MWI`<0MWIf0`1WIfL206UYJ@<0P8200`1`L70306e]K@80Kfm_0`29RHT30;Fe]@<0^KVi0P2][Jd3
0;2`/0<0^KVi0`2k^k/20>KViP<0bLW90`31`L4308F5Q@80@T920`0Z:RX302LW9`<07QhN0P010@43
00T92@<092@T0`16ATH205UIF@<0H61P0`1;Bd/202l_;`<04A4A0`0;2`/5000000<00`<30`092@T3
00D51@800@411P00000300@410800P821P00000300D51@8000001P020P83000000801PH60`010@43
000000800P82203oool000H0oooo0`0410@60000008010@40`00000600410@8010@40`010@430000
00<00P820P0410@300410@<030`<2`00000300820P800@410`00000300@410D00`<31P00000200T9
2@<01@D50`0410@309RHV080Zj^[0`11@D4302<S8`<05ADE0P0K6a/301PH60<071`L0`0?3`l201DE
5@<0@D510`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l
?0<0:BTY0`0c<c<206][J`<0TI6A0`2OWil30:f][@80ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SH
f0<0b/[:0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P8051@D0`0@410301LG5`<0=SHf0P1CDe<306QX
J0<0B4Q80P0X:2P300D51@P000000`0=3@d300l?3`<02`/;0P051@D6000000<00`<320051@D300T9
2@8000000`0A4A4300<30`<000000P0<30`6000000800`<3203oool000H0oooo0`0410@600000080
10@40`00000600410@8010@40`010@43000000<00P820P0410@300410@<030`<2`00000300820P80
0@410`00000300@410D00`<31P00000200T92@<01@D50`0410@309RHV080Zj^[0`11@D4302<S8`<0
5ADE0P0K6a/301PH60<071`L0`0?3`l201DE5@<0@D510`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0
Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l?0<0:BTY0`0c<c<206][J`<0TI6A0`2OWil30:f][@80
ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SHf0<0b/[:0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P80
51@D0`0@410301LG5`<0=SHf0P1CDe<306QXJ0<0B4Q80P0X:2P300D51@P000000`0=3@d300l?3`<0
2`/;0P051@D6000000<00`<320051@D300T92@8000000`0A4A4300<30`<000000P0<30`600000080
0`<3203oool000H0oooo0`0410@60000008010@40`00000600410@8010@40`010@43000000<00P82
0P0410@300410@<030`<2`00000300820P800@410`00000300@410D00`<31P00000200T92@<01@D5
0`0410@309RHV080Zj^[0`11@D4302<S8`<05ADE0P0K6a/301PH60<071`L0`0?3`l201DE5@<0@D51
0`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l?0<0:BTY
0`0c<c<206][J`<0TI6A0`2OWil30:f][@80ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SHf0<0b/[:
0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P8051@D0`0@410301LG5`<0=SHf0P1CDe<306QXJ0<0B4Q8
0P0X:2P300D51@P000000`0=3@d300l?3`<02`/;0P051@D6000000<00`<320051@D300T92@800000
0`0A4A4300<30`<000000P0<30`6000000800`<3203oool000H0oooo0`00000300410@P000000`03
0`<;000000<02`/;0P020P83000000<00@412`00000300410@802@T90`00000300H61P800`<31P02
0P83000000801@D51P0000030;Rh^080hN7Q0`0i>CT303Xj>P<0:RXZ0P0M7Ad300P820<06QXJ0`0F
5QH2010@40<0>CTi0`1bLW830:j^[P80d=3@0`32`/830:NWY`<0MgMg0P1OGel303Lg=`<09RHV0P0J
6QX600820P<0:BTY0P2NWYh30;:b/P<0RXZ:0`2CTi<20;:b/P<0]kNg0`2h^;P30:RXZ080/;2`0`2W
YjL30<O7a`<0S8b<0P1iNGT3079bLP<0D51@0`0];Bd200/;2`H000000`0S8b<204m?C`<0K6a/0`1L
G5`20492@P<04A4A1P00000200d=3@<04Q8B0`0;2`/300<30`801PH62@00000200<30`<02@T90`0>
3Ph300T92@802PX:0`0Z:RX300<30`<00P820P092@T6000000800P82203oool000H0oooo0`000003
00410@P000000`030`<;000000<02`/;0P020P83000000<00@412`00000300410@802@T90`000003
00H61P800`<31P020P83000000801@D51P0000030;Rh^080hN7Q0`0i>CT303Xj>P<0:RXZ0P0M7Ad3
00P820<06QXJ0`0F5QH2010@40<0>CTi0`1bLW830:j^[P80d=3@0`32`/830:NWY`<0MgMg0P1OGel3
03Lg=`<09RHV0P0J6QX600820P<0:BTY0P2NWYh30;:b/P<0RXZ:0`2CTi<20;:b/P<0]kNg0`2h^;P3
0:RXZ080/;2`0`2WYjL30<O7a`<0S8b<0P1iNGT3079bLP<0D51@0`0];Bd200/;2`H000000`0S8b<2
04m?C`<0K6a/0`1LG5`20492@P<04A4A1P00000200d=3@<04Q8B0`0;2`/300<30`801PH62@000002
00<30`<02@T90`0>3Ph300T92@802PX:0`0Z:RX300<30`<00P820P092@T6000000800P82203oool0
00H0oooo0`00000300H61PP000000`061PH3000000800P821P000003014A4@D00@410`00000300D5
1@P000000`010@45000000<01PH60P00000300T92@<03@d=0`00000201<C4`<00@410`071`L309>C
T`80Zj^[0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[
Z`80c/k>0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0<c<c0P0820P300h>3P<09BDU0`1PH6020=3@
d0<0g]kN0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079b
LP<0PX:20`1SHf<302d];@807alO0`0;2`/3000000<05aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De
=@P000000`030`<300P820<000000P030`<9000000800`<30`061PH3018B4PD000000`0M7Ad30082
0PD000000`030`<3000000800`<3203oool000H0oooo0`00000300H61PP000000`061PH300000080
0P821P000003014A4@D00@410`00000300D51@P000000`010@45000000<01PH60P00000300T92@<0
3@d=0`00000201<C4`<00@410`071`L309>CT`80Zj^[0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0
=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[Z`80c/k>0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0
<c<c0P0820P300h>3P<09BDU0`1PH6020=3@d0<0g]kN0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0
Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079bLP<0PX:20`1SHf<302d];@807alO0`0;2`/3000000<0
5aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De=@P000000`030`<300P820<000000P030`<900000080
0`<30`061PH3018B4PD000000`0M7Ad300820PD000000`030`<3000000800`<3203oool000H0oooo
0`00000300H61PP000000`061PH3000000800P821P000003014A4@D00@410`00000300D51@P00000
0`010@45000000<01PH60P00000300T92@<03@d=0`00000201<C4`<00@410`071`L309>CT`80Zj^[
0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[Z`80c/k>
0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0<c<c0P0820P300h>3P<09BDU0`1PH6020=3@d0<0g]kN
0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079bLP<0PX:2
0`1SHf<302d];@807alO0`0;2`/3000000<05aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De=@P00000
0`030`<300P820<000000P030`<9000000800`<30`061PH3018B4PD000000`0M7Ad300820PD00000
0`030`<3000000800`<3203oool000H0oooo0`010@4;000000<04A4A0`00000200@410<00@410`00
000300l?3`d000000`030`<;000000<00@411@00000300<30`<000000P092@T3000000<00`<30`1Z
JVX20:VYZ@<0Ph>30`1ZJVX305eMG@80PH610`2HV9P308:2PP<0JFUY0P10@40304];B`<0HF5Q0`2<
S8`20;Fe]@<0d];B0`3Ph>030?7al@80h>3P0`3Kfm/30<;2`P80WYjN0`2GUiL309RHV0<0/;2`0P3B
d]830;no_`<0Lg=c0`0g=cL204];B`<0G5aL0`27QhL309NGU`80[Zj^0`2WYjL30:ZZZP<0T92@0P27
QhL309:BTP<0Ogmo0`19BDT202/[:`<051@D0`061PH301LG5`80<30`0`0e=CD3065QH@80EUIF0`15
ADD301LG5`<02PX:0P00000300d=3@<08R8R0`0820P8000000<00@410P030`<;000000<02`/;0`03
0`<30000008010@4200000080?ooo`001P3oool300410@/000000`0A4A430000008010@40`010@43
000000<03`l?3@00000300<30`/000000`010@45000000<00`<30`00000200T92@<000000`030`<3
06YZJP80ZJVY0`23Ph<306YZJP<0GEeM0P21PH4309RHV0<0PX:20`1YJFT20410@0<0Bd];0`1QHF43
08b<S080]KFe0`3Bd]830>3Ph0<0lO7a0P3Ph>030=_Kf`<0`/;20P2NWYh309NGU`<0V9RH0`2`/;02
0=;BdP<0_kno0`1cLg<303Lg=`80Bd];0`1LG5`308N7Q`<0UiNG0P2^[Zh30:NWY`<0ZZZZ0`2@T902
08N7Q`<0TY:B0`1oOgl304U9B@80:b/[0`0D51@300H61P<05aLG0P0`<30303De=@<0HF5Q0P1FEUH3
04E5A@<05aLG0`0:2PX2000000<03@d=0`0R8R8300P820P000000`010@4200<30`/000000`0;2`/3
00<30`<000000P0410@8000000P0oooo00060?ooo`<00@412`000003014A4@<000000P0410@30041
0@<000000`0?3`l=000000<00`<32`00000300410@D000000`030`<3000000802@T90`00000300<3
0`<0JVYZ0P2YZJT308>3P`<0JVYZ0`1MGEd20861P@<0V9RH0`22PX8306UYJ@80@4100`1;Bd/3065Q
H@<0S8b<0P2e]KD30=;BdP<0h>3P0`3alO420>3Ph0<0fm_K0`32`/8209jNWP<0UiNG0`2HV9P30;2`
/080d];B0`2o_kl307=cL`<0=cLg0P1;Bd/305aLG0<0QhN70`2GUiL20:j^[P<0YjNW0`2ZZZX3092@
T080QhN70`2BTY8307moO`<0BDU90P0[:b/301@D50<01PH60`0G5aL2030`<0<0=CDe0`1QHF4205IF
EP<0ADE50`0G5aL300X:2P8000000`0=3@d3028R8P<020P82000000300410@800`<32`00000300/;
2`<00`<30`00000200@410P00000203oool000H0oooo0`00000300<30`<000000P020P83000000<0
3@d=2`00000300D51@D000000`0410@300820P8000000`071`L3000000<00@411@00000300410@D0
00000`020P83000000802@T90`030`<300T92@<0DE5A0P22PX8304m?C`<0F5QH0`1cLg<207moO`<0
G5aL0`15ADD303De=@804a<C0`0^;Rh304];B`<0Ph>30P2UYJD30;Rh^0<0clo?0`3Ogml20?;blP<0
jn_[0`3oool20>o_k`<0emOG0`39bLT30<k>cP80alO70`2VYZH305eMG@<0;Rh^0P14A4@305]KF`H0
T92@0P2QXJ4309JFUP<0Y:BT0`2FUYH209NGU`<0XJ6Q0`2IVIT306IVIP80A4A40`0R8R8601HF5P80
8b<S0`0b<S8305mOG`80EEEE0`0f=SH3028R8P<01`L70P00000300`<30<09BDU0`0=3@d5000000H0
0@410P020P86000000<010@40P00000300H61P<000000`020P8200D51@<000000`020P82000000P0
oooo00060?ooo`<000000`030`<3000000800P820`00000300d=3@/000000`051@D5000000<010@4
0`020P82000000<01`L70`00000300410@D000000`010@45000000<00P820`00000200T92@<00`<3
0`092@T3055AD@80PX:20`1?Cdl305QHF0<0Lg=c0P1oOgl305aLG0<0ADE50`0e=CD201<C4`<0;Rh^
0`1;Bd/308>3P`80YJFU0`2h^;P30<o?c`<0gmoO0P3bl_830>_[j`<0oooo0P3_knl30=OGe`<0bLW9
0`3>c/h20<O7a`<0YZJV0`1MGEd302h^;P80A4A40`1KFe/6092@T080XJ6Q0`2FUYH30:BTY0<0UYJF
0P2GUiL30:6QX@<0VIVI0`1VIVH204A4A0<08R8R1P0F5QH202<S8`<0<S8b0`1OGel205EEE@<0=SHf
0`0R8R8300L71`8000000`0<30`302DU9@<03@d=1@00000600410@800P821P00000300@410800000
0`061PH3000000<00P820P051@D3000000<00P820P0000080?ooo`001P3oool3000000<010@40`02
0P85000000<020P80`061PH5000000<00`<30`020P8;000000800P820`010@4C000000<04A4A0`00
000200@410H000000`0k>c/20861P@<0V9RH0`1bLW8304Q8B080>SXj0`1FEUH306EUI@<0GUiN0P15
ADD304m?C`<0?clo0`1dM7@209BDU0<0/[:b0`2a/K430<?3``80dM7A0`3IfMT30>3Ph080g=cL0`3M
gMd30>OWi`<0jn_[0P3Ph>030<o?c`<0JVYZ0`0R8R82030`<0<0Bd];0`1OGel307IfMP80RHV90`1i
NGT306QXJ0<0MWIf0P1aLG4307emO@<0UYJF0`1kNg/206a/K0<0EEEE0`0Z:RX300H61P801@D50`00
000303dm?@80HV9R0`1nOWh305IFEP<0:2PX0P0C4a<303dm?@<0C4a<0`0M7Ad200@410<000000`06
1PH>000000802PX:0`010@4>000000800P82203oool000H0oooo0`00000300@410<00P821@000003
00P820<01PH61@00000300<30`<00P822`00000200820P<00@414`000003014A4@<000000P0410@6
000000<0>c/k0P21PH4309RHV0<0LW9b0`18B4P203Xj>P<0EUIF0`1UIFD305iNGP80ADE50`1?Cdl3
03lo?`<0M7Ad0P2DU9@30;:b/P<0/K6a0`33`l<20=7Ad@<0fMWI0`3Ph>020=cLg0<0gMgM0`3WinL3
0>_[j`80h>3P0`3?cll306YZJP<08R8R0P0`<30304];B`<0GemO0`1fMWH208V9R@<0NGUi0`1XJ6P3
07IfMP80LG5a0`1mOGd309JFUP<0Ng]k0P1/K6`305EEE@<0:RXZ0`061PH200D51@<000000`0m?Cd2
069RHP<0OWin0`1FEUH302PX:0804a<C0`0m?Cd304a<C0<07AdM0P0410@3000000<01PH63P000002
00X:2P<00@413P00000200820PP0oooo00060?ooo`<000000`0410@300820PD000000`0820P300H6
1PD000000`030`<300820P/000000P020P8300410A<000000`0A4A430000008010@41P00000303/k
>`80PH610`2HV9P3079bLP<0B4Q80P0j>SX305IFEP<0IFEU0`1NGUh204E5A@<0Cdm?0`0o?cl307Ad
M080U9BD0`2b/[830;6a/@<0`l?30P3AdM430=WIf@<0h>3P0P3Lg=`30=gMg@<0inOW0`3[jn/20>3P
h0<0clo?0`1ZJVX3028R8P80<30`0`1;Bd/305mOG`<0MWIf0P29RHT307UiN@<0J6QX0`1fMWH2075a
L@<0OGem0`2FUYH307]kN`80K6a/0`1EEED302XZ:P<01PH60P051@D3000000<0?Cdm0P1RHV8307in
OP<0EUIF0`0X:2P201<C4`<0?Cdm0`1<C4`301dM7@8010@40`00000300H61Ph000000P0:2PX30041
0@h000000P020P880?ooo`001P3oool3000000<01@D50`020P85000000<020P82`00000300820PP0
00000`0410@2000000<00P824`00000300X:2P<000000P0410@3000000<02PX:0`0l?3`207=cL`<0
O7al0`29RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0
WIfM0`2VYZH30<30`080h^;R0`3Lg=`30?3`l080i^KV1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0
M7Ad0P1VIVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80
IVIV0`1:BTX301lO7`<030`<0P071`L3014A4@<0F5QH0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<0
6ATI0`0i>CT301TI6@800`<35000000200@4114000000P020P880?ooo`001P3oool3000000<01@D5
0`020P85000000<020P82`00000300820PP000000`0410@2000000<00P824`00000300X:2P<00000
0P0410@3000000<02PX:0`0l?3`207=cL`<0O7al0`29RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c
0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0WIfM0`2VYZH30<30`080h^;R0`3Lg=`30?3`l080i^KV
1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0M7Ad0P1VIVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q
0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80IVIV0`1:BTX301lO7`<030`<0P071`L3014A4@<0F5QH
0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<06ATI0`0i>CT301TI6@800`<35000000200@411400000
0P020P880?ooo`001P3oool3000000<01@D50`020P85000000<020P82`00000300820PP000000`04
10@2000000<00P824`00000300X:2P<000000P0410@3000000<02PX:0`0l?3`207=cL`<0O7al0`29
RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0WIfM0`2V
YZH30<30`080h^;R0`3Lg=`30?3`l080i^KV1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0M7Ad0P1V
IVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80IVIV0`1:
BTX301lO7`<030`<0P071`L3014A4@<0F5QH0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<06ATI0`0i
>CT301TI6@800`<35000000200@4114000000P020P880?ooo`001P3oool3000000<02@T90`030`<2
00P820H000000`051@D200@410/000000`010@4300T92@<01@D50P00000300820P<000000`010@42
00820PH000000P051@D300<30`H010@40P051@D300L71`<04A4A0`1XJ6P20:ZZZP<0TI6A0`2CTi<3
0:b/[080^;Rh0`1/K6`30492@P<0=3@d0P16ATH307EeM@<0IfMW0`1XJ6P2065QH@<0LW9b0`2FUYH3
0=OGe`80oooo0`3bl_830?ooo`80j^[Z0`3Kfm/30>GUi@<0k>c/0P3YjNT30>[ZjP<0inOW0`3Ti>@2
0<30`0<0YjNW0`2UYJD309FEU@80Vi^K0`1fMWH308R8R0<0MWIf0P17AdL306=SH`<0U9BD0`1lO7`2
071`L0<0E5AD0`0b<S8301@D50802`/;0`0D51@304A4A080L71`0`1lO7`305UIF@<09BDU0P0F5QH3
03@d=0<0B4Q80`0X:2P200P820H000000`030`<200820P<020P81P00000200T92@<000000`010@45
000000<01@D50`020P82000000P0oooo00060?ooo`<000000`092@T300<30`8020P81P00000300D5
1@8010@42`00000300410@<02@T90`051@D2000000<00P820`00000300410@800P821P00000200D5
1@<00`<31P0410@200D51@<01`L70`0A4A4306QXJ080ZZZZ0`2ATI4309>CT`<0[:b/0P2h^;P306a/
K0<0@T920`0d=3@204I6AP<0MGEe0`1WIfL306QXJ080HF5Q0`1bLW8309JFUP<0emOG0P3oool30?;b
lP<0oooo0P3Zj^X30=_Kf`<0iNGU0`3/k>`20>WYj@<0j^[Z0`3WinL30>CTi080`<300`2WYjL30:FU
Y@<0UIFE0P2KVi/307IfMP<0R8R80`1fMWH204M7A`<0Hf=S0`2DU9@307alO080L71`0`1DE5@3038b
<P<051@D0P0;2`/301@D50<0A4A40P1`L70307alO0<0FEUI0`0U9BD201HF5P<0=3@d0`18B4P302PX
:08020P81P00000300<30`800P820`0820P6000000802@T90`00000300410@D000000`051@D30082
0P800000203oool000H0oooo0`00000300T92@<00`<30P0820P6000000<01@D50P0410@;000000<0
0@410`092@T300D51@8000000`020P83000000<00@410P020P86000000801@D50`030`<600@41080
1@D50`071`L3014A4@<0J6QX0P2ZZZX3096AT@<0Ti>C0`2/[:`20;Rh^0<0K6a/0`12@T8303@d=080
ATI60`1eMGD306MWI`<0J6QX0P1QHF43079bLP<0UYJF0`3GemL20?ooo`<0l_;b0`3oool20>[ZjP<0
fm_K0`3UiND30>c/k080jNWY0`3Zj^X30>OWi`<0i>CT0P30`<030:NWY`<0YJFU0`2EUID209^KV`<0
MWIf0`28R8P307IfMP80AdM70`1SHf<309BDU0<0O7al0P1`L70305ADE0<0<S8b0`0D51@200/;2`<0
51@D0`14A4@2071`L0<0O7al0`1IFET302DU9@805QHF0`0d=3@304Q8B0<0:2PX0P0820P6000000<0
0`<30P020P8300P820H000000P092@T3000000<00@411@00000300D51@<00P820P0000080?ooo`00
1P3oool6000000<010@40P020P86000000<04A4A0P030`<D000000801`L72@00000200820PH00000
0P010@43000000<02@T90`010@48000000<0KFe]0P2b/[830:>SX`<0KFe]0`0o?cl205EEE@<0LG5a
0`1JFUX304E5A@80@T920`1GEeL302l_;`<0;Bd]0P0e=CD30451@@<0EeMG0`2SXj<20<S8b0<0cLg=
0`3QhN420=SHf0<0h>3P0`3Jf]X30=gMg@80emOG0`3^k^h30??cl`<0g]kN0P36a/H30=7Ad@<0b<S8
0`3MgMd20?ooo`<0`/;20`2QXJ4307YjNP80=CDe0`1<C4`308R8R0<0NGUi0P1RHV8305EEE@<0;Rh^
0`0N7Qh201XJ6P<01PH60`0c<c<206ATI0<0Q8B40`1_Kfl302HV9P804A4A0`19BDT3065QH@<0=3@d
0P0A4A43000000<00`<33P00000200P8214000000P0;2`/80?ooo`001P3oool6000000<010@40P02
0P86000000<04A4A0P030`<D000000801`L72@00000200820PH000000P010@43000000<02@T90`01
0@48000000<0KFe]0P2b/[830:>SX`<0KFe]0`0o?cl205EEE@<0LG5a0`1JFUX304E5A@80@T920`1G
EeL302l_;`<0;Bd]0P0e=CD30451@@<0EeMG0`2SXj<20<S8b0<0cLg=0`3QhN420=SHf0<0h>3P0`3J
f]X30=gMg@80emOG0`3^k^h30??cl`<0g]kN0P36a/H30=7Ad@<0b<S80`3MgMd20?ooo`<0`/;20`2Q
XJ4307YjNP80=CDe0`1<C4`308R8R0<0NGUi0P1RHV8305EEE@<0;Rh^0`0N7Qh201XJ6P<01PH60`0c
<c<206ATI0<0Q8B40`1_Kfl302HV9P804A4A0`19BDT3065QH@<0=3@d0P0A4A43000000<00`<33P00
000200P8214000000P0;2`/80?ooo`001P3oool6000000<01PH61@00000300@410<02@T90P030`<D
0000008010@42@00000200X:2P/000000`010@4300820PP000000`1SHf<20;jn_P<0[Jf]0`2DU9@3
05aLG080Rh^;0`3;bl/30;fm_@<0]kNg0P2a/K430:ZZZP<0NGUi0`1UIFD206UYJ@<0L71`0`1bLW83
08n?S`80WIfM0`2b/[830<30`080dM7A0`3IfMT30=GEe@<0cLg=0P3Fe]H30=_Kf`<0jn_[0`3>c/h2
0<o?c`<0f][J0`2i^KT30<G5a@80d];B0`2^[Zh3096AT@<0Kfm_0P18B4P304];B`<0NGUi0`21PH42
06UYJ@<0HV9R0`0j>SX301@D50804Q8B0`00000302h^;P80I6AT0`1cLg<305mOG`<0=cLg0P0T92@3
04i>CP<0GEeM0`0_;bl2018B4PT000000P010@4300820P<000000`020P8200<30`<000000`020P83
000000800P821P00000200h>3PP0oooo00060?ooo`H000000`061PH5000000<010@40`092@T200<3
0a@000000P0410@9000000802PX:2`00000300410@<00P822000000306=SH`80_[jn0`2][Jd309BD
U0<0G5aL0P2;Rh/30<_;b`<0_Kfm0`2g]kL20;6a/@<0ZZZZ0`1iNGT306EUI@80JFUY0`1`L703079b
LP<0Shn?0P2MWId30;:b/P<0`<300P3AdM430=WIf@<0eMGE0`3=cLd20=KFeP<0fm_K0`3[jn/30<k>
cP80clo?0`3Jf]X30;Vi^@<0aLG50P3Bd]830:j^[P<0TI6A0`1_Kfl204Q8B0<0Bd];0`1iNGT30861
P@80JFUY0`1RHV8303Xj>P<051@D0P0B4Q83000000<0;Rh^0P1TI6@307=cL`<0GemO0`0g=cL202@T
90<0CTi>0`1MGEd302l_;`804Q8B2@00000200410@<00P820`00000300820P800`<30`0000030082
0P<000000P020P86000000803Ph>203oool000H0oooo1P00000300H61PD000000`0410@300T92@80
0`<35000000200@410T000000P0:2PX;000000<00@410`020P88000000<0Hf=S0P2n_[h30:f][@<0
U9BD0`1LG5`208^;R`<0bl_;0`2m_Kd30;Ng]`80/K6a0`2ZZZX307UiN@<0IFEU0P1YJFT3071`L0<0
LW9b0`2?Shl209fMW@<0/[:b0`30`<020=7Ad@<0fMWI0`3EeMD30<g=c@80e]KF0`3Kfm/30>_[j`<0
c/k>0P3?cll30=[JfP<0^KVi0`35aLD20=;BdP<0[Zj^0`2ATI4306m_K`80B4Q80`1;Bd/307UiN@<0
PH610P1YJFT3069RHP<0>SXj0`0D51@2018B4P<000000`0^;Rh206ATI0<0Lg=c0`1OGel303Lg=`80
92@T0`1>CTh305eMG@<0;bl_0P0B4Q89000000800@410`020P83000000<00P820P030`<3000000<0
0P820`00000200820PH000000P0>3Ph80?ooo`001P3oool90000008010@40`00000300410@<00P82
7P00000300820PD000000`010@4500H61P<00@410`071`L200<30`<01PH60`000003071`L080a/K6
0`2h^;P30;bl_0<0YZJV0P2f][H30<k>cP<0b<S80`3?cll20=[JfP<0iNGU0`2n_[h30:n_[`80V9RH
0`1oOgl307IfMP<0O7al0P2BTY8309RHV0<0`/;20P3Ng]h30=gMg@<0e=CD0`2o_kl20<c<c0<0bLW9
0`3AdM430;Rh^080]kNg0`32`/8309jNWP<0Z:RX0P2c/k<308n?S`<0Jf][0`1=CDd203De=@<0BDU9
0`22PX8309BDU080QHF50`1oOgl304i>CP<02PX:0P020P83000000<0<c<c0P1[Jf/3075aL@<0Hf=S
0`11@D4202XZ:P<0E5AD0`1OGel303@d=0804A4A2@00000200D51@<01`L70`00000300820P804a<C
0`020P8300<30`<000000P051@D6000000801PH6203oool000H0oooo2@00000200@410<000000`01
0@4300820Qh000000`020P85000000<00@411@061PH300410@<01`L70P030`<300H61P<000000`1`
L7020<K6aP<0^;Rh0`2l_;`30:JVYP80][Jf0`3>c/h30<S8b0<0clo?0P3Jf]X30>GUi@<0_[jn0`2_
[jl209RHV0<0Ogmo0`1fMWH307alO080TY:B0`2HV9P30<;2`P80g]kN0`3MgMd30=CDe0<0_kno0P3<
c<`30<W9b@<0dM7A0`2h^;P20;Ng]`<0`/;20`2NWYh30:RXZ080/k>c0`2?Shl306][J`<0CDe=0P0e
=CD304U9B@<0PX:20`2DU9@208F5Q@<0Ogmo0`1>CTh300X:2P800P820`00000303<c<`80Jf][0`1a
LG4306=SH`<0@D510P0Z:RX305ADE0<0GemO0`0d=3@2014A4@T000000P051@D300L71`<000000`02
0P8201<C4`<00P820`030`<3000000801@D51P00000200H61PP0oooo00060?ooo`T000000P0410@3
000000<00@410`020P8N000000<00P821@00000300410@D01PH60`010@4300L71`800`<30`061PH3
000000<0L71`0P36a/H30;Rh^0<0_;bl0`2VYZH20;Jf]P<0c/k>0`38b<P30<o?c`80f][J0`3UiND3
0;jn_P<0[jn_0P2HV9P307moO`<0MWIf0`1lO7`209:BTP<0V9RH0`32`/820=kNgP<0gMgM0`3De=@3
0;no_`80c<c<0`39bLT30=7Ad@<0^;Rh0P2g]kL30<;2`P<0WYjN0`2XZ:P20;>c/`<0Shn?0`1[Jf/3
04e=C@80=CDe0`19BDT308:2PP<0U9BD0P25QHD307moO`<0CTi>0`0:2PX200820P<000000`0c<c<2
06][J`<0LG5a0`1SHf<30451@@80:RXZ0`1DE5@305mOG`<0=3@d0P0A4A49000000801@D50`071`L3
000000<00P820P0C4a<300820P<00`<30`00000200D51@H000000P061PH80?ooo`001P3oool90000
00804a<C1P00000300<30`D000000`0410@3000000802@T90`00000300820P/000000`020P850000
00<01@D50P0=3@d600X:2PD02@T90`071`L3000000<0L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;
R`<0HF5Q0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`
/0<0QXJ60`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^
[P<0VIVI0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`8000000`0N7Qh3079bLP<0Shn?0P2<S8`308^;
R`<0IFEU0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJ
FP<0=CDe0P0>3Ph9000000800@410`0:2PX300@410<000000P0^;Rh300D51@<000000`030`<50000
00<020P80P0000080?ooo`001P3oool9000000804a<C1P00000300<30`D000000`0410@300000080
2@T90`00000300820P/000000`020P85000000<01@D50P0=3@d600X:2PD02@T90`071`L3000000<0
L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;R`<0HF5Q0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0
c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`/0<0QXJ60`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80
VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^[P<0VIVI0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`80
00000`0N7Qh3079bLP<0Shn?0P2<S8`308^;R`<0IFEU0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0
TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJFP<0=CDe0P0>3Ph9000000800@410`0:2PX300@410<0
00000P0^;Rh300D51@<000000`030`<5000000<020P80P0000080?ooo`001P3oool9000000804a<C
1P00000300<30`D000000`0410@3000000802@T90`00000300820P/000000`020P85000000<01@D5
0P0=3@d600X:2PD02@T90`071`L3000000<0L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;R`<0HF5Q
0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`/0<0QXJ6
0`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^[P<0VIVI
0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`8000000`0N7Qh3079bLP<0Shn?0P2<S8`308^;R`<0IFEU
0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJFP<0=CDe
0P0>3Ph9000000800@410`0:2PX300@410<000000P0^;Rh300D51@<000000`030`<5000000<020P8
0P0000080?ooo`001P3oool300H61P<000000`051@D5000000<01@D50`010@45000000<00`<36@00
000200`<30h000000`010@48000000<09bLW0P36a/H30<g=c@<0ZJVY0`0l?3`2075aL@<0_[jn0`3N
g]h30=;BdP80^;Rh0`33`l<30:^[Z`<0alO70P3Ogml30?[jnP<0l?3`0`36a/H20;2`/0<0Zj^[0`2B
TY82092@T0<0OGem0`1iNGT305eMG@80C4a<0`1JFUX304i>CP<0ATI60P1TI6@306IVIP<0EeMG1@15
ADD304U9B@<0Hf=S0`1ZJVX205EEE@<0:BTY0`1OGel308F5Q@80LW9b0`1oOgl307=cL`<0<S8b0P0g
=cL3014A4@<0Cdm?1@2<S8`305eMG@<0@D510P1LG5`3075aL@<0ADE50`0J6QX200L71`<000000`02
0P8>000000D01PH62000000600410@801PH6203oool000H0oooo0`061PH3000000<01@D51@000003
00D51@<00@411@00000300<30aT000000P0<30`>000000<00@412000000302LW9`80a/K60`3=cLd3
0:VYZ@<0?3`l0P1aLG430;jn_P<0g]kN0`3Bd]820;Rh^0<0`l?30`2[Zj/30<O7a`80gmoO0`3jn_X3
0?3`l0<0a/K60P2`/;030:^[Z`<0TY:B0P2@T90307emO@<0NGUi0`1MGEd204a<C0<0FUYJ0`1>CTh3
04I6AP80I6AT0`1VIVH305MGE`D0ADE50`19BDT306=SH`<0JVYZ0P1EEED302TY:@<0GemO0`25QHD2
079bLP<0Ogmo0`1cLg<3038b<P80=cLg0`0A4A4304m?C`D0S8b<0`1MGEd30451@@80G5aL0`1aLG43
04E5A@<06QXJ0P071`L3000000<00P823P00000500H61PP000001P010@4200H61PP0oooo00060?oo
o`<01PH60`0410@8000000<01PH6;000000200410@H000000`010@4200L71`<00@410`00000300l?
3`80QXJ60`31`L430=CDe0<0^k^k0P3Ng]h30>SXj0H0l_;b0P3_knl30?ooo`<0lO7a0`3/k>`20=cL
g0<0l?3`0`3^k^h30<S8b080`<300`2d];@30:VYZ@80Y:BT0`2QXJ430:NWY`<0W9bL0P2=SHd307al
O0<0J6QX0`1CDe<2059BDP<0<C4a0`0X:2P3010@408000000`0V9RH30492@P<0Bd];0P16ATH3038b
<P<0EUIF0`1cLg<207]kN`<0Ph>30`1dM7@302l_;`D0:2PX0`1`L702096AT@<0Q8B40`17AdL303Ph
>080AdM70`0k>c/3028R8P<02`/;2000000300<30`8000000`010@46000000800@411P030`<50000
00<00`<31@0000080?ooo`001P3oool300H61P<010@42000000300H61R`000000P010@46000000<0
0@410P071`L300410@<000000`0?3`l208J6QP<0`L710`3De=@30;^k^`80g]kN0`3Xj>P60?;blP80
kno_0`3oool30?7al@<0k>c/0P3Lg=`30?3`l0<0k^k^0`38b<P20<30`0<0];Bd0`2YZJT20:BTY0<0
XJ6Q0`2WYjL309bLW080SHf=0`1lO7`306QXJ0<0De=C0P1BDU83034a<@<0:2PX0`0@4102000000<0
9RHV0`12@T8304];B`80ATI60`0b<S8305IFEP<0Lg=c0P1kNg/308>3P`<0M7Ad0`0_;bl502PX:0<0
L71`0P2ATI4308B4Q0<0AdM70`0h>3P204M7A`<0>c/k0`0R8R8300/;2`P000000`030`<2000000<0
0@411P00000200410@H00`<31@00000300<30`D00000203oool000H0oooo0`061PH300@410P00000
0`061PH/000000800@411P00000300410@801`L70`010@43000000<03`l?0P26QXH30<71`@<0e=CD
0`2k^k/20=kNgP<0j>SX1P3bl_820>o_k`<0oooo0`3alO430>c/k080g=cL0`3`l?030>k^kP<0b<S8
0P30`<030;Bd]0<0ZJVY0P2TY:@30:6QX@<0YjNW0`2LW9`208f=S@<0O7al0`1XJ6P305=CD`80DU9B
0`0a<C4302PX:0<0410@0P00000302HV9P<0@T920`1;Bd/204I6AP<0<S8b0`1FEUH307=cL`80Ng]k
0`23Ph<307AdM0<0;bl_1@0X:2P3071`L080TI6A0`24Q8@304M7A`<0>3Ph0P17AdL303/k>`<08R8R
0`0;2`/8000000<00`<30P00000300410@H000000P010@4600<30`D000000`030`<5000000P0oooo
00060?oooa@000000P051@D300@410H000000P0820P3000000<02PX:0`00000500410@/000000`01
0@4200820P<00@410`0B4Q83000000802PX:1P00000300820P80GEeM0`3IfMT30<c<c0<0a/K60P3U
iND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RXZ080RXZ:0`2o_kl30;>c/`<0/K6a0P2^
[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng]`<0Zj^[0`1ZJVX307=cL`80QHF50`2H
V9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU9@<08b<S0`1>CTh3079bLP80OGem0`1o
Ogl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:bP<0DE5A0`11@D4203hn?P<09BDU0`0K
6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:2P<000000P051@D;000000<030`<0`04
10@2000000P0oooo00060?oooa@000000P051@D300@410H000000P0820P3000000<02PX:0`000005
00410@/000000`010@4200820P<00@410`0B4Q83000000802PX:1P00000300820P80GEeM0`3IfMT3
0<c<c0<0a/K60P3UiND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RXZ080RXZ:0`2o_kl3
0;>c/`<0/K6a0P2^[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng]`<0Zj^[0`1ZJVX3
07=cL`80QHF50`2HV9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU9@<08b<S0`1>CTh3
079bLP80OGem0`1oOgl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:bP<0DE5A0`11@D42
03hn?P<09BDU0`0K6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:2P<000000P051@D;
000000<030`<0`0410@2000000P0oooo00060?oooa@000000P051@D300@410H000000P0820P30000
00<02PX:0`00000500410@/000000`010@4200820P<00@410`0B4Q83000000802PX:1P0000030082
0P80GEeM0`3IfMT30<c<c0<0a/K60P3UiND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RX
Z080RXZ:0`2o_kl30;>c/`<0/K6a0P2^[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng
]`<0Zj^[0`1ZJVX307=cL`80QHF50`2HV9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU
9@<08b<S0`1>CTh3079bLP80OGem0`1oOgl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:
bP<0DE5A0`11@D4203hn?P<09BDU0`0K6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:
2P<000000P051@D;000000<030`<0`0410@2000000P0oooo00060?ooo`<01PH60`0410@300000080
0P820`00000300410@<000000P010@4300<30`H000000P0410@300820P<000000`061PH200820Ph0
00000`030`<500820P<03Ph>0`00000202HV9P<01PH60`0@410300/;2`80;Rh^0`2l_;`30<S8b0<0
fMWI0P3MgMd30=CDe0<0hN7Q0`3MgMd20>GUi@<0k^k^0`3alO430=SHf080Rh^;0`1bLW83065QH@<0
FUYJ0P1BDU83055AD@<0GEeM0P1]KFd30:2PX0<0W9bL0`2b/[820;Jf]P<0X:2P0`1oOgl304m?C`80
@d=30`1BDU83071`L0<0W9bL0P2h^;P30<C4a0<0SHf=0`1`L70505ADE0<0HF5Q0`1^KVh207moO`<0
RHV90`1]KFd30492@P80;Bd]0`1@D503096AT@80PH610`22PX8303lo?`<0<S8b0P0B4Q8300410@<0
30`<0`051@D200410@H000000`071`L200820P<000000`010@43000000800`<30`00000300410@/0
00000P010@480?ooo`001P3oool300H61P<010@40`00000200820P<000000`010@43000000800@41
0`030`<60000008010@40`020P83000000<01PH60P020P8>000000<00`<31@020P8300h>3P<00000
0P0V9RH300H61P<0410@0`0;2`/202h^;P<0_;bl0`38b<P30=WIf@80gMgM0`3De=@30>7Qh@<0gMgM
0P3UiND30>k^kP<0lO7a0`3Hf=P208^;R`<0LW9b0`1QHF4305YJFP80DU9B0`1ADE4305eMG@80KFe]
0`2PX:0309bLW0<0/[:b0P2f][H30:2PX0<0Ogmo0`1?Cdl204=3@`<0DU9B0`1`L70309bLW080^;Rh
0`34a<@308f=S@<0L71`1@1DE5@3065QH@<0KVi^0P1oOgl308V9R@<0KFe]0`12@T8202d];@<0D51@
0`2ATI420861P@<0PX:20`0o?cl3038b<P804Q8B0`010@4300`<30<01@D50P010@46000000<01`L7
0P020P83000000<00@410`00000200<30`<000000`010@4;000000800@41203oool000H0oooo0`07
1`L300<30`h000000P010@4;000000<00`<30`00000500@411<000001P020P83000000806QXJ0`04
10@301<C4`<01PH60P0C4a<307QhN0<0[Jf]0`3Bd]820=oOg`<0h>3P0`3Hf=P30=_Kf`80j^[Z0`3V
i^H30=_Kf`<0Ti>C0P0e=CD300X:2P<03`l?0`0C4a<201`L70<0>CTi0`1WIfL209fMW@<0d];B0`2m
_Kd30<[:bP80_[jn0`2/[:`30;jn_P<0Ti>C0P1TI6@3055AD@<0D51@0`1]KFd209jNWP<0^;Rh0`2C
Ti<3071`L080EeMG0`1TI6@3079bLP<0Ng]k0P2:RXX308j>SP<0K6a/0`1;Bd/203Hf=P<0HF5Q0`29
RHT2075aL@<0De=C0`0c<c<301/K6`801PH60`00000300P820<01PH60P030`<6000000<01@D51@02
0P8;000000<00@412`00000200L71`P0oooo00060?ooo`<01`L70`030`<>000000800@412`000003
00<30`<000001@0410@C000000H00P820`00000201XJ6P<010@40`0C4a<300H61P804a<C0`1hN7P3
0:f][@<0d];B0P3Ogml30>3Ph0<0f=SH0`3Kfm/20>[ZjP<0i^KV0`3Kfm/309>CT`80=CDe0`0:2PX3
00l?3`<04a<C0P0L71`303Ti>@<0IfMW0P2MWId30=;BdP<0_Kfm0`3:b/X20;jn_P<0[:b/0`2n_[h3
09>CT`80I6AT0`1ADE43051@D0<0KFe]0P2NWYh30;Rh^0<0Ti>C0`1`L70205MGE`<0I6AT0`1bLW83
07]kN`80RXZ:0`2>SXh306a/K0<0Bd];0P0f=SH3065QH@<0RHV90P1aLG4305=CD`<0<c<c0`0K6a/2
00H61P<000000`0820P300H61P800`<31P00000300D51@D00P822`00000300410@/000000P071`L8
0?ooo`001P3oool300L71`<00`<33P00000200410@/000000`030`<3000000D010@44`0000060082
0P<000000P0J6QX300@410<04a<C0`061PH201<C4`<0N7Qh0`2][Jd30=;BdP80gmoO0`3Ph>030=SH
f0<0fm_K0P3Zj^X30>KViP<0fm_K0`2CTi<203De=@<02PX:0`0?3`l301<C4`8071`L0`0i>CT306MW
I`80WIfM0`3Bd]830;fm_@<0b/[:0P2n_[h30:b/[0<0_[jn0`2CTi<206ATI0<0DE5A0`1@D50306e]
K@80WYjN0`2h^;P309>CT`<0L71`0P1GEeL306ATI0<0LW9b0`1kNg/208Z:RP<0SXj>0`1/K6`304];
B`80=SHf0`1QHF4308V9R@80LG5a0`1CDe<303<c<`<06a/K0P061PH3000000<020P80`061PH200<3
0`H000000`051@D500820P/000000`010@4;000000801`L7203oool000H0oooo8@00000300410@<0
0`<31@00000300410@h000000P010@4300820P<000000`051@D200L71`<00P820`051@D300000080
3@d=0`0Q8B4308V9R@<0dM7A0P3]kNd30=KFeP<0a<C40`3=cLd20>SXj0<0i>CT0`3AdM4307EeM@80
;Bd]0`0F5QH301lO7`<020P80P0I6AT3030`<0<0HF5Q0P2e]KD30=CDe0<0_;bl0`30`<020;Jf]P<0
VIVI1P2j^[X20:2PX0<0QHF50`1]KFd305QHF080@T920`1KFe/306ATI0<0BTY:0P1IFET306][J`<0
NWYj0`2>SXh208n?S`<0P8200`1YJFT304A4A080=SHf0`1XJ6P307MgM`80GUiN0`0T92@3018B4P<0
2`/;0P0?3`l6000000<010@40P010@46000000<01@D50P010@4300H61P<000000`020P8200D51A40
00000P071`L80?ooo`001P3ooolQ000000<00@410`030`<5000000<00@413P00000200410@<00P82
0`00000300D51@801`L70`020P8300D51@<000000P0=3@d3024Q8@<0RHV90`3AdM420>g]k@<0e]KF
0`34a<@30<g=c@80j>SX0`3Ti>@30=7Ad@<0MGEe0P0];Bd301HF5P<07alO0`0820P201TI6@<0<30`
0`1QHF420;Fe]@<0e=CD0`2l_;`30<30`080][Jf0`2IVIT60;Zj^P80X:2P0`25QHD306e]K@<0F5QH
0P12@T8305]KF`<0I6AT0`1:BTX205UIF@<0Jf][0`1jNWX308j>SP80Shn?0`20P80306UYJ@<0A4A4
0P0f=SH306QXJ0<0MgMg0P1NGUh302@T90<04Q8B0`0;2`/200l?3`H000000`0410@200410@H00000
0`051@D200410@<01PH60`00000300820P801@D54@00000200L71`P0oooo00060?ooob4000000`01
0@4300<30`D000000`010@4>000000800@410`020P83000000<01@D50P071`L300820P<01@D50`00
000200d=3@<08B4Q0`29RHT30=7Ad@80kNg]0`3Fe]H30<C4a0<0cLg=0P3Xj>P30>CTi0<0dM7A0`1e
MGD202d];@<05QHF0`0O7al300P820806ATI0`0`<303065QH@80]KFe0`3De=@30;bl_0<0`<300P2f
][H309VIV@H0^[Zj0P2PX:0308F5Q@<0KFe]0`1HF5P20492@P<0Fe]K0`1TI6@304Y:BP80FEUI0`1[
Jf/307YjNP<0SXj>0P2?Shl30820P0<0JFUY0`14A4@203Hf=P<0J6QX0`1gMgL205iNGP<092@T0`0B
4Q8300/;2`803`l?1P00000300@410800@411P00000300D51@800@410`061PH3000000<00P820P05
1@DA000000801`L7203oool000H0oooo2@00000200820P<000000`010@4>000000D00P820`010@43
00D51@8000000`0410@;000000<00@412000000300820P801@D53P00000305UIF@<0/k>c0P3Lg=`3
0>SXj0<0eMGE0`3Hf=P20=kNgP<0clo?0`3;bl/309JFUP80Ng]k0`1lO7`306m_K`<0=CDe0P0`<303
03Hf=P<0CTi>0P2[Zj/30<_;b`<0YZJV0`2f][H20;jn_PH0T92@0`2CTi<20:2PX0<0Z:RX0`2YZJT3
09RHV080H61P0`1]KFd306IVIP<0@D510P1bLW8308V9R@<0Ph>30`2<S8`208>3P`<0J6QX0`1EEED3
03hn?P80>3Ph0`1gMgL307YjNP80@T922@00000200820Q4000000`030`<8000000<01@D50P030`<3
00H61P<000000`051@D2000000<00@410`030`<201DE5@P0oooo00060?ooo`T000000P020P830000
00<00@413P00000500820P<00@410`051@D2000000<010@42`00000300410@P000000`020P8200D5
1@h000000`1IFET30;>c/`80g=cL0`3Xj>P30=GEe@<0f=SH0P3Ng]h30<o?c`<0bl_;0`2FUYH207]k
N`<0O7al0`1_Kfl303De=@80<30`0`0f=SH304i>CP80Zj^[0`3;bl/30:JVYP<0][Jf0P2n_[h6092@
T0<0Ti>C0P2PX:030:RXZ0<0ZJVY0`2HV9P2061PH0<0KFe]0`1VIVH30451@@80LW9b0`29RHT308>3
P`<0S8b<0P23Ph<306QXJ0<0EEEE0`0n?Sh203Ph>0<0MgMg0`1jNWX20492@PT000000P020P8A0000
00<00`<32000000300D51@800`<30`061PH3000000<01@D50P00000300410@<00`<30P0E5AD80?oo
o`001P3oool9000000800P820`00000300410@h000001@020P8300410@<01@D50P00000300@410/0
00000`010@48000000<00P820P051@D>000000<0FEUI0`2c/k<20=cLg0<0j>SX0`3EeMD30=SHf080
g]kN0`3?cll30<_;b`<0UYJF0P1kNg/307alO0<0Kfm_0`0e=CD2030`<0<0=SHf0`1>CTh20:^[Z`<0
bl_;0`2VYZH30;Jf]P80_[jn1P2@T90309>CT`80X:2P0`2XZ:P30:VYZ@<0V9RH0P1PH60306e]K@<0
IVIV0`11@D42079bLP<0RHV90`23Ph<308b<S080Ph>30`1XJ6P305EEE@<0?Shn0P0h>3P307MgM`<0
NWYj0P12@T89000000800P824@00000300<30`P000000`051@D200<30`<01PH60`00000300D51@80
00000`010@4300<30`805ADE203oool000H0oooo0`030`<6000000801`L70`00000300820PP00000
0`051@D300820P8010@42@00000200410A<000000`030`<>000000<00P820P00000300D51@H06QXJ
0P11@D430>;RhP<0k>c/0`3WinL20>CTi0<0bl_;0`2b/[830:b/[080bl_;0`3Shn<30<C4a0<0SHf=
0P1MGEd305UIF@<0<c<c0P2;Rh/30<_;b`<0XZ:R0`2^[Zh50<G5a@<0`/;20`2d];@20;2`/0<0_;bl
0`2^[Zh30;jn_P80_;bl0`2SXj<306MWI`<0>3Ph0P1GEeL307inOP<0U9BD0`2EUID208f=S@<0OWin
0`1EEED30492@P80@D510`1MGEd304];B`807QhN4@00000300410@800`<30`00000300820PP00000
0`010@4300D51@8000000`030`<6000000800`<31P010@4203@d=0P0oooo00060?ooo`<00`<31P00
000200L71`<000000`020P88000000<01@D50`020P8200@410T000000P010@4C000000<00`<33P00
000300820P8000000`051@D601XJ6P80@D510`3Rh^830>c/k0<0inOW0P3Ti>@30<_;b`<0/[:b0`2/
[:`20<_;b`<0hn?S0`34a<@308f=S@80GEeM0`1IFET303<c<`80Rh^;0`3;bl/30::RXP<0[Zj^1@35
aLD30<;2`P<0];Bd0P2`/;030;bl_0<0[Zj^0`2n_[h20;bl_0<0Xj>S0`1WIfL303Ph>080EeMG0`1n
OWh309BDU0<0UIFE0P2=SHd307inOP<0EEEE0`12@T820451@@<0GEeM0`1;Bd/201hN7Q4000000`01
0@4200<30`<000000`020P88000000<00@410`051@D2000000<00`<31P00000200<30`H00@410P0d
=3@80?ooo`001P3oool9000000800P822@00000200820P<000000`092@T3000000800P820`000003
00D51@<000000P030`<300410@H000000P010@48000000<051@D4`00000300T92@<00`<30`000002
00l?3`<0OGem0`2ZZZX30:n_[`80dm?C0`3AdM430;Vi^@<0XZ:R0P30`<030>OWi`<0jNWY0`38b<P2
08N7Q`<0O7al0`0^;Rh2075aL@<0^k^k0`2c/k<30:2PX080W9bL0`2[Zj/30:VYZ@<0/k>c0P2/[:`3
0;Jf]P<0XZ:R0`2IVIT207moO`<0G5aL0`13@d<303`l?080FUYJ0`1aLG4308n?S`<0W9bL0P2<S8`3
07alO0<0JVYZ0`11@D4204A4A0<0Bd];0`0Q8B4;000000801PH63P00000300H61P<00@411@000003
00D51A0000000`030`<300@410806ATI203oool000H0oooo2@00000200820PT000000P020P830000
00<02@T90`00000200820P<000000`051@D3000000800`<30`010@46000000800@412000000301@D
51<000000`092@T300<30`<000000P0?3`l307emO@<0ZZZZ0`2_[jl20=?Cd`<0dM7A0`2i^KT30::R
XP80`<300`3WinL30>WYj@<0b<S80P27QhL307alO0<0;Rh^0P1aLG430;^k^`<0/k>c0`2PX:0209bL
W0<0Zj^[0`2YZJT30;>c/`80[:b/0`2f][H30::RXP<0VIVI0P1oOgl305aLG0<0@d=30`0l?3`205YJ
FP<0LG5a0`2?Shl309bLW080S8b<0`1lO7`306YZJP<0@D510P14A4@304];B`<08B4Q2`00000200H6
1Ph000000`061PH300410@D000000`051@D@000000<00`<30`0410@201TI6@P0oooo00060?ooo`T0
00000P020P89000000800P820`00000300T92@<000000P020P83000000<01@D50`00000200<30`<0
0@411P00000200410@P000000`0D51@C000000<02@T90`030`<3000000803`l?0`1mOGd30:ZZZP<0
[jn_0P3Cdm<30=7Ad@<0^KVi0`2RXZ820<30`0<0inOW0`3YjNT30<S8b080QhN70`1lO7`302h^;P80
LG5a0`2k^k/30;>c/`<0X:2P0P2LW9`30:^[Z`<0ZJVY0`2c/k<20:b/[0<0][Jf0`2RXZ8309VIV@80
Ogmo0`1LG5`304=3@`<0?3`l0P1JFUX3075aL@<0Shn?0`2LW9`208b<S0<0O7al0`1ZJVX30451@@80
A4A40`1;Bd/3024Q8@/000000P061PH>000000<01PH60`010@45000000<01@D54000000300<30`<0
10@40P0I6AT80?ooo`001P3oool3000000<01@D50`010@4;000000801@D50`00000300H61P<00@41
1@00000300@410<000000P010@49000000802@T90`00000500820P<09BDU1P00000200/;2`<010@4
2000000300h>3P<04A4A0`030`<2000000<06ATI0`1TI6@308:2PP80aLG50`3;bl/30;Zj^P<0Vi^K
0P2XZ:P30<g=c@<0dm?C0`2f][H207alO0<0NGUi0`0/;2`2069RHP<0[jn_0`3EeMD30<30`080aLG5
0`3<c<`30;Jf]P<0/[:b0P2QXJ4309BDU0<0KFe]0`1FEUH502h^;P<0=CDe0`1CDe<207AdM0<0MGEe
0`1nOWh308^;R`80Q8B40`1`L70305mOG`<0:BTY0P0Z:RX302`/;0<020P82000000300/;2`801`L7
0`020P8;000000<01@D50`00000200D51@<00P820`0=3@d5000000<00P82400000080?ooo`001P3o
ool3000000<01@D50`010@4;000000801@D50`00000300H61P<00@411@00000300@410<000000P01
0@49000000802@T90`00000500820P<09BDU1P00000200/;2`<010@42000000300h>3P<04A4A0`03
0`<2000000<06ATI0`1TI6@308:2PP80aLG50`3;bl/30;Zj^P<0Vi^K0P2XZ:P30<g=c@<0dm?C0`2f
][H207alO0<0NGUi0`0/;2`2069RHP<0[jn_0`3EeMD30<30`080aLG50`3<c<`30;Jf]P<0/[:b0P2Q
XJ4309BDU0<0KFe]0`1FEUH502h^;P<0=CDe0`1CDe<207AdM0<0MGEe0`1nOWh308^;R`80Q8B40`1`
L70305mOG`<0:BTY0P0Z:RX302`/;0<020P82000000300/;2`801`L70`020P8;000000<01@D50`00
000200D51@<00P820`0=3@d5000000<00P82400000080?ooo`001P3oool3000000<01@D50`010@4;
000000801@D50`00000300H61P<00@411@00000300@410<000000P010@49000000802@T90`000005
00820P<09BDU1P00000200/;2`<010@42000000300h>3P<04A4A0`030`<2000000<06ATI0`1TI6@3
08:2PP80aLG50`3;bl/30;Zj^P<0Vi^K0P2XZ:P30<g=c@<0dm?C0`2f][H207alO0<0NGUi0`0/;2`2
069RHP<0[jn_0`3EeMD30<30`080aLG50`3<c<`30;Jf]P<0/[:b0P2QXJ4309BDU0<0KFe]0`1FEUH5
02h^;P<0=CDe0`1CDe<207AdM0<0MGEe0`1nOWh308^;R`80Q8B40`1`L70305mOG`<0:BTY0P0Z:RX3
02`/;0<020P82000000300/;2`801`L70`020P8;000000<01@D50`00000200D51@<00P820`0=3@d5
000000<00P82400000080?ooo`001P3oool3000000<030`<0`061PH200<30`T000000P030`<30000
00<00`<31@00000300410@<01`L70`0410@;0000008010@40`00000300410@800`<30`0P82060000
00804A4A0`0410@300l?3`<03Ph>0P00000300410@<02PX:0`0=3@d5000000<04a<C0`0V9RH2061P
H0<0NGUi0`1lO7`307UiN@80MGEe0`20P80309>CT`<0UYJF0P21PH4306][J`<0@d=30P1FEUH308Z:
RP<0XZ:R0`2NWYh20:>SX`<0_Kfm0`2o_kl30;Zj^P80MWIf0`0o?cl301lO7`<0410@0P0b<S8303Ti
>@<0Cdm?0`1TI6@206UYJ@<0OWin0`2BTY8307inOP80QHF50`1/K6`304U9B@<0:2PX0P0P820302d]
;@<02`/;3@00000300820P/000000`071`L3000000800`<30`0820P300d=3@D00@412@0000050041
0@D00000203oool000H0oooo0`00000300`<30<01PH60P030`<9000000800`<30`00000300<30`D0
00000`010@4300L71`<010@42`00000200@410<000000`010@4200<30`<0820P1P000002014A4@<0
10@40`0?3`l300h>3P8000000`010@4300X:2P<03@d=1@00000301<C4`<09RHV0P1PH60307UiN@<0
O7al0`1iNGT207EeM@<0P8200`2CTi<309JFUP80PH610`1[Jf/304=3@`80EUIF0`2:RXX30::RXP<0
WYjN0P2SXj<30;fm_@<0_kno0`2j^[X207IfMP<0?clo0`0O7al3010@4080<S8b0`0i>CT304m?C`<0
I6AT0P1YJFT307inOP<0TY:B0`1nOWh208F5Q@<0K6a/0`19BDT302PX:080820P0`0];Bd300/;2`d0
00000`020P8;000000<01`L70`00000200<30`<020P80`0=3@d500410@T000001@010@45000000P0
oooo00060?ooo`<000000`0:2PX300820P801PH64@00000300D51@8000000`020P8300410@<02@T9
4000000300<30`800@410`0@410300T92@<000000P0E5AD300410@<04Q8B0`0:2PX2000000H010@4
0`0=3@d5000000<00`<30`0820P201LG5`<0:2PX0`10@40306i^KP80O7al0`29RHT308^;R`<0R8R8
0P1hN7P305eMG@<0@D510P0l?3`305YJFP<0JFUY0`1jNWX208V9R@<0SXj>0`1PH6030410@08071`L
0`030`<300h>3P<061PH0P13@d<304i>CP<0De=C0`1SHf<206m_K`<0PX:20`1oOgl305IFEP80Fe]K
0`11@D4301hN7P<051@D0P0@4103020P80<06ATI1@051@DF000000<01`L72000000300T92@<00000
0P010@4300@410h000000P010@480?ooo`001P3oool3000000<02PX:0`020P8200H61Q4000000`05
1@D2000000<00P820`010@4300T92A0000000`030`<200410@<0410@0`092@T3000000805ADE0`01
0@43018B4P<02PX:0P00000600@410<03@d=1@00000300<30`<020P80P0G5aL302PX:0<0@4100`1^
KVh207alO0<0RHV90`2;Rh/308R8R080N7Qh0`1MGEd30451@@80?3`l0`1JFUX306UYJ@<0NWYj0P29
RHT308j>SP<0H61P0`10@40201`L70<00`<30`0>3Ph301PH6080@d=30`1>CTh305=CD`<0Hf=S0P1_
Kfl308:2PP<0Ogmo0`1FEUH205]KF`<0@D510`0N7Qh301@D5080410@0`0P820301TI6@D01@D55P00
000300L71`P000000`092@T3000000800@410`0410@>000000800@41203oool000H0oooo0`000003
00X:2P<00P820P061PHA000000<01@D50P00000300820P<00@410`092@T@000000<00`<30P010@43
010@40<02@T90`00000201DE5@<00@410`0B4Q8300X:2P8000001P0410@300d=3@D000000`030`<3
00P820805aLG0`0X:2P30410@0<0KVi^0P1lO7`308V9R@<0Rh^;0`28R8P207QhN0<0GEeM0`11@D42
03`l?0<0FUYJ0`1YJFT307YjNP80RHV90`2>SXh3061PH0<0@4100P0L71`300<30`<03Ph>0`0H61P2
04=3@`<0CTi>0`1CDe<306=SH`80Kfm_0`22PX8307moO`<0EUIF0P1KFe/30451@@<07QhN0`0D51@2
010@40<0820P0`0I6AT500D51AH000000`071`L8000000<02@T90`00000200410@<010@43P000002
00410@P0oooo00060?ooo`H000000`020P8200H61Ph000000`010@4300820PD000000`051@D50000
00<00P823P00000200410@<01`L70`0410@3000000802@T94@00000300820PD000000`0820P300H6
1P802PX:0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0KFe]0`1QHF4205EEE@<0@D510`0e=CD20492
@P<0Cdm?0`1@D50304i>CP80ADE50`16ATH301XJ6P<02`/;0P092@T301<C4`<09bLW0`0Z:RX20492
@P<0?Cdm0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C
4`<06QXJ0`0D51@200T92@<00P820`051@D3000000800@410`071`L;000000<02`/;2`0000030041
0@801@D50`010@43000000<00`<31@00000500410@P0oooo00060?ooo`H000000`020P8200H61Ph0
00000`010@4300820PD000000`051@D5000000<00P823P00000200410@<01`L70`0410@300000080
2@T94@00000300820PD000000`0820P300H61P802PX:0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0
KFe]0`1QHF4205EEE@<0@D510`0e=CD20492@P<0Cdm?0`1@D50304i>CP80ADE50`16ATH301XJ6P<0
2`/;0P092@T301<C4`<09bLW0`0Z:RX20492@P<0?Cdm0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0
MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C4`<06QXJ0`0D51@200T92@<00P820`051@D300000080
0@410`071`L;000000<02`/;2`00000300410@801@D50`010@43000000<00`<31@00000500410@P0
oooo00060?ooo`H000000`020P8200H61Ph000000`010@4300820PD000000`051@D5000000<00P82
3P00000200410@<01`L70`0410@3000000802@T94@00000300820PD000000`0820P300H61P802PX:
0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0KFe]0`1QHF4205EEE@<0@D510`0e=CD20492@P<0Cdm?
0`1@D50304i>CP80ADE50`16ATH301XJ6P<02`/;0P092@T301<C4`<09bLW0`0Z:RX20492@P<0?Cdm
0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C4`<06QXJ
0`0D51@200T92@<00P820`051@D3000000800@410`071`L;000000<02`/;2`00000300410@801@D5
0`010@43000000<00`<31@00000500410@P0oooo00060?ooo`<00P820`00000300D51@80410@2`00
000300410@/000000`010@45000000<00P823P00000500410@H000000P061PHD000000801@D50`00
000600410@801@D50`0?3`l302/[:`<0I6AT0P1]KFd306m_K`<0JFUY0`1CDe<204i>CP<0:BTY0`0Q
8B4201lO7`H07QhN0`0F5QH200X:2P<03Ph>0`0?3`l301LG5`8061PH0`0K6a/302`/;0<0:b/[0P18
B4P304Y:BP<0H61P0`1hN7P208Z:RP<0MgMg0`22PX8307=cL`80J6QX0`1>CTh303<c<`<04Q8B0P03
0`<300P820<000000P010@43000000<020P80`0;2`/5014A4@/000000`092@T300410@D000001P02
0P8200P820H000000`020P82000000<00@411@0000080?ooo`001P3oool300820P<000000`051@D2
010@40/000000`010@4;000000<00@411@00000300820Ph000001@010@46000000801PH650000002
00D51@<000001P010@4200D51@<03`l?0`0[:b/306ATI080KFe]0`1_Kfl306UYJ@<0De=C0P1>CTh3
02TY:@<08B4Q0P0O7al601hN7P<05QHF0P0:2PX300h>3P<03`l?0`0G5aL201PH60<06a/K0`0/;2`3
02/[:`80B4Q80`1:BTX3061PH0<0N7Qh0P2:RXX307MgM`<0PX:20`1cLg<206QXJ0<0CTi>0`0c<c<3
018B4P800`<30`0820P3000000800@410`00000300P820<02`/;1@0A4A4;000000<02@T90`010@45
000000H00P820P0820P6000000<00P820P00000300410@D00000203oool000H0oooo0`020P830000
00<01@D50P0@410;000000<00@412`00000300410@D000000`020P8>000000D00@411P00000200H6
1Q@000000P051@D3000000H00@410P051@D300l?3`<0:b/[0`1TI6@206e]K@<0Kfm_0`1YJFT305=C
D`80CTi>0`0Y:BT3024Q8@807alO1P0N7Qh301HF5P802PX:0`0>3Ph300l?3`<05aLG0P0H61P301/K
6`<0;2`/0`0[:b/204Q8B0<0BTY:0`1PH60307QhN080RXZ:0`1gMgL308:2PP<0Lg=c0P1XJ6P304i>
CP<0<c<c0`0B4Q8200<30`<020P80`00000200410@<000000`0820P300/;2`D04A4A2`00000300T9
2@<00@411@00000600820P8020P81P00000300820P8000000`010@45000000P0oooo00060?ooo`<0
1PH60`00000300820P804a<C2`00000300820Q<000000`020P8;000000<00@411@030`<600000080
3@d=1P030`<300T92@8010@41P00000300820P801@D52`00000300h>3P<0;bl_0`1[Jf/206i^KP<0
G5aL0`1KFe/305MGE`80D51@0`0Z:RX302PX:0D07alO0`0F5QH300/;2`802@T90`0F5QH301/K6`<0
7AdM0P0H61P302HV9P<0?Cdm0`1=CDd208N7Q`<0Lg=c0`1aLG4307IfMP80O7al0`1jNWX308R8R0<0
KFe]0P1MGEd304A4A0<09bLW0`0>3Ph200@410<02`/;2000000300`<30<01`L70P020P83014A4@<0
1`L70`0410@5000000<01PH60`020P85000000<00@411@061PH90000008010@41P00000200410@P0
oooo00060?ooo`<01PH60`00000300820P804a<C2`00000300820Q<000000`020P8;000000<00@41
1@030`<6000000803@d=1P030`<300T92@8010@41P00000300820P801@D52`00000300h>3P<0;bl_
0`1[Jf/206i^KP<0G5aL0`1KFe/305MGE`80D51@0`0Z:RX302PX:0D07alO0`0F5QH300/;2`802@T9
0`0F5QH301/K6`<07AdM0P0H61P302HV9P<0?Cdm0`1=CDd208N7Q`<0Lg=c0`1aLG4307IfMP80O7al
0`1jNWX308R8R0<0KFe]0P1MGEd304A4A0<09bLW0`0>3Ph200@410<02`/;2000000300`<30<01`L7
0P020P83014A4@<01`L70`0410@5000000<01PH60`020P85000000<00@411@061PH90000008010@4
1P00000200410@P0oooo00060?ooo`<01`L70`010@4300D51@8071`L7000000300820P8000000`02
0P8;000000D00`<30`00000300820P<000000P092@T300410@<00P822000000300<30`<05ADE0P0N
7Qh300820P/000000`0L71`3071`L080Q8B40`27QhL307alO0<0MWIf0P22PX8304I6AP<0A4A40P0R
8R8301@D50H05ADE0P0G5aL301XJ6P<0:2PX0`0c<c<202/[:`<0:2PX0`0k>c/30492@P80JFUY0`1L
G5`306ATI0<0L71`0P1iNGT3075aL@<0Q8B40`1YJFT2069RHP<0@T920`0I6AT=000000<00@410`0C
4a<3010@40803@d=0`0D51@300`<30<020P80P010@43000000<01@D52000000300D51@<00`<30P0:
2PX;000000<01@D51@0000080?ooo`001P3oool300L71`<00@410`051@D201`L71`000000`020P82
000000<00P822`00000500<30`<000000`020P83000000802@T90`010@4300820PP000000`030`<3
01DE5@807QhN0`020P8;000000<071`L0`1`L70208B4Q0<0QhN70`1lO7`307IfMP80PX:20`16ATH3
04A4A0808R8R0`0D51@601DE5@805aLG0`0J6QX302PX:0<0<c<c0P0[:b/302PX:0<0>c/k0`12@T82
06UYJ@<0G5aL0`1TI6@3071`L080NGUi0`1aLG4308B4Q0<0JFUY0P1RHV830492@P<06ATI3@000003
00410@<04a<C0`0@410200d=3@<051@D0`0<30`300P820800@410`00000300D51@P000000`051@D3
00<30`802PX:2`00000300D51@D00000203oool000H0oooo0`071`L300410@<01@D50P0L71`L0000
00<00P820P00000300820P/000001@030`<3000000<00P820`00000200T92@<00@410`020P880000
00<00`<30`0E5AD201hN7P<00P822`00000301`L70<0L71`0P24Q8@308N7Q`<0O7al0`1fMWH208:2
PP<0ATI60`14A4@2028R8P<051@D1P0E5AD201LG5`<06QXJ0`0X:2P303<c<`80:b/[0`0X:2P303/k
>`<0@T920P1YJFT305aLG0<0I6AT0`1`L70207UiN@<0LG5a0`24Q8@306UYJ@80HV9R0`12@T8301TI
6@d000000`010@4301<C4`<0410@0P0=3@d301@D50<030`<0`0820P200410@<000000`051@D80000
00<01@D50`030`<200X:2P/000000`051@D5000000P0oooo00060?ooo`<02@T90`00000300L71`80
5ADE8@00000300410@/000000`020P8200410@T000000P020P86000000<01@D50P071`L900000080
1`L73P00000300d=3@<0JFUY0P2=SHd3092@T0<0PX:20`1^KVh207QhN0<0B4Q80`1;Bd/2034a<@<0
61PH0`0>3Ph301DE5@80820P0`0S8b<302d];@<0<30`0P0/;2`301lO7`H0<c<c0P1SHf<306QXJ0<0
O7al0`1iNGT207emO@<0Jf][0`1/K6`304];B`80@D510`0W9bL300`<30<01@D50P00000300H61P<0
0`<30P0410@3000000<00@410`00000200X:2P<02`/;0`051@D300410@D000000`030`<8000000<0
0`<31@092@T300H61PH000000P030`<300820P<000000P051@D80?ooo`001P3oool300T92@<00000
0`071`L201DE5B4000000`010@4;000000<00P820P010@49000000800P821P00000300D51@801`L7
2@00000200L71`h000000`0=3@d306UYJ@80SHf=0`2@T90308:2PP<0KVi^0P1hN7P304Q8B0<0Bd];
0P0a<C4301PH60<03Ph>0`0E5AD2020P80<08b<S0`0];Bd3030`<080;2`/0`0O7al603<c<`80Hf=S
0`1XJ6P307alO0<0NGUi0P1mOGd306][J`<0K6a/0`1;Bd/20451@@<09bLW0`0<30`300D51@800000
0`061PH300<30`8010@40`00000300410@<000000P0:2PX300/;2`<01@D50`010@45000000<00`<3
2000000300<30`D02@T90`061PH6000000800`<30`020P83000000801@D5203oool000H0oooo0`09
2@T3000000<01`L70P0E5ADQ000000<00@412`00000300820P800@412@00000200820PH000000`05
1@D200L71`T000000P071`L>000000<03@d=0`1YJFT208f=S@<0T92@0`22PX8306i^KP80N7Qh0`18
B4P304];B`80<C4a0`0H61P300h>3P<05ADE0P0P820302<S8`<0;Bd]0`0`<30202`/;0<07alO1P0c
<c<206=SH`<0J6QX0`1lO7`307UiN@80OGem0`1[Jf/306a/K0<0Bd];0P11@D4302LW9`<030`<0`05
1@D2000000<01PH60`030`<200@410<000000`010@43000000802PX:0`0;2`/300D51@<00@411@00
000300<30`P000000`030`<500T92@<01PH61P00000200<30`<00P820`00000200D51@P0oooo0006
0?ooo`<010@40`00000300410@804a<C0`00000300<30`h000000P0410@;000000<00P822`000003
00<30`D000000`030`<3000000800P822@00000200<30`/000000`0820P300X:2P<020P81@000003
01HF5P<0MgMg0P2][Jd30<C4a0<0Z:RX0`2:RXX208>3P`<0F5QH0`14A4@202XZ:P<07QhN0`0M7Ad3
02@T9080<30`0`0U9BD301HF5P<04A4A0P0`<30304E5A@<0IFEU0`1/K6`207EeM@<0M7Ad0`1aLG43
06e]K@80MWIf0`1BDU8304I6AP<0<c<c0P0U9BD3018B4P<01PH62000000300820PP000000`092@T2
00P820<01@D50`010@48000000<00@412000000300<30`<000000P051@D300H61P<000000`061PH2
000000<00P820`00000200D51@P0oooo00060?ooo`<010@40`00000300410@804a<C0`00000300<3
0`h000000P0410@;000000<00P822`00000300<30`D000000`030`<3000000800P822@00000200<3
0`/000000`0820P300X:2P<020P81@00000301HF5P<0MgMg0P2][Jd30<C4a0<0Z:RX0`2:RXX208>3
P`<0F5QH0`14A4@202XZ:P<07QhN0`0M7Ad302@T9080<30`0`0U9BD301HF5P<04A4A0P0`<30304E5
A@<0IFEU0`1/K6`207EeM@<0M7Ad0`1aLG4306e]K@80MWIf0`1BDU8304I6AP<0<c<c0P0U9BD3018B
4P<01PH62000000300820PP000000`092@T200P820<01@D50`010@48000000<00@412000000300<3
0`<000000P051@D300H61P<000000`061PH2000000<00P820`00000200D51@P0oooo00060?ooo`T0
00000P0>3Ph3000000<00@410`030`<500820PH000000P051@D3000000<00@410`0410@2000000<0
0`<31P00000200<30`<000000`030`<5000000<00@410`00000200410@H000000`020P8200H61P<0
1@D51P00000200l?3`h000000`0D51@3051@D080NGUi0`2HV9P308^;R`<0QhN70P1mOGd305EEE@<0
<30`0P0:2PX300/;2`<05aLG0`0R8R82034a<@<0;Bd]0`0a<C4303hn?P80F5QH0`1^KVh308^;R`<0
SXj>0P26QXH307MgM`<0MGEe0`1ZJVX2065QH@<0>SXj0`0];Bd3020P80803`l?0`010@4300820P<0
10@40P00000300<30`D000000`010@43000000<030`<0P020P8A000000<00@411@00000300H61PD0
00000`010@48000000<01`L71@0000080?ooo`001P3oool9000000803Ph>0`00000300410@<00`<3
1@020P86000000801@D50`00000300410@<010@40P00000300<30`H000000P030`<3000000<00`<3
1@00000300410@<000000P010@46000000<00P820P061PH300D51@H000000P0?3`l>000000<051@D
0`1@D50207UiN@<0V9RH0`2;Rh/308N7Q`80OGem0`1EEED3030`<0802PX:0`0;2`/301LG5`<08R8R
0P0a<C4302d];@<0<C4a0`0n?Sh205QHF0<0KVi^0`2;Rh/308j>SP80QXJ60`1gMgL307EeM@<0JVYZ
0P1QHF4303Xj>P<0;Bd]0`0P820200l?3`<00@410`020P8300@4108000000`030`<5000000<00@41
0`00000300`<30800P824@00000300410@D000000`061PH5000000<00@412000000300L71`D00000
203oool000H0oooo2@00000200h>3P<000000`010@4300<30`D00P821P00000200D51@<000000`01
0@4300@4108000000`030`<6000000800`<30`00000300<30`D000000`010@43000000800@411P00
000300820P801PH60`051@D6000000803`l?3P00000301@D50<0D51@0P1iNGT309RHV0<0Rh^;0`27
QhL207emO@<0EEEE0`0`<30200X:2P<02`/;0`0G5aL3028R8P80<C4a0`0];Bd3034a<@<0?Shn0P1H
F5P306i^KP<0Rh^;0`2>SXh208J6QP<0MgMg0`1eMGD306YZJP80HF5Q0`0j>SX302d];@<0820P0P0?
3`l300410@<00P820`0410@2000000<00`<31@00000300410@<000000`0<30`200820Q4000000`01
0@45000000<01PH61@00000300410@P000000`071`L5000000P0oooo00060?ooo`<010@40`020P83
000000803Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`000003
00@410/000000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@000003
01hN7P<0FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT3
02d];@80>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV82
04e=C@<06ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I
000000<01@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<010@40`020P830000
00803Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`00000300@4
10/000000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@00000301hN
7P<0FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT302d]
;@80>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV8204e=
C@<06ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I0000
00<01@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<010@40`020P8300000080
3Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`00000300@410/0
00000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@00000301hN7P<0
FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT302d];@80
>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV8204e=C@<0
6ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I000000<0
1@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<020P80`010@43000000804a<C
1P00000300P820/000000P092@T6000000<01@D54000000300D51@800P821P00000300820P800@41
2`00000300`<30h000000`0820P200T92@<05aLG0`0/;2`306=SH`80Q8B40`2ATI4307YjNP<0K6a/
0P1dM7@305ADE0<0B4Q80P0^;Rh6034a<@<0;bl_0P0`<303034a<@<0GUiN0`1aLG4207AdM0<0LG5a
0`1iNGT307MgM`80OGem0`1hN7P3069RHP<0?clo0P0I6AT>000000<03@d=0`0;2`/2000000<01@D5
0`0410@200410@H010@40`0=3@d200H61QT000000`0820P3000000801`L70`010@43000000<00P82
0P00000300@410<000000P010@480?ooo`001P3oool300P820<00@410`00000201<C4`H000000`08
20P;000000802@T91P00000300D51A0000000`051@D200820PH000000`020P8200410@/000000`0<
30`>000000<020P80P092@T301LG5`<0;2`/0`1SHf<208B4Q0<0TI6A0`1jNWX306a/K080M7Ad0`1D
E5@304Q8B080;Rh^1P0a<C4302l_;`80<30`0`0a<C4305iNGP<0LG5a0P1dM7@3075aL@<0NGUi0`1g
MgL207emO@<0N7Qh0`1RHV8303lo?`806ATI3P00000300d=3@<02`/;0P00000300D51@<010@40P01
0@4600@410<03@d=0P061PHI000000<020P80`00000200L71`<00@410`00000300820P8000000`04
10@3000000800@41203oool000H0oooo0`0820P300410@<000000P0C4a<6000000<020P82`000002
00T92@H000000`051@D@000000<01@D50P020P86000000<00P820P010@4;000000<030`<3P000003
00P820802@T90`0G5aL302`/;0<0Hf=S0P24Q8@3096AT@<0NWYj0`1/K6`207AdM0<0E5AD0`18B4P2
02h^;PH0<C4a0`0_;bl2030`<0<0<C4a0`1NGUh3075aL@80M7Ad0`1aLG4307UiN@<0MgMg0P1mOGd3
07QhN0<0HV9R0`0o?cl201TI6@h000000`0=3@d300/;2`8000000`051@D300@410800@411P0410@3
00d=3@801PH66@00000300P820<000000P071`L300410@<000000`020P82000000<010@40`000002
00410@P0oooo00060?ooo`<00`<31P00000201HF5PH000000`051@D;0000008030`<0`020P830000
00<02`/;4000000300D51@800P820`00000300H61P/000000`092@T=000000<01@D52000000300L7
1`<0410@0`1<C4`207QhN0<0Shn?0`1`L70306ATI080LG5a0`19BDT30451@@80=3@d0`0f=SH302h^
;P<0>c/k0P1;Bd/304Q8B0<0DU9B0`1TI6@206i^KP<0Ng]k0`26QXH308^;R`80OGem0`1QHF4303dm
?@<061PH0P051@D6000000<00@410P020P8300410@P000000`020P8300@4108000000`0:2PX300@4
10<00@411@00000300D51@<01PH60P010@4>000000<020P80`00000200h>3P<00@410`00000300D5
1@8000000`0410@300410@803@d=203oool000H0oooo0`030`<6000000805QHF1P00000300D51@/0
00000P0<30`300820P<000000`0;2`/@000000<01@D50P020P83000000<01PH62`00000300T92@d0
00000`051@D8000000<01`L70`0@410304a<C080N7Qh0`2?Shl3071`L0<0I6AT0P1aLG4304U9B@<0
@D510P0d=3@303Hf=P<0;Rh^0`0k>c/204];B`<0B4Q80`1BDU8306ATI080KVi^0`1kNg/308J6QP<0
Rh^;0P1mOGd3065QH@<0?Cdm0`0H61P200D51@H000000`010@4200820P<00@412000000300820P<0
10@40P00000300X:2P<010@40`010@45000000<01@D50`061PH200410@h000000`0820P300000080
3Ph>0`010@43000000<01@D50P00000300@410<00@410P0=3@d80?ooo`001P3oool9000000803@d=
1P00000300L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<00000
0`061PH;000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=
0`1YJFT3059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO
0`1SHf<3071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@41
0P020P8C000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<00000
0P0;2`/6000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool9000000803@d=1P00
000300L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<000000`06
1PH;000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=0`1Y
JFT3059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO0`1S
Hf<3071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@410P02
0P8C000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<000000P0;
2`/6000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool9000000803@d=1P000003
00L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<000000`061PH;
000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=0`1YJFT3
059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO0`1SHf<3
071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@410P020P8C
000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<000000P0;2`/6
000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool3000000H00`<30P010@460000
00<00`<31@00000300410@<000000P020P83000000<00`<30`0410@2000000<00@411P00000200l?
3`<000000`010@42000000<00P820`010@4>000000802`/;1P00000300410@8030`<2@00000200P8
20<03Ph>0`00000300T92@80>c/k0`1kNg/307AdM0<0KFe]0P1eMGD305]KF`<0=cLg0P0Z:RX302LW
9`<0@T920`1CDe<206IVIP<0GEeM0`1HF5P307EeM@80OWin0`1]KFd305YJFP<0<c<c2`00000200H6
1PH000000`020P8200410A4000000P071`L301<C4`H000000P0>3PhF000000<00`<30`0:2PX30000
00800@410`030`<8000000<02PX:0`020P82000000P0oooo00060?ooo`<000001P030`<200410@H0
00000`030`<5000000<00@410`00000200820P<000000`030`<300@4108000000`010@4600000080
3`l?0`00000300410@8000000`020P8300410@h000000P0;2`/6000000<00@410P0<30`900000080
20P80`0>3Ph3000000<02@T90P0k>c/307]kN`<0M7Ad0`1]KFd207EeM@<0Fe]K0`0g=cL202XZ:P<0
9bLW0`12@T8305=CD`80IVIV0`1MGEd305QHF0<0MGEe0P1nOWh306e]K@<0FUYJ0`0c<c<;00000080
1PH61P00000300820P800@414@00000200L71`<04a<C1P00000200h>3QH000000`030`<300X:2P<0
00000P010@4300<30`P000000`0:2PX300820P800000203oool000H0oooo0`00000600<30`800@41
1P00000300<30`D000000`010@43000000800P820`00000300<30`<010@40P00000300410@H00000
0P0?3`l3000000<00@410P00000300820P<00@413P00000200/;2`H000000`010@4200`<30T00000
0P0820P300h>3P<000000`092@T203/k>`<0Ng]k0`1dM7@306e]K@80MGEe0`1KFe/303Lg=`80:RXZ
0`0W9bL30492@P<0De=C0P1VIVH305eMG@<0F5QH0`1eMGD207inOP<0KFe]0`1JFUX303<c<`/00000
0P061PH6000000<00P820P010@4A000000801`L70`0C4a<6000000803Ph>5P00000300<30`<02PX:
0`00000200410@<00`<32000000300X:2P<00P820P0000080?ooo`001P3oool3000000<00P820`01
0@45000000<00@410`0820P200@410<000000`010@43000000D00@410`030`<300X:2P800`<32@00
000200D51@P000000`0820P;000000<020P80`0=3@d200L71`<02`/;2000000300/;2`H01PH60P0G
5aL301`L70<030`<0`0410@2024Q8@<0B4Q80`1DE5@306m_K`80K6a/0`1TI6@30451@@80<S8b0`19
BDT305YJFP<0H61P0P1TI6@306QXJ0<0Jf][0`1/K6`205MGE`<0ATI60`0k>c/3038b<P807QhN0`0@
410300/;2`<010@41@00000300H61P<000000P010@46000000D00P822000000300T92@<00P822000
000600410@d000000`020P8300H61Q0000000`051@D5000000P0oooo00060?ooo`<000000`020P83
00410@D000000`010@4300P8208010@40`00000300410@<000001@010@4300<30`<02PX:0P030`<9
000000801@D52000000300P820/000000`0820P300d=3@801`L70`0;2`/8000000<02`/;1P061PH2
01LG5`<071`L0`0<30`300@410808B4Q0`18B4P305ADE0<0Kfm_0P1/K6`306ATI0<0@D510P0b<S83
04U9B@<0FUYJ0`1PH60206ATI0<0J6QX0`1[Jf/306a/K080EeMG0`16ATH303/k>`<0<S8b0P0N7Qh3
010@40<02`/;0`0410@5000000<01PH60`00000200410@H000001@020P88000000<02@T90`020P88
000000H00@413@00000300820P<01PH64000000300D51@D00000203oool000H0oooo0`0000030082
0P<00@411@00000300410@<020P80P0410@3000000<00@410`00000500410@<00`<30`0:2PX200<3
0`T000000P051@D8000000<020P82`00000300P820<03@d=0P071`L300/;2`P000000`0;2`/600H6
1P805aLG0`0L71`300`<30<010@40P0Q8B4304Q8B0<0E5AD0`1_Kfl206a/K0<0I6AT0`11@D42038b
<P<0BDU90`1JFUX3061PH080I6AT0`1XJ6P306][J`<0K6a/0P1GEeL304I6AP<0>c/k0`0b<S8201hN
7P<0410@0`0;2`/300@410D000000`061PH3000000800@411P00000500820PP000000`092@T30082
0PP000001P010@4=000000<00P820`061PH@000000<01@D51@0000080?ooo`001P3oool3000000<0
0@412000000300410@<00P820P010@43000000<01PH60`00000500820PH020P80P00000300410@<0
00000`010@4200@410<000001@010@4300P820<000000`010@42000000<00`<30`0=3@d3030`<080
;2`/1P00000300`<30800`<32@00000200@410<05QHF0`0:2PX3000000805QHF0`0Y:BT303hn?P<0
EeMG0P1PH60305eMG@<0EeMG0P1JFUX3065QH@<0Hf=S0`1PH60206=SH`<0IFEU0`1HF5P305]KF`80
Cdm?0`1:BTX30492@P<0=3@d0P0Q8B4600<30`D000000`0F5QH3024Q8@<04Q8B0P092@T900000080
2@T90`0<30`300<30`D000000`030`<8000000<03@d=0`092@T;000000800P820`030`<300410@<0
1@D52`00000200@410<000000`030`<2000000P0oooo00060?ooo`<000000`010@48000000<00@41
0`020P8200410@<000000`061PH3000000D00P821P0820P2000000<00@410`00000300410@8010@4
0`00000500410@<020P80`00000300410@8000000`030`<300d=3@<0<30`0P0/;2`6000000<030`<
0P030`<90000008010@40`0F5QH300X:2P<000000P0F5QH302TY:@<0?Shn0`1GEeL2061PH0<0GEeM
0`1GEeL205YJFP<0HF5Q0`1SHf<3061PH080Hf=S0`1UIFD305QHF0<0Fe]K0P1?Cdl304Y:BP<0@T92
0`0d=3@2024Q8@H00`<31@00000301HF5P<08B4Q0`0B4Q8200T92@T000000P092@T300`<30<00`<3
1@00000300<30`P000000`0=3@d300T92@/000000P020P8300<30`<00@410`051@D;0000008010@4
0`00000300<30`800000203oool000H0oooo0`00000300D51@/000000`030`<5000000<00P820`00
000200820P<00@410`030`<300L71`800P822@00000200<30`P000000`030`<300820PP000000`01
0@48000000<00@410`0?3`l200@410H000000`030`<200l?3`<05ADE0`0820P300<30`8061PH0`0f
=SH303Ph>0<0@4100P1@D503055AD@<0CTi>0P1CDe<305eMG@<0IfMW0`1/K6`206ATI0<0FUYJ0`1D
E5@305IFEP80D51@0`14A4@303Ti>@<09bLW1@0410@300L71`<010@42`00000200@410<000000`03
0`<300820P8000000`020P8300T92@8030`<0`0B4Q8300D51@P000000`030`<300820Q0000000`03
0`<30000008010@41P00000300410@8000000`010@45000000P0oooo00060?ooo`<000000`051@D;
000000<00`<31@00000300820P<000000P020P8300410@<00`<30`071`L200820PT000000P030`<8
000000<00`<30`020P88000000<00@412000000300410@<03`l?0P0410@6000000<00`<30P0?3`l3
01DE5@<020P80`030`<201PH60<0=SHf0`0h>3P30410@080D51@0`1ADE4304i>CP80De=C0`1MGEd3
06MWI`<0K6a/0P1TI6@305YJFP<0E5AD0`1FEUH2051@D0<0A4A40`0i>CT302LW9`D010@40`071`L3
00@410/000000P0410@3000000<00`<30`020P82000000<00P820`092@T200`<30<04Q8B0`051@D8
000000<00`<30`020P8@000000<00`<30`00000200@410H000000`010@42000000<00@411@000008
0?ooo`001P3oool3000000<01@D52`00000300<30`D000000`020P83000000800P820`010@4300<3
0`<01`L70P020P89000000800`<32000000300<30`<00P822000000300410@P000000`010@4300l?
3`8010@41P00000300<30`803`l?0`0E5AD300P820<00`<30P0H61P303Hf=P<0>3Ph0`10@402051@
D0<0DE5A0`1>CTh205=CD`<0GEeM0`1WIfL306a/K080I6AT0`1JFUX305ADE0<0EUIF0P1@D50304A4
A0<0>CTi0`0W9bL500@410<01`L70`0410@;0000008010@40`00000300<30`<00P820P0000030082
0P<02@T90P0<30`3018B4P<01@D52000000300<30`<00P824000000300<30`<000000P0410@60000
00<00@410P00000300410@D00000203oool000H0oooo0`00000300D51@<00@412000000300410@D0
00000`020P85000000H00@410`0410@200410@T000000P061PH6000000800@410`030`<3000000<0
0@412000000300T92@801`L71P00000300d=3@P000000`0820P201@D50<06ATI0`0=3@d300P82080
6QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1QHF4306EUI@<0JVYZ0`1UIFD205aLG0<0
DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00000300L71`<00`<32000000300820P80
0`<30`00000300<30`P000000`010@4200H61P<00@410`020P88000000<01PH60`0410@=000000<0
0P820`010@4300<30`801@D52@00000200410@P00000203oool000H0oooo0`00000300D51@<00@41
2000000300410@D000000`020P85000000H00@410`0410@200410@T000000P061PH6000000800@41
0`030`<3000000<00@412000000300T92@801`L71P00000300d=3@P000000`0820P201@D50<06ATI
0`0=3@d300P820806QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1QHF4306EUI@<0JVYZ
0`1UIFD205aLG0<0DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00000300L71`<00`<3
2000000300820P800`<30`00000300<30`P000000`010@4200H61P<00@410`020P88000000<01PH6
0`0410@=000000<00P820`010@4300<30`801@D52@00000200410@P00000203oool000H0oooo0`00
000300D51@<00@412000000300410@D000000`020P85000000H00@410`0410@200410@T000000P06
1PH6000000800@410`030`<3000000<00@412000000300T92@801`L71P00000300d=3@P000000`08
20P201@D50<06ATI0`0=3@d300P820806QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1Q
HF4306EUI@<0JVYZ0`1UIFD205aLG0<0DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00
000300L71`<00`<32000000300820P800`<30`00000300<30`P000000`010@4200H61P<00@410`02
0P88000000<01PH60`0410@=000000<00P820`010@4300<30`801@D52@00000200410@P00000203o
ool000H0oooo0`00000300410@<010@40P020P86000000<00P821@00000300D51AT000000P020P8;
000000<00`<32`00000300`<30801`L74@00000300l?3`802`/;0`0820P3000000<01`L70P0X:2P3
03Hf=P<09RHV0`0I6AT202d];@<0=SHf0`18B4P2069RHP<0Hf=S0`1JFUX305iNGP80HV9R0`1PH603
06=SH`<0FEUI0P19BDT3030`<0<04Q8B0`071`L200D51@<030`<0`051@D;000000<00@410P092@T3
00L71`/000000`020P8200X:2P<00`<30`061PH5000000<00`<30`0A4A4300P820800P822`000003
00820P<00@410`0820P200h>3P<010@40`00000300820P801@D51P000002010@40P0oooo00060?oo
o`<000000`010@4300@410800P821P00000300820PD000000`051@DI000000800P822`00000300<3
0`/000000`0<30`200L71a4000000`0?3`l200/;2`<020P80`00000300L71`80:2PX0`0f=SH302HV
9P<06ATI0P0];Bd303Hf=P<0B4Q80P1RHV8306=SH`<0FUYJ0`1NGUh2069RHP<0H61P0`1SHf<305UI
F@80BDU90`0`<303018B4P<01`L70P051@D300`<30<01@D52`00000300410@802@T90`071`L;0000
00<00P820P0:2PX300<30`<01PH61@00000300<30`<04A4A0`0820P200820P/000000`020P830041
0@<020P80P0>3Ph300@410<000000`020P8200D51@H000000P0@41080?ooo`001P3oool3000000<0
10@40`030`<8000000<00`<31@00000300@411T000000P051@D8000000<010@40`010@4;000000<0
1`L70P061PHA000000<0410@0P0F5QH301LG5`<02`/;0`0H61P203Lg=`<0Bd];0`14A4@303Xj>P80
@d=31P1:BTX205YJFP<0HV9R0`1TI6@3065QH@80GemO0`1NGUh3069RHP<0FEUI0P15ADD302LW9`<0
2`/;1@00000300H61P<01`L70`010@4;000000801PH60`0820P300@410<00P820P010@4600000080
10@40`00000300820PD000000`030`<300P820<00`<33@00000300820P<00`<30`051@D200P820<0
0`<31P00000200<30`H000000P071`L80?ooo`001P3oool3000000<010@40`030`<8000000<00`<3
1@00000300@411T000000P051@D8000000<010@40`010@4;000000<01`L70P061PHA000000<0410@
0P0F5QH301LG5`<02`/;0`0H61P203Lg=`<0Bd];0`14A4@303Xj>P80@d=31P1:BTX205YJFP<0HV9R
0`1TI6@3065QH@80GemO0`1NGUh3069RHP<0FEUI0P15ADD302LW9`<02`/;1@00000300H61P<01`L7
0`010@4;000000801PH60`0820P300@410<00P820P010@460000008010@40`00000300820PD00000
0`030`<300P820<00`<33@00000300820P<00`<30`051@D200P820<00`<31P00000200<30`H00000
0P071`L80?ooo`001P3oool3000000<010@40`030`<8000000<00`<31@00000300@411T000000P05
1@D8000000<010@40`010@4;000000<01`L70P061PHA000000<0410@0P0F5QH301LG5`<02`/;0`0H
61P203Lg=`<0Bd];0`14A4@303Xj>P80@d=31P1:BTX205YJFP<0HV9R0`1TI6@3065QH@80GemO0`1N
GUh3069RHP<0FEUI0P15ADD302LW9`<02`/;1@00000300H61P<01`L70`010@4;000000801PH60`08
20P300@410<00P820P010@460000008010@40`00000300820PD000000`030`<300P820<00`<33@00
000300820P<00`<30`051@D200P820<00`<31P00000200<30`H000000P071`L80?ooo`001P3oool3
00<30`<01`L70`020P8200<30`<000000`030`<300410@D000000`010@45000000<00@410`000003
00X:2Q0000000`020P82000000<00`<31P00000500410@<030`<2`00000300d=3@8000000`0:2PX3
00820P<030`<0P0A4A4301TI6@<05QHF0`0P820203hn?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<3
06][J`80IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069RHP<0EUIF0P0g=cL3014A4@<02@T91@000003
00H61P<020P80`010@4C000000<00P820P00000300L71`<020P88`00000300410@H00P822`000002
00<30`<00@411@0000080?ooo`001P3oool300<30`<01`L70`020P8200<30`<000000`030`<30041
0@D000000`010@45000000<00@410`00000300X:2Q0000000`020P82000000<00`<31P0000050041
0@<030`<2`00000300d=3@8000000`0:2PX300820P<030`<0P0A4A4301TI6@<05QHF0`0P820203hn
?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<306][J`80IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069R
HP<0EUIF0P0g=cL3014A4@<02@T91@00000300H61P<020P80`010@4C000000<00P820P00000300L7
1`<020P88`00000300410@H00P822`00000200<30`<00@411@0000080?ooo`001P3oool300<30`<0
1`L70`020P8200<30`<000000`030`<300410@D000000`010@45000000<00@410`00000300X:2Q00
00000`020P82000000<00`<31P00000500410@<030`<2`00000300d=3@8000000`0:2PX300820P<0
30`<0P0A4A4301TI6@<05QHF0`0P820203hn?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<306][J`80
IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069RHP<0EUIF0P0g=cL3014A4@<02@T91@00000300H61P<0
20P80`010@4C000000<00P820P00000300L71`<020P88`00000300410@H00P822`00000200<30`<0
0@411@0000080?ooo`001P3oool300<30`<020P80`030`<200820P<000001P030`<=000000<00@41
0`00000300L71`800@412@00000200410@<000000`010@42000000<010@41P00000500820P<02`/;
0`061PH5000000<00P820`0>3Ph2000000<010@40`00000300/;2`804Q8B0`0J6QX301DE5@<07alO
0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH306e]K@<0LG5a0`1/K6`205mOG`<0FEUI
0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX300H61PD000000`010@430000008010@4
0`030`<300410@P000000`020P8200<30`<000000`071`L8000000<010@40`010@4=000000H00P82
0`030`<;0000008010@4200000080?ooo`001P3oool300<30`<020P80`030`<200820P<000001P03
0`<=000000<00@410`00000300L71`800@412@00000200410@<000000`010@42000000<010@41P00
000500820P<02`/;0`061PH5000000<00P820`0>3Ph2000000<010@40`00000300/;2`804Q8B0`0J
6QX301DE5@<07alO0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH306e]K@<0LG5a0`1/
K6`205mOG`<0FEUI0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX300H61PD000000`01
0@430000008010@40`030`<300410@P000000`020P8200<30`<000000`071`L8000000<010@40`01
0@4=000000H00P820`030`<;0000008010@4200000080?ooo`001P3oool300<30`<020P80`030`<2
00820P<000001P030`<=000000<00@410`00000300L71`800@412@00000200410@<000000`010@42
000000<010@41P00000500820P<02`/;0`061PH5000000<00P820`0>3Ph2000000<010@40`000003
00/;2`804Q8B0`0J6QX301DE5@<07alO0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH3
06e]K@<0LG5a0`1/K6`205mOG`<0FEUI0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX3
00H61PD000000`010@430000008010@40`030`<300410@P000000`020P8200<30`<000000`071`L8
000000<010@40`010@4=000000H00P820`030`<;0000008010@4200000080?ooo`001P3oool30082
0P<01PH60`0410@200410@<000000`0410@300<30`D000000`010@45000000<00@410`00000300H6
1P800@415P00000300<30`P000000`051@D300820PP000000`010@42000000<0410@0`061PH3010@
40801`L70`030`<3000000<02`/;0P0/;2`304A4A0<0@D510`17AdL205UIF@<0HF5Q0`1XJ6P206UY
J@H0KFe]0`1cLg<206e]K@<0HV9R0`1HF5P303/k>`808R8R0`030`<8000000<03@d=0`061PH30041
0@8000000`051@D300H61P<000000P030`<>000000<00`<30P0820P300T92@<02PX:2000000300d=
3@<010@44`00000300@410800P822@00000200@410H000000P071`L80?ooo`001P3oool300820P<0
1PH60`0410@200410@<000000`0410@300<30`D000000`010@45000000<00@410`00000300H61P80
0@415P00000300<30`P000000`051@D300820PP000000`010@42000000<0410@0`061PH3010@4080
1`L70`030`<3000000<02`/;0P0/;2`304A4A0<0@D510`17AdL205UIF@<0HF5Q0`1XJ6P206UYJ@H0
KFe]0`1cLg<206e]K@<0HV9R0`1HF5P303/k>`808R8R0`030`<8000000<03@d=0`061PH300410@80
00000`051@D300H61P<000000P030`<>000000<00`<30P0820P300T92@<02PX:2000000300d=3@<0
10@44`00000300@410800P822@00000200@410H000000P071`L80?ooo`001P3oool3000000<02@T9
2000000300@410<00@411@00000300@410<00@410P00000300410@<000000`0820P200410@h00000
0`010@42000000<01`L70`010@43000000801PH60`020P8300/;2`<01PH60P00000300D51@<00`<3
0`0:2PX5000000<020P80`0H61P2020P80<09BDU0`0O7al3020P8080<C4a0`13@d<304a<C0<0D51@
0P1ADE4305iNGP<0EeMG0P1OGel3079bLP<0Ng]k0`1gMgL206a/K0<0HF5Q0`1<C4`3030`<0806a/K
0`051@D8000000<01PH60`010@4300@410800`<30`0820P300410@<000001@020P8300@410<00`<3
0P0410@300H61P<03@d=0P0410@O000000800@410`00000300410@h000000P030`<8000000P0oooo
00060?ooo`<000000`092@T8000000<010@40`010@45000000<010@40`010@42000000<00@410`00
000300P820800@413P00000300410@8000000`071`L300410@<000000P061PH300820P<02`/;0`06
1PH2000000<01@D50`030`<300X:2PD000000`0820P301PH6080820P0`0U9BD301lO7`<0820P0P0a
<C4304=3@`<0C4a<0`1@D502055AD@<0GUiN0`1GEeL205mOG`<0LW9b0`1kNg/307MgM`80K6a/0`1Q
HF4304a<C0<0<30`0P0K6a/300D51@P000000`061PH300410@<010@40P030`<300P820<00@410`00
000500820P<010@40`030`<200@410<01PH60`0=3@d200@411l000000P010@43000000<00@413P00
000200<30`P00000203oool000H0oooo0`00000300T92@P000000`0410@300410@D000000`0410@3
00410@8000000`010@43000000<020P80P010@4>000000<00@410P00000300L71`<00@410`000002
00H61P<00P820`0;2`/300H61P8000000`051@D300<30`<02PX:1@00000300P820<061PH0P0P8203
02DU9@<07alO0`0P8202034a<@<0@d=30`1<C4`3051@D080DE5A0`1NGUh305MGE`80GemO0`1bLW83
07]kN`<0MgMg0P1/K6`3065QH@<0C4a<0`0`<30201/K6`<01@D52000000300H61P<00@410`0410@2
00<30`<020P80`010@43000000D00P820`0410@300<30`8010@40`061PH300d=3@8010@47`000002
00410@<000000`010@4>000000800`<3200000080?ooo`001P3oool3000000<02PX:2000000300H6
1P<00@411@00000300<30`D000000`010@43000000<01PH60P010@4>000000<00@410P00000300D5
1@H000000P071`L300@410<030`<1@051@D300`<30<02PX:0`0B4Q85000000<00`<30`0D51@201TI
6@<07alO0`0L71`3020P8080<C4a0`11@D43055AD@<0FEUI0P1NGUh6071`L080Lg=c0`1mOGd308J6
QP<0N7Qh0P1PH60304i>CP<0<c<c0`0A4A4200<30a4000000`061PH200P820<02@T90`010@480000
00<00`<32000000300T92@8010@40`00000300H61PP000000`030`<>000000800`<31P0000030041
0@/000000P051@D8000000P0oooo00060?ooo`<000000`0:2PX8000000<01PH60`010@45000000<0
0`<31@00000300410@<000000`061PH200410@h000000`010@42000000<01@D51P00000200L71`<0
10@40`0<30`500D51@<030`<0`0:2PX3018B4PD000000`030`<301@D50806ATI0`0O7al301`L70<0
820P0P0a<C430451@@<0DE5A0`1IFET205iNGPH0L71`0P1cLg<307emO@<0QXJ60`1hN7P2061PH0<0
CTi>0`0c<c<3014A4@800`<34@00000300H61P8020P80`092@T300410@P000000`030`<8000000<0
2@T90P0410@3000000<01PH62000000300<30`h000000P030`<6000000<00@412`00000200D51@P0
0000203oool000H0oooo0`00000300X:2PP000000`061PH300410@D000000`030`<5000000<00@41
0`00000300H61P800@413P00000300410@8000000`051@D6000000801`L70`0410@300`<30D01@D5
0`0<30`300X:2P<04Q8B1@00000300<30`<051@D0P0I6AT301lO7`<071`L0`0P8202034a<@<0@D51
0`1ADE4305UIF@80GUiN1P1`L70207=cL`<0OGem0`26QXH307QhN080H61P0`1>CTh303<c<`<04A4A
0P030`<A000000<01PH60P0820P300T92@<00@412000000300<30`P000000`092@T200@410<00000
0`061PH8000000<00`<33P00000200<30`H000000`010@4;000000801@D5200000080?ooo`001P3o
ool3000000<01PH62000000300H61P<010@41@00000300D51@<000000P020P86000000<01@D50P03
0`<>000000<00P820P00000300D51@<010@40`00000200D51@<00P820`061PH300820P8000000`0;
2`/;000000<01`L70`0J6QX501PH60<03`l?0`0U9BD204I6APH0EUIF0`1BDU8205=CD`H0IfMW0P1g
MgL308F5Q@<0R8R80`1fMWH205iNGP<0Bd];0`0Q8B48000000<00P820`071`L200D51@<020P81P00
000200820P<00`<32`00000300410A0000000`0<30`5000000<00@410`0<30`300820P/000000P02
0P86000000<00@410P0410@6000000<01@D50P061PH8000000P0oooo00060?ooo`<000000`061PH8
000000<01PH60`0410@5000000<01@D50`00000200820PH000000`051@D200<30`h000000`020P82
000000<01@D50`0410@3000000801@D50`020P8300H61P<00P820P00000300/;2`/000000`071`L3
01XJ6PD061PH0`0?3`l302DU9@80ATI61P1FEUH3059BDP80De=C1P1WIfL207MgM`<0QHF50`28R8P3
07IfMP80GUiN0`1;Bd/3024Q8@P000000`020P8300L71`801@D50`0820P6000000800P820`030`<;
000000<00@414000000300`<30D000000`010@4300`<30<00P822`00000200820PH000000`010@42
00@410H000000`051@D200H61PP00000203oool000H0oooo0`00000300D51@P000000`0:2PX30041
0A<000000`0410@200<30`<00P822`00000300410@P000000`0410@200D51@<010@40`051@D30000
00800P820`0F5QH300l?3`<0410@0P092@T301/K6`<09BDU0`0g=cL202h^;P<08R8R0`0I6AT302LW
9`80@d=30`1DE5@305QHF0D0EeMG0`1`L703079bLP80N7Qh0`1lO7`308:2PP<0IfMW0P18B4P302HV
9P<01PH62000000300<30`<01`L70P00000300<30`H000000P0A4A4300D51Ah000001P0>3Ph20000
00<00P820`0>3Ph300<30`/000000P0410@6000000<00P821@00000300410@<00P820P061PH80000
00P0oooo00060?ooo`<000000`051@D8000000<02PX:0`010@4C000000<010@40P030`<300820P/0
00000`010@48000000<010@40P051@D300@410<01@D50`00000200820P<05QHF0`0?3`l3010@4080
2@T90`0K6a/302DU9@<0=cLg0P0^;Rh3028R8P<06ATI0`0W9bL204=3@`<0E5AD0`1HF5P505MGE`<0
L71`0`1bLW8207QhN0<0O7al0`22PX8306MWI`80B4Q80`0V9RH300H61PP000000`030`<300L71`80
00000`030`<6000000804A4A0`051@DN000000H03Ph>0P00000300820P<03Ph>0`030`<;00000080
10@41P00000300820PD000000`010@4300820P801PH6200000080?ooo`001P3oool3000000<01@D5
2000000300X:2P<00@414`00000300@410800`<30`020P8;000000<00@412000000300@410801@D5
0`0410@300D51@<000000P020P8301HF5P<03`l?0`0@410200T92@<06a/K0`0U9BD303Lg=`80;Rh^
0`0R8R8301TI6@<09bLW0P13@d<305ADE0<0F5QH1@1GEeL3071`L0<0LW9b0P1hN7P307alO0<0PX:2
0`1WIfL204Q8B0<09RHV0`061PH8000000<00`<30`071`L2000000<00`<31P000002014A4@<01@D5
7P00000600h>3P8000000`020P8300h>3P<00`<32`00000200@410H000000`020P85000000<00@41
0`020P8200H61PP00000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P00
000200410@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`07
1`L3000000800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U
9BD302d];@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F
5QH300`<30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`07
1`L200410@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`00
000300820P800000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P000002
00410@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`071`L3
000000800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U9BD3
02d];@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F5QH3
00`<30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`071`L2
00410@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`000003
00820P800000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P0000020041
0@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`071`L30000
00800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U9BD302d]
;@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F5QH300`<
30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`071`L20041
0@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`0000030082
0P800000203oool000H0oooo1P020P88000000<02PX:0`00000200820PH00@410`00000200<30`<0
00000`030`<300@410800P820`030`<3000000<00@411@00000300410@P000000`061PH200`<30<0
20P80`0<30`300820P80410@0`0X:2P3010@40<04Q8B0P0?3`l301@D50<08R8R0`0X:2P2028R8P<0
:BTY0`0/;2`3034a<@80@4100`1:BTX3065QH@<0KVi^0P1QHF43079bLP<0IfMW0P1QHF4306YZJP<0
JFUY0`19BDT201lO7`<02PX:2`00000300L71`D03@d=0`061PH6000000800`<30`020P8;000000<0
3@d=0`00000200@410<000000`0:2PX5000000<03Ph>0`061PH5000000<00`<32`00000300820P80
1PH63P00000300820P<000000P051@D3000000<00P820P0000080?ooo`001P3oool600820PP00000
0`0:2PX3000000800P821P010@43000000800`<30`00000300<30`<010@40P020P8300<30`<00000
0`010@45000000<00@412000000300H61P8030`<0`0820P300`<30<00P820P0@410302PX:0<0410@
0`0B4Q8200l?3`<051@D0`0R8R8302PX:0808R8R0`0Y:BT302`/;0<0<C4a0P10@40304Y:BP<0HF5Q
0`1^KVh2065QH@<0LW9b0`1WIfL2065QH@<0JVYZ0`1YJFT304U9B@807alO0`0:2PX;000000<01`L7
1@0=3@d300H61PH000000P030`<300820P/000000`0=3@d30000008010@40`00000300X:2PD00000
0`0>3Ph300H61PD000000`030`<;000000<00P820P061PH>000000<00P820`00000200D51@<00000
0`020P82000000P0oooo00060?ooo`H00P822000000300X:2P<000000P020P8600410@<000000P03
0`<3000000<00`<30`0410@200820P<00`<30`00000300410@D000000`010@48000000<01PH60P0<
30`300P820<030`<0`020P82010@40<0:2PX0`0@4103018B4P803`l?0`0D51@3028R8P<0:2PX0P0R
8R8302TY:@<0;2`/0`0a<C420410@0<0BTY:0`1QHF4306i^KP80HF5Q0`1bLW8306MWI`80HF5Q0`1Z
JVX306UYJ@<0BDU90P0O7al300X:2P/000000`071`L500d=3@<01PH61P00000200<30`<00P822`00
000300d=3@<000000P0410@3000000<02PX:1@00000300h>3P<01PH61@00000300<30`/000000`02
0P8200H61Ph000000`020P83000000801@D50`00000300820P800000203oool000H0oooo0`092@T6
0000008020P80`00000300410A<000000`071`L3000000D00@411P00000200<30`<000000`010@42
00820PH000000`0;2`/200410@<01@D50`020P830000008010@40`061PH300P820<0410@0P0G5aL3
01@D50<04a<C0`0J6QX202<S8`<0=cLg0`0h>3P303`l?080ATI60`1;Bd/3069RHP<0IfMW0P1]KFd6
06EUI@80GemO0`1MGEd3055AD@<0;Bd]0P00000300410@<0:2PX0`0e=CD2020P80<01`L70`061PH8
000000<01PH60`0410@5000000<00@410`0;2`/200`<30<05ADE0`0U9BD3010@40802`/;0`092@T5
00<30`<000000`0A4A43000000801@D50`0820P3000000<00@412000000500410@H000000`0410@5
000000<00@410`00000200@410<000000`020P82000000P0oooo00060?ooo`<02@T91P00000200P8
20<000000`010@4C000000<01`L70`00000500410@H000000P030`<3000000<00@410P020P860000
00<02`/;0P010@4300D51@<00P820`00000200@410<01PH60`0820P3010@40805aLG0`0D51@301<C
4`<06QXJ0P0S8b<303Lg=`<0>3Ph0`0l?3`204I6AP<0Bd];0`1RHV8306MWI`80KFe]1P1UIFD205mO
G`<0GEeM0`1ADE4302d];@8000000`010@4302PX:0<0=CDe0P0P820300L71`<01PH62000000300H6
1P<010@41@00000300410@<02`/;0P0<30`301DE5@<09BDU0`0@410200/;2`<02@T91@030`<30000
00<04A4A0`00000200D51@<020P80`00000300410@P000001@010@46000000<010@41@0000030041
0@<000000P0410@3000000<00P820P0000080?ooo`001P3oool300H61P<00@410`00000200<30`<0
00000`0820P3000000800P825P00000300<30`<000000`020P8200P820<000001@020P8300410@<0
00000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00000300820P<04Q8B0P0M7Ad301TI6@<0
51@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17AdL3065QH@<0HV9R0P1JFUX3061PH0<0
HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00000200410@<000000`030`<>00000080
20P80`051@D300<30`P000000`051@DH000000<00`<31P010@48000000<00@410P0820P6000000<0
410@1@00000300H61P<000000P0A4A43000000<00P820P0000080?ooo`001P3oool300H61P<00@41
0`00000200<30`<000000`0820P3000000800P825P00000300<30`<000000`020P8200P820<00000
1@020P8300410@<000000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00000300820P<04Q8B
0P0M7Ad301TI6@<051@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17AdL3065QH@<0HV9R
0P1JFUX3061PH0<0HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00000200410@<00000
0`030`<>0000008020P80`051@D300<30`P000000`051@DH000000<00`<31P010@48000000<00@41
0P0820P6000000<0410@1@00000300H61P<000000P0A4A43000000<00P820P0000080?ooo`001P3o
ool300H61P<00@410`00000200<30`<000000`0820P3000000800P825P00000300<30`<000000`02
0P8200P820<000001@020P8300410@<000000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00
000300820P<04Q8B0P0M7Ad301TI6@<051@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17
AdL3065QH@<0HV9R0P1JFUX3061PH0<0HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00
000200410@<000000`030`<>0000008020P80`051@D300<30`P000000`051@DH000000<00`<31P01
0@48000000<00@410P0820P6000000<0410@1@00000300H61P<000000P0A4A43000000<00P820P00
00080?ooo`001P3oool300P820H000000P0820P3000000<010@43P00000200820P/000000`010@4;
000000<00P820P010@46000000<01PH6200410@300H61P8051@D0`0:2PX300/;2`<05ADE0P0H61P3
01dM7@<05aLG0`0K6a/201@D50<08B4Q0`0Z:RX30492@P80EEEE0`1FEUH305eMG@<0EeMG0P1IFET3
04i>CP<0DE5A0P18B4P303/k>`<0;Bd]0`0F5QH5000000<00@412000000300@410<000000P051@D3
00820P/000001P020P82000000<00`<30`0<30`8000000<00`<30P010@43000000<02@T90`000002
00410@<01PH60`0410@300820P/000000P010@46000000<01@D50P010@43000000<00@410`000002
00H61P<000000`020P82000000P0oooo00060?ooo`<020P81P00000200P820<000000`0410@>0000
00800P822`00000300410@/000000`020P8200410@H000000`061PH800@410<01PH60P0D51@300X:
2P<02`/;0`0E5AD201PH60<07AdM0`0G5aL301/K6`8051@D0`0Q8B4302XZ:P<0@T920P1EEED305IF
EP<0GEeM0`1GEeL205UIF@<0CTi>0`1ADE4204Q8B0<0>c/k0`0];Bd301HF5PD000000`010@480000
00<010@40`00000200D51@<00P822`00000600820P8000000`030`<300`<30P000000`030`<20041
0@<000000`092@T3000000800@410`061PH300@410<00P822`00000200410@H000000`051@D20041
0@<000000`010@43000000801PH60`00000300820P800000203oool000H0oooo0`0820P600000080
20P80`00000300@410h000000P020P8;000000<00@412`00000300820P800@411P00000300H61PP0
10@40`061PH201@D50<02PX:0`0;2`/301DE5@8061PH0`0M7Ad301LG5`<06a/K0P0D51@3024Q8@<0
:RXZ0`12@T8205EEE@<0EUIF0`1MGEd305MGE`80FEUI0`1>CTh3055AD@80B4Q80`0k>c/302d];@<0
5QHF1@00000300410@P000000`0410@3000000801@D50`020P8;000000H00P820P00000300<30`<0
30`<2000000300<30`800@410`00000300T92@<000000P010@4300H61P<010@40`020P8;00000080
0@411P00000300D51@800@410`00000300410@<000000P061PH3000000<00P820P0000080?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`2790\)], "Output"]
}, Open  ]],

Cell["Compare the original to the filtered.", "Text"],

Cell[CellGroupData[{

Cell["\<\
showImage[handMat];  (* perfect original on top *)
showImage[newHand];  (* filtered from speckled on bottom *)\
\>", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000000001010001030202080B151A
1D1E20232522201D1913100C0C0E151D232B2B2B21100801
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000102060E18
1F1F2125282A2726211B140D0B0F171E2941515853381706
010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000100010710
1B1F22292D302F2D292319100C0F0D1726353231373B2A15
070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000010105
0E1A212933333434332B211C1C1A151C1E181115171B151C
1F1608040404030100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
030917253235363A35312C2C2F2A242C1F0F0A0D12120C0F
15191A181C21232216110A05010100000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000104132933353938353437352B293E29190C091314151F
1A0A0E04070E171B171A191715130C0C0D08030000010000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000E242E3638393C3C342929443B290B081E1B163E
270E080805000205020917151C191A221C190F0701000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000A213135393D3B32252F564C260D0351A12E3F
340B0F0604011B261B0406050406080D0E151C1B0C030100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000081E2D353A3832262D4F491F15081A748246
1C07070B0115364A4F1E020001010507070B161D180C0502
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000071D2E3737342C2B323A180D131F365247
270E00001A3F382D252F22130A0405040B0A0E1114150D03
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B30343730322D2440526C8C9C8A74
531000144D4B38392A2C291F1D0E03040A09070B13211401
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000051D303431302E1F3FABD0D5CDB791
36010B4654565D6064554C3F260D09050503050D141D1001
010100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000051D32352F2A231858B0BEA57829
00063D606369605C5D584E4D50452B130301070E11130901
000001010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000031D33322C221B0E0B0C080100
00236369645A4F504845414E595157391903050B13110801
010101010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000004213231231D120601000002
133A57564F453E3C362F333D41433D2E261D091121110601
000301010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000720302B1F180C05010415
243947443F3B39373F55778B8684775D3F26101C210A0303
000404010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000006222F261B0D0907161D
1D2B3B403C3C414D6091BDCBC3BEAEAE9F6B1A1A12060605
080502010101000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000007282C0C0609111615
1A273039404B59657E7884ABD6E6DECEC5A53A1912140909
100B00010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000510060A0800050E111013
1D29333D4B5B72908D63374288C1DADCD0C153241F170D15
1D0900010101010000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000003212D100202050B0F0F1017
2333414A60718B939FAB763113366F98A8A66D563F26171E
180100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000051A181F190905090F0F101222
364560798699894A205EC0AD7A3A161F5B9599939C733617
070100000101010100000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000001432180F0E0A0A1112141E2944
576D7F97A1A3947E52171F52A2C39C807BACBFB6CBC78623
030503030302010000010100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000010005282B1C24211F14131C223152667B
8C91A2A2AA9FAFB4B3976335296FB6D1C9BBB4B4A6A4650E
060505060704010000030300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000061B301D0902020D141E324F7189949B
A2A5AF9FA7B0A18A8DA7AAB187353C518CB7BAAC956B0A05
0404070806040100000A0900000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001000311213332302C180E1D365787A1A6A6AA
ACB3BBB0AA8E38142A6685A0B5957F686BADBCA78F591E1F
0C0F0D0A0704070409170600000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000031722232F393E3D2F1C386084A3A59B9899
A6BAB8B6A3707133081F62C0DDE1E7DEB7AEB39274443A47
3227240F060512210F080000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000012737391A192221202A2B3C517F868D8A8C93
A3B2BDC5B0799372647F8988AFCDDBDACCAA8C6559394555
434E533A1E1A262F05000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000011322E2A2613060714192D37454A445D5E5560
82ABC0C3BD87797B98989BA0AFB6C1D2C0973D2D3D2B3C62
3D6B8575533B3A1300010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002031251F2C2818100D1A2B3322110A245B8290
858FB9B8B0947DA9C1A497A0A5B5CFD0BA52091224182867
6660A4B2884B1B0000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000005322D2927222D2C160A1329391C161419316E7D
A19C99A39583A1DEC9B4AB9BA6C7CCD192221814100B124B
7F646CA0882A010101010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000044E6C5722282A34332B15224F4C2E27495F5973
7D7470746E669BC4A9B2BCBFC6C8CCD3723432331B080628
6572503D2002000202000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000493AD431C1C171418241F2D669D7E5D657A6E51
4E363A323461A4ADA0B1C2CCC5BDB5C97D5956543D120210
3E6466461E09000404020000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000001D9D96313730210C090B1D3C76ABCCB79F816846
261B0F093AB7B6839CACA3ABB8BCBABE7F746D423F1E0402
204A62564321020106090300000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000002CD4825C662A192B3C2B1E3F78A8C6DDCABEA15B
2C130C1C7BD3BE83847C7888999B9BB5847C8C6022150A02
072A5655462D0F00040E0800000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000DAAC0955B568293846D3C446895BBD7E2E5DED5
C1997EA1CED9B66D4B42608A97A9A6A9927C92924F200E08
06214F685A41220301131907000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004F9E36197AA16528263737517BA7C2D6DDEDF1
EFE9DFD7CBC8B553213D4F83979DA3B5AD8491947143230F
051A47717C5A370E00183319010000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000002D6395934E4A6D845B302E3A71989FBACCDADB
DDE2E7D8CDD0D08626254F6E7A826F667C828D92855F4012
030F3967886E451802264125020000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000004C653E9BACABA678766E5F535B85A8B6C7D1DA
E0E5EBEBECE6DFCB81414F7A6C6B5A4A5569878D84674E26
060625537F7F531E052C492A040000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000063CF8E7EC7CB69222F4754473F588AB7C3C6D0
E1ECF3F1ECE7E2E4E4BE95949A97979B71475B8D866F5836
170611386C83622803214F2B060000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000016EC9A6704E566E64523D3C2022354866A7C3CB
CDD2E9EBE6E0DEDEE0E5D5BCBEC0B8AA7A274A7B7E785C40
2610082660896833092D61320A0000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000006BAFB88E5289D4C0B3A7AA80667081706F94C7
D2C8D0D8D9DAD2D6D2D6C5B7BABDB4A06B3D5B8687816C44
2C17072759806B40174C6A3C1E0100000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000087B6AC9795CDCBBDE2EFD3C7BEA0786A84879D
D7D9D1D0C8D1CEC3BFBBB5A8A9A89670503342828C8E8659
32200B336A837542266E6246250000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000066C4B9B4B38F6568609ACDCABDAEA39B8CAA97
B9C6A9A19A9FA3A8A8969EA69C7C5D3512022A71868A855E
2F1A104782837B374479673E090000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000029C2BED3AA73B3EFD79DABB4C3E0EBEDCFBEAC
919080715A535B6E766C635D4F4B435E69521F657C818869
361D134D937C602E66683706000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000005A7C8B8C9F1F8EFEAEEE7EAF6EFEBEBD2B3A7
979BB0B4B58D81685C412A25171017325F510E547F81826C
4E2C1C629874413A76470700000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000066DAC3BAD4D8CECDC8D4DDD0D4C4ACB6A28E
7E6C7D6F99B4714C80989E8D85633F14342F2D4777817D6F
48352B89956C3B5C4E0D0000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000020D1D1CCD5DBE4E5EDEBDDE0AA5D3C53686E
67668DA49EC5B469445D6B748FA9B59C813C566B7A807D74
512D4F9A875F463E08000100000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000073E3CFD1DADAE6E9DADEB128060A091C58
7583BABCC4AEB8D38E555D54779FAE9C624D6F7F8483846A
482A6192734D250200010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000012BFE0CFD1D6CDDDE9DC6326271F160B28
6CA8B5C9C8AA81BBBF967E7C59534E5E435E7882858A8364
3E31727C5C29000001010000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000002FC0E7D9DBDEDAD5BB82817A613E2B14
47AED6A4C7C97E7C90BD9F9C915D7D7E3A6B7B838E8B7E60
44386F673F06000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000001AABEFE0DDE3DCB6A6C1DCDFA26B4A
2C94D896A4D2CCBFACB1C1AAB2BDBE503E697989928F7A60
3F445E521A00000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000777E7EDE4D9ABA4CBECE2C49486
327CDAC4958F9FBEC898A5A4AB7D454648687D898F88775C
3D3E4D300200000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000004BB1E8E89E81A8E6C9A7898A
3D55A9C2C2C0C6ABB496937E4E213A56525D7C918E7E6F55
2F2A38110001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000003DA99C736E989A817071
464A8DAFA5A4C8BFA987370F1636454A5F6983918B796747
212130050001000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000075F6C749598806955
43375F77808D8A743E0E0B191F3A4E4E5571888F85715A32
182C1E000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000386863676A605042
362A53626153361505101F271E3B4B565E728B8B7F724C2E
262C05000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000038736B6B67574432
2F291B120B0C1413121A2E3129364F597B8F827978694834
2B0900010000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000002D897C756E5E482F
2B30120A10141B161D2635303B40415F828C7C7C7B664E34
0C0000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000100128A766D6565593A
352C121119161721233635314D5658697E7772826F605016
000100000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000038196877A776951
492D121B1D1F19292B3C384765687480766C796958482100
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001068999288817267
512D1B1E1C1A282638404355737B78786C6A5B4A49240000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001B589092867A7567
47291F231F232E304F4C5866727A79797253494017000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000001D58878E88796B5D
4028282527372B4A595A6A787375797D6649310800000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000000000001010D59839186756556
40322F2B36314661606A757E79757D734B1C000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001040302467B897B6A5F4F
4036323A39475A6568797F83807C6D460E00000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000002030200206F8477625D52
463C42484D595E6771798182756142140001000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000001010102083C7E7B6A655D
4A4650575E63656D757A735D4B4026000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010304081645626E6E67
59555A5C5E65696C695C5149413409000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010101010A0D0A1B233C53605F
605F5D606265646057504D42391700000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000010100030D19181D272B3D5256
585E626364675F5953504B43250000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000000000000000000102070E1B201E22262E4556
5D646664615D5B5858524D32030000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000000000000000002050C0F1A25262320212E3F
525B62655E5B5B5A59554310000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000001030A0E101929363F44433E46
555D606263605D5E5B552C00000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000000000000000202080C0E121A293E5666717171
717273706963615F5D450800000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010001020306080A0D121C2737434E5E656B
6F71706B615F5E5F5D1E0000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010003030404050B11151B26313B454E555D
676E716D6A6D6B7145000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
000000000001010102020201060C11171D27313D474E5A68
6F757B7A7473715E0E000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000000000010101010203050A0E131C2228323F4B54616E
777C7D7B756D672D00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
00000000000101000004090B0F141A21272D36434D596772
78797876746E490300000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0000010001030202040A0C1116191E232B313A45525C6776
777477776D5B1A0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
0001020102020203070C1015191D21272E343E4A5A636B76
736F70685E37010100000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
01020203020102060A0C10161D1F242E3235404E5C686D6F
6E6B695E4F0E000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000000
01050505030306080B1114171D20232C313C45536064666A
69675C562800000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000001
020506050609080C101013161D222429303B48535B636664
615E55410700000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
000000000000000000000000000000000000000000000003
0506090A0A0A0E0E101112171C1E2228313E4856595C5C59
595348180000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooolT000000H00@410P00000300410@<00`<31@020P8300P820<0
2`/;0P0E5AD301XJ6P<07AdM0`0N7Qh2020P80<08b<S0`0U9BD3028R8P80820P0`0M7Ad301TI6@<0
4a<C0P0@410600`<30<03Ph>0P0E5AD301dM7@<08b<S200[:b/3024Q8@<0410@0P0820P300410Hh0
0000203oool000H0oooo9000000600410@8000000`010@4300<30`D00P820`0820P300/;2`805ADE
0`0J6QX301dM7@<07QhN0P0P820302<S8`<09BDU0`0R8R82020P80<07AdM0`0I6AT301<C4`80410@
1P0<30`300h>3P805ADE0`0M7Ad302<S8`P0:b/[0`0Q8B43010@408020P80`010@6>000000P0oooo
00060?ooocD000000P010@4300820P<01PH60P0>3Ph301PH60H07alO0P0Q8B4302DU9@<0:2PX0`0Z
:RX202LW9`<09RHV0`0Q8B4301/K6`8051@D0`0=3@d300/;2`<03`l?0P0G5aL301hN7P<0:BTY0`11
@D42055AD@<0F5QH0`1CDe<303Ph>0805aLG0`061PH300410H/00000203oool000H0oooo=@000002
00410@<00P820`061PH200h>3P<061PH1P0O7al2024Q8@<09BDU0`0X:2P302XZ:P809bLW0`0V9RH3
024Q8@<06a/K0P0D51@300d=3@<02`/;0`0?3`l201LG5`<07QhN0`0Y:BT30451@@80DE5A0`1HF5P3
05=CD`<0>3Ph0P0G5aL300H61P<00@41R`0000080?ooo`001P3ooole000000800@410`020P8300H6
1P803Ph>0`0H61P601lO7`808B4Q0`0U9BD302PX:0<0:RXZ0P0W9bL302HV9P<08B4Q0`0K6a/201@D
50<03@d=0`0;2`/300l?3`805aLG0`0N7Qh302TY:@<0@D510P1ADE4305QHF0<0De=C0`0h>3P201LG
5`<01PH60`010@6;000000P0oooo00060?ooocD000000P010@43000000<00@410P071`L3010@40<0
6a/K0`0O7al2028R8P<0:BTY0`0];Bd3030`<080;bl_0`0];Bd302TY:@<08b<S0P0I6AT3010@40<0
30`<0`0?3`l200d=3@<05aLG0`0V9RH303De=@80<S8b0`0a<C4303Lg=`<0>c/k0P0Z:RX301DE5@<0
1`L7R`0000080?ooo`001P3ooole000000800@410`00000300410@801`L70`0@410301/K6`<07alO
0P0R8R8302TY:@<0;Bd]0`0`<30202l_;`<0;Bd]0`0Y:BT302<S8`806ATI0`0@410300`<30<03`l?
0P0=3@d301LG5`<09RHV0`0e=CD2038b<P<0<C4a0`0g=cL303/k>`80:RXZ0`0E5AD300L71h/00000
203oool000H0oooo=@00000200410@<000000`010@4200L71`<0410@0`0K6a/301lO7`808R8R0`0Y
:BT302d];@<0<30`0P0_;bl302d];@<0:BTY0`0S8b<201TI6@<0410@0`0<30`300l?3`803@d=0`0G
5aL302HV9P<0=CDe0P0b<S83034a<@<0=cLg0`0k>c/202XZ:P<05ADE0`071`N;000000P0oooo0006
0?ooocX000001@010@4300D51@<03Ph>0`0J6QX2024Q8@<0:BTY1P0c<c<503@d=0<0<c<c0`0[:b/2
024Q8@H071`L0`0J6QX201DE5@<071`L0`0N7Qh301PH60804A4A0`0E5AD301LG5`<06a/K0P0E5AD3
01`L70<07alO0P0F5QH300P820P010@40`030`<300410GP00000203oool000H0oooo>P0000050041
0@<01@D50`0>3Ph301XJ6P808B4Q0`0Y:BT603<c<`D0=3@d0`0c<c<302/[:`808B4Q1P0L71`301XJ
6P805ADE0`0L71`301hN7P<061PH0P0A4A4301DE5@<05aLG0`0K6a/201DE5@<071`L0`0O7al201HF
5P<020P8200410@300<30`<00@41N00000080?ooo`001P3ooolo000000<00@410`030`<300T92@80
5aLG0`0U9BD3038b<P<0=CDe0P0f=SH303Xj>P<0=CDe0`0a<C4502`/;0<0;bl_0`0Z:RX202@T90<0
;2`/0`0O7al300l?3`802PX:0`0=3@d6018B4P8030`<0`0?3`l301DE5@806ATI0`0J6QX301PH60<0
71`L0P0Q8B4302<S8`<08R8R0`0F5QH2014A4@<02PX:0`051@D500410FP00000203oool000H0oooo
?`00000300410@<00`<30`092@T201LG5`<09BDU0`0b<S8303De=@80=SHf0`0j>SX303De=@<0<C4a
1@0/;2`302l_;`<0:RXZ0P0T92@302`/;0<07alO0`0?3`l200X:2P<03@d=1P0B4Q8200`<30<03`l?
0`0E5AD201TI6@<06QXJ0`0H61P301`L70808B4Q0`0S8b<3028R8P<05QHF0P0A4A4300X:2P<01@D5
1@010@5X000000P0oooo00060?ooocl000000`010@4300<30`<02@T90P0G5aL302DU9@<0<S8b0`0e
=CD203Hf=P<0>SXj0`0e=CD3034a<@D0;2`/0`0_;bl302XZ:P8092@T0`0/;2`301lO7`<03`l?0P0:
2PX300d=3@H04Q8B0P0<30`300l?3`<05ADE0P0I6AT301XJ6P<061PH0`0L71`2024Q8@<08b<S0`0R
8R8301HF5P804A4A0`0:2PX300D51@D00@41J00000080?ooo`001P3ooom5000000<00@410P0410@3
01<C4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT3
03hn?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph3
00@410<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`3
00d=3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C
4`<0:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn
?P<0:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@4
10<01`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=
3@8020P80`030`<6000000800@41DP0000080?ooo`001P3ooom5000000<00@410P0410@301<C4`<0
:BTY0`0c<c<203De=@<0>CTi0`0h>3P303De=@80=3@d0`0g=cL303De=@<0:b/[0P0Y:BT303hn?P<0
:BTY0`0I6AT200`<30<02@T90`0C4a<301@D50805ADE0`0O7al301XJ6P802PX:0`0>3Ph300@410<0
1`L70P0>3Ph301LG5`<06a/K0`0G5aL201XJ6P<06ATI0`0G5aL301DE5@804a<C1P0<30`300d=3@80
20P80`030`<6000000800@41DP0000080?ooo`001P3ooom=000000<03Ph>0`0T92@202h^;P<0=SHf
0`0h>3P303Ti>@D0?3`l0`0d=3@502TY:@<0A4A40`0k>c/302TY:@802`/;0`0820P301hN7P<06a/K
0P0F5QH303hn?P<09bLW0P0>3Ph600P820<01@D50P00000300820P<01@D50`020P8200T92@<05aLG
0`0E5AD301`L70806ATI0`0J6QX3028R8P<071`L0P0I6AT300l?3`<01`L70`010@5D000000P0oooo
00060?ooodd000000`0>3Ph302@T9080;Rh^0`0f=SH303Ph>0<0>CTi1@0l?3`303@d=0D0:BTY0`14
A4@303/k>`<0:BTY0P0;2`/300P820<07QhN0`0K6a/201HF5P<0?Shn0`0W9bL200h>3PH020P80`05
1@D2000000<00P820`051@D300820P802@T90`0G5aL301DE5@<071`L0P0I6AT301XJ6P<08R8R0`0L
71`201TI6@<03`l?0`071`L300410E@00000203oool000H0ooooC@00000300h>3P<092@T0P0^;Rh3
03Hf=P<0>3Ph0`0i>CT503`l?0<0=3@d1@0Y:BT304A4A0<0>c/k0`0Y:BT200/;2`<020P80`0N7Qh3
01/K6`805QHF0`0n?Sh302LW9`803Ph>1P0820P300D51@8000000`020P8300D51@<00P820P092@T3
01LG5`<05ADE0`0L71`201TI6@<06QXJ0`0R8R8301`L70806ATI0`0?3`l300L71`<00@41E0000008
0?ooo`001P3ooom@000000<02PX:0P0Q8B43034a<@<0=CDe0`0i>CT203dm?@<0>c/k0`0b<S8302DU
9@80;bl_0`1FEUH304a<C0<09RHV0P0=3@d300<30`<0DE5A0`2QXJ4202h^;P<0?clo0`0d=3@200/;
2`<03`l?0`061PH300@410800@410`0K6a/302HV9P<06a/K0P0410@300H61P<01@D50`0410@200H6
1P<020P80`0=3@d300h>3P805ADE0`0L71`301/K6`<030`<0P030`<300410Dl00000203oool000H0
ooooD000000300X:2P808B4Q0`0a<C4303De=@<0>CTi0P0m?Cd303/k>`<0<S8b0`0U9BD202l_;`<0
EUIF0`1<C4`302HV9P803@d=0`030`<3055AD@<0XJ6Q0P0^;Rh303lo?`<0=3@d0P0;2`/300l?3`<0
1PH60`0410@200410@<06a/K0`0V9RH301/K6`8010@40`061PH300D51@<010@40P061PH300P820<0
3@d=0`0>3Ph201DE5@<071`L0`0K6a/300`<30800`<30`010@5?000000P0oooo00060?oooe<00000
0P0820P301hN7P<0;Bd]0`0e=CD203Xj>P<0>3Ph0`0b<S8302HV9P80;Bd]0`1?Cdl304U9B@<07alO
0P0E5AD300P820<06QXJ0`1dM7@208:2PP<0ATI60`0L71`500L71`<02`/;0`010@4201DE5@<0=SHf
0`1:BTX304m?C`807QhN0`020P83000000D00@410`051@D600L71`802`/;0`0F5QH301dM7@<061PH
0P0<30`300D51@<00P82C00000080?ooo`001P3ooomC0000008020P80`0N7Qh302d];@<0=CDe0P0j
>SX303Ph>0<0<S8b0`0V9RH202d];@<0Cdm?0`19BDT301lO7`805ADE0`0820P301XJ6P<0M7Ad0P22
PX8304I6AP<071`L1@071`L300/;2`<00@410P0E5AD303Hf=P<0BTY:0`1?Cdl201hN7P<00P820`00
000500410@<01@D51P071`L200/;2`<05QHF0`0M7Ad301PH608030`<0`051@D300820T`00000203o
ool000H0ooooD`00000200P820<07QhN0`0];Bd303De=@80>SXj0`0h>3P3038b<P<09RHV0P0];Bd3
04m?C`<0BDU90`0O7al201DE5@<020P80`0J6QX307AdM080PX:20`16ATH301`L70D01`L70`0;2`/3
00410@805ADE0`0f=SH304Y:BP<0Cdm?0P0N7Qh300820P<000001@010@4300D51@H01`L70P0;2`/3
01HF5P<07AdM0`0H61P200`<30<01@D50`020P9<000000P0oooo00060?oooeD000000`071`L301dM
7@<0;Rh^1@0g=cL303@d=0<0;2`/0P0[:b/3038b<P<0>SXj0`0H61P200d=3@<04a<C0`0O7al303Hf
=P80DU9B0`17AdL302LW9`803Ph>1P00000301XJ6P80?clo0`0h>3P302d];@<09BDU0P0_;bl3028R
8P<04a<C0`0:2PX200@410<01@D50`0410@300/;2`802PX:0`0>3Ph3014A4@<051@D0P0E5AD300d=
3@<00`<3C00000080?ooo`001P3ooomE000000<01`L70`0M7Ad302h^;PD0=cLg0`0d=3@302`/;080
:b/[0`0b<S8303Xj>P<061PH0P0=3@d301<C4`<07alO0`0f=SH2059BDP<0AdM70`0W9bL200h>3PH0
00000`0J6QX203lo?`<0>3Ph0`0];Bd302DU9@80;bl_0`0R8R8301<C4`<02PX:0P0410@300D51@<0
10@40`0;2`/200X:2P<03Ph>0`0A4A4301@D50805ADE0`0=3@d300<30d`00000203oool000H0oooo
E@00000300L71`<07AdM0`0^;Rh503Lg=`<0=3@d0`0/;2`202/[:`<0<S8b0`0j>SX301PH60803@d=
0`0C4a<301lO7`<0=SHf0P1BDU8304M7A`<09bLW0P0>3Ph6000000<06QXJ0P0o?cl303Ph>0<0;Bd]
0`0U9BD202l_;`<08R8R0`0C4a<300X:2P8010@40`051@D300@410<02`/;0P0:2PX300h>3P<04A4A
0`0D51@201DE5@<03@d=0`030`=<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d
=3@303Lg=`<0<30`0P0b<S8302d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1d
M7@305=CD`80410@0`00000301@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O
7al301dM7@803Ph>0`030`<300@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`01
0@5<000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0d=3@303Lg=`<0<30`0P0b<S83
02d];@<092@T0`10@402059BDP<0K6a/0`2<S8`309bLW080RXZ:0`1dM7@305=CD`80410@0`000003
01@D50<0CDe=0P1;Bd/303Ph>0<0>CTi0`0Z:RX202`/;0<0:BTY0`0O7al301dM7@803Ph>0`030`<3
00@410<02PX:0P092@T300L71`<02`/;0`0C4a<2024Q8@<051@D0`010@5<000000P0oooo00060?oo
oe/000000`051@D201dM7@<0<30`0`0d=3@3034a<@80<30`0`0^;Rh301lO7`<0?clo0P2[Zj/30=3@
d0<0eMGE0`3=cLd20;Ng]`<0TI6A0`0f=SH200410@<02`/;0`16ATH305ADE080EUIF0`1MGEd3061P
H0<0I6AT0P1EEED304a<C0<0?clo0`0V9RH200d=3@<02@T91P051@D200<30`<01@D50`0=3@d301@D
50807AdM0`0@410800410DL00000203oool000H0ooooF`00000300D51@807AdM0`0`<30303@d=0<0
<C4a0P0`<30302h^;P<07alO0`0o?cl20:^[Z`<0d=3@0`3EeMD30<g=c@80]kNg0`2ATI4303Hf=P80
0@410`0;2`/304I6AP<0E5AD0P1FEUH305eMG@<0H61P0`1TI6@205EEE@<0C4a<0`0o?cl302HV9P80
3@d=0`092@T600D51@800`<30`051@D300d=3@<051@D0P0M7Ad3010@40P00@41A`0000080?ooo`00
1P3ooomK000000<01@D50P0M7Ad3030`<0<0=3@d0`0a<C42030`<0<0;Rh^0`0O7al303lo?`80Zj^[
0`3@d=030=GEe@<0cLg=0P2g]kL3096AT@<0=SHf0P010@4300/;2`<0ATI60`1DE5@205IFEP<0GEeM
0`1PH60306ATI080EEEE0`1<C4`303lo?`<09RHV0P0=3@d300T92@H01@D50P030`<300D51@<03@d=
0`0D51@201dM7@<0410@20010@57000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e
=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P06
1PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15
ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P01
0@51000000P0oooo00060?oooeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<3
01PH6080F5QH0`2`/;030;jn_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<2
06UYJ@<0H61P0`1LG5`305eMG@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<2
00410@<01`L70`0>3Ph3014A4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?oo
oeh000000P051@D301dM7@<0<S8b0`0e=CD202l_;`<0:RXZ0`0S8b<301PH6080F5QH0`2`/;030;jn
_P<0YJFU0P1hN7P302TY:@<000000P061PH303dm?@<0H61P0`1SHf<206UYJ@<0H61P0`1LG5`305eM
G@80F5QH0`1>CTh304e=C@<0D51@0P15ADD302/[:`<04a<C0`030`<200410@<01`L70`0>3Ph3014A
4@804a<C0`092@T300410@D000001P010@51000000P0oooo00060?ooof0000000`030`<301dM7@<0
<c<c0P0b<S8302`/;0<08R8R0`0K6a/200h>3P<02`/;0`0<30`300P820800@411P00000202<S8`<0
Hf=S0`1YJFT306ATI080FUYJ0`1?Cdl3051@D0<0B4Q80P15ADD30451@@<0CTi>0`1IFET2055AD@<0
EeMG0`0i>CT301TI6@800`<30`051@D300/;2`<04a<C0P0A4A4300P820h00@41@@0000080?ooo`00
1P3ooomP000000<00`<30`0M7Ad303<c<`80<S8b0`0/;2`3028R8P<06a/K0P0>3Ph300/;2`<030`<
0`0820P200410@H000000P0S8b<306=SH`<0JFUY0`1TI6@205YJFP<0Cdm?0`1@D50304Q8B080ADE5
0`11@D4304i>CP<0FEUI0P1ADE4305MGE`<0>CTi0`0I6AT200<30`<01@D50`0;2`/301<C4`804A4A
0`0820P>00410D400000203oool000H0ooooH000000300<30`<07AdM0`0c<c<2038b<P<0;2`/0`0R
8R8301/K6`803Ph>0`0;2`/300`<30<020P80P010@46000000808b<S0`1SHf<306UYJ@<0I6AT0P1J
FUX304m?C`<0D51@0`18B4P204E5A@<0@D510`1>CTh305UIF@80DE5A0`1GEeL303Ti>@<06ATI0P03
0`<300D51@<02`/;0`0C4a<2014A4@<020P83P010@51000000P0oooo00060?ooof<000000`0410@3
024Q8@80<S8b0`0a<C4302<S8`<07AdM0P0B4Q8300H61P<00@411@00000300820P<04a<C0P0j>SX3
05MGE`<0EUIF0`1?Cdl204E5A@<0?Shn0`0l?3`303Hf=P80;bl_0`0c<c<303dm?@<0@D510P13@d<3
03dm?@<0;Rh^0`0V9RH201dM7@<02@T90`0A4A43024Q8@804A4A0`061PH300410@<000000P030`<;
00410C`00000203oool000H0ooooH`00000300@410<08B4Q0P0b<S83034a<@<08b<S0`0M7Ad2018B
4P<01PH60`010@45000000<00P820`0C4a<203Xj>P<0EeMG0`1FEUH304m?C`80ADE50`0n?Sh303`l
?0<0=SHf0P0_;bl303<c<`<0?Cdm0`11@D4204=3@`<0?Cdm0`0^;Rh302HV9P807AdM0`092@T3014A
4@<08B4Q0P0A4A4300H61P<00@410`00000200<30`/00@41?00000080?ooo`001P3ooomV000000<0
1`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080
>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80
Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P0
0@41?00000080?ooo`001P3ooomV000000<01`L70P0P8203030`<0<0:b/[0`0O7al201PH60<030`<
0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg
0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1gMgL305eMG@<0?clo0P0V9RH3010@40<071`L
0`0Q8B4200X:2PH00`<30`00000500@410P00@41?00000080?ooo`001P3ooomV000000<01`L70P0P
8203030`<0<0:b/[0`0O7al201PH60<030`<0`051@D300410@8010@40`0E5AD302@T9080>CTi0`17
AdL304A4A0<0?clo0P0k>c/303Ti>@<0=cLg0`0o?cl205EEE@<0MgMg0`2;Rh/308J6QP80Q8B40`1g
MgL305eMG@<0?clo0P0V9RH3010@40<071`L0`0Q8B4200X:2PH00`<30`00000500@410P00@41?000
00080?ooo`001P3ooomY000000801PH60`0R8R8302l_;`<09RHV0P0K6a/300d=3@<02@T90`071`L2
01HF5PH07AdM0P0[:b/303/k>`<0@4101@0l?3`30451@@<0CDe=0`1PH602096AT@<0_Kfm0`3;bl/3
0<?3``80_[jn1P2^[Zh309nOW`80Jf][1P0J6QX3018B4PD01PH60`051@D300P820801@D50`020P88
00410C`00000203oool000H0ooooJ@00000200H61P<08R8R0`0_;bl302HV9P806a/K0`0=3@d300T9
2@<01`L70P0F5QH601dM7@80:b/[0`0k>c/30410@0D0?3`l0`11@D4304e=C@<0H61P0P2ATI430;fm
_@<0bl_;0`33`l<20;jn_PH0[Zj^0`2OWil206][J`H06QXJ0`0B4Q8500H61P<01@D50`0820P200D5
1@<00P8220010@4l000000P0oooo00060?ooofT000000P061PH3028R8P<0;bl_0`0V9RH201/K6`<0
3@d=0`092@T300L71`805QHF1P0M7Ad202/[:`<0>c/k0`10@40503`l?0<0@D510`1=CDd3061PH080
TI6A0`2m_Kd30<_;b`<0`l?30P2n_[h60:j^[P<0WinO0P1[Jf/601XJ6P<04Q8B1@061PH300D51@<0
20P80P051@D300820PP00@41?00000080?ooo`001P3ooom[000000<01`L70`0X:2P302`/;08030`<
0`061PH300T92@<04A4A0P0F5QH301DE5@<06QXJ0P0W9bL3030`<0<0>CTi0`10@40204];B`<0FEUI
0`1UIFD307inOP80N7Qh0`24Q8@30:^[Z`<0e]KF0P3Vi^H30=kNgP<0c/k>0`35aLD20:FUY@<0>SXj
0`0I6AT3018B4P8051@D1P092@T3010@40802`/;0`00000;00410CT00000203oool000H0ooooJ`00
000300L71`<0:2PX0`0/;2`200`<30<01PH60`092@T3014A4@805QHF0`0E5AD301XJ6P809bLW0`0`
<30303Ti>@<0@4100P1;Bd/305UIF@<0IFEU0`1nOWh207QhN0<0Q8B40`2[Zj/30=KFeP80i^KV0`3N
g]h30<k>cP<0aLG50P2UYJD303Xj>P<06ATI0`0B4Q8201@D50H02@T90`0@410200/;2`<000002`01
0@4i000000P0oooo00060?ooof/000000`071`L302PX:0<0;2`/0P0<30`300H61P<02@T90`0A4A42
01HF5P<05ADE0`0J6QX202LW9`<0<30`0`0i>CT30410@080Bd];0`1IFET306EUI@<0OWin0P1hN7P3
08B4Q0<0Zj^[0`3Fe]H20>KViP<0g]kN0`3>c/h30<G5a@80YJFU0`0j>SX301TI6@<04Q8B0P0D51@6
00T92@<0410@0P0;2`/3000000/00@41>@0000080?ooo`001P3ooomV000000<01@D50P0@410300H6
1P<02PX:0`0820P2000000<01@D50`0>3Ph3014A4@80410@0`0C4a<301dM7@80:BTY0`0c<c<303dm
?@<0Bd];0P1KFe/3079bLP<0T92@0`2=SHd206=SH`<0=cLg0`12@T8308R8R080`L710`3Jf]X30=cL
g0<0d=3@0P31`L4305=CD`<092@T0`0O7al201LG5`<03@d=0`0E5AD301dM7@802@T90`00000;0041
0CT00000203oool000H0ooooIP00000300D51@80410@0`061PH300X:2P<020P80P00000300D51@<0
3Ph>0`0A4A42010@40<04a<C0`0M7Ad202TY:@<0<c<c0`0m?Cd304];B`80Fe]K0`1bLW83092@T0<0
SHf=0P1SHf<303Lg=`<0@T920`28R8P20<71`@<0f][J0`3Lg=`30=3@d080`L710`1CDe<302@T90<0
7alO0P0G5aL300d=3@<05ADE0`0M7Ad200T92@<000002`010@4i000000P0oooo00060?ooof<00000
0`030`<3024Q8@80;Bd]0`0@410600820P801@D50`0;2`/600l?3`80410@0`0G5aL302<S8`80<c<c
0`11@D4304Y:BP<0H61P0P1aLG4308^;R`<0Ti>C0`2OWil20:^[Z`<0MWIf0`0a<C4301<C4`80=SHf
0`1_Kfl309RHV0<0Z:RX0P2VYZH306e]K@<0EUIF0`0o?cl202HV9P<05aLG0`0N7Qh301PH60800@41
1P00000;00410CH00000203oool000H0ooooH`00000300<30`<08B4Q0P0];Bd3010@40H00P820P05
1@D300/;2`H03`l?0P0@410301LG5`<08b<S0P0c<c<30451@@<0BTY:0`1PH602075aL@<0Rh^;0`2C
Ti<309nOW`80Zj^[0`1fMWH3034a<@<04a<C0P0f=SH306m_K`<0V9RH0`2XZ:P20:JVYP<0KFe]0`1F
EUH303lo?`809RHV0`0G5aL301hN7P<061PH0P010@46000000/00@41=P0000080?ooo`001P3ooomS
000000<00`<30`0Q8B4202d];@<0410@1P020P8200D51@<02`/;1P0?3`l2010@40<05aLG0`0S8b<2
03<c<`<0@D510`1:BTX3061PH080LG5a0`2;Rh/309>CT`<0WinO0P2[Zj/307IfMP<0<C4a0`0C4a<2
03Hf=P<0Kfm_0`2HV9P30:RXZ080YZJV0`1]KFd305IFEP<0?clo0P0V9RH301LG5`<07QhN0`0H61P2
00410@H000002`010@4f000000P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI
6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6
QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]K
F`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f0000
00P0oooo00060?ooof0000000`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H0
3`l?0`0@4102018B4P<08R8R0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0
820P0P1NGUh30<30`0<0[Jf]0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0
W9bL0P1cLg<303Hf=P<05aLG0`071`L200410@H000002`010@4f000000P0oooo00060?ooof000000
0`051@D301XJ6P<061PH0P0O7al301TI6@<02@T90`051@D200T92@H03`l?0`0@4102018B4P<08R8R
0`0f=SH204E5A@<0H61P0`1iNGT308J6QP80VIVI0`29RHT304Y:BP<0820P0P1NGUh30<30`0<0[Jf]
0`1jNWX203Xj>P<05QHF0`0O7al305]KF`80UIFE0`2IVIT309>CT`<0W9bL0P1cLg<303Hf=P<05aLG
0`071`L200410@H000002`010@4f000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?
3`l300h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2G
UiL30:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20
P80307]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`02
0P8300410@D000001P010@4^000000P0oooo00060?ooof0000000`0D51@3038b<P<061PH0P0?3`l3
00h>3PH02PX:0P0A4A43018B4P<051@D0`0N7Qh202TY:@<0A4A40`1GEeL206e]K@<0Ogmo0`2GUiL3
0:6QX@80Xj>S0`2DU9@307inOP<0DU9B0P0G5aL301lO7`<0DU9B0`2RXZ820<?3``<0W9bL0`20P803
07]kN`80[:b/0`2o_kl30;Jf]P<0bl_;0P37alL308J6QP<08b<S0`030`<200D51@P00`<30`020P83
00410@D000001P010@4^000000P0oooo00060?oooeD000000`010@43000000<01@D50P0X:2P302/[
:`<071`L0`0T92@2024Q8@<07alO0`0D51@301<C4`8071`L0`0R8R83034a<@<0DU9B0P1VIVH307]k
N`<0S8b<0P2ATI460::RXP<0ZZZZ0P2OWil30:n_[`<0];Bd0`2c/k<209NGU`<0Hf=S0`0e=CD302TY
:@80Kfm_0`2f][H30=7Ad@<0bLW90P2k^k/60;Bd]0<0YZJV0P2TY:@306EUI@<03Ph>0`061PH500D5
1@<01PH60P071`L300@410<00@411@00000600<30bh00000203oool000H0ooooE@00000300410@<0
00000`051@D202PX:0<0:b/[0`0L71`302@T90808B4Q0`0O7al301@D50<04a<C0P0L71`3028R8P<0
<C4a0`1BDU8206IVIP<0Ng]k0`2<S8`2096AT@H0XZ:R0`2ZZZX209nOW`<0[jn_0`2d];@30;>c/`80
UiNG0`1SHf<303De=@<0:BTY0P1_Kfl30;Jf]P<0dM7A0`39bLT20;^k^`H0];Bd0`2VYZH20:BTY0<0
IFEU0`0>3Ph300H61PD01@D50`061PH200L71`<010@40`010@45000000H00`<3;P0000080?ooo`00
1P3ooomE000000<00@410`00000300D51@80:2PX0`0[:b/301`L70<092@T0P0Q8B4301lO7`<051@D
0`0C4a<201`L70<08R8R0`0a<C43059BDP80IVIV0`1kNg/308b<S080TI6A1P2RXZ830:ZZZP80WinO
0`2_[jl30;Bd]0<0/k>c0P2GUiL306=SH`<0=CDe0`0Y:BT206m_K`<0][Jf0`3AdM430<W9b@80^k^k
1P2d];@30:JVYP80Y:BT0`1UIFD300h>3P<01PH61@051@D300H61P801`L70`0410@300410@D00000
1P030`<^000000P0oooo00060?oooeP000000`061PH301/K6`80<30`0`0M7Ad300T92@D00P820`0=
3@d301@D50<07QhN0P0b<S8304m?C`<0LG5a0`29RHT209BDU0<0Vi^K0`2RXZ820:FUY@<0[jn_0`2O
Wil30:NWY`80/;2`0`2QXJ4308Z:RP<0SHf=0P2WYjL30:ZZZP<0/K6a0`27QhL203De=@<0?3`l0`1A
DE4308b<S080]kNg0`2j^[X30:b/[0<0UIFE0P1[Jf/300X:2P<01@D51@0410@300L71`<020P80P06
1PH300@410<00@411@00000300X:2P<02@T9;P0000080?ooo`001P3ooomH000000<01PH60`0K6a/2
030`<0<07AdM0`092@T500820P<03@d=0`0D51@301hN7P80<S8b0`1?Cdl3075aL@<0RHV90P2DU9@3
09^KV`<0XZ:R0P2UYJD30:n_[`<0WinO0`2WYjL20;2`/0<0XJ6Q0`2:RXX308f=S@80YjNW0`2ZZZX3
0;6a/@<0QhN70P0e=CD303`l?0<0DE5A0`2<S8`20;Ng]`<0^[Zj0`2/[:`309FEU@80Jf][0`0:2PX3
00D51@D010@40`071`L300P820801PH60`0410@300410@D000000`0:2PX300T92Bh00000203oool0
00H0ooooF000000300H61P<06a/K0P0`<30301dM7@<02@T91@020P8300d=3@<051@D0`0N7Qh2038b
<P<0Cdm?0`1aLG4308V9R@80U9BD0`2KVi/30::RXP80YJFU0`2_[jl309nOW`<0YjNW0P2`/;030:6Q
X@<0RXZ:0`2=SHd20:NWY`<0ZZZZ0`2a/K4308N7Q`80=CDe0`0l?3`3055AD@<0S8b<0P2g]kL30;Zj
^P<0[:b/0`2EUID206][J`<02PX:0`051@D500@410<01`L70`0820P200H61P<010@40`010@450000
00<02PX:0`092@T^000000P0oooo00060?oooe0000000`010@42000000<00`<30`0A4A43024Q8@80
<c<c0`0b<S83030`<0<0;2`/0P0H61P300h>3P<07AdM0`0f=SH205MGE`<0QhN70`2QXJ450:JVYP<0
ZZZZ0`2/[:`20;>c/`<0^k^k0`2`/;030:ZZZP80SXj>0`0h>3P301@D50<0:RXZ0P1VIVH308F5Q@<0
X:2P0`2e]KD209FEU@<0Ogmo0`1XJ6P306][J`80[Jf]0`2l_;`30:NWY`<0Shn?0P1IFET301hN7P<0
7alO0`0<30`200l?3`<03@d=0`0:2PX200L71`<010@40`071`L300@410802@T90`0G5aL300H61Rh0
0000203oool000H0ooooD000000300410@8000000`030`<3014A4@<08B4Q0P0c<c<3038b<P<0<30`
0`0/;2`201PH60<03Ph>0`0M7Ad303Hf=P80EeMG0`27QhL30:6QX@D0YZJV0`2ZZZX30:b/[080/k>c
0`2k^k/30;2`/0<0ZZZZ0P2>SXh303Ph>0<051@D0`0Z:RX206IVIP<0QHF50`2PX:030;Fe]@80UIFE
0`1oOgl306QXJ0<0Jf][0P2][Jd30;bl_0<0YjNW0`2?Shl205UIF@<07QhN0`0O7al300`<30803`l?
0`0=3@d300X:2P801`L70`0410@300L71`<010@40P092@T301LG5`<01PH6;P0000080?ooo`001P3o
oom@000000<00@410P00000300<30`<04A4A0`0Q8B4203<c<`<0<S8b0`0`<30302`/;08061PH0`0>
3Ph301dM7@<0=SHf0P1GEeL308N7Q`<0XJ6Q1@2VYZH30:ZZZP<0[:b/0P2c/k<30;^k^`<0/;2`0`2Z
ZZX208j>SP<0>3Ph0`0D51@302XZ:P80IVIV0`25QHD30:2PX0<0]KFe0P2EUID307moO`<0J6QX0`1[
Jf/20:f][@<0_;bl0`2WYjL308n?S`80FEUI0`0N7Qh301lO7`<030`<0P0?3`l300d=3@<02PX:0P07
1`L300@410<01`L70`0410@200T92@<05aLG0`061PH^000000P0oooo00060?oooe<000000P030`<3
01LG5`<08R8R0`0S8b<202l_;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@3
0:>SX`<0YJFU0`2KVi/209RHV0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG43
03<c<`<020P80P0O7al3069RHP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<3
09:BTP<0M7Ad0P14A4@303Xj>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83
024Q8@803`l?0`0820Pa000000P0oooo00060?oooe<000000P030`<301LG5`<08R8R0`0S8b<202l_
;`<0>CTi0`0n?Sh303dm?@80;bl_0`0L71`303Ph>0<0H61P0P24Q8@30:>SX`<0YJFU0`2KVi/209RH
V0<0VIVI0`2VYZH20;Zj^P<0^;Rh0`2f][H30:>SX`80L71`0`1aLG4303<c<`<020P80P0O7al3069R
HP<0`<300`3MgMd20>7Qh@<0inOW0`3Ng]h30;Ng]`80[Zj^0`2c/k<309:BTP<0M7Ad0P14A4@303Xj
>P<0AdM70`0b<S8202LW9`<092@T0`0?3`l200H61P<01@D50`0B4Q83024Q8@803`l?0`0820Pa0000
00P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0
820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80
/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80
cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80
CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe000000
0`010@4202LW9`<0=cLg0`0i>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l
0`1ADE4207moO`<0QXJ60`2=SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`
0P1iNGT309>CT`<0LW9b0`1TI6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<
0P2ZZZX308b<S0<0IFEU0`1IFET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN
0`0J6QX302HV9P<0;bl_0P051@Dd000000P0oooo00060?oooe0000000`010@4202LW9`<0=cLg0`0i
>CT301XJ6P806ATI0`0R8R83024Q8@<0820P0P0Z:RX302/[:`<0?3`l0`1ADE4207moO`<0QXJ60`2=
SHd308Z:RP80S8b<0`2CTi<30:>SX`80/[:b0`2m_Kd30<G5a@<0/;2`0P1iNGT309>CT`<0LW9b0`1T
I6@207moO`<0RHV90`28R8P30:n_[`80cLg=0`3Kfm/30=[JfP<0c<c<0P2ZZZX308b<S0<0IFEU0`1I
FET203Ti>@<0ADE50`1EEED304=3@`80CTi>0`1CDe<303Xj>P807QhN0`0J6QX302HV9P<0;bl_0P05
1@Dd000000P0oooo00060?oooe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH3
00L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH603
08:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl2
0;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd2
06][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oo
oe0000000`0A4A42038b<P<0;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d]
;@<0=cLg0`15ADD204Y:BP<0A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3
``<0_Kfm0P27QhL307UiN@<0Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30
`080UiNG0`0m?Cd302d];@<0?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=C
D`<0>c/k0`0j>SX301<C4`8000000`010@4a000000P0oooo00060?oooe0000000`0A4A42038b<P<0
;Rh^0`0Z:RX302HV9P804a<C0`061PH300L71`<051@D0P0I6AT302d];@<0=cLg0`15ADD204Y:BP<0
A4A40`1MGEd305iNGP80EEEE0`1PH60308:2PP80Zj^[0`30`<030<?3``<0_Kfm0P27QhL307UiN@<0
Ng]k1@2HV9P309^KV`<0X:2P0`2_[jl20;Jf]P<0`L710`3Bd]830<30`080UiNG0`0m?Cd302d];@<0
?Cdm0P0[:b/303`l?0<0HV9R0`0m?Cd206][J`<0QHF50`1eMGD205=CD`<0>c/k0`0j>SX301<C4`80
00000`010@4a000000P0oooo00060?oooe0000000`0P8202034a<@<09BDU0`0O7al302`/;080:2PX
0`0H61P3010@40<03@d=0P0J6QX302/[:`<0<c<c0`0R8R82014A4@<02PX:0`0T92@305]KF`80PX:2
0`2@T90308F5Q@80Shn?0`2i^KT30;Rh^0<0/;2`0P2DU9@307emO@<0ZJVY0`31`L420:BTY0<0UiNG
0`2PX:030:FUY@80]KFe0`3?cll30=3@d0<0^[Zj0P1BDU8300T92@<04Q8B0`0T92@201PH60<0:2PX
0`1WIfL306IVIP80H61P0`2TY:@30;:b/P80R8R80`1;Bd/301/K6cT00000203oool000H0ooooD000
0003020P8080<C4a0`0U9BD301lO7`<0;2`/0P0X:2P301PH60<0410@0`0=3@d201XJ6P<0:b/[0`0c
<c<3028R8P804A4A0`0:2PX302@T90<0Fe]K0P22PX83092@T0<0QHF50P2?Shl30;Vi^@<0^;Rh0`2`
/;0209BDU0<0OGem0`2YZJT30<71`@80Y:BT0`2GUiL30:2PX0<0YJFU0P2e]KD30<o?c`<0d=3@0`2j
^[X2059BDP<02@T90`0B4Q8302@T908061PH0`0X:2P306MWI`<0IVIV0P1PH6030:BTY0<0/[:b0P28
R8P304];B`<06a/K>@0000080?ooo`001P3ooom=000000<01@D50`0b<S8202d];@<0:BTY0`0W9bL3
028R8P80;Bd]0`0/;2`301HF5P<02PX:0P0C4a<302TY:@<0>CTi0`0L71`201HF5P<051@D0`0I6AT3
034a<@80KVi^0`1mOGd30:6QX@80W9bL0`2IVIT30:>SX`<0UIFE0P23Ph<30:6QX@<0g]kN0`39bLT2
0;Bd]0<0Zj^[0`2KVi/30:JVYP80alO70`3<c<`30=7Ad@<0TY:B0P0R8R8301PH60<051@D0`0@4102
00/;2`<04Q8B0`1;Bd/307moO`80I6AT0`1/K6`30:2PX080R8R80`0Z:RX;00410C400000203oool0
00H0ooooC@00000300D51@<0<S8b0P0];Bd302TY:@<09bLW0`0R8R8202d];@<0;2`/0`0F5QH300X:
2P804a<C0`0Y:BT303Ti>@<071`L0P0F5QH301@D50<06ATI0`0a<C4206i^KP<0OGem0`2QXJ4209bL
W0<0VIVI0`2SXj<309FEU@80Ph>30`2QXJ430=kNgP<0bLW90P2d];@30:^[Z`<0Vi^K0`2VYZH20<O7
a`<0c<c<0`3AdM4309:BTP808R8R0`0H61P301@D50<0410@0P0;2`/3018B4P<0Bd];0`1oOgl206AT
I0<0K6a/0`2PX:0208R8R0<0:RXZ2`010@4a000000P0oooo00060?ooodd000000`051@D3038b<P80
;Bd]0`0Y:BT302LW9`<08R8R0P0];Bd302`/;0<05QHF0`0:2PX201<C4`<0:BTY0`0i>CT301`L7080
5QHF0`0D51@301TI6@<0<C4a0P1^KVh307emO@<0XJ6Q0P2LW9`309VIV@<0Xj>S0`2EUID208>3P`<0
XJ6Q0`3Ng]h30<W9b@80];Bd0`2[Zj/309^KV`<0YZJV0P37alL30<c<c0<0dM7A0`2BTY82028R8P<0
61PH0`0D51@3010@40802`/;0`0B4Q8304];B`<0Ogmo0P1TI6@306a/K0<0X:2P0P28R8P302XZ:P/0
0@41<@0000080?ooo`001P3ooom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ
0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI
0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl
0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH6
0`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3o
oom=000000<010@40`1>CTh206a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E
5AD3028R8P<0Cdm?0`1<C4`202h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`
L70307AdM0<0KVi^0P1VIVH309^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<
c<`30=?Cd`<0LW9b0P0d=3@3038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@
D50303dm?@80820P0`020P83000000D00P82=00000080?ooo`001P3ooom=000000<010@40`1>CTh2
06a/K0<0EeMG0`0R8R8302PX:080:RXZ0`0d=3@303<c<`<0:b/[0P0E5AD3028R8P<0Cdm?0`1<C4`2
02h^;P<09bLW0`19BDT305mOG`80FEUI0`1cLg<307emO@80M7Ad0`1`L70307AdM0<0KVi^0P1VIVH3
09^KV`<0a<C40`2YZJT20;:b/P<0_;bl0`2o_kl30<K6aP80b<S80`3<c<`30=?Cd`<0LW9b0P0d=3@3
038b<P<0<c<c0`0K6a/200P820<01PH60`0X:2P306EUI@80LW9b0`1@D50303dm?@80820P0`020P83
000000D00P82=00000080?ooo`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG
5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^
KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2
`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q830082
0P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?oo
o`001P3ooom=000000<010@40`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T9080
7alO0`0];Bd306IVIP<0WIfM0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0
>SXj0`0b<S8303@d=080HF5Q0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0
]KFe0`39bLT307emO@80FEUI0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0
IVIV0`16ATH201hN7P<02@T90`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<010@4
0`2CTi<20:f][@<0@d=31P0L71`201LG5`<051@D0`0H61P302@T90807alO0`0];Bd306IVIP<0WIfM
0P1nOWh305eMG@<0IFEU0`1jNWX206i^KP<0DE5A0`1>CTh203Hf=P<0>SXj0`0b<S8303@d=080HF5Q
0`2TY:@30:f][@<0X:2P0P2a/K430<;2`P<0c<c<0`35aLD20;fm_@<0]KFe0`39bLT307emO@80FEUI
0`1FEUH305ADE0<0?Cdm0P0B4Q8300820P<0410@0`0n?Sh206ATI0<0IVIV0`16ATH201hN7P<02@T9
0`00000500@410<00P82<@0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g
=cL3030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2O
Wil30861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2L
W9`20:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o
?cl201hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P06
1PH300T92@<00`<3;P0000080?ooo`001P3ooom=000000<07AdM0`2MWId209JFUP<0<C4a0`0g=cL3
030`<0808B4Q0`0<30`300T92@<02`/;0P0M7Ad303`l?0<0MWIf0`2[Zj/20<c<c0<0]kNg0`2OWil3
0861P@80J6QX0`16ATH302HV9P806a/K0`0?3`l300T92@<0>SXj0P2g]kL30;Jf]P<0Ph>30`2LW9`2
0:b/[0<0Xj>S0`2[Zj/30;Rh^080_;bl0`2j^[X30;jn_P<0Ogmo0P1dM7@306e]K@<0@T920`0o?cl2
01hN7P<010@40`020P83020P8080BTY:0`1RHV8305IFEP80@d=30`0Q8B4300820P<00@410P061PH3
00T92@<00`<3;P0000080?ooo`001P3ooom=000000<0;2`/0`3De=@208:2PP<0G5aL0`1VIVH302XZ
:P806ATI0`0[:b/303`l?0<0:b/[0P0N7Qh303lo?`<0N7Qh0`2XZ:P20<K6aP<0gMgM0`3:b/X30;jn
_P80XJ6Q0`1KFe/302`/;0804a<C0`0<30`301`L70<0Ng]k0P3Cdm<30;jn_P<0Ph>30`24Q8@207al
O0<0N7Qh0`28R8P309VIV@D0Vi^K0`2e]KD308B4Q080O7al0`2<S8`3061PH0<08R8R0P0E5AD300X:
2P<00P820`071`L202XZ:P<0EUIF0`1EEED204I6AP<0;Bd]0`0?3`l30000008010@40`0>3Ph300P8
22h00000203oool000H0ooooC@00000302`/;0<0e=CD0P22PX8305aLG0<0IVIV0`0Z:RX201TI6@<0
:b/[0`0l?3`302/[:`807QhN0`0o?cl307QhN0<0Z:RX0P36a/H30=gMg@<0b/[:0`2n_[h20:6QX@<0
Fe]K0`0/;2`201<C4`<030`<0`0L71`307]kN`80dm?C0`2n_[h308>3P`<0Q8B40P1lO7`307QhN0<0
R8R80`2IVIT509^KV`<0]KFe0`24Q8@207alO0<0S8b<0`1PH603028R8P805ADE0`0:2PX300820P<0
1`L70P0Z:RX305IFEP<0EEEE0P16ATH302d];@<03`l?0`00000200@410<03Ph>0`0820P^000000P0
oooo00060?ooodd000000`0/;2`30=CDe080PX:20`1LG5`306IVIP<0:RXZ0P0I6AT302/[:`<0?3`l
0`0[:b/201hN7P<0?clo0`1hN7P30:RXZ080a/K60`3MgMd30<[:bP<0_[jn0P2QXJ4305]KF`<0;2`/
0P0C4a<300`<30<071`L0`1kNg/20=?Cd`<0_[jn0`23Ph<308B4Q080O7al0`1hN7P308R8R0<0VIVI
1@2KVi/30;Fe]@<0Q8B40P1lO7`308b<S0<0H61P0`0R8R8201DE5@<02PX:0`020P8300L71`80:RXZ
0`1FEUH305EEE@80ATI60`0];Bd300l?3`<000000P0410@300h>3P<020P8;P0000080?ooo`001P3o
oom=000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l
?3`304A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1n
OWh30:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2V
YZH30:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1X
J6P205YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=
000000<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`3
04A4A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh3
0:6QX@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH3
0:VYZ@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P2
05YJFP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom=0000
00<03@d=0`2ZZZX20<30`0<0UIFE0`1KFe/305IFEP80PX:20`2CTi<308B4Q0<0KFe]0P0l?3`304A4
A0<0J6QX0`2EUID20;^k^`<0emOG0`3Rh^830>GUi@80g]kN0`3EeMD30<71`@80VIVI0`1nOWh30:6Q
X@<0c/k>0P3IfMT30;Jf]P<0KFe]0`1;Bd/20492@P<0H61P0`2:RXX309NGU`80ZJVY0`2VYZH30:VY
Z@<0TY:B0P1lO7`609:BTP<0Cdm?0P0P820300h>3P<020P80`061PH2024Q8@<0Cdm?0`1XJ6P205YJ
FP<0@D510`0R8R8300<30`800@410`0C4a<301TI6@<01`L7:`0000080?ooo`001P3ooom@000000<0
Cdm?0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80
YjNW0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0
]KFe0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0
TI6A0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0
=cLg0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0Cdm?
0P2NWYh303Hf=P<06ATI0`1jNWX20:6QX@<0IFEU0`0X:2P302HV9PD0=cLg0`1ADE4307]kN`80YjNW
0`32`/830=KFeP<0gMgM0P3]kNd30?7al@<0kno_0P3YjNT30=oOg`<0emOG0`3;bl/20<S8b0<0]KFe
0`1CDe<3024Q8@80?Cdm0`1?Cdl308>3P`<0UiNG0P2MWId30:>SX`<0]KFe0`2][Jd208B4Q0<0TI6A
0`2DU9@3075aL@80@d=30`0S8b<300l?3`<01@D50P0J6QX304M7A`<0LG5a0P1lO7`305YJFP<0=cLg
0`0>3Ph2000000<061PH0`0c<c<301TI6@800@41:@0000080?ooo`001P3ooom@000000<0;Bd]0P1S
Hf<309FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2H
V9P309nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26
QXH302HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2B
TY8308F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H
61P200820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<3
09FEU@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P3
09nOW`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH3
02HV9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY83
08F5Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P2
00820P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0;Bd]0P1SHf<309FE
U@<0Ti>C0`1>CTh204Y:BP<0KFe]0`24Q8@305]KF`80<30`0`0^;Rh303Xj>P<0LG5a0P2HV9P309nO
W`<0^[Zj0`3<c<`20=[JfP<0fm_K0`3MgMd20>;RhP<0inOW0`3Hf=P30<g=c@D0d=3@0`26QXH302HV
9P809BDU0`1?Cdl306i^KP<0NWYj0P22PX8306m_K`<0IVIV0`1lO7`208:2PP<0SHf=0`2BTY8308F5
Q@80GemO0`10@403018B4P<00`<30P0?3`l303Ti>@<0IfMW0P28R8P306i^KP<0ADE50`0H61P20082
0P<09RHV0`11@D4302DU9@800P82:@0000080?ooo`001P3ooom@000000<0C4a<0P1UIFD303hn?P<0
Vi^K0`2/[:`20:^[Z`<0YZJV0`1hN7P307IfMP80KVi^0`1OGel305=CD`<0Fe]K0P25QHD30:RXZ0<0
][Jf0`37alL20=7Ad@<0f][J0`3Ph>020>GUi@H0jn_[0`3/k>`20>KViP<0gmoO0`3;bl/30861P@80
@D510`1?Cdl307YjNP<0K6a/0P1[Jf/305YJFP<0BTY:0`1EEED206UYJ@<0QhN70`2=SHd308B4Q080
IfMW0`1>CTh302HV9PD01PH60`0U9BD305=CD`D0Ogmo0`1CDe<301hN7P801@D50`0/;2`304U9B@<0
:RXZ0P0410@Y000000P0oooo00060?oooe0000000`1<C4`206EUI@<0?Shn0`2KVi/30:b/[080Zj^[
0`2VYZH307QhN0<0MWIf0P1^KVh305mOG`<0De=C0`1KFe/208F5Q@<0Z:RX0`2f][H30<O7a`80dM7A
0`3Jf]X30>3Ph080iNGU1P3[jn/30>c/k080i^KV0`3Ogml30<_;b`<0PH610P11@D4304m?C`<0NWYj
0`1/K6`206][J`<0FUYJ0`1:BTX305EEE@80JFUY0`27QhL308f=S@<0Q8B40P1WIfL304i>CP<09RHV
1@061PH302DU9@<0De=C1@1oOgl305=CD`<07QhN0P051@D302`/;0<0BDU90`0Z:RX200@412T00000
203oool000H0ooooD000000304a<C080IFEU0`0n?Sh309^KV`<0[:b/0P2[Zj/30:JVYP<0N7Qh0`1f
MWH206i^KP<0GemO0`1CDe<305]KF`80QHF50`2XZ:P30;Jf]P<0alO70P3AdM430=[JfP<0h>3P0P3U
iND60>_[j`<0k>c/0P3Vi^H30=oOg`<0bl_;0`21PH420451@@<0Cdm?0`1jNWX306a/K080Jf][0`1J
FUX304Y:BP<0EEEE0P1YJFT308N7Q`<0SHf=0`24Q8@206MWI`<0CTi>0`0V9RH500H61P<09BDU0`1C
De<507moO`<0De=C0`0N7Qh200D51@<0;2`/0`19BDT302XZ:P8010@4:@0000080?ooo`001P3ooom@
000000<0Hf=S0P3?cll308j>SP<0OWin0`37alL20<_;b`<0JFUY0`0R8R8302l_;`80AdM70`1DE5@3
04M7A`<0?clo0P1HF5P308Z:RP<0]kNg0`33`l<20<K6aP<0d=3@0`3QhN420>c/k0<0lo?c0`3alO43
0>c/k080inOW0`3Rh^860>CTi080_[jn0`2EUID309BDU0<0VYZJ1@2GUiL309^KV`<0LG5a0P17AdL3
05]KF`<0SHf=0`26QXH206m_K`<0F5QH0`0f=SH301LG5`801PH60`0A4A4303Ph>080K6a/0`23Ph<3
069RHP<0:2PX0P030`<3024Q8@<0Cdm?0`0[:b/200H61RT00000203oool000H0ooooD000000306=S
H`80clo?0`2>SXh307inOP<0alO70P3;bl/306UYJ@<08R8R0`0_;bl204M7A`<0E5AD0`17AdL303lo
?`80F5QH0`2:RXX30;Ng]`<0`l?30P36a/H30=3@d0<0hN7Q0P3/k>`30??cl`<0lO7a0`3/k>`20>OW
i`<0h^;R1P3Ti>@20;jn_P<0UIFE0`2DU9@309ZJVPD0UiNG0`2KVi/3075aL@80AdM70`1KFe/308f=
S@<0QXJ60P1_Kfl305QHF0<0=SHf0`0G5aL200H61P<04A4A0`0h>3P206a/K0<0Ph>30`1RHV8302PX
:0800`<30`0Q8B4304m?C`<0:b/[0P061PHY000000P0oooo00060?oooe0000000`1SHf<20<o?c`<0
SXj>0`1nOWh30<O7a`80bl_;0`1YJFT3028R8P<0;bl_0P17AdL305ADE0<0AdM70`0o?cl205QHF0<0
RXZ:0`2g]kL30<?3``80a/K60`3@d=030>7Qh@80k>c/0`3clo<30?7al@<0k>c/0P3WinL30>;RhPH0
i>CT0P2n_[h309FEU@<0U9BD0`2JVYX509NGU`<0Vi^K0`1aLG4204M7A`<0Fe]K0`2=SHd308J6QP80
Kfm_0`1HF5P303Hf=P<05aLG0P061PH3014A4@<0>3Ph0P1/K6`308>3P`<0HV9R0`0X:2P200<30`<0
8B4Q0`1?Cdl302/[:`801PH6:@0000080?ooo`001P3ooom=000000<00@410`1^KVh20<W9b@<0YZJV
0`1`L70304i>CP80EUIF0`1^KVh306ATI0<0DU9B0P0m?Cd303`l?0<0820P0`0R8R8203De=@<0B4Q8
0`1VIVH30:NWY`80`l?30`3;bl/30<g=c@80d];B0`3YjNT30>_[j`<0i^KV0P3Ph>060=kNgP<0h>3P
0P3UiND30=GEe@<0_;bl0`2n_[h20<30`0<0^;Rh0`2ZZZX307YjNP809bLW0`1:BTX307]kN`<0OWin
0P1hN7P305aLG0<0@4100`0V9RH2010@40<020P80`0V9RH2061PH0<0RHV90`1XJ6P303<c<`802@T9
0`0];Bd3065QH@<0<S8b0P0:2PXY000000P0oooo00060?ooodd000000`010@4306i^KP80bLW90`2V
YZH3071`L0<0CTi>0P1FEUH306i^KP<0I6AT0`1BDU8203dm?@<0?3`l0`0P8203028R8P80=CDe0`18
B4P306IVIP<0YjNW0P33`l<30<_;b`<0cLg=0P3Bd]830>WYj@<0jn_[0`3Vi^H20>3Ph0H0g]kN0`3P
h>020>GUi@<0eMGE0`2l_;`30;jn_P80`<300`2h^;P30:ZZZP<0NWYj0P0W9bL304Y:BP<0Ng]k0`1n
OWh207QhN0<0G5aL0`10@40302HV9P80410@0`0820P302HV9P80H61P0`29RHT306QXJ0<0<c<c0P09
2@T302d];@<0HF5Q0`0b<S8200X:2RT00000203oool000H0ooooD000000306][J`80[jn_0`2h^;P3
08j>SP<0DU9B0P29RHT30=CDe0<0`<300`2c/k<20:NWY`<0ZZZZ0`20P80306IVIP80L71`0`21PH43
071`L0<0Kfm_0P2DU9@30<O7a`<0d];B0P38b<P30=3@d0<0f=SH0`3IfMT20=[JfP<0d];B0`3Fe]H3
0=;BdP80e]KF0`35aLD30;Ng]`<0^[Zj0P2m_Kd30;Bd]0<0X:2P0`1[Jf/203dm?@<0Fe]K0`26QXH3
08N7Q`80PH610`1/K6`304A4A0<0;2`/0P0G5aL300L71`<09bLW0P1IFET30820P0<0Jf][0`10@402
01LG5`<0C4a<0`1ZJVX303`l?0807QhN0`010@4V000000P0oooo00060?oooe0000000`1[Jf/20:n_
[`<0^;Rh0`2>SXh3059BDP80RHV90`3De=@30<30`0<0/k>c0P2WYjL30:ZZZP<0P8200`1VIVH2071`
L0<0PH610`1`L70306m_K`80U9BD0`37alL30=;BdP80b<S80`3@d=030=SHf0<0fMWI0P3Jf]X30=;B
dP<0e]KF0`3Bd]820=KFeP<0aLG50`2g]kL30;Zj^P80_Kfm0`2d];@30:2PX0<0Jf][0P0m?Cd305]K
F`<0QXJ60`27QhL20861P@<0K6a/0`14A4@302`/;0805aLG0`071`L302LW9`80FEUI0`20P80306][
J`<0@4100P0G5aL304a<C0<0JVYZ0`0l?3`201hN7P<00@419P0000080?ooo`001P3ooom@000000<0
Jf][0P2_[jl30;Rh^0<0SXj>0`1BDU8208V9R@<0e=CD0`30`<030;>c/`80YjNW0`2ZZZX30820P0<0
IVIV0P1`L7030861P@<0L71`0`1_Kfl209BDU0<0alO70`3Bd]820<S8b0<0d=3@0`3Hf=P30=WIf@80
f][J0`3Bd]830=KFeP<0d];B0P3Fe]H30<G5a@<0]kNg0`2j^[X20;fm_@<0];Bd0`2PX:0306][J`80
?Cdm0`1KFe/308J6QP<0QhN70P21PH4306a/K0<0A4A40`0/;2`201LG5`<01`L70`0W9bL205UIF@<0
P8200`1[Jf/30410@0805aLG0`1<C4`306YZJP<0?3`l0P0N7Qh300410BH00000203oool000H0oooo
D000000308N7Q`80][Jf0`2/[:`309NGU`<0UIFE0P3=cLd30<_;b`<0_Kfm0`3Rh^820>o_k`<0dm?C
0`37alL30;jn_P80X:2P0`1hN7P306YZJP<0Q8B40P27QhL309fMW@<0emOG0P3IfMT30=7Ad@<0d=3@
0`38b<P20=7Ad@<0c/k>0`33`l<30;no_`80^k^k0`2e]KD30:RXZ0<0ZJVY0P2XZ:P309JFUP<0L71`
0`1@D50203<c<`<0@T920`22PX8308b<S080SXj>0`26QXH305UIF@<0<S8b0P0P820300/;2`<0<c<c
0P1ZJVX308>3P`<0MGEe0`12@T8202HV9P<0KVi^0`1RHV8304I6AP809BDU:@0000080?ooo`001P3o
oom@000000<0QhN70P2f][H30:b/[0<0UiNG0`2EUID20<g=c@<0bl_;0`2m_Kd30>;RhP80kno_0`3C
dm<30<O7a`<0_[jn0P2PX:0307QhN0<0JVYZ0`24Q8@208N7Q`<0WIfM0`3GemL20=WIf@<0dM7A0`3@
d=030<S8b080dM7A0`3>c/h30<?3``<0_kno0P2k^k/30;Fe]@<0Z:RX0`2YZJT20:RXZ0<0UYJF0`1`
L703051@D080<c<c0`12@T8308:2PP<0S8b<0P2>SXh308J6QP<0FEUI0`0b<S82020P80<02`/;0`0c
<c<206YZJP<0Ph>30`1eMGD30492@P809RHV0`1^KVh3069RHP<0ATI60P0U9BDY000000P0oooo0006
0?oooe0000000`27QhL20;Jf]P<0[:b/0`2GUiL309FEU@80cLg=0`3;bl/30;fm_@<0h^;R0P3_knl3
0=?Cd`<0alO70`2n_[h20:2PX0<0N7Qh0`1ZJVX308B4Q080QhN70`2MWId30=OGe`80fMWI0`3AdM43
0=3@d0<0b<S80P3AdM430<k>cP<0`l?30`2o_kl20;^k^`<0]KFe0`2XZ:P30:VYZ@80Z:RX0`2FUYH3
071`L0<0D51@0P0c<c<30492@P<0PX:20`2<S8`208j>SP<0QXJ60`1IFET3038b<P80820P0`0;2`/3
03<c<`80JVYZ0`23Ph<307EeM@<0@T920P0V9RH306i^KP<0HV9R0`16ATH202DU9BT00000203oool0
00H0ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJ
VP<0cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VY
Z@<0XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De
=@<04Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7
A`80PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0
ooooD000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0
cLg=0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0
XJ6Q0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<0
4Q8B0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80
PX:20`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0oooo
D000000306IVIP80a<C40`2i^KT30;Bd]0<0/k>c0P2?Shl306EUI@<0J6QX0`1PH60209ZJVP<0cLg=
0`3:b/X30;fm_@80[Zj^0`2SXj<309^KV`<0S8b<0P2ZZZX309NGU`<0^KVi0P36a/H30:VYZ@<0XJ6Q
0`2JVYX209nOW`<0Xj>S1P2XZ:P209JFUP<0WYjN0`2VYZH309bLW080O7al0`1MGEd303De=@<04Q8B
0P020P8302XZ:P<0LG5a0`26QXH208Z:RP<0QHF50`1NGUh302l_;`806QXJ0`0@410304M7A`80PX:2
0`23Ph<307]kN`<0=cLg0P14A4@307UiN@<0IfMW0`0n?Sh200T92BT00000203oool000H0ooooD000
000302TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d
];@30<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1J
FUX205=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1Y
JFT2059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2C
Ti<307alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD0000003
02TY:@80`/;20`2n_[h30=?Cd`<0ZZZZ0P1cLg<30;>c/`<0kno_0`3GemL209fMW@<0Zj^[0`2d];@3
0<?3``80h>3P0`3[jn/30>g]k@<0clo?0P2n_[h30:b/[0<0TI6A0P2@T9030820P0<0LG5a0`1JFUX2
05=CD`<0Fe]K0`1^KVh307IfMP80K6a/0`1SHf<305eMG@<0Cdm?0P1;Bd/304=3@`<0GUiN0`1YJFT2
059BDP<07alO0`1UIFD307alO080PH610`28R8P306UYJ@<0=SHf0P0M7Ad301<C4`<0CDe=0P2CTi<3
07alO0<0H61P0`0^;Rh206IVIP<0J6QX0`0g=cL300H61R/00000203oool000H0ooooD000000300D5
1@80YjNW0`38b<P30;Rh^0<0bLW90P3alO430?Shn0<0kno_0`3Zj^X20>k^kP<0inOW0`3Zj^X30?Kf
mP80kno_1P3[jn/30=;BdP80/k>c0`2WYjL309NGU`80Vi^K0`2`/;030;Bd]0<0]KFe0P2=SHd30861
P@<0J6QX0`1LG5`20451@@<0:RXZ0`0U9BD301LG5`80410@0`0G5aL3038b<P<0GemO0P1ADE4300h>
3P<0E5AD0`1oOgl20861P@<0PX:20`1/K6`304i>CP80;2`/0`0L71`3069RHP80V9RH0`1dM7@30451
@@<0>SXj0P1fMWH304M7A`<01`L7;P0000080?ooo`001P3ooom@000000<01@D50P2WYjL30<S8b0<0
^;Rh0`39bLT20?7al@<0n?Sh0`3_knl30>[ZjP80k^k^0`3WinL30>[ZjP<0m_Kf0P3_knl60>_[j`<0
d];B0P2c/k<30:NWY`<0UiNG0P2KVi/30;2`/0<0];Bd0`2e]KD208f=S@<0PH610`1XJ6P305aLG080
@D510`0Z:RX302DU9@<05aLG0P0@410301LG5`<0<S8b0`1OGel2055AD@<03Ph>0`1DE5@307moO`80
PH610`22PX8306a/K0<0CTi>0P0/;2`301`L70<0HV9R0P2HV9P307AdM0<0@D510`0j>SX207IfMP<0
AdM70`071`L^000000P0oooo00060?oooe0000000`051@D20:NWY`<0b<S80`2h^;P30<W9b@80lO7a
0`3hn?P30>o_k`<0j^[Z0P3^k^h30>OWi`<0j^[Z0`3fm_H20>o_k`H0jn_[0`3Bd]820;>c/`<0YjNW
0`2GUiL209^KV`<0/;2`0`2d];@30;Fe]@80SHf=0`21PH4306QXJ0<0G5aL0P11@D4302XZ:P<09BDU
0`0G5aL2010@40<05aLG0`0b<S8305mOG`80DE5A0`0>3Ph305ADE0<0Ogmo0P21PH4308:2PP<0K6a/
0`1>CTh202`/;0<071`L0`1RHV8209RHV0<0M7Ad0`11@D4303Xj>P80MWIf0`17AdL300L71bh00000
203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38
b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1m
OGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o
?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[
:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`000002
06IVIP<0f][J0`33`l<30;Zj^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=02
0=CDe0<0a<C40`2/[:`30;Jf]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3
075aL@<0C4a<0`20P80209RHV0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl3
02d];@<0AdM70`1gMgL20861P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`3
03/k>`<0G5aL0P1>CTh300d=3C400000203oool000H0ooooD`00000206IVIP<0f][J0`33`l<30;Zj
^P80e=CD0`3Hf=P30<k>cP<0cLg=0P38b<P30=CDe0<0gMgM0`3@d=020=CDe0<0a<C40`2/[:`30;Jf
]P80XZ:R0`2>SXh307inOP80K6a/0`1mOGd306m_K`<0VIVI0P2d];@3075aL@<0C4a<0`20P80209RH
V0<0WYjN0`2=SHd308F5Q@80Hf=S0`0o?cl301@D50<0=3@d0P0_;bl302d];@<0AdM70`1gMgL20861
P@<0OGem0`1_Kfl304Q8B080=CDe0`0[:b/308V9R@80UIFE0`1/K6`303/k>`<0G5aL0P1>CTh300d=
3C400000203oool000H0ooooD`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80
kNg]0`3[jn/30=gMg@<0h>3P0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0
SHf=0`2TY:@309jNWP80aLG50`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0
]KFe0`2LW9`30861P@80?3`l0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0
Cdm?0`2JVYX208N7Q`<0GemO0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0oooo
D`000002020P80H0dM7A0`3<c<`20=GEe@<0fm_K0`3Ti>@30>GUi@80kNg]0`3[jn/30=gMg@<0h>3P
0P2ZZZX305eMG@<0?3`l0`1CDe<206QXJ0<0KVi^0`1WIfL206IVIP<0SHf=0`2TY:@309jNWP80aLG5
0`2d];@306UYJ@<0A4A40P1MGEd306][J`<0M7Ad0`2?Shl20:VYZ@<0]KFe0`2LW9`30861P@80?3`l
0`1FEUH306][J`<0NWYj0P20P80307emO@<0M7Ad0`1ADE4202d];@<0Cdm?0`2JVYX208N7Q`<0GemO
0`16ATH303hn?P8020P80`00000300410Bh00000203oool000H0ooooE@00000307=cL`<0hn?S0`3?
cll20=7Ad@H0f][J0`3Vi^H20>WYj@<0f][J0`3Ng]h30;6a/@80:2PX0`061PH300X:2P<02@T90P0L
71`305QHF0<0MGEe0P23Ph<30;Zj^P<0_;bl0`34a<@20:j^[P<0^;Rh0`3Cdm<308j>SP80EEEE0`1M
GEd305ADE0<0MgMg0P2OWil30:j^[P<0W9bL0`1RHV8204e=C@<0Kfm_0`1oOgl308B4Q080Ph>30`24
Q8@306YZJP<0B4Q80P0Z:RX3065QH@<0TY:B0P1cLg<304e=C@<09BDU0`020P82000000<00@41<@00
00080?ooo`001P3ooomE000000<0Lg=c0`3Shn<30<o?c`80dM7A1P3Jf]X30>KViP80jNWY0`3Jf]X3
0=kNgP<0/K6a0P0X:2P300H61P<02PX:0`092@T201`L70<0F5QH0`1eMGD208>3P`<0^[Zj0`2l_;`3
0<C4a080[Zj^0`2h^;P30=?Cd`<0SXj>0P1EEED305eMG@<0E5AD0`1gMgL209nOW`<0[Zj^0`2LW9`3
069RHP80CDe=0`1_Kfl307moO`<0Q8B40P23Ph<308B4Q0<0JVYZ0`18B4P202XZ:P<0HF5Q0`2BTY82
07=cL`<0CDe=0`0U9BD300820P8000000`010@4a000000P0oooo00060?oooeD000000`1cLg<30>?S
h`<0clo?0P3AdM460=[JfP<0i^KV0P3YjNT30=[JfP<0g]kN0`2a/K4202PX:0<01PH60`0:2PX300T9
2@8071`L0`1HF5P307EeM@80Ph>30`2j^[X30;bl_0<0a<C40P2^[Zh30;Rh^0<0dm?C0`2>SXh205EE
E@<0GEeM0`1DE5@307MgM`80WinO0`2^[Zh309bLW0<0HV9R0P1=CDd306m_K`<0Ogmo0`24Q8@208>3
P`<0Q8B40`1ZJVX304Q8B080:RXZ0`1QHF4309:BTP80Lg=c0`1=CDd302DU9@<00P820P0000030041
0C400000203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80
gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0
]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0
CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0
LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooE@000003018B4P<0_kno
0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3YjNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO
0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno
0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1NGUh304=3@`80GUiN0`1hN7P308:2PP<0QHF5
0P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1lO7`205aLG0<0:BTY1P00000500410C400000
203oool000H0ooooE@000003018B4P<0_kno0`3Ph>020<o?c`<0dM7A0`3Fe]H30<g=c@80gMgM0`3Y
jNT30=cLg0<0Hf=S0P0V9RH302LW9`<07alO0`0F5QH200/;2`<0:2PX0`1/K6`20:RXZ0<0]KFe0`39
bLT30<S8b080ZZZZ0`21PH430;^k^`<0_kno0P2FUYH307inOP<0O7al0`1IFET205=CD`<0CTi>0`1N
GUh304=3@`80GUiN0`1hN7P308:2PP<0QHF50P2:RXX308>3P`<0I6AT0`0n?Sh2034a<@<0LW9b0`1l
O7`205aLG0<0:BTY1P00000500410C400000203oool000H0ooooF000000302l_;`<0`<300P3WinL3
0=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065QH@<0?Shn0P0[:b/3
01@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@T080_Kfm0`2OWil3
09bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3
061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0ooooF000000302l_
;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80PH610`1jNWX3065Q
H@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0OWin0`1lO7`3092@
T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0Ng]k0`23Ph<308j>
SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`00000203oool000H0
ooooF000000302l_;`<0`<300P3WinL30=WIf@<0fm_K0`3Ng]h20=[JfP<0eMGE0`2k^k/308:2PP80
PH610`1jNWX3065QH@<0?Shn0P0[:b/301@D50<0AdM70P2^[Zh30=KFeP<0Y:BT0`37alL20<W9b@<0
OWin0`1lO7`3092@T080_Kfm0`2OWil309bLW0<0TI6A0P1MGEd307emO@<0OWin0`0j>SX206][J`<0
Ng]k0`23Ph<308j>SP80Rh^;0`1nOWh3061PH0<0A4A40P0h>3P306m_K`<0IfMW0P0o?cl300H61S`0
0000203oool000H0ooooF`00000301XJ6P80Zj^[0`3_knl30>3Ph0<0gMgM0P3Shn<30=cLg0<0][Jf
0`2VYZH20<71`@<0g=cL0`3Ogml30::RXP80Jf][0`1:BTX302`/;080U9BD0`3Hf=P309JFUP<0Y:BT
0P3Bd]830<c<c0<0_kno0`2/[:`20;6a/@<0`L710`2ZZZX30;:b/P80_Kfm0`2n_[h3051@D0<0?Shn
0P1YJFT307UiN@<0RHV90`2BTY8208n?S`<0NWYj0`1PH60303lo?`80A4A40`1NGUh3059BDP806QXJ
?`0000080?ooo`001P3ooomK000000<06QXJ0P2[Zj/30>o_k`<0h>3P0`3MgMd20>?Sh`<0g=cL0`2f
][H30:JVYP80`L710`3Lg=`30=oOg`<0XZ:R0P1[Jf/304Y:BP<0;2`/0P2DU9@30=SHf0<0UYJF0`2T
Y:@20=;BdP<0c<c<0`2o_kl30:b/[080/K6a0`31`L430:ZZZP<0/[:b0P2m_Kd30;jn_P<0D51@0`0n
?Sh206UYJ@<0NGUi0`29RHT309:BTP80Shn?0`1jNWX3061PH0<0?clo0P14A4@305iNGP<0DU9B0P0J
6QXo000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/3
0:BTY080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID2
08n?S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P2
06QXJ0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o
000000P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BT
Y080bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?
S`<0WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QX
J0<0OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o0000
00P0oooo00060?oooeh000000P071`L307MgM`<0inOW0`3]kNd20>CTi0<0fMWI0`2[Zj/30:BTY080
bl_;0`3/k>`30>;RhP<0a<C40P2DU9@308J6QP<0<S8b0P1lO7`30=[JfP<0a<C40`2EUID208n?S`<0
WinO0`2n_[h30<S8b080V9RH0`2UYJD30:BTY0<0Zj^[0P1mOGd304E5A@<0ATI60`18B4P206QXJ0<0
OGem0`29RHT308n?S`80R8R80`1gMgL305aLG0<0?Cdm0P0n?Sh304e=C@<0<30`0P020P8o000000P0
oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW
0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C
0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_
0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;
Bd/30;6a/@D0j>SX0`2NWYh30861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1E
EED30:VYZ@H0`/;20P30`<030<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j
>SX305IFEP<0DU9B0P1MGEd307alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h
>3P3014A4@8000000`010@4l000000P0oooo00060?ooof<000000`1;Bd/30;6a/@D0j>SX0`2NWYh3
0861P@80Z:RX0`3Vi^H30<W9b@<0YjNW0P29RHT308Z:RP<0?Cdm0P1EEED30:VYZ@H0`/;20P30`<03
0<K6aP<0Zj^[0`2d];@209JFUP<0Ti>C0`1nOWh304i>CP808B4Q0`0j>SX305IFEP<0DU9B0P1MGEd3
07alO0<0TI6A0`2>SXh207inOP<0Kfm_0`1EEED302l_;`80:RXZ0`0h>3P3014A4@8000000`010@4l
000000P0oooo00060?ooofT000000P0m?Cd30:VYZ@<0W9bL0`1cLg<206i^KP<0V9RH0`2JVYX30861
P@80L71`0`1aLG4304I6AP80BTY:0`2=SHd30:n_[`<0YJFU0P2TY:@30<S8b0<0_kno0`2YZJT208N7
Q`<0=cLg0`0?3`l301HF5P80=SHf0`15ADD304Y:BP<0GemO0P1YJFT308>3P`<0TI6A0`2;Rh/207Ui
N@<0IfMW0`17AdL5024Q8@<0<30`0`051@D2000000<00@41?00000080?ooo`001P3ooomY00000080
?Cdm0`2YZJT309bLW0<0Lg=c0P1^KVh309RHV0<0VYZJ0`21PH42071`L0<0LG5a0`16ATH204Y:BP<0
SHf=0`2_[jl30:FUY@80Y:BT0`38b<P30;no_`<0ZJVY0P27QhL303Lg=`<03`l?0`0F5QH203Hf=P<0
ADE50`1:BTX305mOG`80JFUY0`23Ph<3096AT@<0Rh^;0P1iNGT306MWI`<0AdM71@0Q8B43030`<0<0
1@D50P00000300410C`00000203oool000H0ooooJ`00000300L71`<0GemO0`1/K6`207AdM0<0UIFE
0`2HV9P30820P080JFUY0`1EEED304=3@`80=cLg0`1OGel307MgM`<0P8200P2=SHd308Z:RP<0M7Ad
0`0n?Sh200h>3P<02`/;0`0I6AT301lO7`80>SXj1P1>CTh305EEE@80LG5a0`28R8P308n?S`<0QHF5
0P1aLG4305YJFP<0<S8b0`0H61P202`/;0<07QhNA00000080?ooo`001P3ooom[000000<01`L70`1O
Gel306a/K080M7Ad0`2EUID309RHV0<0P8200P1YJFT305EEE@<0@d=30P0g=cL305mOG`<0MgMg0`20
P80208f=S@<0RXZ:0`1dM7@303hn?P803Ph>0`0;2`/301TI6@<07alO0P0j>SX604i>CP<0EEEE0P1a
LG4308R8R0<0Shn?0`25QHD2075aL@<0FUYJ0`0b<S8301PH6080;2`/0`0N7Qi4000000P0oooo0006
0?ooof/000000`071`L305mOG`<0K6a/0P1dM7@309FEU@<0V9RH0`20P80206UYJ@<0EEEE0`13@d<2
03Lg=`<0GemO0`1gMgL30820P080SHf=0`2:RXX307AdM0<0?Shn0P0>3Ph300/;2`<06ATI0`0O7al2
03Xj>PH0CTi>0`1EEED2075aL@<0R8R80`2?Shl308F5Q@80LG5a0`1JFUX3038b<P<061PH0P0/;2`3
01hN7T@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0JVYZ0`1PH602051@
D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<01@D50P0@410301lO
7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80LW9b0`1<C4`302h^
;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX0P1SHf<306MWI`<0
JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C0`0f=SH301DE5@<0
1@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b1P2;Rh/307moO`80
LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00000303Ph>0<0J6QX
0P1SHf<306MWI`<0JVYZ0`1PH602051@D0<0@T920`0f=SH202XZ:P<0De=C0`1RHV83065QH@80De=C
0`0f=SH301DE5@<01@D50P0@410301lO7`<09bLW0`0N7Qh203/k>`<0Bd];0`1FEUH305iNGP80LW9b
1P2;Rh/307moO`80LW9b0`1<C4`302h^;P<09RHV0P0/;2`300D51D@00000203oool000H0ooooKP00
000303Ph>0<0Lg=c1@1[Jf/306MWI`<0EeMG0P14A4@3038b<P<0;bl_0P0Y:BT301/K6`<04Q8B0`0;
2`/200`<30<051@D0`0C4a<3018B4P806QXJ0`0^;Rh3034a<@<0:BTY0P0f=SH304m?C`<0FEUI0`1k
Ng/208n?S`<0PX:20`1iNGT307QhN080JFUY0`18B4P303@d=0<0:b/[0P092@T3000000<00@41@@00
00080?ooo`001P3ooom^000000<0>3Ph0`1cLg<506][J`<0IfMW0`1GEeL204A4A0<0<S8b0`0_;bl2
02TY:@<06a/K0`0B4Q8300/;2`8030`<0`0D51@301<C4`<04Q8B0P0J6QX302h^;P<0<C4a0`0Y:BT2
03Hf=P<0Cdm?0`1IFET307]kN`80Shn?0`22PX8307UiN@<0N7Qh0P1YJFT304Q8B0<0=3@d0`0[:b/2
00T92@<000000`010@51000000P0oooo00060?ooofh000000`0h>3P307=cL`D0Jf][0`1WIfL305MG
E`80A4A40`0b<S8302l_;`80:BTY0`0K6a/3018B4P<02`/;0P0<30`301@D50<04a<C0`0B4Q8201XJ
6P<0;Rh^0`0a<C4302TY:@80=SHf0`1?Cdl305UIF@<0Ng]k0P2?Shl308:2PP<0NGUi0`1hN7P206UY
J@<0B4Q80`0d=3@302/[:`802@T90`00000300410D400000203oool000H0ooooKP00000302d];@<0
RHV90P1lO7`307EeM@<0KVi^0`1NGUh204Q8B0<0;bl_0`0[:b/2030`<0<04Q8B0`0:2PX3010@4080
51@D0`0K6a/301HF5P<07AdM0P0V9RH303De=@<0<30`0`0k>c/20410@0<0@D510`1OGel308:2PP80
S8b<1P1lO7`307]kN`80IVIV0`1>CTh303@d=0<030`<B@0000080?ooo`001P3ooom^000000<0;Bd]
0`29RHT207alO0<0MGEe0`1^KVh305iNGP80B4Q80`0_;bl302/[:`80<30`0`0B4Q8300X:2P<0410@
0P0D51@301/K6`<05QHF0`0M7Ad202HV9P<0=CDe0`0`<30303/k>`80@4100`11@D4305mOG`<0PX:2
0P2<S8`607alO0<0Ng]k0P1VIVH304i>CP<0=3@d0`0<30a9000000P0oooo00060?ooofT000000P01
0@43000000<04Q8B0`2:RXX207IfMP<0KFe]1P1UIFD205UIF@<0>SXj0`0e=CD202`/;0<04Q8B0`0A
4A4301TI6@805QHF0`0G5aL3024Q8@<08b<S0P0f=SH303De=@<0<C4a0`1=CDd205IFEP<0F5QH0`1Y
JFT307inOP80MgMg0`1bLW8308:2PP<0Kfm_0P1PH603051@D0<05QHF0`00000200410DL00000203o
ool000H0ooooJ@00000200410@<000000`0B4Q8308Z:RP80MWIf0`1]KFd606EUI@80FEUI0`0j>SX3
03De=@80;2`/0`0B4Q83014A4@<06ATI0P0F5QH301LG5`<08B4Q0`0S8b<203Hf=P<0=CDe0`0a<C43
04e=C@80EUIF0`1HF5P306UYJ@<0OWin0P1gMgL3079bLP<0PX:20`1_Kfl2061PH0<0D51@0`0F5QH3
000000800@41A`0000080?ooo`001P3ooomY000000800@410`000003018B4P<0RXZ:0P1fMWH306e]
K@H0IFEU0P1IFET303Xj>P<0=CDe0P0/;2`3018B4P<04A4A0`0I6AT201HF5P<05aLG0`0Q8B4302<S
8`80=SHf0`0e=CD3034a<@<0CDe=0P1FEUH305QHF0<0JFUY0`1nOWh207MgM`<0LW9b0`22PX8306m_
K`80H61P0`1@D50301HF5P<000000P010@57000000P0oooo00060?ooofh000000`030`<30861P@80
UYJF0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<0
6ATI0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0
NGUi0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF
0`27QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI
0`0Y:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi
0`1YJFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`030`<30861P@80UYJF0`27
QhL307YjNP<0MgMg0P1YJFT3055AD@<0BDU90P0];Bd3018B4P<06a/K0`0M7Ad201lO7`<06ATI0`0Y
:BT302/[:`80?3`l0`0h>3P304M7A`<0IFEU0P1XJ6P307AdM0<0P8200`1fMWH206a/K0<0NGUi0`1Y
JFT305QHF080B4Q80`0Q8B5?000000P0oooo00060?ooofh000000`0@410306QXJ080VIVI0`2BTY83
08R8R0<0PH610P1bLW8306MWI`<0DE5A0P0];Bd301/K6`<07QhN0`0L71`201XJ6P<0:2PX0`0V9RH3
03Ph>080@4100`13@d<305EEE@<0Lg=c0P1kNg/607QhN0<0K6a/0P1ZJVX305]KF`<0BTY:0`19BDT2
02@T95800000203oool000H0ooooKP000003010@40<0J6QX0P2IVIT309:BTP<0R8R80`21PH42079b
LP<0IfMW0`1ADE4202d];@<06a/K0`0N7Qh301`L70806QXJ0`0X:2P302HV9P<0>3Ph0P10@40304=3
@`<0EEEE0`1cLg<207]kN`H0N7Qh0`1/K6`206YZJP<0Fe]K0`1:BTX304U9B@8092@TDP0000080?oo
o`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80
:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80
NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K
0`1HF5P2092@T0<0TY:B0`26QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO
0P0S8b<302h^;P<0<30`0`1?Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C
0`19BDT30410@0<05aLGE00000080?ooo`001P3ooom^000000<06a/K0`1HF5P2092@T0<0TY:B0`26
QXH307YjNP80MGEe0`1WIfL304M7A`80:BTY0`0O7al302<S8`<07alO0P0S8b<302h^;P<0<30`0`1?
Cdl204a<C0<0F5QH0`1VIVH3079bLP80NWYj1P1iNGT3079bLP80De=C0`19BDT30410@0<05aLGE000
00080?ooo`001P3ooom^000000<07AdM0`1HF5P208N7Q`<0SXj>0`28R8P307UiN@80Jf][0`1MGEd3
0410@0D0:2PX0`0U9BD302LW9`80=cLg0`0[:b/304Y:BP<0FEUI0P1JFUX306YZJP<0N7Qh0`1cLg<2
07EeM@<0NGUi0`1mOGd306IVIP80BDU90`0a<C4300P825L00000203oool000H0ooooKP00000301dM
7@<0F5QH0P27QhL308j>SP<0R8R80`1iNGT206][J`<0GEeM0`10@40502PX:0<09BDU0`0W9bL203Lg
=`<0:b/[0`1:BTX305UIF@80FUYJ0`1ZJVX307QhN0<0Lg=c0P1eMGD307UiN@<0OGem0`1VIVH204U9
B@<0<C4a0`0820QG000000P0oooo00060?ooofh000000`0M7Ad305QHF080QhN70`2>SXh308R8R0<0
NGUi0P1[Jf/305eMG@<0@4101@0X:2P302DU9@<09bLW0P0g=cL302/[:`<0BTY:0`1IFET205YJFP<0
JVYZ0`1hN7P307=cL`80MGEe0`1iNGT307emO@<0IVIV0P19BDT3034a<@<020P8E`0000080?ooo`00
1P3ooomY000000D00@410`0=3@d305UIF@80Ph>30`2ATI4308J6QP<0MGEe0P1UIFD305IFEP<0@410
0P0b<S8302l_;`<0:b/[0`0f=SH2034a<@<0ATI60`1QHF43061PH080JVYZ0`1eMGD307inOP<0NGUi
0P1eMGD307emO@<0Lg=c0`1;Bd/201`L75d00000203oool000H0ooooJ@00000500410@<03@d=0`1I
FET208>3P`<0TI6A0`26QXH307EeM@80IFEU0`1FEUH30410@080<S8b0`0_;bl302/[:`<0=SHf0P0a
<C4304I6AP<0HF5Q0`1PH60206YZJP<0MGEe0`1nOWh307UiN@80MGEe0`1mOGd307=cL`<0Bd];0P0L
71aM000000P0oooo00060?ooofT000001@010@4300d=3@<0FEUI0P23Ph<3096AT@<0QXJ60`1eMGD2
06EUI@<0EUIF0`10@402038b<P<0;bl_0`0[:b/303Hf=P80<C4a0`16ATH3065QH@<0H61P0P1ZJVX3
07EeM@<0OWin0`1iNGT207EeM@<0OGem0`1cLg<304];B`8071`LG@0000080?ooo`001P3ooomV0000
00<00@410P0410@300<30`<00P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410
@080=SHf0`0b<S8303Xj>P<0>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820
P080O7al0`1]KFd304I6AP<03Ph>G`0000080?ooo`001P3ooomV000000<00@410P0410@300<30`<0
0P820`16ATH207]kN`<0RHV90`1kNg/306YZJP80GemO0`1?Cdl30410@080=SHf0`0b<S8303Xj>P<0
>CTi0P17AdL305YJFP<0IFEU0`1XJ6P207UiN@<0Ogmo0`23Ph<30820P080O7al0`1]KFd304I6AP<0
3Ph>G`0000080?ooo`001P3ooomV000000<00P820P030`<300820P<000000`0P820206m_K`<0Q8B4
0`1gMgL3069RHP80GEeM0`1BDU8304I6AP80?3`l0`12@T8304Q8B0<0CDe=0P1IFET305iNGP<0IfMW
0`1aLG4207UiN@<0PH610`22PX8307EeM@80HF5Q0`12@T8301@D50<000000P010@5M000000P0oooo
00060?ooofH000000`020P8200<30`<00P820`000003020P8080Kfm_0`24Q8@307MgM`<0HV9R0P1M
GEd3059BDP<0ATI60P0l?3`30492@P<0B4Q80`1=CDd205UIF@<0GUiN0`1WIfL3075aL@80NGUi0`21
PH4308:2PP<0MGEe0P1QHF430492@P<051@D0`00000200410Ed00000203oool000H0ooooIP000003
00820P800`<30`020P83000000<0820P0P1_Kfl308B4Q0<0MgMg0`1RHV8205eMG@<0DU9B0`16ATH2
03`l?0<0@T920`18B4P304e=C@80FEUI0`1NGUh306MWI`<0LG5a0P1iNGT30861P@<0PX:20`1eMGD2
065QH@<0@T920`0D51@3000000800@41G@0000080?ooo`001P3ooomV000000P00@410`020P8300P8
2080?3`l0`1nOWh307]kN`<0JVYZ0P1UIFD305eMG@<0BTY:0P16ATH3051@D0<0EeMG0`1NGUh206=S
H`<0IFEU0`1]KFd307EeM@80NWYj0`1cLg<305eMG@<0Bd];0P10@40302HV9VD00000203oool000H0
ooooIP00000800410@<00P820`0820P203`l?0<0OWin0`1kNg/306YZJP80IFEU0`1MGEd304Y:BP80
ATI60`1@D50305MGE`<0GUiN0P1SHf<306EUI@<0KFe]0`1eMGD207YjNP<0Lg=c0`1MGEd304];B`80
@4100`0V9RIU000000P0oooo00060?ooofH0000020010@4300820P<020P80P0l?3`307inOP<0Ng]k
0`1ZJVX206EUI@<0GEeM0`1:BTX204I6AP<0D51@0`1GEeL305iNGP80Hf=S0`1UIFD306e]K@<0MGEe
0P1jNWX307=cL`<0GEeM0`1;Bd/20410@0<09RHVI@0000080?ooo`001P3ooomP000000/00@410`03
0`<300@410<020P80P0F5QH304E5A@<0HV9R1@1^KVh306MWI`<0FEUI0P1EEED305YJFP<0G5aL0`1N
GUh206EUI@<0JFUY0`1/K6`306UYJ@80G5aL0`1ADE4304U9B@<0@D510P0d=3@300T92FD00000203o
ool000H0ooooH000000;00410@<00`<30`0410@300P820805QHF0`15ADD3069RHPD0KVi^0`1WIfL3
05UIF@80EEEE0`1JFUX305aLG0<0GUiN0P1UIFD306UYJ@<0K6a/0`1YJFT205aLG0<0DE5A0`19BDT3
0451@@80=3@d0`092@UU000000P0oooo00060?ooof0000002`010@4300<30`<010@40`0820P201HF
5P<0ADE50`1RHV8506i^KP<0IfMW0`1IFET205EEE@<0FUYJ0`1LG5`305iNGP80IFEU0`1YJFT306a/
K0<0JFUY0P1LG5`3055AD@<0BDU90`11@D4203@d=0<02@T9I@0000080?ooo`001P3ooomP000000/0
0@410`0:2PX300d=3@<02PX:0P0K6a/302<S8`<0?3`l0`1CDe<2061PH0<0GemO0`1PH60205mOG`<0
GEeM0`1PH603069RHP80IFEU0`1TI6@3061PH0<0EeMG0P1@D50304e=C@<0@T920`0i>CT201LG5fP0
0000203oool000H0ooooH000000;00410@<02PX:0`0=3@d300X:2P806a/K0`0S8b<303`l?0<0De=C
0P1PH60305mOG`<0H61P0P1OGel305eMG@<0H61P0`1RHV8206EUI@<0I6AT0`1PH60305MGE`80D51@
0`1=CDd30492@P<0>CTi0P0G5aMX000000P0oooo00060?ooof0000001P010@43000000800`<30`0=
3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1S
Hf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo0006
0?ooof0000001P010@43000000800`<30`0=3@d301TI6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2
059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306ATI080IfMW0`1OGel305UIF@<0De=C0P1@D503
04];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof0000001P010@43000000800`<30`0=3@d301TI
6@<061PH0P0M7Ad302LW9`<0:b/[0`0m?Cd2059BDP<0EUIF0`1HF5P205iNGP<0HV9R0`1SHf<306AT
I080IfMW0`1OGel305UIF@<0De=C0P1@D50304];B`<0@d=30`0U9BEZ000000P0oooo00060?ooof<0
00000`010@4300820P801`L70`0>3Ph301/K6`<0820P0P0N7Qh3028R8P<09RHV0`0^;Rh204E5A@<0
EUIF0`1MGEd206ATI0<0IVIV0`1TI6@3065QH@80GEeM0`1KFe/605QHF080DU9B0`1=CDd3038b<P<0
0`<3JP0000080?ooo`001P3ooomS000000<00@410`020P8200L71`<03Ph>0`0K6a/3020P80807QhN
0`0R8R8302HV9P<0;Rh^0P15ADD305IFEP<0GEeM0P1TI6@306IVIP<0I6AT0`1QHF4205eMG@<0Fe]K
1P1HF5P2059BDP<0CDe=0`0b<S8300<30fX00000203oool000H0ooooH`00000300410@<00P820P07
1`L300h>3P<06a/K0`0P820201hN7P<08R8R0`0V9RH302h^;P80ADE50`1FEUH305eMG@80I6AT0`1V
IVH306ATI0<0HF5Q0P1MGEd305]KF`H0F5QH0P1BDU8304e=C@<0<S8b0`030`=Z000000P0oooo0006
0?ooof<000000`020P8300D51@8030`<0`0?3`l301XJ6P<09BDU0P0V9RH302<S8`<0820P0`0Q8B42
02h^;P<0?clo0`1BDU8205]KF`<0HV9R0`1UIFD305iNGPD0Fe]K0`1JFUX305UIF@80EEEE0`13@d<3
010@46d00000203oool000H0ooooH`00000300820P<01@D50P0<30`300l?3`<06QXJ0`0U9BD202HV
9P<08b<S0`0P8203024Q8@80;Rh^0`0o?cl3059BDP80Fe]K0`1RHV8306EUI@<0GUiN1@1KFe/305YJ
FP<0FEUI0P1EEED304=3@`<0410@K@0000080?ooo`001P3ooomP000000<00@410`030`<300X:2P80
3Ph>0`0@410301TI6@<0:BTY0P0f=SH303lo?`<0A4A40`13@d<203hn?P<0ATI60`1EEED205eMG@<0
H61P0`1RHV8306=SH`80H61P0`1MGEd305iNGP<0Fe]K0P1EEED302`/;7000000203oool000H0oooo
H000000300410@<00`<30`0:2PX200h>3P<0410@0`0I6AT302TY:@80=SHf0`0o?cl304A4A0<0@d=3
0P0n?Sh304I6AP<0EEEE0P1MGEd3061PH0<0HV9R0`1SHf<2061PH0<0GEeM0`1NGUh305]KF`80EEEE
0`0/;2a`000000P0oooo00060?ooof0000000`010@4300<30`<02PX:0P0>3Ph3010@40<06ATI0`0Y
:BT203Hf=P<0?clo0`14A4@304=3@`80?Shn0`16ATH305EEE@80GEeM0`1PH603069RHP<0Hf=S0P1P
H60305eMG@<0GUiN0`1KFe/205EEE@<0;2`/L00000080?ooo`001P3ooomN000000D00P820`0820P3
00`<30803Ph>0`0B4Q8301XJ6P<0:BTY0P0n?Sh305IFEP<0IVIV2`1aLG42079bLP<0Lg=c0`1`L703
06UYJ@80Hf=S0`1QHF4305mOG`<0GEeM0P15ADD300P827000000203oool000H0ooooGP0000050082
0P<020P80`0<30`200h>3P<04Q8B0`0J6QX302TY:@80?Shn0`1FEUH306IVIP/0LG5a0P1bLW8307=c
L`<0L71`0`1YJFT206=SH`<0HF5Q0`1OGel305eMG@80ADE50`0820Q`000000P0oooo00060?oooeh0
00001@020P8300P820<030`<0P0>3Ph3018B4P<06QXJ0`0Y:BT203hn?P<0EUIF0`1VIVH;075aL@80
LW9b0`1cLg<3071`L0<0JFUY0P1SHf<3065QH@<0GemO0`1MGEd204E5A@<020P8L00000080?ooo`00
1P3ooom@000000D00@410`00000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B
0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][
0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00
000300410@<00P820P030`<300H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13
@d<304i>CP<0GUiN0P1UIFD306][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1O
Gel305eMG@807QhNL`0000080?ooo`001P3ooom@000000D00@410`00000300410@<00P820P030`<3
00H61P<020P80`0:2PX200d=3@<04Q8B0`0L71`302LW9`80=cLg0`13@d<304i>CP<0GUiN0P1UIFD3
06][J`<0Kfm_0P1aLG43071`L0<0Jf][0`1QHF4205mOG`<0GUiN0`1OGel305eMG@807QhNL`000008
0?ooo`001P3ooom@000000D00@410`00000600<30`D010@40`051@D300/;2`804A4A0`0E5AD301/K
6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZ
JP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`001P3ooom@000000D00@410`00000600<30`D0
10@40`051@D300/;2`804A4A0`0E5AD301/K6`<09RHV0P0a<C4303/k>`<0ADE50`1>CTh205EEE@<0
GEeM0`1WIfL206i^KP<0LG5a0`1]KFd306YZJP80KFe]0`1[Jf/3075aL@<0ADE5M@0000080?ooo`00
1P3ooom@000000P00@4120020P8300410@<01PH60`0<30`2014A4@<05aLG0`0M7Ad302LW9`80<C4a
0`0m?Cd304M7A`<0CTi>0P1JFUX306QXJ0<0Kfm_0P1eMGD307]kN`<0NWYj0`1dM7@207=cL`<0LG5a
0`1NGUh300h>3WD00000203oool000H0ooooD000000800410@P00P820`010@4300H61P<030`<0P0A
4A4301LG5`<07AdM0`0W9bL2034a<@<0?Cdm0`17AdL304i>CP80FUYJ0`1XJ6P306m_K`80MGEe0`1k
Ng/307YjNP<0M7Ad0P1cLg<3075aL@<0GUiN0`0>3Pie000000P0oooo00060?oooe00000020010@48
00820P<00@410`061PH300`<30804A4A0`0G5aL301dM7@<09bLW0P0a<C4303dm?@<0AdM70`1>CTh2
05YJFP<0J6QX0`1_Kfl207EeM@<0Ng]k0`1jNWX307AdM080Lg=c0`1aLG4305iNGP<03Ph>M@000008
0?ooo`001P3ooom@000000/00@410`020P8200<30`<01@D50`0:2PX300h>3P804a<C0`0L71`3028R
8P<0:2PX0P0b<S8303lo?`<0Bd];0`1DE5@2065QH@<0KVi^0`1gMgL207alO0<0OGem0`1kNg/307Ee
M@80KFe]0`1WIfL302d];GP00000203oool000H0ooooD000000;00410@<00P820P030`<300D51@<0
2PX:0`0>3Ph201<C4`<071`L0`0R8R8302PX:080<S8b0`0o?cl304];B`<0E5AD0P1QHF4306i^KP<0
MgMg0P1lO7`307emO@<0Ng]k0`1eMGD206e]K@<0IfMW0`0];Beh000000P0oooo00060?oooe000000
2`010@4300820P800`<30`051@D300X:2P<03Ph>0P0C4a<301`L70<08R8R0`0X:2P2038b<P<0?clo
0`1;Bd/305ADE080HF5Q0`1^KVh307MgM`80O7al0`1mOGd307]kN`<0MGEe0P1]KFd306MWI`<0;Bd]
N00000080?ooo`001P3ooom@000000D00@411P00000300@410802@T90`0;2`/300l?3`<051@D0P0J
6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd305UIF@80IfMW0`1bLW8307QhN080NGUi0`1h
N7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N00000080?ooo`001P3ooom@000000D00@411P000003
00@410802@T90`0;2`/300l?3`<051@D0P0J6QX3024Q8@<09bLW0`0];Bd203Hf=P<0@d=30`1=CDd3
05UIF@80IfMW0`1bLW8307QhN080NGUi0`1hN7P307IfMP<0M7Ad0P1^KVh304U9B@<00`<3N0000008
0?ooo`001P3ooom8000000800@410`00000300410@<00`<31@020P8300@410<02PX:0P0<30`3014A
4@<05QHF0`0I6AT201hN7P<08b<S0`0[:b/3034a<@80>SXj0`15ADD3059BDP<0G5aL0P1WIfL307If
MP<0MgMg0P1dM7@607MgM`<0KFe]0P1KFe/301XJ6W/00000203oool000H0ooooB000000200410@<0
00000`010@4300<30`D00P820`0410@300X:2P8030`<0`0A4A4301HF5P<06ATI0P0N7Qh302<S8`<0
:b/[0`0a<C4203Xj>P<0ADE50`1BDU8305aLG080IfMW0`1fMWH307MgM`80M7Ad1P1gMgL306e]K@80
Fe]K0`0J6QYk000000P0oooo00060?ooodP000000P010@43000000<00@410`030`<500820P<010@4
0`0:2PX200`<30<04A4A0`0F5QH301TI6@807QhN0`0S8b<302/[:`<0<C4a0P0j>SX304E5A@<0DU9B
0`1LG5`206MWI`<0MWIf0`1gMgL207AdM0H0MgMg0`1]KFd205]KF`<06QXJN`0000080?ooo`001P3o
oom5000000<00@410P020P8300410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M
7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_
Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P83
00410@P00P820`030`<300L71`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh3
03@d=080?Shn0`1:BTX305YJFP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh2
03Lg=`H00@41N00000080?ooo`001P3ooom5000000<00@410P020P8300410@P00P820`030`<300L7
1`<030`<0P0@410301DE5@<06ATI0`0M7Ad2024Q8@<09bLW0`0^;Rh303@d=080?Shn0`1:BTX305YJ
FP<0Hf=S0P1[Jf/307IfMP<0Lg=c0P1_Kfl3071`L0<0J6QX0`1NGUh203Lg=`H00@41N00000080?oo
o`001P3ooolo000000H00@411@020P8300<30`<00P820`010@4200820P<01PH60`0:2PX300`<3080
410@0`0F5QH301dM7@<07alO0P0T92@302h^;P<0<S8b0`0e=CD20410@0<0CTi>0`1LG5`306QXJ080
KFe]0`1_Kfl306i^KP80Jf][0`1YJFT305iNGP<0Cdm?0P0>3Pin000000P0oooo00060?ooocl00000
1P010@4500820P<00`<30`020P8300410@800P820`061PH300X:2P<030`<0P0@410301HF5P<07AdM
0`0O7al202@T90<0;Rh^0`0b<S8303De=@80@4100`1>CTh305aLG0<0J6QX0P1]KFd306m_K`<0KVi^
0P1[Jf/306UYJ@<0GUiN0`1?Cdl200h>3Wh00000203oool000H0oooo?`00000600410@D00P820`03
0`<300820P<00@410P020P8300H61P<02PX:0`0<30`2010@40<05QHF0`0M7Ad301lO7`8092@T0`0^
;Rh3038b<P<0=CDe0P10@40304i>CP<0G5aL0`1XJ6P206e]K@<0Kfm_0`1^KVh206][J`<0JFUY0`1N
GUh304m?C`803Ph>OP0000080?ooo`001P3ooom2000000<00@4120051@D600<30`801PH60`0820P3
00/;2`<04A4A0P0D51@301LG5`<07AdM0`0P820202<S8`<0;2`/0`0a<C4303`l?080ADE50`1CDe<3
061PH0<0I6AT0P1VIVH306YZJP<0JFUY0P1WIfL305aLG0<0EUIF0`0X:2R0000000P0oooo00060?oo
od8000000`010@4800D51@H00`<30P061PH300P820<02`/;0`0A4A4201@D50<05aLG0`0M7Ad3020P
80808b<S0`0/;2`3034a<@<0?3`l0P15ADD305=CD`<0H61P0`1TI6@206IVIP<0JVYZ0`1YJFT206MW
I`<0G5aL0`1FEUH302PX:8000000203oool000H0oooo?`00000300410@<00P820`051@D200H61P<0
1@D50`061PH300T92@8020P80`0<30`6010@40804a<C0`0F5QH301dM7@<08R8R0P0T92@302TY:@<0
<30`0`0k>c/204Q8B0<0De=C0`1KFe/306=SH`80IVIV0`1TI6@3065QH@80GUiN0`1EEED30451@@<0
1`L7P00000080?ooo`001P3ooolo000000<00@410`020P8300D51@801PH60`051@D300H61P<02@T9
0P0820P300`<30H0410@0P0C4a<301HF5P<07AdM0`0R8R8202@T90<0:BTY0`0`<30303/k>`80B4Q8
0`1CDe<305]KF`<0Hf=S0P1VIVH306ATI0<0HF5Q0P1NGUh305EEE@<0@D510`071`N0000000P0oooo
00060?ooocl000000`010@4300820P<01@D50P061PH300D51@<01PH60`092@T200P820<030`<1P0@
410201<C4`<05QHF0`0M7Ad3028R8P8092@T0`0Y:BT3030`<0<0>c/k0P18B4P305=CD`<0Fe]K0`1S
Hf<206IVIP<0I6AT0`1QHF4205iNGP<0EEEE0`11@D4300L71h000000203oool000H0oooo?`000003
00<30`<01@D50`061PH200T92@T02PX:1@0>3Ph3010@40<04A4A0P0B4Q8301LG5`<071`L0`0N7Qh2
028R8P<0:2PX0`0a<C4303hn?P80B4Q80`1FEUH305UIF@D0G5aL1P1IFET205=CD`<0B4Q80`0H61R3
000000P0oooo00060?ooocl000000`030`<300D51@<01PH60P092@T900X:2PD03Ph>0`0@4103014A
4@804Q8B0`0G5aL301`L70<07QhN0P0R8R8302PX:0<0<C4a0`0n?Sh204Q8B0<0EUIF0`1IFET505aL
G0H0FEUI0P1CDe<304Q8B0<061PHP`0000080?ooo`001P3ooolo000000<00`<30`051@D300H61P80
2@T92@0:2PX500h>3P<0410@0`0A4A42018B4P<05aLG0`0L71`301hN7P808R8R0`0X:2P3034a<@<0
?Shn0P18B4P305IFEP<0FEUI1@1LG5`605UIF@80De=C0`18B4P301PH68<00000203oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0202381 0.00952381 [
[ 0 0 0 0 ]
[ 1 .85 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85 L
0 .85 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02024 translate
.95238 .80952 scale
100 string
100 85 8 [100 0 0 85 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000A0002000000020200000203050700000002000004050D
0003150C1425201C21371B000000122A3A32130000060600
0600000B0005040000000000000400000000020000000208
000004010000000B00020001000000030806030004020401
03000000
030400050002000000000004000002000000010000040303
00000D0608252C1A1C2617070B0F11243750544B43322D18
16060000000D0B0000000001000304020000010000000000
00020B0F0900000101020000000000000303040004070202
03000100
020400020002010302000002010003000000020000030206
00010E080D272F261C231E09090A13243137322931362D1D
120000000006090000000000010800000000040400000000
000001010000000600050101000000020504030000020400
03000000
000200000003000401000002010005000000020000020309
00040C09123137251F2C271814141F2D2C1E130514221C19
170E0C0F020A0A0000000000010000000000020801000000
000000000000040500070B08000000020704000100000400
06000200
000400000002000300000200010004000000010000010106
000009060D2F372A2D33322820232D302B1401000006060E
1713141917272525170D0700010907000000040300000000
000000040908060800050D07020000000606000200020500
06000000
010100000001000602000100010403000000020000010105
00020A070E29342A26323E2519131F2D301906000F25201B
1505060A0710141A1C141216161B0D0E06000B0F07020105
040A0F0D0A07040500020404000000050505000000000400
02010000
010500000005000702000100000000000100010600000003
000509080619312F3030422C2C323A3A3E24100319271D2D
2B20222C160D041102050506040C141B1F1A0C040500000B
000300030500051200070400000000040801000200000700
05000000
040100000005021106000500000703000200020900000009
00050C0A13192D3B2323504535293C44441A0D1745735550
2100081C0C050E211F0A0003010A000A110714180A02000C
060E070000000208000000000000000A0804000000000800
02060000
0B0003020002010D03000300000006010000010600000005
00020605130D12271F2C5F6D402D3A3B33150D1B3C695D48
2500070E1115234F54260000000E050B0400142712181105
040002000000090000000002000000060207020000000500
010A0000
00030000000100090300020002010A000100000300010003
000006040E0102172545694E2E24312F2D130A1D2B403C28
1000000D1C2C2430392C1B1B14000008090C19190F130600
00000204040B000700000000000000050205040000000300
00090000
020300020003080601000301000006010000000000010003
0700050006000D4A271B2E3E3426272C24365082859A8E6F
39071631464F50362C1D0D171B0C08050D02081409151206
0000000C183B150D0A030300000000010000080000000000
00090000
0200000A0002060400000004000009000000000200040005
0200000002000019000017392E242D342F5490D6D0D0BB86
39091A334860645B685B413F320B020403040A1409140A01
0000000000140000080000000000000000010E0000000000
000E0004
000000040001050200000205000009010000000000020007
050000000000000F00000029302C36322738689F9391775D
1D103043556C6C58585858565630200D05090F110D110A03
04030300000C0000000000000000000000000A0000000000
0007000B
000100000000050000000004010006060000000000010004
0102020100000008030000021C3240342814100F02000013
153353584E4537453A44574D5644441E0E0100000000020E
050000010000010E00000000000000000200000002000004
00000002
000200000000010000000000010004030000000000000106
0101040201040002050500001122302923160E0500000012
1A374F5349443C3F30323F3740403F29221F130C15111210
050103010000030900000302010000000200000103000002
03000001
000000050000040000000006030008030100000000020203
0502020100110100020B03000515231B191C1C170200070E
1A33454C4B56474D4C6891909D866F4B38321A111D100905
000000000002031500000C0904000000020002000A010007
00000003
000000030000040201000004000101040300000900000000
00040000000306020000100004101509161B1D1C0D0B0C18
1A2939433F3F31556293CAD7E0C9B9A78D73260B20020012
110B0D050001002000000001030000030000000000010007
00000000
030605090000070702000000010004050100000D00000000
000504020000000C13143C03000C1302202C1300000D1C21
321D2839332D2383868D99A1B2DBEBE6CB9A36181E0C090F
0B0000000000062A00000000030000040200000300000300
00020000
04080A000001060600000600000001030000000B00000000
010003000000000B07000100000B0A000D1C0D00000E0E21
24193244535E609B7B6554526BB7DDDFCDA25935221A1408
170B0E070100001100000000030000000000010400020100
03000000
000A10000000000400000600000000000000001E00000003
0000000000000A00080009000416260D1003020C0D0C0E23
1F2D3958647778A9A18E653C2836669BA49D644B4338210F
0E0907000600000D0E060000050001000004040A00080000
00020000
000001000000000201060600010402020600000B00000010
090000000009030000060800151A35240E00001F1E150313
003A5A7A889E86342F66A49E94371A2B5293A3978E693316
000507000009000E0000090405000A020200010002050008
00000202
0000070500000003010006000300060A030000000000000F
0B000B001006000A0000001F20111B1209160D0C21504A4A
466391929D949F7545263F4F7EC59C849DB2E6FFC7B27B2E
1506050000152A03000C2110070012010000000400000000
03000011
000615000000000200000500000000040000001600000001
00000000000000000E0825341E2528100F181B24364F6270
7F8F9EA8AFA6A6D4B3835439387B9BC2D0CFBBBB94855922
140302000D011507030C1607050008000000001200000000
07000008
00000B010000000000000000010704000A00001C00000002
00040000000F0A000025461400000D0B090735637E80938C
8FB6AAB2AFAB8B8092A8ADA5732E1F5C72AEBAB49367220B
000010000000000000000706000006000000001600020000
04040400
000001060006000103000000000703030C00000500000000
0007000000000D000C325F3F31271917213C5E819AA7ACA9
A8B5B2AE9F7A532D1F5088B6B191737F8EB3AAA4885A2A20
08060C150B000F0E00000F06000007050100000700000002
00000300
00000004000A000002000200000100040900000000000000
0001080000000419121331314543291E3A6C8899A2A293A2
9CAEC0BAA87E5828002E77B7D0E0D4C4CCDEB29980543531
1B191A2B1305131700000900000008040100000100000008
01000000
010002000005000000000000000900020200000000000000
000002000005232E23101B162E30212B46667279888E8E9F
A3AEC1B8AE867D7A5B6273969FCED7DBCEAF776B5D443B42
3D3B404D39211C0E01080700000006020000000000000003
00000000
000700000000000000010000001C00010000000000000200
03000200000D2E2D2A1C0000000310365253423F4F4E5D75
88A7BFBEB4888786888E9CB4A5B3C0D4C28B3E30412E355A
595B6B705739170F0907000000000604000000000B050010
00000000
010000000000000201050000002700020000000000000000
00000000000D3236312D360312060730421F061037576E85
93A2BCA8B2818EB1C3A898B49FB8BFD8A750171521162656
797D989A744A1C0004000000000005080000000000000004
00010000
0C0000020000000000020001011600000000000000000000
000000000038451C232F3731110000071D1D1A16243E6669
9095976A8E8B9FD0DBAE889A94D1D2D68027151506030F23
61678F926B36120000000101000000000000000204050000
00020010
040000000003040701000200001000000000000A00000000
000000000055723C19001C2E3025253A463034314F736776
676980706D6F89B5B9ADB0B9BBE6C9C185422A271E010924
4659604B2F110B0000030905010000040200000500020200
06010002
040000040001010401000204010C00000000020100040303
000009050498AB4123151B181C0F1541687E83666E7B674D
40353C29336B919FADAABACAD4FFD8CA844F565336141017
3653684828050000000D0F0B050000030505050900110300
0C000003
000100000003000000000B02000100000000010900060302
0200050000B8E1393A2A1D081A16103972AED0C2A7775F37
261A0202299EB28A93B2B7B8A8B0A7C78C7972502D0B0000
234F6C5C421100000D120B030600000003090E090A2A0302
09000002
000600000006000200001101010005000000010000060009
0D0013010793AB6548362A2D372924416DABCEDDC7B89567
33080E2560D0DE91747A768793A6A1A8827282632D1F0B00
17364C533D350000000308000300000003061200001D0200
00030003
010000000011000401000F00000000000300000000010000
03000900036AA9836A5D81988269404B618CB5D2E0F1E0DB
C29E9798B0D2BF73374B5C8797AEA7AA9087927F492B1406
173035615645170A000D22080000000103000000000B0300
04000000
00030002000D000000000500000402000700010000010000
020009030951824F58737F5C4535132E4B83A5B8CFDFF2EB
FFEFD7C9CEC7A65D2E445B9090A196A49697A19966442216
1623325F55362207000C250D000001010200000400060002
05000200
000402000008060000030200000000020100000000000000
11000400003B819872483A56655E454F3F7494B2B1C3D1D9
E0DCDDE7EBE0CF6A22304B5F7689796876717D967B6C552A
0605003D627E5628133D4C1D04000600000000000A010000
00000002
000502000008000000000200000004000200000000000000
0A0004000A3C737C899CA9A78273606B5A6C7C9DA6C0E2DC
F0E6DFDFF8FCE0A574665963666461615650738A6A664A1F
0C0711586F7243160E193919030000000000000004000000
00000002
000903080000050400000000010905000200010200000503
040405071168AA9193ACB86C423446756768617296D7FFF2
FFEADBE5ECE9EAE7E4C0A7A5959B7688764763947C705432
140B1444707C592516344828080000030208000009000100
00050200
000004020000110300000000000000070000000200000100
09010000006DB2A36D3F55715A4542572F2D354157A3C8CD
E1D8E0DADDD7EEF3DEC6D1C8DDFFC2A17A354C887962552E
1E1A063364846F2611496134110003000000000008000000
0000000B
000006000004090300000000000000040000000A00000000
010200000063BEAD945C8BCBBDB7B1AA79656970728F9DB2
C0D1D9D5CDD6DBEBCECFDAB9C5D2AE916F484B798169623A
1412002E64735F37244E5D2F120000000102000203000200
0200000E
000000040001020000000000000000000000020000010606
010703060070C6B8BCA6B6CEC8CFDAE5BEAF987F767C9298
C2DEDDD4BFCCC9D1B8B7C29EA8B38F6B4D35498294857F4E
0A0200336B7163412A545F34110000000507000213020300
05000006
000000130000030000040009000200000000020000050D0A
0A0909070070C6B3B4AE8B616F728ECDB6CCB49C8D84B086
B7C4B2A39299A795AAA5AE998F884E381F001E728F8C8B65
190E124A84916D393A615A350E000000010A04002E050003
00000800
060005000005010000030000000000000000000C00000000
000100000027C6CDA93C71BEDED2B8C3ABC7DFFAF0C6B0AB
92907D795D4C5A4E46646657454549636A55295F85727F73
3237114F8C8C5D415C71451A070002000000000006060000
00010106
060400000006000000000000000000000000000000000100
00010701000F86C1D4BBDEE8F2F2EFFFF1ECDCF0EEC8C0B4
A9A4A1A79C8D7C6853523128100026424B463256737B8374
2F28287091844738473B220B000000030001000001030300
00030000
000000000000000504000008000A00010100000000010201
12000A0000025DD9CCC6E5C4D1B7C8E1C3A88ABFB3B1AE8A
61506E8BAFB7AB6A738598AAA753443D3C25234E727D7F6E
3B2A3787A1CA51413E251B0D0400010A00000A0005000000
000C0400
060400020001000103000004020006020000000000030202
0E002606100B2EBCC8D9DDD4E1DDE5EEF1D88B72615A5251
5D6DA09CB2B6A07F4F4352709CB8C48D705454616E7F896D
422D509181823F3212010C05010000070200010003000100
00000001
070300000000000100000000030004040000000000000002
02001A0413061378ADD2DFE0D8DBEAE6DB93350A0F131C39
679DD2BDCABEACBE936451506D9EB893705764727B8A8E6C
4B3661897153331B06000806030000050202000000000100
00000007
000000000000000000000000010300000100000000000102
0005070205000D2189D1EDD6C4CDE8E4D1752D161F081930
61B5D4BCC0B699BABAA0856D58425B644A596B7A8E8F8069
443668775E24120B0F000004010000050106000205000000
00000007
000000020001000000000002020105000400000000010000
000205000000000059B3DCE8D5D8DECFCB967B7C6F353036
4EABCBA6B6BE909093A0A8A998606D66417289838C836855
3E38777A4200000002000000000000030000000503060005
00010315
030000070002000000050204000000010000000000000003
00000000000200051A1A41E2ECE7E4CBB2ACCBE3C48D5D59
338BCBA2AEC5C5C2B4B0BCAEBEBCA36738577E94958D7E55
42415D4B1E00000000000001030002000000010500030000
03010134
000000020000000200090002000500030100000100000014
000000000000000903000F7DAAAFD3D1B9A2C0E7E9C8877C
2E71BBB3A09CABA9B3ACB6A2997F5C433C5A718F9C8C7C6A
41444B210000000006000000000006010000050000000000
00030419
000501000000000500060100000400010000000900020225
00000B040000000E110300196482C5CBBA9BA8CDD3B67C79
2C62AFD5C0C5CCB6B2A1946D562E2E355374757E8B84705F
292A2C080000000B070200000000050005020D0000020000
00000000
000C06030000000300030000010704000000000400010320
000011040F0E00010A0D0000132660797C7975809396816B
43568AA29EA3BDBFBA763F1F1032394F64697E927E856C49
28202D0B00000000000200000000070003080D0101000000
01010000
000A02060000000000000500020109000000000000030110
09001501120A0004040D000003081728406E7C898B88785D
413C5A697A898E60401C030E18434E53636F827F565B411E
141020190505000000000000000007000000090001040000
00000001
000002060000000000010200000500000200000000000107
04000900000000000002000008060A172B5460686D615541
35424F504E45461A0B0913272A423D4D67838D94776A4A2E
16131A14090205000107000000000B000000000105010003
00000101
020005100000000001000000000100000200000000000101
0000060000000000000005000101050F2B646D6F69534E29
211F1E1E160A0E0F17181B2C2B484A60788A778273684E33
120308000100080B11110000000009010000020208000002
00010000
060002130000000002000000000000000200000000010303
00000D0303090400000205000000000E2F6B6E5C5B57502A
281F1F160B09161B1D18263D4D877371767C7A886D5D4427
0E040B0000000C0702110704000006020000010606000000
04000001
0701051C0000000000000000000002000200000000030300
020009010200000003151E02000000001C7084877C768246
4422141515171A28332B283B42695C647079718469624219
00000000000113100D140C0801000500000005030A000000
00050000
090007150000000000000000000000000100000000020100
000002000005070000000700000000000D698D90826E7848
4B31180E1520232D302C1F333363687C797D6B6C4B41270C
05000603040001000A0B0501000003000000030909060000
03020005
040001130003000000000004000000000200000000030000
0300020000000300000000080A0800001677ADC4A88A8358
442A1E1D24302516113045656C7574716D76524633251206
000000020000000908050100000001000000030005060006
00020005
0000000E0001030202000005000104000300000300030000
010001000002060500000F0000000000145079988B877D55
300A0B1722312D313E586E8B8E8677756A613A2D200F0102
040003000001000C02000000000000010000060000010000
00070000
0402000E0002040000000004000004000000000300040000
000001000004070200000700000300001E597F9281757457
432422292D38314A505E627272787C78624D190601000000
040004020000000A02000000000000000000050000040000
00040000
080100130000080000000009000005000000000000050200
000201000000000C00000000000809172C6384917A6C7454
482E31312F30315E71747179777D78623F1900000000000D
0B0005040104040D06000000000000000000080007010002
00040001
03000016000005000000000C02000B000000000000050200
06000000000900000000000500000007104C788F70647149
4134362E3B4B4852646E7B868B7D613D1805000001020100
00000204000A04010000050601000000000008000E010005
0004010D
0000000D000007000000000902000B010000000000030100
06000000000D0000000000030002050B04254D6952505F48
403D444553645F6370767E7B7A5C43250900000001020000
00000000000E050200000A0802000000000007000B000003
0003000C
000303010000030000010002000304000100000F00010002
0100000000000B0000010C000000080E00093B7B746D755B
372A274253665D58757E6D5A330000000006000002010000
00000000071300000E0000000000000000030A0001030000
000A0200
00020100000108040001000101030A030000000500000008
00000000080D070B0000000B0606171C0C042148546F6C64
4132495A6064686B6C57463B321E100B0400000600010000
020200000009020000000101000000000002060000000000
00050000
000100000001020100060002020808000100010400010108
000100030D302C00000C0300000004160A0016293E57605D
575A6163606365585B4F4A42342103030000162112090000
00090C030000030000000D09000000000203010500000000
04000300
000500000000030000020002010307020000000300000003
0200000001000000010F040000030F150803183638405051
4E535D676C645A5456504439270404070400000000040003
020002090C12050000000302000000000000030004000001
00010000
000501000000010000020000010104010000000600000103
0001000000090700000D0000000814190D081A2D3132444B
5361656A655C5257584F3E2B160000070300000002030003
000000010601020000000604000000000002010305000000
01000000
000104020000020000050000000000000000000200000000
03000000000C070000000000000F0B080007283626192D36
4862635A5E6260635949301207050C050000000001090700
000000020A0306000003110802000000000201080E040002
05000010
000403000000030000040000000000000000000500000004
010000000007060000000000001016170B18374B443A434A
4A5A6264615F5E625945270B000006070100000000060804
020100000400020000030803000000000002030508030000
03000007
03070203000301000001000001000A000000000000020003
000001010C000000000D000A020C111916203E5A646C7773
6B666F7272665E6256371109000006080100000000000000
020007080000000000000000000000000001020200000000
03010000
030803020003030000000000010007010000000100010004
000002020B060000020E0004000B121A151F3547515C6B6B
6C666D716C5F5962523009000000090A0600000100040301
000000020300070000000401000000000002020300000000
04000000
020604010004030000010000010006010000000000000000
03000000050200000001001006100703000B2C4441475961
68696D6D736D62583B22030000000D060100050600030000
0000000308090A0000000D04000000000000000402000000
04000007
000900000004010000040100010008010000000000010007
010006020B060005030A0000081820251F2031434C50515E
575F727B776C614C301B0500000006010403080100020204
0304060D0400000000000000000000000100010000000000
03000000
000A00000006010000030000010006010000000000010005
000007040C05050C0A1200000314191F1C20314151595E70
70737D8678604E3311030000000000000608090100000003
000000090400060000000300000000000300000100000000
05000000
000600000006040000050002000005030000000000020005
040005020602000B00000000071A18180F25465656525367
67778588765E4B2100000002070508000002030000000001
0000000000000C0000010C02000000000200000104000005
06000000
00050000000A010000000000000004030200000000010000
00040504050002160F10091B25372E221927435458575770
72787C826748260600000003070003000011050000000000
0000000000000E0E00020E03000000000400000200000102
06000000
020300010007000000000001000202010200000000010000
00060405070002080714111216201D24252D414F61636570
7070716C5129160C0000000800000000010500000000000E
000100070100090000000000000000000300000200000100
05000200
02020000000A000201010003000304020300010000010000
00060C080C02102810120F14222822292C31404A616E6172
67616A69491F0A00000000070D0D0600000302000000000D
0004000A00000E0600000300000000020600000000000200
05000200
090000080001000000000000000700010100000300010200
000B01050200040608101714131A2337383C464B62676D65
655F5D512D0001283520070600000006040000010B0C1525
100B09030300110005080001000000010100000400000100
04000200
060100030008000200000000000000000300020800020201
000C070B0A1C290002121D191422242F3B41514761625A60
625D50451600000300010003000000000008050300000005
000000000000000000030101000000010800001000000600
11000200
080000080004000000000002000000000100000000020100
000604040406140A0B15181D171B14212A4255565D57594E
51483B2D160000010000000400050200000000020200030C
000000030100090001060402000000000100000501000100
06000200
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 244.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000m2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool3000000<02PX:0`00000200820PT000001@020P8600000080
0P820`030`<300D51@<01`L72000000300820PD000000`0410@200D51@<03@d=0`00000300<30`80
5ADE0`0<30`301@D50<09BDU0P0P820301`L70<08B4Q0`0g=cL201/K6`T000000P0B4Q8302XZ:P<0
>SXj0`0b<S8201<C4`H000001@061PH3000000<01PH61@00000300/;2`<000000P051@D300@41140
00000P0410@;000000<00P822000000300820P<020P81@00000300@410<00@412000000300/;2`80
00000`020P83000000<00@412000000300<30`8020P80`061PH300<30`<000000P0410@300820P<0
10@40`010@4200<30`P00000203oool000H0oooo0`00000300X:2P<000000P020P89000000D00P82
1P00000200820P<00`<30`051@D300L71`P000000`020P85000000<010@40P051@D300d=3@<00000
0`030`<201DE5@<030`<0`0D51@302DU9@80820P0`0L71`3024Q8@<0=cLg0P0K6a/9000000804Q8B
0`0Z:RX303Xj>P<0<S8b0P0C4a<6000000D01PH60`00000300H61PD000000`0;2`/3000000801@D5
0`0410@A0000008010@42`00000300820PP000000`020P8300P820D000000`0410@300410@P00000
0`0;2`/2000000<00P820`00000300410@P000000`030`<200P820<01PH60`030`<30000008010@4
0`020P8300@410<00@410P030`<8000000P0oooo00060?ooo`<00`<30`0410@3000000801@D50`00
000300820Ph000000P0410@6000000<00P822000000300410@D000000`0410@500<30`H000000P0=
3@d300H61P<020P80`0U9BD202`/;0<06QXJ0`0L71`302HV9P805aLG0`071`L300/;2`<03`l?0P0A
4A4302@T90<0=cLg0`1@D50205ADE0<0Bd];0`13@d<3038b<P80;Bd]0`0H61P301HF5P801PH62@00
000200d=3@<02`/;2`00000300410@<000000P030`<300@410<00P821@00000300410A4000000P02
0P8300/;2`<03`l?0P092@T6000000D00@410`020P8A000000D00`<30`0410@30000008010@40`07
1`L600820P800`<30`00000300410@800000203oool000H0oooo0`030`<300@410<000000P051@D3
000000<00P823P00000200@410H000000`020P88000000<00@411@00000300@410D00`<31P000002
00d=3@<01PH60`0820P302DU9@80;2`/0`0J6QX301`L70<09RHV0P0G5aL300L71`<02`/;0`0?3`l2
014A4@<092@T0`0g=cL3051@D080E5AD0`1;Bd/304=3@`<0<S8b0P0];Bd301PH60<05QHF0P061PH9
000000803@d=0`0;2`/;000000<00@410`00000200<30`<010@40`020P85000000<00@414@000002
00820P<02`/;0`0?3`l200T92@H000001@010@4300820Q4000001@030`<300@410<000000P0410@3
00L71`H00P820P030`<3000000<00@410P0000080?ooo`001P3oool300<30`<010@40`00000200D5
1@<000000`020P8>0000008010@41P00000300820PP000000`010@45000000<010@41@030`<60000
00803@d=0`061PH300P820<09BDU0P0/;2`301XJ6P<071`L0`0V9RH201LG5`<01`L70`0;2`/300l?
3`804A4A0`0T92@303Lg=`<0D51@0P1DE5@304];B`<0@d=30`0b<S8202d];@<061PH0`0F5QH200H6
1PT000000P0=3@d300/;2`/000000`010@43000000800`<30`0410@300820PD000000`010@4A0000
00800P820`0;2`/300l?3`802@T91P00000500410@<00P824@00000500<30`<010@40`00000200@4
10<01`L71P020P8200<30`<000000`010@42000000P0oooo00060?ooo`<00P820`0410@300000080
0P820`00000300820P<00@410P030`<300820PH000000P020P8300410@<000000`030`<8000000<0
0P821@00000300<30`800P820`061PH3000000<00@410P0>3Ph300P820<03@d=0`0W9bL202l_;`<0
9RHV0`0L71`302<S8`807QhN1P092@T300X:2P804a<C0`0T92@3034a<@<0=cLg0P0b<S8302TY:@<0
<C4a0`0f=SH202d];@<07AdM0`0B4Q8;000000801PH60`092@T>000000<00@410P0820P;000000H0
10@44000000600410@P000000`061PH2000000<01@D51P010@48000000<00P820P051@D300@410<0
0`<31@00000300820P<010@40`00000200<30`P00000203oool000H0oooo0`020P8300@410<00000
0P020P83000000<00P820`010@4200<30`<00P821P00000200820P<00@410`00000300<30`P00000
0`020P85000000<00`<30P020P8300H61P<000000`010@4200h>3P<020P80`0=3@d302LW9`80;bl_
0`0V9RH301`L70<08b<S0P0N7Qh600T92@<02PX:0P0C4a<302@T90<0<C4a0`0g=cL2038b<P<0:BTY
0`0a<C4303Hf=P80;Bd]0`0M7Ad3018B4P/000000P061PH300T92@h000000`010@4200P820/00000
1P0410@@000000H00@412000000300H61P8000000`051@D600410@P000000`020P8200D51@<010@4
0`030`<5000000<00P820`0410@3000000800`<3200000080?ooo`001P3oool300820P<010@40`00
000200820P<000000`020P8300410@800`<30`020P86000000800P820`010@43000000<00`<32000
000300820PD000000`030`<200820P<01PH60`00000300410@803Ph>0`0820P300d=3@<09bLW0P0_
;bl302HV9P<071`L0`0S8b<201hN7PH02@T90`0:2PX201<C4`<092@T0`0a<C4303Lg=`80<S8b0`0Y
:BT3034a<@<0=SHf0P0];Bd301dM7@<04Q8B2`00000200H61P<02@T93P00000300410@8020P82`00
000600@4110000001P010@48000000<01PH60P00000300D51@H00@412000000300820P801@D50`04
10@300<30`D000000`020P8300@410<000000P030`<8000000P0oooo00060?ooo`<000000`020P88
000000<00`<30`00000200@410<00@411P00000200820P<00@410`00000300D51@P000000`020P85
000000<00P820P030`<300T92@<000000`0410@200`<30<02@T90`0B4Q83034a<@80=cLg0`0U9BD3
01lO7`<0;2`/0P0W9bL301PH60H051@D0P0O7al302d];@<0;2`/0`0N7Qh201<C4`<01@D50`0D51@3
028R8P8071`L0`0I6AT301LG5`803Ph>0`0<30`300l?3`<00P821@0:2PX>000000<00@413@000003
00820P<020P80`010@4H000000<010@40`051@D2000000<01`L70`0;2`/300P820P000000`020P82
00L71`<010@40`00000300410@D000000`0410@3000000801PH60`00000300820P800000203oool0
00H0oooo0`00000300820PP000000`030`<30000008010@40`010@46000000800P820`010@430000
00<01@D52000000300820PD000000`020P8200<30`<02@T90`00000300@4108030`<0`092@T3018B
4P<0<C4a0P0g=cL302DU9@<07alO0`0/;2`202LW9`<061PH1P0D51@201lO7`<0;Bd]0`0/;2`301hN
7P804a<C0`051@D301@D50<08R8R0P0L71`301TI6@<05aLG0P0>3Ph300`<30<03`l?0`020P8500X:
2Ph000000`010@4=000000<00P820`0820P300410AP000000`0410@300D51@8000000`071`L300/;
2`<020P82000000300820P801`L70`0410@3000000<00@411@00000300@410<000000P061PH30000
00<00P820P0000080?ooo`001P3oool3000000<010@42000000300820P<000000P030`<6000000<0
0P820P00000300410@<000000`0410@8000000<00@411@00000500410@<01PH61P00000200T92@<0
1PH60`0=3@d302l_;`80=cLg0`0Z:RX302d];@<0<c<c0P0b<S8302PX:0<0820P0`0S8b<202d];@<0
<30`0`0[:b/301@D50800@411P00000500H61P<03Ph>0`0G5aL201<C4`<051@D0`0I6AT301LG5`80
9bLW1P0U9BD301LG5`803@d=0`071`L3000000<00@410P092@T300L71`P000000`0410@300<30a<0
00000`0410@200T92@<020P80`061PH300P8208000000`051@D300d=3@<01`L70P020P89000000D0
1PH60`00000300820P8000000`020P8300D51@<000000P061PH8000000P0oooo00060?ooo`<00000
0`0410@8000000<00P820`00000200<30`H000000`020P82000000<00@410`00000300@410P00000
0`010@45000000D00@410`061PH6000000802@T90`061PH300d=3@<0;bl_0P0g=cL302XZ:P<0;Bd]
0`0c<c<2038b<P<0:2PX0`0P820302<S8`80;Bd]0`0`<30302/[:`<051@D0P010@46000000D01PH6
0`0>3Ph301LG5`804a<C0`0D51@301TI6@<05aLG0P0W9bL602DU9@<05aLG0P0=3@d300L71`<00000
0`010@4200T92@<01`L72000000300@410<00`<34`00000300@410802@T90`0820P300H61P<020P8
0P00000300D51@<03@d=0`071`L200820PT000001@061PH3000000<00P820P00000300820P<01@D5
0`00000200H61PP00000203oool000H0oooo0`00000300@410P000000`020P83000000800`<31P00
000300820P8000000`010@43000000<010@42000000300410@D000001@010@4300H61PH000000P09
2@T300H61P<03@d=0`0_;bl203Lg=`<0:RXZ0`0];Bd303<c<`80<S8b0`0X:2P3020P80<08b<S0P0]
;Bd3030`<0<0:b/[0`0D51@200410@H000001@061PH300h>3P<05aLG0P0C4a<301@D50<06ATI0`0G
5aL202LW9`H09BDU0`0G5aL200d=3@<01`L70`00000300410@802@T90`071`L8000000<010@40`03
0`<C000000<010@40P092@T300P820<01PH60`0820P2000000<01@D50`0=3@d300L71`800P822@00
000500H61P<000000`020P82000000<00P820`051@D3000000801PH6200000080?ooo`001P3oool6
00410@P000000`010@43000000801PH60`020P83000000<00@410P00000300410@<010@40`030`<8
000000<00P821@00000500410@<01@D50`00000300820P802PX:0`071`L300h>3P<0:BTY0P0d=3@3
02XZ:P<09RHV0`0b<S8203hn?P<09BDU0`0I6AT301<C4`807alO0`0];Bd3030`<0<06ATI0P061PH3
000000<03`l?0`0U9BD2020P80<06a/K0`0E5AD200D51@<01PH60`0:2PX300L71`80410@0`0D51@3
01XJ6P<071`L0P0D51@3018B4PH05QHF0P0K6a/300d=3@<03Ph>0`061PH2000000<02`/;0`0?3`l3
00L71`800P820`010@4300D51@<010@40P0:2PX300l?3`<03@d=0P0:2PX300L71`<010@40`051@D2
000000<00P821P0410@8000000P01@D52`00000300@410<000000P020P8300410@D00000203oool0
00H0oooo1P010@48000000<00@410`00000200H61P<00P820`00000300410@8000000`010@4300@4
10<00`<32000000300820PD000001@010@4300D51@<000000`020P8200X:2P<01`L70`0>3Ph302TY
:@80=3@d0`0Z:RX302HV9P<0<S8b0P0n?Sh302DU9@<06ATI0`0C4a<201lO7`<0;Bd]0`0`<30301TI
6@801PH60`00000300l?3`<09BDU0P0P820301/K6`<05ADE0P051@D300H61P<02PX:0`071`L2010@
40<051@D0`0J6QX301`L708051@D0`0B4Q8601HF5P806a/K0`0=3@d300h>3P<01PH60P00000300/;
2`<03`l?0`071`L200820P<00@410`051@D300@410802PX:0`0?3`l300d=3@802PX:0`071`L300@4
10<01@D50P00000300820PH010@42000000800D51@/000000`0410@3000000800P820`010@450000
00P0oooo00060?ooo`H00@412000000300410@<000000P061PH300820P<000000`010@42000000<0
0@410`0410@300<30`P000000`020P85000000D00@410`051@D3000000<00P820P0:2PX300L71`<0
3Ph>0`0Y:BT203@d=0<0:RXZ0`0V9RH3038b<P80?Shn0`0U9BD301TI6@<04a<C0P0O7al302d];@<0
<30`0`0I6AT200H61P<000000`0?3`l302DU9@80820P0`0K6a/301DE5@801@D50`061PH300X:2P<0
1`L70P0@410301@D50<06QXJ0`0L71`201@D50<04Q8B1P0F5QH201/K6`<03@d=0`0>3Ph300H61P80
00000`0;2`/300l?3`<01`L70P020P8300410@<01@D50`0410@200X:2P<03`l?0`0=3@d200X:2P<0
1`L70`0410@300D51@8000000`020P8600@410P0000020051@D;000000<010@40`00000200820P<0
0@411@0000080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<00000
0`010@4=000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P8
0`061PH301TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@
0`030`<301TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@4
0`0A4A4300820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@4
0`051@D5000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P800000
0`071`L300@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D5
200000080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<000000`01
0@4=000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P80`06
1PH301TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@0`03
0`<301TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@40`0A
4A4300820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@40`05
1@D5000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P8000000`07
1`L300@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D52000
00080?ooo`001P3oool300410@<01@D52000000300D51@<000000P071`L300820P<000000`010@4=
000000<00@410`00000300410@801PH62000000300<30`<000000`051@D200T92@<020P80`061PH3
01TI6@80<C4a0`0_;bl6030`<080@T921P0/;2`3038b<PD0>SXj0`0n?Sh302@T9080410@0`030`<3
01TI6@<09bLW0P0M7Ad302d];@<0:b/[0P0P8203028R8P<0;2`/0`0F5QH200d=3@<010@40`0A4A43
00820PD01@D50`061PH300@4108030`<0`0D51@301/K6`<07alO0P0J6QX300`<30<010@40`051@D5
000000<02`/;0`00000200<30`<000000`030`<200D51@<000000`051@D3018B4P8000000`071`L3
00@410/000000`0410@200P820<00@410`00000300820PD000000`071`L3000000801@D520000008
0?ooo`001P3oool300@410<00@412000000300D51@<00P820P0A4A4300H61P<000000`051@D50000
00<01`L70`030`<2000000<00P820`00000300820P802@T92000000300T92@<000000`051@D200`<
30<02PX:0`0C4a<301TI6@80;Bd]0`0k>c/602<S8`80D51@0`15ADD303De=@<0:BTY0P0l?3`604A4
A0<06QXJ0P0=3@d301LG5`<0ADE50`1cLg<205EEE@<0D51@0`0Q8B42000000<020P80`0L71`300`<
30801@D50`0>3Ph3024Q8@<07alO0P0:2PX3000000<00`<30`010@4200X:2P<000000`0:2PX3014A
4@801`L70`0D51@301PH60<02PX:0P020P83000000<030`<0`061PH200h>3P<01`L7200000030082
0P<020P84`00000300X:2P8020P80`0410@;000000<020P80`00000200820P<01PH61@0000080?oo
o`001P3oool300@410<00@412000000300D51@<00P820P0A4A4300H61P<000000`051@D5000000<0
1`L70`030`<2000000<00P820`00000300820P802@T92000000300T92@<000000`051@D200`<30<0
2PX:0`0C4a<301TI6@80;Bd]0`0k>c/602<S8`80D51@0`15ADD303De=@<0:BTY0P0l?3`604A4A0<0
6QXJ0P0=3@d301LG5`<0ADE50`1cLg<205EEE@<0D51@0`0Q8B42000000<020P80`0L71`300`<3080
1@D50`0>3Ph3024Q8@<07alO0P0:2PX3000000<00`<30`010@4200X:2P<000000`0:2PX3014A4@80
1`L70`0D51@301PH60<02PX:0P020P83000000<030`<0`061PH200h>3P<01`L72000000300820P<0
20P84`00000300X:2P8020P80`0410@;000000<020P80`00000200820P<01PH61@0000080?ooo`00
1P3oool300/;2`<000000`030`<200820P<000000`020P8300410@803@d=0`030`<3000000<00`<3
2000000300H61P800@411P00000300410@801PH62000000300D51@<000000`020P8200H61P<01@D5
0`0C4a<300d=3@804Q8B0`0W9bL301lO7`<0;2`/0P1OGel306e]K@<0@4100`0];Bd203Xj>P<0>c/k
0`0c<c<301DE5@803@d=0`0K6a/303`l?0<0JFUY0P1MGEd304Q8B0<09BDU0P00000300L71`<03Ph>
0`0A4A4201DE5@<08b<S0`1?Cdl305ADE0809RHV2@00000200h>3P<01@D50`0;2`/300@410800000
0`0D51@302LW9`<04Q8B0P0H61P3014A4@<01@D50`0410@2000000<00P822000000300T92@/00000
0`020P88000000<01PH60P020P8300L71`<00P822000000300D51@<000000P010@4300X:2PD00000
203oool000H0oooo0`0;2`/3000000<00`<30P020P83000000<00P820`010@4200d=3@<00`<30`00
000300<30`P000000`061PH200410@H000000`010@4200H61PP000000`051@D3000000<00P820P06
1PH300D51@<04a<C0`0=3@d2018B4P<09bLW0`0O7al302`/;080GemO0`1]KFd30410@0<0;Bd]0P0j
>SX303/k>`<0<c<c0`0E5AD200d=3@<06a/K0`0l?3`306UYJ@80GEeM0`18B4P302DU9@8000000`07
1`L300h>3P<04A4A0P0E5AD302<S8`<0Cdm?0`1DE5@202HV9PT000000P0>3Ph300D51@<02`/;0`04
10@2000000<051@D0`0W9bL3018B4P8061PH0`0A4A4300D51@<010@40P00000300820PP000000`09
2@T;000000<00P822000000300H61P800P820`071`L300820PP000000`051@D3000000800@410`0:
2PX5000000P0oooo00060?ooo`<02`/;0`00000300<30`800P820`00000300820P<00@410P0=3@d3
00<30`<000000`030`<8000000<01PH60P010@46000000<00@410P061PH8000000<01@D50`000003
00820P801PH60`051@D301<C4`<03@d=0P0B4Q8302LW9`<07alO0`0/;2`205mOG`<0KFe]0`10@403
02d];@80>SXj0`0k>c/303<c<`<05ADE0P0=3@d301/K6`<0?3`l0`1YJFT205eMG@<0B4Q80`0U9BD2
000000<01`L70`0>3Ph3014A4@805ADE0`0S8b<304m?C`<0E5AD0P0V9RH9000000803Ph>0`051@D3
00/;2`<010@40P00000301@D50<09bLW0`0B4Q8201PH60<04A4A0`051@D300@4108000000`020P88
000000<02@T92`00000300820PP000000`061PH200820P<01`L70`020P88000000<01@D50`000002
00410@<02PX:1@0000080?ooo`001P3oool3000000<00`<32000000300410@<000000P092@T300<3
0`<000000`020P82000000<00P820`010@4300X:2P8000000`010@46000000800`<30`0000030041
0@8000000`030`<6000000801PH60`0410@300h>3P<00@410P020P8301LG5`<09BDU0`15ADD206UY
J@<0CTi>0`0^;Rh302@T9080<C4a0`0_;bl302d];@<04a<C0P0:2PX301dM7@<0:b/[0`10@40203`l
?0<0:2PX0`0@4105000000<03@d=0`0L71`202`/;0<092@T0`0`<30303Ti>@80;2`/1P0K6a/301@D
50D000000`0820P300T92@8030`<1P0I6AT300l?3`804a<C0`061PH8000000<00P821@0410@300/;
2`<000000`071`LC000000<01@D50P020P8300D51@<010@42000000300<30`D000000`092@T50000
00P0oooo00060?ooo`<000000`030`<8000000<00@410`00000200T92@<00`<30`00000300820P80
00000`020P8300410@<02PX:0P00000300410@H000000P030`<3000000<00@410P00000300<30`H0
00000P061PH300@410<03Ph>0`010@4200820P<05aLG0`0U9BD304E5A@80JFUY0`1>CTh302h^;P<0
92@T0P0a<C4302l_;`<0;Bd]0`0C4a<200X:2P<07AdM0`0[:b/30410@080?3`l0`0X:2P3010@40D0
00000`0=3@d301`L7080;2`/0`0T92@3030`<0<0>CTi0P0/;2`601/K6`<051@D1@00000300P820<0
2@T90P0<30`601TI6@<03`l?0P0C4a<300H61PP000000`020P8500@410<02`/;0`00000300L71a<0
00000`051@D200820P<01@D50`0410@8000000<00`<31@00000300T92@D00000203oool000H0oooo
0`00000300<30`P000000`010@43000000802@T90`030`<3000000<00P820P00000300820P<00@41
0`0:2PX2000000<00@411P00000200<30`<000000`010@42000000<00`<31P00000200H61P<010@4
0`0>3Ph300410@800P820`0G5aL302DU9@<0ADE50P1YJFT304i>CP<0;Rh^0`0T92@2034a<@<0;bl_
0`0];Bd301<C4`802PX:0`0M7Ad302/[:`<0@4100P0l?3`302PX:0<0410@1@00000300d=3@<071`L
0P0/;2`302@T90<0<30`0`0i>CT202`/;0H06a/K0`0D51@5000000<020P80`092@T200`<30H06ATI
0`0?3`l201<C4`<01PH62000000300820PD010@40`0;2`/3000000<01`L74`00000300D51@800P82
0`051@D300@410P000000`030`<5000000<02@T91@0000080?ooo`001P3oool300820P<00`<30`00
000200820P<000000`030`<300P820801PH60`010@43000000<00`<30P010@46000000<01PH60P01
0@4>000000<00@410P00000300<30`<01`L70`00000200D51@<000000`061PH3000000803@d=0`1:
BTX302LW9`<06a/K0P0^;Rh303hn?P<0=3@d0`0V9RH202LW9`<0;2`/0`0T92@303Hf=P80D51@0`22
PX8308F5Q@<0VYZJ0P2>SXh306m_K`<0>CTi0P071`L301HF5P<0<C4a0`16ATH204m?C`<0D51@0`0f
=SH302`/;0807AdM0`0=3@d301LG5`<06a/K0P0<30`300P820<01@D50`0=3@d200820P<020P80`0D
51@300T92@805ADE0`0B4Q8300H61PP000000`0<30`201PH60<0>c/k0`0E5AD300d=3@802PX:1P03
0`<;000000<00@411@00000300P8210000000`092@T5000000P0oooo00060?ooo`<00P820`030`<3
000000800P820`00000300<30`<020P80P061PH300410@<000000`030`<200410@H000000`061PH2
00410@h000000`010@42000000<00`<30`071`L3000000801@D50`00000300H61P<000000P0=3@d3
04Y:BP<09bLW0`0K6a/202h^;P<0?Shn0`0d=3@302HV9P809bLW0`0/;2`302@T90<0=SHf0P1@D503
08:2PP<0QHF50`2JVYX208j>SP<0Kfm_0`0i>CT200L71`<05QHF0`0a<C4304I6AP80Cdm?0`1@D503
03Hf=P<0;2`/0P0M7Ad300d=3@<05aLG0`0K6a/200`<30<020P80`051@D300d=3@800P820`0820P3
01@D50<02@T90P0E5AD3018B4P<01PH62000000300`<308061PH0`0k>c/301DE5@<03@d=0P0:2PX6
00<30`/000000`010@45000000<020P84000000300T92@D00000203oool000H0oooo0`020P860000
00802PX:0`00000300820P<01PH60P0410@90000008010@41P00000300T92@/000000P020P830000
00<010@40P00000300D51@<00P822000000300820PD000000`0I6AT6000000805aLG0`0i>CT302h^
;P<092@T0P0];Bd303@d=0<0;bl_0`1DE5@2092@T0<0e]KF1P3@d=020;^k^`<0QXJ60`0i>CT200T9
2@<06QXJ0`0c<c<304Q8B080H61P0`1TI6@305]KF`<0J6QX0P1KFe/30451@@<0?clo0`0b<S8200/;
2`<00P820`0410@300<30`8010@40`0:2PX301@D50<02@T90P0D51@300X:2P<00@413@00000301@D
50H000000P0820PF000000<00@410`0>3Ph@000000<03Ph>0`00000200@410P0oooo00060?ooo`<0
0P821P00000200X:2P<000000`020P8300H61P8010@42@00000200@410H000000`092@T;00000080
0P820`00000300@4108000000`051@D300820PP000000`020P85000000<06ATI1P00000201LG5`<0
>CTi0`0^;Rh302@T9080;Bd]0`0d=3@302l_;`<0E5AD0P2@T9030=KFePH0d=3@0P2k^k/308J6QP<0
>CTi0P092@T301XJ6P<0<c<c0`18B4P2061PH0<0I6AT0`1KFe/306QXJ080Fe]K0`11@D4303lo?`<0
<S8b0P0;2`/300820P<010@40`030`<200@410<02PX:0`0D51@300T92@8051@D0`0:2PX300410@d0
00000`0D51@60000008020P85P00000300410@<03Ph>4000000300h>3P<000000P0410@80?ooo`00
1P3oool300820PH000000P0:2PX3000000<00P820`061PH200@410T000000P0410@6000000<02@T9
2`00000200820P<000000`0410@2000000<01@D50`020P88000000<00P821@00000301TI6@H00000
0P0G5aL303Ti>@<0;Rh^0`0T92@202d];@<0=3@d0`0_;bl305ADE080T92@0`3Fe]H60=3@d080^k^k
0`26QXH303Ti>@802@T90`0J6QX303<c<`<0B4Q80P1PH60306ATI0<0Fe]K0`1XJ6P205]KF`<0@D51
0`0o?cl3038b<P802`/;0`020P8300@410<00`<30P0410@300X:2P<051@D0`092@T201@D50<02PX:
0`010@4=000000<051@D1P00000200P821H000000`010@4300h>3Q0000000`0>3Ph30000008010@4
203oool000H0oooo2@00000200@410<000000`010@4300D51@800P821P00000300820P801@D51P00
000300T92@800@413P00000300820P8000000`071`L300D51A0000000`0?3`l8000000<0:BTY0`0`
<30302`/;080=SHf0`0b<S8302LW9`<0>3Ph0P1XJ6P309nOW`<0Ti>C0`2ATI4207MgM`<0GEeM0`0M
7Ad2010@40<0<30`0`13@d<305EEE@D0K6a/2`1HF5P605IFEP80<30`0`0P820300d=3@<01@D50P09
2@T300l?3`<04A4A0`0=3@d2014A4@<02PX:0`030`<300@410D00`<31@00000300`<324000000`0:
2PX@000000<01`L70`00000200/;2`P0oooo00060?ooo`T000000P0410@3000000<00@410`051@D2
00820PH000000`020P8200D51@H000000`092@T200410@h000000`020P82000000<01`L70`051@D@
000000<03`l?2000000302TY:@<0<30`0`0/;2`203Hf=P<0<S8b0`0W9bL303Ph>080J6QX0`2OWil3
09>CT`<0TI6A0P1gMgL305eMG@<07AdM0P0@4103030`<0<0@d=30`1EEED506a/K0/0F5QH1P1FEUH2
030`<0<0820P0`0=3@d300D51@802@T90`0?3`l3014A4@<03@d=0P0A4A4300X:2P<00`<30`0410@5
00<30`D000000`0<30`Q000000<02PX:4000000300L71`<000000P0;2`/80?ooo`001P3oool90000
008010@40`00000300410@<01@D50P020P86000000<00P820P051@D6000000<02@T90P010@4>0000
00<00P820P00000300L71`<01@D54000000300l?3`P000000`0Y:BT3030`<0<0;2`/0P0f=SH3038b
<P<09bLW0`0h>3P206QXJ0<0WinO0`2CTi<3096AT@80MgMg0`1MGEd301dM7@80410@0`0`<30304=3
@`<0EEEE1@1/K6`;05QHF0H0EUIF0P0`<303020P80<03@d=0`051@D200T92@<03`l?0`0A4A4300d=
3@804A4A0`0:2PX300<30`<010@41@030`<5000000<030`<8@00000300X:2Q0000000`071`L30000
00802`/;203oool000H0oooo0`00000300410@/000000`051@D;0000008010@40`010@43000000D0
1PH63P00000300410@8000000`0410@300410@D00P820`010@48000000<020P80`030`<5000000<0
0P820`0L71`3038b<P80@4100`0d=3@302PX:0<051@D0P0@410300l?3`<00P821@00000301<C4`<0
5ADE0P0c<c<305=CD`<0F5QH0`1>CTh204E5A@<0=cLg0`15ADD303Xj>P80A4A40`1GEeL304e=C@<0
EUIF1@14A4@301hN7P<03Ph>0P010@4;000000<00P820`0>3Ph300D51@D000000`010@45000000<0
0@410`0>3PhF000000800P822@00000200820PH000000`0410@8000000800P82203oool000H0oooo
0`00000300410@/000000`051@D;0000008010@40`010@43000000D01PH63P00000300410@800000
0`0410@300410@D00P820`010@48000000<020P80`030`<5000000<00P820`0L71`3038b<P80@410
0`0d=3@302PX:0<051@D0P0@410300l?3`<00P821@00000301<C4`<05ADE0P0c<c<305=CD`<0F5QH
0`1>CTh204E5A@<0=cLg0`15ADD303Xj>P80A4A40`1GEeL304e=C@<0EUIF1@14A4@301hN7P<03Ph>
0P010@4;000000<00P820`0>3Ph300D51@D000000`010@45000000<00@410`0>3PhF000000800P82
2@00000200820PH000000`0410@8000000800P82203oool000H0oooo0`00000300410@/000000`05
1@D;0000008010@40`010@43000000D01PH63P00000300410@8000000`0410@300410@D00P820`01
0@48000000<020P80`030`<5000000<00P820`0L71`3038b<P80@4100`0d=3@302PX:0<051@D0P0@
410300l?3`<00P821@00000301<C4`<05ADE0P0c<c<305=CD`<0F5QH0`1>CTh204E5A@<0=cLg0`15
ADD303Xj>P80A4A40`1GEeL304e=C@<0EUIF1@14A4@301hN7P<03Ph>0P010@4;000000<00P820`0>
3Ph300D51@D000000`010@45000000<00@410`0>3PhF000000800P822@00000200820PH000000`04
10@8000000800P82203oool000H0oooo0`00000300820P/000000`010@4=000000<00@410`000003
00@410800`<34@00000200410@<01PH61P010@4200@410<00P820`010@4300@4108000000`020P86
00D51@D000000`0A4A43028R8P80<30`0`0Y:BT302<S8`<05QHF0P0>3Ph300D51@P000000`0B4Q83
01XJ6P80=cLg0`1?Cdl305=CD`<0BDU90P14A4@303`l?0<0?clo0`0`<302038b<P<0?clo0`0g=cL5
0410@0<0?clo0`0Y:BT3028R8P807alO0`0C4a<300`<30<05ADE0P0A4A43018B4P<0410@0`051@D2
00410@<00`<30`010@45000000<00`<30`092@T5000000<00`<30`020P8200410@T000000P020P86
000000<00@410P030`<6000000<00P820P030`<6000000800@41203oool000H0oooo0`0000030082
0P/000000`010@4=000000<00@410`00000300@410800`<34@00000200410@<01PH61P010@4200@4
10<00P820`010@4300@4108000000`020P8600D51@D000000`0A4A43028R8P80<30`0`0Y:BT302<S
8`<05QHF0P0>3Ph300D51@P000000`0B4Q8301XJ6P80=cLg0`1?Cdl305=CD`<0BDU90P14A4@303`l
?0<0?clo0`0`<302038b<P<0?clo0`0g=cL50410@0<0?clo0`0Y:BT3028R8P807alO0`0C4a<300`<
30<05ADE0P0A4A43018B4P<0410@0`051@D200410@<00`<30`010@45000000<00`<30`092@T50000
00<00`<30`020P8200410@T000000P020P86000000<00@410P030`<6000000<00P820P030`<60000
00800@41203oool000H0oooo2@00000200D51@H000000`0410@;000000801PH60`030`<3000000<0
20P80P030`<300410@/000001@020P8300<30`<01@D51@020P8300410@<000000`0A4A4200410@<0
00000`020P8300/;2`800`<30`00000300D51@<05ADE0P0S8b<301/K6`<06ATI1@0L71`301LG5`<0
0P820`00000200L71`<03Ph>0`0J6QX203<c<`<0ADE50`1<C4`304];B`80EUIF0`17AdL304e=C@<0
C4a<0P1XJ6P3096AT@<0T92@0`2MWId208J6QP<0Kfm_0`1;Bd/303Ph>080<S8b0`0J6QX3014A4@<0
7AdM0P0@410300T92@<01@D53@00000300820P<00`<30`0E5AD5000000<030`<0`092@T200@410T0
00000P020P83000000<00P820`00000200X:2P<00@410`00000300L71`P000000P030`<80?ooo`00
1P3oool9000000801@D51P00000300@410/000000P061PH300<30`<000000`0820P200<30`<00@41
2`00000500820P<00`<30`051@D500820P<00@410`000003014A4@800@410`00000300820P<02`/;
0P030`<3000000<01@D50`0E5AD202<S8`<06a/K0`0I6AT501`L70<05aLG0`020P83000000801`L7
0`0>3Ph301XJ6P80<c<c0`15ADD304a<C0<0Bd];0P1FEUH304M7A`<0CDe=0`1<C4`206QXJ0<0TI6A
0`2@T90309fMW@80QXJ60`1_Kfl304];B`<0>3Ph0P0b<S8301XJ6P<04A4A0`0M7Ad2010@40<02@T9
0`051@D=000000<00P820`030`<301DE5@D000000`0<30`300T92@8010@42@00000200820P<00000
0`020P83000000802PX:0`010@43000000<01`L72000000200<30`P0oooo00060?ooo`T000000P05
1@D6000000<010@42`00000200H61P<00`<30`00000300P820800`<30`010@4;000000D00P820`03
0`<300D51@D00P820`010@43000000<04A4A0P010@43000000<00P820`0;2`/200<30`<000000`05
1@D301DE5@808b<S0`0K6a/301TI6@D071`L0`0G5aL300820P<000000P071`L300h>3P<06QXJ0P0c
<c<304E5A@<0C4a<0`1;Bd/205IFEP<0AdM70`1=CDd304a<C080J6QX0`2ATI43092@T0<0WIfM0P26
QXH306m_K`<0Bd];0`0h>3P2038b<P<06QXJ0`0A4A4301dM7@80410@0`092@T300D51@d000000`02
0P8300<30`<05ADE1@00000300`<30<02@T90P0410@9000000800P820`00000300820P<000000P0:
2PX300410@<000000`071`L8000000800`<3203oool000H0oooo2@00000200<30`H000000`0410@2
00820P<00@411P00000200@410<000001P010@4200@410<00`<31P00000200T92@h000000`0410@8
000000<00`<30P061PH300820PH000000P0@4103000000<010@40`0@410201DE5@<02@T90`0F5QH3
01/K6`807AdM0`0L71`300d=3@<02`/;0P0<30`301PH60<06QXJ0P0Y:BT303Ti>@<0@d=31@0o?cl3
034a<@<0EEEE0`1RHV8209>CT`<0b/[:0`3GemL30>3Ph080bLW90`2i^KT30:NWY`<0SHf=0P1cLg<3
02HV9P<02`/;0`0P820200820P<000000`0B4Q83014A4@802`/;0`0=3@d300D51@8000000`010@43
000000<0820P2000000300410@800`<31P00000300<30`d000000`010@43000000<01`L72P000008
0?ooo`001P3oool9000000800`<31P00000300@410800P820`010@460000008010@40`0000060041
0@8010@40`030`<6000000802@T93P00000300@410P000000`030`<200H61P<00P821P000002010@
40<000000`0410@3010@40805ADE0`092@T301HF5P<06a/K0P0M7Ad301`L70<03@d=0`0;2`/200`<
30<061PH0`0J6QX202TY:@<0>CTi0`13@d<503lo?`<0<C4a0`1EEED3069RHP80Ti>C0`3:b/X30=OG
e`<0h>3P0P39bLT30;Vi^@<0YjNW0`2=SHd207=cL`<09RHV0`0;2`/3020P80800P820`000003018B
4P<04A4A0P0;2`/300d=3@<01@D50P00000300410@<000000`0P8208000000<00@410P030`<60000
00<00`<33@00000300410@<000000`071`L:000000P0oooo00060?ooo`T000000P030`<6000000<0
10@40P020P8300410@H000000P0410@3000000H00@410P0410@300<30`H000000P092@T>000000<0
10@42000000300<30`801PH60`020P8600000080410@0`00000300@410<0410@0P0E5AD300T92@<0
5QHF0`0K6a/201dM7@<071`L0`0=3@d300/;2`8030`<0`0H61P301XJ6P80:BTY0`0i>CT304=3@`D0
?clo0`0a<C4305EEE@<0HV9R0P2CTi<30<[:bP<0emOG0`3Ph>020<W9b@<0^KVi0`2WYjL308f=S@80
Lg=c0`0V9RH300/;2`<0820P0P020P83000000<04Q8B0`0A4A4200/;2`<03@d=0`051@D2000000<0
0@410`000003020P80P000000`010@4200<30`H000000`030`<=000000<00@410`00000300L71`X0
0000203oool000H0oooo0`030`<300H61P<01@D50P092@T6000000D01`L70`020P88000000<00@41
0`00000300@410801@D50`010@46000000803@d=3P00000300D51@8010@40`020P88000000<030`<
0`0C4a<301@D5080?3`l0`030`<3000000<030`<0P0C4a<300820P<0820P0`0/;2`201<C4`H00000
0`0=3@d201`L70<08B4Q0`0b<S8201dM7@<0:2PX0`0i>CT303<c<`80;Bd]0`0S8b<308>3P`<0QXJ6
0P2=SHd309VIV@<0XJ6Q0`2b/[820=_Kf`<0jn_[0`3Vi^H30<_;b`80VYZJ0`0f=SH301PH60<07QhN
0P0<30`300T92@<03`l?0`0;2`/=000000<01PH60`0Z:RX;000000800`<31P00000300@410800P82
1P00000300<30`D000000`030`<5000000<00P821@0000080?ooo`001P3oool300<30`<01PH60`05
1@D200T92@H000001@071`L300820PP000000`010@43000000<010@40P051@D300410@H000000P0=
3@d>000000<01@D50P0410@300820PP000000`0<30`301<C4`<051@D0P0l?3`300<30`<000000`0<
30`201<C4`<00P820`0P820302`/;0804a<C1P00000300d=3@8071`L0`0Q8B43038b<P807AdM0`0X
:2P303Ti>@<0<c<c0P0];Bd302<S8`<0Ph>30`26QXH208f=S@<0VIVI0`2QXJ430;:b/P80fm_K0`3[
jn/30>KViP<0bl_;0P2JVYX303Hf=P<061PH0`0N7Qh200`<30<02@T90`0?3`l300/;2`d000000`06
1PH302XZ:P/000000P030`<6000000<010@40P020P86000000<00`<31@00000300<30`D000000`02
0P85000000P0oooo00060?ooo`<00`<30`061PH300D51@802@T91P00000500L71`<00P8220000003
00410@<000000`0410@200D51@<00@411P00000200d=3@h000000`051@D200@410<00P8220000003
00`<30<04a<C0`0D51@203`l?0<00`<30`00000300`<30804a<C0`020P83020P80<0;2`/0P0C4a<6
000000<03@d=0P0L71`3024Q8@<0<S8b0P0M7Ad302PX:0<0>CTi0`0c<c<202d];@<08b<S0`23Ph<3
08J6QP80SHf=0`2IVIT30:6QX@<0/[:b0P3Kfm/30>_[j`<0i^KV0`3;bl/209ZJVP<0=SHf0`0H61P3
01hN7P8030`<0`092@T300l?3`<02`/;3@00000300H61P<0:RXZ2`00000200<30`H000000`0410@2
00820PH000000`030`<5000000<00`<31@00000300820PD00000203oool000H0oooo0`0410@300P8
20<02PX:1@00000300410@D01PH61P00000300H61PP000000`010@4200<30`T000000P0;2`/;0000
00<00@410`00000200<30`/000000`0;2`/300L71`<000000P010@46000000<02`/;0P0:2PX30000
00<03@d=0`0L71`200d=3@H000001@0>3Ph3024Q8@<092@T0P0I6AT3038b<P<0A4A40`1CDe<205iN
GP<0H61P0`2KVi/307]kN`80IFEU0`1DE5@3059BDP<0Jf][0P2g]kL30=gMg@<0gmoO0`3=cLd20::R
XP<0FEUI0`0e=CD3028R8P806QXJ0`0D51@300P820<05aLG0P0;2`/300h>3P<01`L70P010@460000
00<04A4A2`00000200<30`h000000`010@4300@4108000000`020P8300410@<000000P030`<80000
00P0oooo00060?ooo`<010@40`0820P300X:2PD000000`010@4500H61PH000000`061PH8000000<0
0@410P030`<9000000802`/;2`00000300410@<000000P030`<;000000<02`/;0`071`L300000080
0@411P00000300/;2`802PX:0`00000300d=3@<071`L0P0=3@d6000000D03Ph>0`0Q8B4302@T9080
6ATI0`0b<S8304A4A0<0De=C0P1NGUh3061PH0<0Vi^K0`1kNg/206EUI@<0E5AD0`1BDU8306][J`80
]kNg0`3MgMd30=oOg`<0cLg=0P2RXZ8305UIF@<0=CDe0`0R8R8201XJ6P<051@D0`0820P301LG5`80
2`/;0`0>3Ph300L71`800@411P000003014A4@/000000P030`<>000000<00@410`0410@2000000<0
0P820`010@43000000800`<3200000080?ooo`001P3oool3000000<02PX:0`0@410;0000008010@4
1P00000300H61QH000000P0N7Qh8000000<00`<34@00000200X:2P<000000`0820P3000000802@T9
0`00000300@410<05QHF0P0V9RH300d=3@<0410@0`030`<200820P<030`<0`0=3@d300`<30803Ph>
0`0S8b<301lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1gMgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU
0`0l?3`302PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2MWId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q
0`0?3`l300h>3P802@T90`071`L3000000801PH61P00000300d=3@803Ph>0`061PH6000000801@D5
0`00000300410@D000001P0410@300X:2P8000000`0820P8000000<00P821@0000080?ooo`001P3o
ool3000000<02PX:0`0@410;0000008010@41P00000300H61QH000000P0N7Qh8000000<00`<34@00
000200X:2P<000000`0820P3000000802@T90`00000300@410<05QHF0P0V9RH300d=3@<0410@0`03
0`<200820P<030`<0`0=3@d300`<30803Ph>0`0S8b<301lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1g
MgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU0`0l?3`302PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2M
WId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q0`0?3`l300h>3P802@T90`071`L3000000801PH61P00
000300d=3@803Ph>0`061PH6000000801@D50`00000300410@D000001P0410@300X:2P8000000`08
20P8000000<00P821@0000080?ooo`001P3oool3000000<02PX:0`0@410;0000008010@41P000003
00H61QH000000P0N7Qh8000000<00`<34@00000200X:2P<000000`0820P3000000802@T90`000003
00@410<05QHF0P0V9RH300d=3@<0410@0`030`<200820P<030`<0`0=3@d300`<30803Ph>0`0S8b<3
01lO7`80;Bd]0`0i>CT305QHF0<0I6AT0P1gMgL307QhN0<0ZJVY0`2QXJ4208j>SP<0IFEU0`0l?3`3
02PX:080=SHf0`1VIVH309^KV`<0Y:BT0P2MWId306ATI0<0Bd];0`13@d<203Ph>0<08B4Q0`0?3`l3
00h>3P802@T90`071`L3000000801PH61P00000300d=3@803Ph>0`061PH6000000801@D50`000003
00410@D000001P0410@300X:2P8000000`0820P8000000<00P821@0000080?ooo`001P3oool60000
00<00@412`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;
2`P000000`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ
6P80=CDe0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJ
FP<0NWYj0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ
6P<0:b/[0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L7
1`D000000`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P830000
00<00@410`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<0
0@412`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;2`P0
00000`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ6P80
=CDe0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJFP<0
NWYj0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ6P<0
:b/[0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L71`D0
00000`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P83000000<0
0@410`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<00@41
2`00000200820P<00@411P061PH2000000<00@410`0410@500820P<01PH61P00000200/;2`P00000
0`0@410300T92@/000000`092@T200<30`H000000`061PH200P820<000000`0E5AD301XJ6P80=CDe
0`0T92@300h>3PD000000`0O7al301hN7P<05ADE0P030`<301<C4`<000000P0j>SX305YJFP<0NWYj
0`28R8P209jNWP<0QXJ60`0d=3@302l_;`80IVIV0`2TY:@309jNWP<0U9BD0P0g=cL301XJ6P<0:b/[
0`1BDU8209>CT`<0Xj>S0`2GUiL308j>SP80JFUY0`0c<c<301HF5P<000000P051@D300L71`D00000
0`092@T3000000<03Ph>1@00000300T92@<010@40P051@D3000000<02PX:1@020P83000000<00@41
0`00000200820P<01@D50`00000300P820D000001@020P880?ooo`001P3oool6000000<01`L70P05
1@D9000000800`<30`010@43000000<01PH60P00000300<30`<000000`061PH200X:2P<00`<34000
000300l?3`<02`/;0`00000200/;2`<000000`0@410300H61P8000000`0:2PX8000000<07alO0`0P
8203014A4@806a/K0`0B4Q8300T92@<05QHF0P0=3@d300`<30<08B4Q0`1@D50504Y:BP<0ATI60P1S
Hf<3096AT@<0TY:B0`2MWId209BDU0<0WinO0`1eMGD304E5A@809RHV0`0o?cl304m?C`<0OWin0P35
aLD309bLW0<0Q8B40`2MWId20;:b/P<0i^KV0`3oool30<O7a`80/[:b0`1kNg/302h^;P<05ADE0P06
1PH300D51@D000000`0E5AD302XZ:P<00`<30P00000300`<30<08B4Q0`0@410200L71`<000000`0B
4Q8300410@P000000`0410@;000000800`<31P000002014A4@P0oooo00060?ooo`H000000`071`L2
00D51@T000000P030`<300410@<000000`061PH2000000<00`<30`00000300H61P802PX:0`030`<@
000000<03`l?0`0;2`/3000000802`/;0`000003010@40<01PH60P00000300X:2PP000000`0O7al3
020P80<04A4A0P0K6a/3018B4P<02@T90`0F5QH200d=3@<030`<0`0Q8B43051@D0D0BTY:0`16ATH2
06=SH`<0TI6A0`2BTY8309fMW@80U9BD0`2OWil307EeM@<0ADE50P0V9RH303lo?`<0Cdm?0`1nOWh2
0<G5a@<0W9bL0`24Q8@309fMW@80/[:b0`3Vi^H30?ooo`<0alO70P2b/[8307]kN`<0;Rh^0`0E5AD2
00H61P<01@D51@00000301DE5@<0:RXZ0`030`<2000000<030`<0`0Q8B43010@40801`L70`000003
018B4P<00@412000000300@410/000000P030`<6000000804A4A203oool000H0oooo0`00000300H6
1P<05ADE2`00000200820PH000000`051@D;0000008010@42@00000201HF5PP000000`010@4F0000
00<03Ph>0`0820P202DU9@<0=3@d0`0N7Qh302DU9@80:2PX0`0@410300l?3`<061PH0P0K6a/302@T
90<0=SHf0`1?Cdl2069RHP<0L71`0`1oOgl208n?S`<0WYjN0`2XZ:P30:n_[`D0YZJV0`3De=@30;>c
/`80Ph>30`1DE5@303Ti>@<0>3Ph0P1kNg/309^KV`<0`/;20`3@d=020<o?c`H0^k^k0`2DU9@208F5
Q@<0FEUI0`0R8R8301@D50800`<30`020P83000000803@d=0`010@4301DE5@<01`L70P030`<300`<
30<05QHF0`071`L200D51@<000000`0820P;000000<04Q8B2`00000200L71`H000000P0820P80?oo
o`001P3oool3000000<01PH60`0E5AD;000000800P821P00000300D51@/000000P0410@900000080
5QHF2000000300410AH000000`0>3Ph300P820809BDU0`0d=3@301hN7P<09BDU0P0X:2P3010@40<0
3`l?0`0H61P201/K6`<092@T0`0f=SH304m?C`80HV9R0`1`L70307moO`80Shn?0`2NWYh30:RXZ0<0
[jn_1@2VYZH30=CDe0<0/k>c0P23Ph<305ADE0<0>CTi0`0h>3P207]kN`<0Vi^K0`32`/830=3@d080
clo?1P2k^k/309BDU080QHF50`1IFET3028R8P<051@D0P030`<300820P<000000P0=3@d300410@<0
5ADE0`071`L200<30`<030`<0`0F5QH300L71`801@D50`00000300P820/000000`0B4Q8;00000080
1`L71P00000200P820P0oooo00060?ooo`<000000`061PH301DE5@/000000P020P86000000<01@D5
2`00000200@410T000000P0F5QH8000000<00@415P00000300h>3P<020P80P0U9BD303@d=0<07QhN
0`0U9BD202PX:0<0410@0`0?3`l301PH60806a/K0`0T92@303Hf=P<0Cdm?0P1RHV83071`L0<0Ogmo
0P2?Shl309jNWP<0Z:RX0`2_[jl50:JVYP<0e=CD0`2c/k<208>3P`<0E5AD0`0i>CT303Ph>080Ng]k
0`2KVi/30<;2`P<0d=3@0P3?cll60;^k^`<0U9BD0P25QHD305UIF@<08R8R0`0D51@200<30`<00P82
0`00000200d=3@<00@410`0E5AD300L71`800`<30`0<30`301HF5P<01`L70P051@D3000000<020P8
2`000003018B4P/000000P071`L60000008020P8203oool000H0oooo1P00000300/;2`800@415P00
000300410@<01`L70`0410@2000000<02PX:1P00000201`L70P000000`020P83000000<010@42000
000300l?3`802PX:1P00000302DU9@80ATI60`0D51@6000000803@d=0`0;2`/300T92@<01`L70P0e
=CD306=SH`<0OWin0`20P80209>CT`<0S8b<0`2?Shl20;Jf]P<0ZZZZ0`2b/[830:n_[`80Zj^[0`2;
Rh/30820P0<0TY:B0P2XZ:P30:f][@<0YJFU0`1cLg<202h^;P<07alO0`1LG5`3079bLP80[Zj^0`2j
^[X30;Bd]0<0Ti>C0P1WIfL3028R8P<02`/;1@000003010@41<000000`071`L300H61PD000000`06
1PH;000000<05QHF0P00000300820PH00000200410@2000000P0oooo00060?ooo`H000000`0;2`/2
00410AH000000`010@4300L71`<010@40P00000300X:2PH000000P0L71`8000000<00P820`000003
00@410P000000`0?3`l200X:2PH000000`0U9BD204I6AP<051@D1P00000200d=3@<02`/;0`092@T3
00L71`80=CDe0`1SHf<307inOP<0P8200P2CTi<308b<S0<0Shn?0P2f][H30:ZZZP<0/[:b0`2_[jl2
0:^[Z`<0Rh^;0`20P80309:BTP80Z:RX0`2][Jd30:FUY@<0Lg=c0P0^;Rh301lO7`<0G5aL0`1bLW82
0:j^[P<0^[Zj0`2d];@309>CT`80IfMW0`0R8R8300/;2`D000000`0@410C000000<01`L70`061PH5
000000<01PH62`00000301HF5P8000000`020P86000000P010@40P0000080?ooo`001P3oool60000
00<02`/;0P010@4F000000<00@410`071`L300@4108000000`0:2PX60000008071`L200000030082
0P<000000`0410@8000000<03`l?0P0:2PX6000000<09BDU0P16ATH301@D50H000000P0=3@d300/;
2`<02@T90`071`L203De=@<0Hf=S0`1nOWh30820P080Ti>C0`2<S8`308n?S`80][Jf0`2ZZZX30;:b
/P<0[jn_0P2[Zj/308^;R`<0P8200`2BTY820:RXZ0<0[Jf]0`2UYJD307=cL`80;Rh^0`0O7al305aL
G0<0LW9b0P2^[Zh30;Zj^P<0];Bd0`2CTi<206MWI`<08R8R0`0;2`/5000000<0410@4`00000300L7
1`<01PH61@00000300H61P/000000`0F5QH2000000<00P821P00000800@410800000203oool000H0
oooo1P00000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<0
30`<1P00000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0
<C4a0`0W9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0
Z:RX0P2e]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0
/K6a0P2ATI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<0
20P80P061PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<0
1`L70`051@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo
1P00000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<030`<
1P00000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0<C4a
0`0W9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0Z:RX
0P2e]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0/K6a
0P2ATI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<020P8
0P061PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<01`L7
0`051@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo1P00
000300410@801PH60`00000300H61P<000000P010@4300<30`/000000`071`L500<30`<030`<1P00
000200D51@h000000`071`L;000000803@d=0`00000300`<30<0<S8b0P1OGel303lo?`<0<C4a0`0W
9bL201TI6@<05aLG0`0Q8B4303`l?080GUiN0`21PH4309ZJVP<0YjNW0P2/[:`30:VYZ@<0Z:RX0P2e
]KD30;:b/P<0[Zj^0`2OWil207YjNP<0De=C0`0];Bd301lO7`80D51@0`28R8P30;Jf]P<0/K6a0P2A
TI4307=cL`<0Ogmo0`2>SXh20;>c/`<0ZZZZ0`2TY:@308R8R080FUYJ0`0Z:RX3020P80<020P80P06
1PH300`<30<05ADE0P0;2`/3000000<03`l?0`0>3Ph5000000<03`l?0`061PH5000000<01`L70`05
1@D200410@H000000`071`L8000000<00P821@00000300<30`800000203oool000H0oooo2@000002
00@410<000000`0:2PX5000000<00P820`00000300820PD000000`010@430000008010@40`092@TF
000000<00@410P0820P90000008010@40`0I6AT3018B4P<04a<C1@0a<C4304E5A@<0@d=30P0Y:BT3
01hN7P<0>SXj0`1/K6`208R8R0<0VIVI1P2RXZ8209>CT`<0XZ:R0`2LW9`20:j^[P<0`<300`2j^[X3
0:RXZ080OWin0`1HF5P302PX:0<000000P0^;Rh307MgM`<0]kNg0`3@d=020>3Ph0<0e=CD0`34a<@3
0<c<c080g]kN0`2b/[8309VIV@<0P8200P1DE5@303De=@<0<C4a0`0K6a/201TI6@<06QXJ0`0[:b/2
01<C4`<01@D50`0C4a<301LG5`D000000`092@T8000000<020P80`0410@200410@H000000`010@48
000000<020P80P010@48000000P0oooo00060?ooo`T000000P0410@3000000<02PX:1@0000030082
0P<000000`020P85000000<00@410`00000200@410<02@T95P00000300410@8020P82@00000200@4
10<06ATI0`0B4Q8301<C4`D0<C4a0`15ADD304=3@`80:BTY0`0N7Qh303Xj>P<0K6a/0P28R8P309VI
V@H0XZ:R0P2CTi<30::RXP<0W9bL0P2^[Zh30<30`0<0^[Zj0`2XZ:P207inOP<0F5QH0`0X:2P30000
0080;Rh^0`1gMgL30;Ng]`<0d=3@0P3Ph>030=CDe0<0a<C40`3<c<`20=kNgP<0/[:b0`2IVIT30820
P080E5AD0`0e=CD3034a<@<06a/K0P0I6AT301XJ6P<0:b/[0P0C4a<300D51@<04a<C0`0G5aL50000
00<02@T92000000300P820<010@40P010@46000000<00@412000000300P820800@41200000080?oo
o`001P3oool300410@<000000`020P85000000<01@D54`00000300T92@<000001@020P8I00000080
0P821P00000300D51@808b<S0`0^;Rh302<S8`<0410@0P0K6a/301HF5P<0;Rh^0`0`<302024Q8@<0
:b/[0`16ATH306IVIP80LW9b0`1iNGT308R8R0D0SXj>0`2OWil30:>SX`80[Zj^0`31`L430;Rh^0<0
[Zj^0P26QXH307emO@<0NWYj0`1KFe/2069RHP<0Lg=c0`2FUYH309nOW`80c/k>0`3GemL30=_Kf`<0
c/k>0P2_[jl307MgM`<0Jf][0`1MGEd204A4A0<0>c/k0`12@T8303dm?@80>c/k0`10@40304e=C@80
>CTi0`0Q8B4301`L70<03Ph>0P010@4300P820<01`L72000000300H61P<00P824`00000300<30`X0
0000203oool000H0oooo0`010@43000000<00P821@00000300D51A<000000`092@T3000000D00P82
6@00000200820PH000000`051@D202<S8`<0;Rh^0`0S8b<3010@40806a/K0`0F5QH302h^;P<0<30`
0P0Q8B4302/[:`<0ATI60`1VIVH2079bLP<0NGUi0`28R8P508j>SP<0WinO0`2SXj<20:j^[P<0`L71
0`2h^;P30:j^[P80QXJ60`1mOGd307YjNP<0Fe]K0P1RHV8307=cL`<0UYJF0`2OWil20<k>cP<0emOG
0`3Kfm/30<k>cP80[jn_0`1gMgL306][J`<0GEeM0P14A4@303/k>`<0@T920`0m?Cd203/k>`<0@410
0`1=CDd203Ti>@<08B4Q0`0L71`300h>3P800@410`0820P300L71`P000000`061PH300820Q<00000
0`030`<:000000P0oooo00060?ooo`<00@410`00000300820PD000000`051@DC000000<02@T90`00
000500820QT000000P020P86000000<01@D50P0S8b<302h^;P<08b<S0`0@410201/K6`<05QHF0`0^
;Rh3030`<0808B4Q0`0[:b/304I6AP<0IVIV0P1bLW8307UiN@<0R8R81@2>SXh309nOW`<0Xj>S0P2^
[Zh30<71`@<0^;Rh0`2^[Zh208J6QP<0OGem0`1jNWX305]KF`80HV9R0`1cLg<309JFUP<0WinO0P3>
c/h30=OGe`<0fm_K0`3>c/h20:n_[`<0MgMg0`1[Jf/305eMG@80A4A40`0k>c/30492@P<0?Cdm0P0k
>c/30410@0<0CDe=0P0i>CT3024Q8@<071`L0`0>3Ph200410@<020P80`071`L8000000<01PH60`02
0P8C000000<00`<32P0000080?ooo`001P3oool3000000<01`L74`00000300410@P000000`0L71`3
000000800@414@00000200820P<000000`030`<3000000800P821P00000300d=3@80;Rh^0`0];Bd3
02XZ:P<071`L2000000300<30`80410@0`0f=SH3059BDP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh2
05eMG@<0MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd]080R8R80`27QhL308J6QP<0R8R80P2>SXh3
09bLW0<0];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh3
03De=@<0FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MGE`<0>CTi0`0G5aL300l?3`802@T90`071`L;
000000<01PH60`0410@;000000802`/;0`051@D3000000<0410@2P0000080?ooo`001P3oool30000
00<01`L74`00000300410@P000000`0L71`3000000800@414@00000200820P<000000`030`<30000
00800P821P00000300d=3@80;Rh^0`0];Bd302XZ:P<071`L2000000300<30`80410@0`0f=SH3059B
DP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh205eMG@<0MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd
]080R8R80`27QhL308J6QP<0R8R80P2>SXh309bLW0<0];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2
`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh303De=@<0FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MG
E`<0>CTi0`0G5aL300l?3`802@T90`071`L;000000<01PH60`0410@;000000802`/;0`051@D30000
00<0410@2P0000080?ooo`001P3oool3000000<01`L74`00000300410@P000000`0L71`300000080
0@414@00000200820P<000000`030`<3000000800P821P00000300d=3@80;Rh^0`0];Bd302XZ:P<0
71`L2000000300<30`80410@0`0f=SH3059BDP<0De=C0P12@T8303lo?`<0Cdm?0`1>CTh205eMG@<0
MGEe0`28R8P20:NWY`<0_kno0`2n_[h30;Bd]080R8R80`27QhL308J6QP<0R8R80P2>SXh309bLW0<0
];Bd0`2UYJD20;>c/`<0`<300`3De=@30<;2`P80Rh^;0`0n?Sh3030`<0<0@D510P0^;Rh303De=@<0
FUYJ0`1IFET205]KF`<0Jf][0`1`L70205MGE`<0>CTi0`0G5aL300l?3`802@T90`071`L;000000<0
1PH60`0410@;000000802`/;0`051@D3000000<0410@2P0000080?ooo`001P3oool300410A400000
0P020P8300410@<01@D52000000302LW9`<000000P020P8T000000<03@d=0P0b<S8303Hf=P<0<C4a
0`0];Bd203Hf=P<00`<30`0B4Q8300H61P801`L70`0`<3030492@P<07alO0P061PH3010@40<0=cLg
0`1GEeL206i^KP<0QHF50`2CTi<20::RXP<0_;bl0`2XZ:P30;:b/P80PH610`2>SXh30;6a/@<0`l?3
0P2XZ:P309RHV0<0];Bd0`2OWil20;Rh^0<0_kno0`3Hf=P30:NWY`80D51@0`0G5aL301DE5@<08B4Q
0P0F5QH302HV9P<0EUIF0`1iNGT207emO@<0V9RH0`2JVYX207AdM0<0BTY:0`0L71`30000008010@4
3P00000300D51@<020P84`00000300@4108000000`010@45000000P0oooo00060?ooo`<00@414@00
000200820P<00@410`051@D8000000<09bLW0`00000200820R@000000`0=3@d2038b<P<0=SHf0`0a
<C4302d];@80=SHf0`030`<3018B4P<01PH60P071`L3030`<0<0@T920`0O7al200H61P<0410@0`0g
=cL305MGE`80KVi^0`25QHD309>CT`80XZ:R0`2l_;`30:RXZ0<0/[:b0P21PH4308j>SP<0/K6a0`33
`l<20:RXZ0<0V9RH0`2d];@309nOW`80^;Rh0`2o_kl30=SHf0<0YjNW0P1@D50301LG5`<05ADE0`0Q
8B4201HF5P<09RHV0`1FEUH307UiN@80OGem0`2HV9P309ZJVP80M7Ad0`1:BTX301`L70<000000P04
10@>000000<01@D50`0820PC000000<010@40P00000300410@D00000203oool000H0oooo0`0<30`6
000000800P823P00000300820P<000001@010@4301HF5RT000000`0h>3P204E5A@<071`L0`0S8b<3
02l_;`80=cLg0`0a<C43014A4@D000000`071`L601dM7@806QXJ0`0F5QH302@T90<0?Shn0P1VIVH3
06UYJ@<0T92@0P2EUID309NGU`<0JVYZ0`2>SXh208^;R`<0WinO0`3@d=030=_Kf`80[Zj^0`28R8P3
09ZJVP<0U9BD0P3AdM430=;BdP<0e]KF0`20P80202LW9`H05ADE0`061PH200<30`<03`l?0`0S8b<3
065QH@80IfMW0`2?Shl309:BTP80Jf][0`0f=SH3018B4PP000001P010@4C000000<00P820P0410@3
00D51@P000000`020P8300000080410@203oool000H0oooo0`0<30`6000000800P823P0000030082
0P<000001@010@4301HF5RT000000`0h>3P204E5A@<071`L0`0S8b<302l_;`80=cLg0`0a<C43014A
4@D000000`071`L601dM7@806QXJ0`0F5QH302@T90<0?Shn0P1VIVH306UYJ@<0T92@0P2EUID309NG
U`<0JVYZ0`2>SXh208^;R`<0WinO0`3@d=030=_Kf`80[Zj^0`28R8P309ZJVP<0U9BD0P3AdM430=;B
dP<0e]KF0`20P80202LW9`H05ADE0`061PH200<30`<03`l?0`0S8b<3065QH@80IfMW0`2?Shl309:B
TP80Jf][0`0f=SH3018B4PP000001P010@4C000000<00P820P0410@300D51@P000000`020P830000
0080410@203oool000H0oooo0`0<30`6000000800P823P00000300820P<000001@010@4301HF5RT0
00000`0h>3P204E5A@<071`L0`0S8b<302l_;`80=cLg0`0a<C43014A4@D000000`071`L601dM7@80
6QXJ0`0F5QH302@T90<0?Shn0P1VIVH306UYJ@<0T92@0P2EUID309NGU`<0JVYZ0`2>SXh208^;R`<0
WinO0`3@d=030=_Kf`80[Zj^0`28R8P309ZJVP<0U9BD0P3AdM430=;BdP<0e]KF0`20P80202LW9`H0
5ADE0`061PH200<30`<03`l?0`0S8b<3065QH@80IfMW0`2?Shl309:BTP80Jf][0`0f=SH3018B4PP0
00001P010@4C000000<00P820P0410@300D51@P000000`020P8300000080410@203oool000H0oooo
0`0410@;000000<00`<30`0410@200L71`<00@410`00000300820PD000000`0@410>000000802PX:
6@00000305EEE@80LW9b0`0l?3`301TI6@<000000P0L71`302h^;P<0<30`1@0U9BD303Xj>P<0ATI6
0`0`<30203@d=0<0<C4a0`1?Cdl307=cL`80IfMW0`1fMWH306MWI`80JFUY0`20P803071`L0<0KFe]
0P1_Kfl308V9R@<0]KFe0`2i^KT20:f][@<0/;2`0`2i^KT30;^k^`80i^KV0`39bLT30<71`@<0QHF5
0P12@T8302XZ:P<09bLW0`0N7Qh200410@<02@T90`0T92@304I6AP80FEUI0`1PH60304];B`80;bl_
0`0A4A4300/;2`D000000`030`<300T92@<01@D50P010@46000000<010@40P020P86000000<01@D5
0P00000600820P<000000P061PH300410@<000000P020P880?ooo`001P3oool300@410/000000`03
0`<300@410801`L70`010@43000000<00P821@000003010@40h000000P0:2PXI000000<0EEEE0P1b
LW8303`l?0<06ATI0`00000201`L70<0;Rh^0`0`<30502DU9@<0>SXj0`16ATH3030`<080=3@d0`0a
<C4304m?C`<0Lg=c0P1WIfL307IfMP<0IfMW0P1YJFT30820P0<0L71`0`1]KFd206m_K`<0RHV90`2e
]KD30;Vi^@80[Jf]0`2`/;030;Vi^@<0^k^k0P3Vi^H30<W9b@<0`L710`25QHD20492@P<0:RXZ0`0W
9bL301hN7P800@410`092@T302@T90<0ATI60P1IFET3061PH0<0Bd];0P0_;bl3014A4@<02`/;1@00
000300<30`<02@T90`051@D200410@H000000`0410@200820PH000000`051@D2000000H00P820`00
000200H61P<00@410`00000200820PP0oooo00060?ooo`<010@42`00000300<30`<010@40P071`L3
00410@<000000`020P85000000<0410@3P00000200X:2QT000000`1EEED2079bLP<0?3`l0`0I6AT3
0000008071`L0`0^;Rh3030`<0D09BDU0`0j>SX304I6AP<0<30`0P0d=3@3034a<@<0Cdm?0`1cLg<2
06MWI`<0MWIf0`1WIfL206UYJ@<0P8200`1`L70306e]K@80Kfm_0`29RHT30;Fe]@<0^KVi0P2][Jd3
0;2`/0<0^KVi0`2k^k/20>KViP<0bLW90`31`L4308F5Q@80@T920`0Z:RX302LW9`<07QhN0P010@43
00T92@<092@T0`16ATH205UIF@<0H61P0`1;Bd/202l_;`<04A4A0`0;2`/5000000<00`<30`092@T3
00D51@800@411P00000300@410800P821P00000300D51@8000001P020P83000000801PH60`010@43
000000800P82203oool000H0oooo0`0410@60000008010@40`00000600410@8010@40`010@430000
00<00P820P0410@300410@<030`<2`00000300820P800@410`00000300@410D00`<31P00000200T9
2@<01@D50`0410@309RHV080Zj^[0`11@D4302<S8`<05ADE0P0K6a/301PH60<071`L0`0?3`l201DE
5@<0@D510`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l
?0<0:BTY0`0c<c<206][J`<0TI6A0`2OWil30:f][@80ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SH
f0<0b/[:0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P8051@D0`0@410301LG5`<0=SHf0P1CDe<306QX
J0<0B4Q80P0X:2P300D51@P000000`0=3@d300l?3`<02`/;0P051@D6000000<00`<320051@D300T9
2@8000000`0A4A4300<30`<000000P0<30`6000000800`<3203oool000H0oooo0`0410@600000080
10@40`00000600410@8010@40`010@43000000<00P820P0410@300410@<030`<2`00000300820P80
0@410`00000300@410D00`<31P00000200T92@<01@D50`0410@309RHV080Zj^[0`11@D4302<S8`<0
5ADE0P0K6a/301PH60<071`L0`0?3`l201DE5@<0@D510`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0
Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l?0<0:BTY0`0c<c<206][J`<0TI6A0`2OWil30:f][@80
ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SHf0<0b/[:0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P80
51@D0`0@410301LG5`<0=SHf0P1CDe<306QXJ0<0B4Q80P0X:2P300D51@P000000`0=3@d300l?3`<0
2`/;0P051@D6000000<00`<320051@D300T92@8000000`0A4A4300<30`<000000P0<30`600000080
0`<3203oool000H0oooo0`0410@60000008010@40`00000600410@8010@40`010@43000000<00P82
0P0410@300410@<030`<2`00000300820P800@410`00000300@410D00`<31P00000200T92@<01@D5
0`0410@309RHV080Zj^[0`11@D4302<S8`<05ADE0P0K6a/301PH60<071`L0`0?3`l201DE5@<0@D51
0`1XJ6P307inOP80Ph>30`1VIVH306i^KP<0Ng]k0P1WIfL304e=C@<0@4100P0e=CD303`l?0<0:BTY
0`0c<c<206][J`<0TI6A0`2OWil30:f][@80ZZZZ0`2j^[X30<[:bP<0e=CD0P3oool30=SHf0<0b/[:
0`24Q8@204m?C`<0EUIF0`1CDe<303Hf=P8051@D0`0@410301LG5`<0=SHf0P1CDe<306QXJ0<0B4Q8
0P0X:2P300D51@P000000`0=3@d300l?3`<02`/;0P051@D6000000<00`<320051@D300T92@800000
0`0A4A4300<30`<000000P0<30`6000000800`<3203oool000H0oooo0`00000300410@P000000`03
0`<;000000<02`/;0P020P83000000<00@412`00000300410@802@T90`00000300H61P800`<31P02
0P83000000801@D51P0000030;Rh^080hN7Q0`0i>CT303Xj>P<0:RXZ0P0M7Ad300P820<06QXJ0`0F
5QH2010@40<0>CTi0`1bLW830:j^[P80d=3@0`32`/830:NWY`<0MgMg0P1OGel303Lg=`<09RHV0P0J
6QX600820P<0:BTY0P2NWYh30;:b/P<0RXZ:0`2CTi<20;:b/P<0]kNg0`2h^;P30:RXZ080/;2`0`2W
YjL30<O7a`<0S8b<0P1iNGT3079bLP<0D51@0`0];Bd200/;2`H000000`0S8b<204m?C`<0K6a/0`1L
G5`20492@P<04A4A1P00000200d=3@<04Q8B0`0;2`/300<30`801PH62@00000200<30`<02@T90`0>
3Ph300T92@802PX:0`0Z:RX300<30`<00P820P092@T6000000800P82203oool000H0oooo0`000003
00410@P000000`030`<;000000<02`/;0P020P83000000<00@412`00000300410@802@T90`000003
00H61P800`<31P020P83000000801@D51P0000030;Rh^080hN7Q0`0i>CT303Xj>P<0:RXZ0P0M7Ad3
00P820<06QXJ0`0F5QH2010@40<0>CTi0`1bLW830:j^[P80d=3@0`32`/830:NWY`<0MgMg0P1OGel3
03Lg=`<09RHV0P0J6QX600820P<0:BTY0P2NWYh30;:b/P<0RXZ:0`2CTi<20;:b/P<0]kNg0`2h^;P3
0:RXZ080/;2`0`2WYjL30<O7a`<0S8b<0P1iNGT3079bLP<0D51@0`0];Bd200/;2`H000000`0S8b<2
04m?C`<0K6a/0`1LG5`20492@P<04A4A1P00000200d=3@<04Q8B0`0;2`/300<30`801PH62@000002
00<30`<02@T90`0>3Ph300T92@802PX:0`0Z:RX300<30`<00P820P092@T6000000800P82203oool0
00H0oooo0`00000300H61PP000000`061PH3000000800P821P000003014A4@D00@410`00000300D5
1@P000000`010@45000000<01PH60P00000300T92@<03@d=0`00000201<C4`<00@410`071`L309>C
T`80Zj^[0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[
Z`80c/k>0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0<c<c0P0820P300h>3P<09BDU0`1PH6020=3@
d0<0g]kN0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079b
LP<0PX:20`1SHf<302d];@807alO0`0;2`/3000000<05aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De
=@P000000`030`<300P820<000000P030`<9000000800`<30`061PH3018B4PD000000`0M7Ad30082
0PD000000`030`<3000000800`<3203oool000H0oooo0`00000300H61PP000000`061PH300000080
0P821P000003014A4@D00@410`00000300D51@P000000`010@45000000<01PH60P00000300T92@<0
3@d=0`00000201<C4`<00@410`071`L309>CT`80Zj^[0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0
=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[Z`80c/k>0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0
<c<c0P0820P300h>3P<09BDU0`1PH6020=3@d0<0g]kN0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0
Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079bLP<0PX:20`1SHf<302d];@807alO0`0;2`/3000000<0
5aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De=@P000000`030`<300P820<000000P030`<900000080
0`<30`061PH3018B4PD000000`0M7Ad300820PD000000`030`<3000000800`<3203oool000H0oooo
0`00000300H61PP000000`061PH3000000800P821P000003014A4@D00@410`00000300D51@P00000
0`010@45000000<01PH60P00000300T92@<03@d=0`00000201<C4`<00@410`071`L309>CT`80Zj^[
0`1UIFD304Q8B0<0=SHf0P0Z:RX302d];@<0=cLg0`0Y:BT202@T90<0@D510`1]KFd30:^[Z`80c/k>
0`3MgMd30<O7a`<0^;Rh0P2EUID306MWI`<0<c<c0P0820P300h>3P<09BDU0`1PH6020=3@d0<0g]kN
0`2ATI4307AdM080NWYj0`1fMWH308N7Q`<0Ti>C0P2VYZH30:6QX@<0Z:RX0`22PX82079bLP<0PX:2
0`1SHf<302d];@807alO0`0;2`/3000000<05aLG0P0f=SH304a<C0<0De=C0P0m?Cd303De=@P00000
0`030`<300P820<000000P030`<9000000800`<30`061PH3018B4PD000000`0M7Ad300820PD00000
0`030`<3000000800`<3203oool000H0oooo0`010@4;000000<04A4A0`00000200@410<00@410`00
000300l?3`d000000`030`<;000000<00@411@00000300<30`<000000P092@T3000000<00`<30`1Z
JVX20:VYZ@<0Ph>30`1ZJVX305eMG@80PH610`2HV9P308:2PP<0JFUY0P10@40304];B`<0HF5Q0`2<
S8`20;Fe]@<0d];B0`3Ph>030?7al@80h>3P0`3Kfm/30<;2`P80WYjN0`2GUiL309RHV0<0/;2`0P3B
d]830;no_`<0Lg=c0`0g=cL204];B`<0G5aL0`27QhL309NGU`80[Zj^0`2WYjL30:ZZZP<0T92@0P27
QhL309:BTP<0Ogmo0`19BDT202/[:`<051@D0`061PH301LG5`80<30`0`0e=CD3065QH@80EUIF0`15
ADD301LG5`<02PX:0P00000300d=3@<08R8R0`0820P8000000<00@410P030`<;000000<02`/;0`03
0`<30000008010@4200000080?ooo`001P3oool300410@/000000`0A4A430000008010@40`010@43
000000<03`l?3@00000300<30`/000000`010@45000000<00`<30`00000200T92@<000000`030`<3
06YZJP80ZJVY0`23Ph<306YZJP<0GEeM0P21PH4309RHV0<0PX:20`1YJFT20410@0<0Bd];0`1QHF43
08b<S080]KFe0`3Bd]830>3Ph0<0lO7a0P3Ph>030=_Kf`<0`/;20P2NWYh309NGU`<0V9RH0`2`/;02
0=;BdP<0_kno0`1cLg<303Lg=`80Bd];0`1LG5`308N7Q`<0UiNG0P2^[Zh30:NWY`<0ZZZZ0`2@T902
08N7Q`<0TY:B0`1oOgl304U9B@80:b/[0`0D51@300H61P<05aLG0P0`<30303De=@<0HF5Q0P1FEUH3
04E5A@<05aLG0`0:2PX2000000<03@d=0`0R8R8300P820P000000`010@4200<30`/000000`0;2`/3
00<30`<000000P0410@8000000P0oooo00060?ooo`<00@412`000003014A4@<000000P0410@30041
0@<000000`0?3`l=000000<00`<32`00000300410@D000000`030`<3000000802@T90`00000300<3
0`<0JVYZ0P2YZJT308>3P`<0JVYZ0`1MGEd20861P@<0V9RH0`22PX8306UYJ@80@4100`1;Bd/3065Q
H@<0S8b<0P2e]KD30=;BdP<0h>3P0`3alO420>3Ph0<0fm_K0`32`/8209jNWP<0UiNG0`2HV9P30;2`
/080d];B0`2o_kl307=cL`<0=cLg0P1;Bd/305aLG0<0QhN70`2GUiL20:j^[P<0YjNW0`2ZZZX3092@
T080QhN70`2BTY8307moO`<0BDU90P0[:b/301@D50<01PH60`0G5aL2030`<0<0=CDe0`1QHF4205IF
EP<0ADE50`0G5aL300X:2P8000000`0=3@d3028R8P<020P82000000300410@800`<32`00000300/;
2`<00`<30`00000200@410P00000203oool000H0oooo0`00000300<30`<000000P020P83000000<0
3@d=2`00000300D51@D000000`0410@300820P8000000`071`L3000000<00@411@00000300410@D0
00000`020P83000000802@T90`030`<300T92@<0DE5A0P22PX8304m?C`<0F5QH0`1cLg<207moO`<0
G5aL0`15ADD303De=@804a<C0`0^;Rh304];B`<0Ph>30P2UYJD30;Rh^0<0clo?0`3Ogml20?;blP<0
jn_[0`3oool20>o_k`<0emOG0`39bLT30<k>cP80alO70`2VYZH305eMG@<0;Rh^0P14A4@305]KF`H0
T92@0P2QXJ4309JFUP<0Y:BT0`2FUYH209NGU`<0XJ6Q0`2IVIT306IVIP80A4A40`0R8R8601HF5P80
8b<S0`0b<S8305mOG`80EEEE0`0f=SH3028R8P<01`L70P00000300`<30<09BDU0`0=3@d5000000H0
0@410P020P86000000<010@40P00000300H61P<000000`020P8200D51@<000000`020P82000000P0
oooo00060?ooo`<000000`030`<3000000800P820`00000300d=3@/000000`051@D5000000<010@4
0`020P82000000<01`L70`00000300410@D000000`010@45000000<00P820`00000200T92@<00`<3
0`092@T3055AD@80PX:20`1?Cdl305QHF0<0Lg=c0P1oOgl305aLG0<0ADE50`0e=CD201<C4`<0;Rh^
0`1;Bd/308>3P`80YJFU0`2h^;P30<o?c`<0gmoO0P3bl_830>_[j`<0oooo0P3_knl30=OGe`<0bLW9
0`3>c/h20<O7a`<0YZJV0`1MGEd302h^;P80A4A40`1KFe/6092@T080XJ6Q0`2FUYH30:BTY0<0UYJF
0P2GUiL30:6QX@<0VIVI0`1VIVH204A4A0<08R8R1P0F5QH202<S8`<0<S8b0`1OGel205EEE@<0=SHf
0`0R8R8300L71`8000000`0<30`302DU9@<03@d=1@00000600410@800P821P00000300@410800000
0`061PH3000000<00P820P051@D3000000<00P820P0000080?ooo`001P3oool3000000<010@40`02
0P85000000<020P80`061PH5000000<00`<30`020P8;000000800P820`010@4C000000<04A4A0`00
000200@410H000000`0k>c/20861P@<0V9RH0`1bLW8304Q8B080>SXj0`1FEUH306EUI@<0GUiN0P15
ADD304m?C`<0?clo0`1dM7@209BDU0<0/[:b0`2a/K430<?3``80dM7A0`3IfMT30>3Ph080g=cL0`3M
gMd30>OWi`<0jn_[0P3Ph>030<o?c`<0JVYZ0`0R8R82030`<0<0Bd];0`1OGel307IfMP80RHV90`1i
NGT306QXJ0<0MWIf0P1aLG4307emO@<0UYJF0`1kNg/206a/K0<0EEEE0`0Z:RX300H61P801@D50`00
000303dm?@80HV9R0`1nOWh305IFEP<0:2PX0P0C4a<303dm?@<0C4a<0`0M7Ad200@410<000000`06
1PH>000000802PX:0`010@4>000000800P82203oool000H0oooo0`00000300@410<00P821@000003
00P820<01PH61@00000300<30`<00P822`00000200820P<00@414`000003014A4@<000000P0410@6
000000<0>c/k0P21PH4309RHV0<0LW9b0`18B4P203Xj>P<0EUIF0`1UIFD305iNGP80ADE50`1?Cdl3
03lo?`<0M7Ad0P2DU9@30;:b/P<0/K6a0`33`l<20=7Ad@<0fMWI0`3Ph>020=cLg0<0gMgM0`3WinL3
0>_[j`80h>3P0`3?cll306YZJP<08R8R0P0`<30304];B`<0GemO0`1fMWH208V9R@<0NGUi0`1XJ6P3
07IfMP80LG5a0`1mOGd309JFUP<0Ng]k0P1/K6`305EEE@<0:RXZ0`061PH200D51@<000000`0m?Cd2
069RHP<0OWin0`1FEUH302PX:0804a<C0`0m?Cd304a<C0<07AdM0P0410@3000000<01PH63P000002
00X:2P<00@413P00000200820PP0oooo00060?ooo`<000000`0410@300820PD000000`0820P300H6
1PD000000`030`<300820P/000000P020P8300410A<000000`0A4A430000008010@41P00000303/k
>`80PH610`2HV9P3079bLP<0B4Q80P0j>SX305IFEP<0IFEU0`1NGUh204E5A@<0Cdm?0`0o?cl307Ad
M080U9BD0`2b/[830;6a/@<0`l?30P3AdM430=WIf@<0h>3P0P3Lg=`30=gMg@<0inOW0`3[jn/20>3P
h0<0clo?0`1ZJVX3028R8P80<30`0`1;Bd/305mOG`<0MWIf0P29RHT307UiN@<0J6QX0`1fMWH2075a
L@<0OGem0`2FUYH307]kN`80K6a/0`1EEED302XZ:P<01PH60P051@D3000000<0?Cdm0P1RHV8307in
OP<0EUIF0`0X:2P201<C4`<0?Cdm0`1<C4`301dM7@8010@40`00000300H61Ph000000P0:2PX30041
0@h000000P020P880?ooo`001P3oool3000000<01@D50`020P85000000<020P82`00000300820PP0
00000`0410@2000000<00P824`00000300X:2P<000000P0410@3000000<02PX:0`0l?3`207=cL`<0
O7al0`29RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0
WIfM0`2VYZH30<30`080h^;R0`3Lg=`30?3`l080i^KV1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0
M7Ad0P1VIVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80
IVIV0`1:BTX301lO7`<030`<0P071`L3014A4@<0F5QH0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<0
6ATI0`0i>CT301TI6@800`<35000000200@4114000000P020P880?ooo`001P3oool3000000<01@D5
0`020P85000000<020P82`00000300820PP000000`0410@2000000<00P824`00000300X:2P<00000
0P0410@3000000<02PX:0`0l?3`207=cL`<0O7al0`29RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c
0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0WIfM0`2VYZH30<30`080h^;R0`3Lg=`30?3`l080i^KV
1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0M7Ad0P1VIVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q
0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80IVIV0`1:BTX301lO7`<030`<0P071`L3014A4@<0F5QH
0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<06ATI0`0i>CT301TI6@800`<35000000200@411400000
0P020P880?ooo`001P3oool3000000<01@D50`020P85000000<020P82`00000300820PP000000`04
10@2000000<00P824`00000300X:2P<000000P0410@3000000<02PX:0`0l?3`207=cL`<0O7al0`29
RHT309bLW080ZJVY0`2WYjL308:2PP<0Lg=c0P1PH60306][J`<0FUYJ0`1/K6`207alO0<0WIfM0`2V
YZH30<30`080h^;R0`3Lg=`30?3`l080i^KV1P3Ogml30?Shn080o?cl0`3Ph>030:FUY@<0M7Ad0P1V
IVH305UIF@<0Hf=S0`1VIVH206ATI0H0HF5Q0`1FEUH2051@D0<0Lg=c0`2:RXX306YZJP80IVIV0`1:
BTX301lO7`<030`<0P071`L3014A4@<0F5QH0P1_Kfl3079bLP<0@d=30`0F5QH200h>3P<06ATI0`0i
>CT301TI6@800`<35000000200@4114000000P020P880?ooo`001P3oool3000000<02@T90`030`<2
00P820H000000`051@D200@410/000000`010@4300T92@<01@D50P00000300820P<000000`010@42
00820PH000000P051@D300<30`H010@40P051@D300L71`<04A4A0`1XJ6P20:ZZZP<0TI6A0`2CTi<3
0:b/[080^;Rh0`1/K6`30492@P<0=3@d0P16ATH307EeM@<0IfMW0`1XJ6P2065QH@<0LW9b0`2FUYH3
0=OGe`80oooo0`3bl_830?ooo`80j^[Z0`3Kfm/30>GUi@<0k>c/0P3YjNT30>[ZjP<0inOW0`3Ti>@2
0<30`0<0YjNW0`2UYJD309FEU@80Vi^K0`1fMWH308R8R0<0MWIf0P17AdL306=SH`<0U9BD0`1lO7`2
071`L0<0E5AD0`0b<S8301@D50802`/;0`0D51@304A4A080L71`0`1lO7`305UIF@<09BDU0P0F5QH3
03@d=0<0B4Q80`0X:2P200P820H000000`030`<200820P<020P81P00000200T92@<000000`010@45
000000<01@D50`020P82000000P0oooo00060?ooo`<000000`092@T300<30`8020P81P00000300D5
1@8010@42`00000300410@<02@T90`051@D2000000<00P820`00000300410@800P821P00000200D5
1@<00`<31P0410@200D51@<01`L70`0A4A4306QXJ080ZZZZ0`2ATI4309>CT`<0[:b/0P2h^;P306a/
K0<0@T920`0d=3@204I6AP<0MGEe0`1WIfL306QXJ080HF5Q0`1bLW8309JFUP<0emOG0P3oool30?;b
lP<0oooo0P3Zj^X30=_Kf`<0iNGU0`3/k>`20>WYj@<0j^[Z0`3WinL30>CTi080`<300`2WYjL30:FU
Y@<0UIFE0P2KVi/307IfMP<0R8R80`1fMWH204M7A`<0Hf=S0`2DU9@307alO080L71`0`1DE5@3038b
<P<051@D0P0;2`/301@D50<0A4A40P1`L70307alO0<0FEUI0`0U9BD201HF5P<0=3@d0`18B4P302PX
:08020P81P00000300<30`800P820`0820P6000000802@T90`00000300410@D000000`051@D30082
0P800000203oool000H0oooo0`00000300T92@<00`<30P0820P6000000<01@D50P0410@;000000<0
0@410`092@T300D51@8000000`020P83000000<00@410P020P86000000801@D50`030`<600@41080
1@D50`071`L3014A4@<0J6QX0P2ZZZX3096AT@<0Ti>C0`2/[:`20;Rh^0<0K6a/0`12@T8303@d=080
ATI60`1eMGD306MWI`<0J6QX0P1QHF43079bLP<0UYJF0`3GemL20?ooo`<0l_;b0`3oool20>[ZjP<0
fm_K0`3UiND30>c/k080jNWY0`3Zj^X30>OWi`<0i>CT0P30`<030:NWY`<0YJFU0`2EUID209^KV`<0
MWIf0`28R8P307IfMP80AdM70`1SHf<309BDU0<0O7al0P1`L70305ADE0<0<S8b0`0D51@200/;2`<0
51@D0`14A4@2071`L0<0O7al0`1IFET302DU9@805QHF0`0d=3@304Q8B0<0:2PX0P0820P6000000<0
0`<30P020P8300P820H000000P092@T3000000<00@411@00000300D51@<00P820P0000080?ooo`00
1P3oool6000000<010@40P020P86000000<04A4A0P030`<D000000801`L72@00000200820PH00000
0P010@43000000<02@T90`010@48000000<0KFe]0P2b/[830:>SX`<0KFe]0`0o?cl205EEE@<0LG5a
0`1JFUX304E5A@80@T920`1GEeL302l_;`<0;Bd]0P0e=CD30451@@<0EeMG0`2SXj<20<S8b0<0cLg=
0`3QhN420=SHf0<0h>3P0`3Jf]X30=gMg@80emOG0`3^k^h30??cl`<0g]kN0P36a/H30=7Ad@<0b<S8
0`3MgMd20?ooo`<0`/;20`2QXJ4307YjNP80=CDe0`1<C4`308R8R0<0NGUi0P1RHV8305EEE@<0;Rh^
0`0N7Qh201XJ6P<01PH60`0c<c<206ATI0<0Q8B40`1_Kfl302HV9P804A4A0`19BDT3065QH@<0=3@d
0P0A4A43000000<00`<33P00000200P8214000000P0;2`/80?ooo`001P3oool6000000<010@40P02
0P86000000<04A4A0P030`<D000000801`L72@00000200820PH000000P010@43000000<02@T90`01
0@48000000<0KFe]0P2b/[830:>SX`<0KFe]0`0o?cl205EEE@<0LG5a0`1JFUX304E5A@80@T920`1G
EeL302l_;`<0;Bd]0P0e=CD30451@@<0EeMG0`2SXj<20<S8b0<0cLg=0`3QhN420=SHf0<0h>3P0`3J
f]X30=gMg@80emOG0`3^k^h30??cl`<0g]kN0P36a/H30=7Ad@<0b<S80`3MgMd20?ooo`<0`/;20`2Q
XJ4307YjNP80=CDe0`1<C4`308R8R0<0NGUi0P1RHV8305EEE@<0;Rh^0`0N7Qh201XJ6P<01PH60`0c
<c<206ATI0<0Q8B40`1_Kfl302HV9P804A4A0`19BDT3065QH@<0=3@d0P0A4A43000000<00`<33P00
000200P8214000000P0;2`/80?ooo`001P3oool6000000<01PH61@00000300@410<02@T90P030`<D
0000008010@42@00000200X:2P/000000`010@4300820PP000000`1SHf<20;jn_P<0[Jf]0`2DU9@3
05aLG080Rh^;0`3;bl/30;fm_@<0]kNg0P2a/K430:ZZZP<0NGUi0`1UIFD206UYJ@<0L71`0`1bLW83
08n?S`80WIfM0`2b/[830<30`080dM7A0`3IfMT30=GEe@<0cLg=0P3Fe]H30=_Kf`<0jn_[0`3>c/h2
0<o?c`<0f][J0`2i^KT30<G5a@80d];B0`2^[Zh3096AT@<0Kfm_0P18B4P304];B`<0NGUi0`21PH42
06UYJ@<0HV9R0`0j>SX301@D50804Q8B0`00000302h^;P80I6AT0`1cLg<305mOG`<0=cLg0P0T92@3
04i>CP<0GEeM0`0_;bl2018B4PT000000P010@4300820P<000000`020P8200<30`<000000`020P83
000000800P821P00000200h>3PP0oooo00060?ooo`H000000`061PH5000000<010@40`092@T200<3
0a@000000P0410@9000000802PX:2`00000300410@<00P822000000306=SH`80_[jn0`2][Jd309BD
U0<0G5aL0P2;Rh/30<_;b`<0_Kfm0`2g]kL20;6a/@<0ZZZZ0`1iNGT306EUI@80JFUY0`1`L703079b
LP<0Shn?0P2MWId30;:b/P<0`<300P3AdM430=WIf@<0eMGE0`3=cLd20=KFeP<0fm_K0`3[jn/30<k>
cP80clo?0`3Jf]X30;Vi^@<0aLG50P3Bd]830:j^[P<0TI6A0`1_Kfl204Q8B0<0Bd];0`1iNGT30861
P@80JFUY0`1RHV8303Xj>P<051@D0P0B4Q83000000<0;Rh^0P1TI6@307=cL`<0GemO0`0g=cL202@T
90<0CTi>0`1MGEd302l_;`804Q8B2@00000200410@<00P820`00000300820P800`<30`0000030082
0P<000000P020P86000000803Ph>203oool000H0oooo1P00000300H61PD000000`0410@300T92@80
0`<35000000200@410T000000P0:2PX;000000<00@410`020P88000000<0Hf=S0P2n_[h30:f][@<0
U9BD0`1LG5`208^;R`<0bl_;0`2m_Kd30;Ng]`80/K6a0`2ZZZX307UiN@<0IFEU0P1YJFT3071`L0<0
LW9b0`2?Shl209fMW@<0/[:b0`30`<020=7Ad@<0fMWI0`3EeMD30<g=c@80e]KF0`3Kfm/30>_[j`<0
c/k>0P3?cll30=[JfP<0^KVi0`35aLD20=;BdP<0[Zj^0`2ATI4306m_K`80B4Q80`1;Bd/307UiN@<0
PH610P1YJFT3069RHP<0>SXj0`0D51@2018B4P<000000`0^;Rh206ATI0<0Lg=c0`1OGel303Lg=`80
92@T0`1>CTh305eMG@<0;bl_0P0B4Q89000000800@410`020P83000000<00P820P030`<3000000<0
0P820`00000200820PH000000P0>3Ph80?ooo`001P3oool90000008010@40`00000300410@<00P82
7P00000300820PD000000`010@4500H61P<00@410`071`L200<30`<01PH60`000003071`L080a/K6
0`2h^;P30;bl_0<0YZJV0P2f][H30<k>cP<0b<S80`3?cll20=[JfP<0iNGU0`2n_[h30:n_[`80V9RH
0`1oOgl307IfMP<0O7al0P2BTY8309RHV0<0`/;20P3Ng]h30=gMg@<0e=CD0`2o_kl20<c<c0<0bLW9
0`3AdM430;Rh^080]kNg0`32`/8309jNWP<0Z:RX0P2c/k<308n?S`<0Jf][0`1=CDd203De=@<0BDU9
0`22PX8309BDU080QHF50`1oOgl304i>CP<02PX:0P020P83000000<0<c<c0P1[Jf/3075aL@<0Hf=S
0`11@D4202XZ:P<0E5AD0`1OGel303@d=0804A4A2@00000200D51@<01`L70`00000300820P804a<C
0`020P8300<30`<000000P051@D6000000801PH6203oool000H0oooo2@00000200@410<000000`01
0@4300820Qh000000`020P85000000<00@411@061PH300410@<01`L70P030`<300H61P<000000`1`
L7020<K6aP<0^;Rh0`2l_;`30:JVYP80][Jf0`3>c/h30<S8b0<0clo?0P3Jf]X30>GUi@<0_[jn0`2_
[jl209RHV0<0Ogmo0`1fMWH307alO080TY:B0`2HV9P30<;2`P80g]kN0`3MgMd30=CDe0<0_kno0P3<
c<`30<W9b@<0dM7A0`2h^;P20;Ng]`<0`/;20`2NWYh30:RXZ080/k>c0`2?Shl306][J`<0CDe=0P0e
=CD304U9B@<0PX:20`2DU9@208F5Q@<0Ogmo0`1>CTh300X:2P800P820`00000303<c<`80Jf][0`1a
LG4306=SH`<0@D510P0Z:RX305ADE0<0GemO0`0d=3@2014A4@T000000P051@D300L71`<000000`02
0P8201<C4`<00P820`030`<3000000801@D51P00000200H61PP0oooo00060?ooo`T000000P0410@3
000000<00@410`020P8N000000<00P821@00000300410@D01PH60`010@4300L71`800`<30`061PH3
000000<0L71`0P36a/H30;Rh^0<0_;bl0`2VYZH20;Jf]P<0c/k>0`38b<P30<o?c`80f][J0`3UiND3
0;jn_P<0[jn_0P2HV9P307moO`<0MWIf0`1lO7`209:BTP<0V9RH0`32`/820=kNgP<0gMgM0`3De=@3
0;no_`80c<c<0`39bLT30=7Ad@<0^;Rh0P2g]kL30<;2`P<0WYjN0`2XZ:P20;>c/`<0Shn?0`1[Jf/3
04e=C@80=CDe0`19BDT308:2PP<0U9BD0P25QHD307moO`<0CTi>0`0:2PX200820P<000000`0c<c<2
06][J`<0LG5a0`1SHf<30451@@80:RXZ0`1DE5@305mOG`<0=3@d0P0A4A49000000801@D50`071`L3
000000<00P820P0C4a<300820P<00`<30`00000200D51@H000000P061PH80?ooo`001P3oool90000
00804a<C1P00000300<30`D000000`0410@3000000802@T90`00000300820P/000000`020P850000
00<01@D50P0=3@d600X:2PD02@T90`071`L3000000<0L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;
R`<0HF5Q0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`
/0<0QXJ60`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^
[P<0VIVI0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`8000000`0N7Qh3079bLP<0Shn?0P2<S8`308^;
R`<0IFEU0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJ
FP<0=CDe0P0>3Ph9000000800@410`0:2PX300@410<000000P0^;Rh300D51@<000000`030`<50000
00<020P80P0000080?ooo`001P3oool9000000804a<C1P00000300<30`D000000`0410@300000080
2@T90`00000300820P/000000`020P85000000<01@D50P0=3@d600X:2PD02@T90`071`L3000000<0
L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;R`<0HF5Q0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0
c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`/0<0QXJ60`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80
VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^[P<0VIVI0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`80
00000`0N7Qh3079bLP<0Shn?0P2<S8`308^;R`<0IFEU0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0
TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJFP<0=CDe0P0>3Ph9000000800@410`0:2PX300@410<0
00000P0^;Rh300D51@<000000`030`<5000000<020P80P0000080?ooo`001P3oool9000000804a<C
1P00000300<30`D000000`0410@3000000802@T90`00000300820P/000000`020P85000000<01@D5
0P0=3@d600X:2PD02@T90`071`L3000000<0L71`0P36a/H30;>c/`<0];Bd0`2^[Zh208^;R`<0HF5Q
0`1_Kfl3079bLP80SXj>0`3=cLd30;Jf]P<0c<c<0P2d];@309bLW0<0SHf=0`24Q8@20;2`/0<0QXJ6
0`2g]kL20<C4a0<0/[:b0`2SXj<309:BTP80VIVI0`2WYjL309FEU@<0ZZZZ0P2UYJD30:j^[P<0VIVI
0`2?Shl208R8R0<0CTi>0`0h>3P301lO7`8000000`0N7Qh3079bLP<0Shn?0P2<S8`308^;R`<0IFEU
0`0I6AT200h>3P<04Q8B0`1:BTX208B4Q0<0TI6A0`1]KFd303Ti>@80>SXj0`1QHF4305YJFP<0=CDe
0P0>3Ph9000000800@410`0:2PX300@410<000000P0^;Rh300D51@<000000`030`<5000000<020P8
0P0000080?ooo`001P3oool300H61P<000000`051@D5000000<01@D50`010@45000000<00`<36@00
000200`<30h000000`010@48000000<09bLW0P36a/H30<g=c@<0ZJVY0`0l?3`2075aL@<0_[jn0`3N
g]h30=;BdP80^;Rh0`33`l<30:^[Z`<0alO70P3Ogml30?[jnP<0l?3`0`36a/H20;2`/0<0Zj^[0`2B
TY82092@T0<0OGem0`1iNGT305eMG@80C4a<0`1JFUX304i>CP<0ATI60P1TI6@306IVIP<0EeMG1@15
ADD304U9B@<0Hf=S0`1ZJVX205EEE@<0:BTY0`1OGel308F5Q@80LW9b0`1oOgl307=cL`<0<S8b0P0g
=cL3014A4@<0Cdm?1@2<S8`305eMG@<0@D510P1LG5`3075aL@<0ADE50`0J6QX200L71`<000000`02
0P8>000000D01PH62000000600410@801PH6203oool000H0oooo0`061PH3000000<01@D51@000003
00D51@<00@411@00000300<30aT000000P0<30`>000000<00@412000000302LW9`80a/K60`3=cLd3
0:VYZ@<0?3`l0P1aLG430;jn_P<0g]kN0`3Bd]820;Rh^0<0`l?30`2[Zj/30<O7a`80gmoO0`3jn_X3
0?3`l0<0a/K60P2`/;030:^[Z`<0TY:B0P2@T90307emO@<0NGUi0`1MGEd204a<C0<0FUYJ0`1>CTh3
04I6AP80I6AT0`1VIVH305MGE`D0ADE50`19BDT306=SH`<0JVYZ0P1EEED302TY:@<0GemO0`25QHD2
079bLP<0Ogmo0`1cLg<3038b<P80=cLg0`0A4A4304m?C`D0S8b<0`1MGEd30451@@80G5aL0`1aLG43
04E5A@<06QXJ0P071`L3000000<00P823P00000500H61PP000001P010@4200H61PP0oooo00060?oo
o`<01PH60`0410@8000000<01PH6;000000200410@H000000`010@4200L71`<00@410`00000300l?
3`80QXJ60`31`L430=CDe0<0^k^k0P3Ng]h30>SXj0H0l_;b0P3_knl30?ooo`<0lO7a0`3/k>`20=cL
g0<0l?3`0`3^k^h30<S8b080`<300`2d];@30:VYZ@80Y:BT0`2QXJ430:NWY`<0W9bL0P2=SHd307al
O0<0J6QX0`1CDe<2059BDP<0<C4a0`0X:2P3010@408000000`0V9RH30492@P<0Bd];0P16ATH3038b
<P<0EUIF0`1cLg<207]kN`<0Ph>30`1dM7@302l_;`D0:2PX0`1`L702096AT@<0Q8B40`17AdL303Ph
>080AdM70`0k>c/3028R8P<02`/;2000000300<30`8000000`010@46000000800@411P030`<50000
00<00`<31@0000080?ooo`001P3oool300H61P<010@42000000300H61R`000000P010@46000000<0
0@410P071`L300410@<000000`0?3`l208J6QP<0`L710`3De=@30;^k^`80g]kN0`3Xj>P60?;blP80
kno_0`3oool30?7al@<0k>c/0P3Lg=`30?3`l0<0k^k^0`38b<P20<30`0<0];Bd0`2YZJT20:BTY0<0
XJ6Q0`2WYjL309bLW080SHf=0`1lO7`306QXJ0<0De=C0P1BDU83034a<@<0:2PX0`0@4102000000<0
9RHV0`12@T8304];B`80ATI60`0b<S8305IFEP<0Lg=c0P1kNg/308>3P`<0M7Ad0`0_;bl502PX:0<0
L71`0P2ATI4308B4Q0<0AdM70`0h>3P204M7A`<0>c/k0`0R8R8300/;2`P000000`030`<2000000<0
0@411P00000200410@H00`<31@00000300<30`D00000203oool000H0oooo0`061PH300@410P00000
0`061PH/000000800@411P00000300410@801`L70`010@43000000<03`l?0P26QXH30<71`@<0e=CD
0`2k^k/20=kNgP<0j>SX1P3bl_820>o_k`<0oooo0`3alO430>c/k080g=cL0`3`l?030>k^kP<0b<S8
0P30`<030;Bd]0<0ZJVY0P2TY:@30:6QX@<0YjNW0`2LW9`208f=S@<0O7al0`1XJ6P305=CD`80DU9B
0`0a<C4302PX:0<0410@0P00000302HV9P<0@T920`1;Bd/204I6AP<0<S8b0`1FEUH307=cL`80Ng]k
0`23Ph<307AdM0<0;bl_1@0X:2P3071`L080TI6A0`24Q8@304M7A`<0>3Ph0P17AdL303/k>`<08R8R
0`0;2`/8000000<00`<30P00000300410@H000000P010@4600<30`D000000`030`<5000000P0oooo
00060?oooa@000000P051@D300@410H000000P0820P3000000<02PX:0`00000500410@/000000`01
0@4200820P<00@410`0B4Q83000000802PX:1P00000300820P80GEeM0`3IfMT30<c<c0<0a/K60P3U
iND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RXZ080RXZ:0`2o_kl30;>c/`<0/K6a0P2^
[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng]`<0Zj^[0`1ZJVX307=cL`80QHF50`2H
V9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU9@<08b<S0`1>CTh3079bLP80OGem0`1o
Ogl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:bP<0DE5A0`11@D4203hn?P<09BDU0`0K
6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:2P<000000P051@D;000000<030`<0`04
10@2000000P0oooo00060?oooa@000000P051@D300@410H000000P0820P3000000<02PX:0`000005
00410@/000000`010@4200820P<00@410`0B4Q83000000802PX:1P00000300820P80GEeM0`3IfMT3
0<c<c0<0a/K60P3UiND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RXZ080RXZ:0`2o_kl3
0;>c/`<0/K6a0P2^[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng]`<0Zj^[0`1ZJVX3
07=cL`80QHF50`2HV9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU9@<08b<S0`1>CTh3
079bLP80OGem0`1oOgl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:bP<0DE5A0`11@D42
03hn?P<09BDU0`0K6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:2P<000000P051@D;
000000<030`<0`0410@2000000P0oooo00060?oooa@000000P051@D300@410H000000P0820P30000
00<02PX:0`00000500410@/000000`010@4200820P<00@410`0B4Q83000000802PX:1P0000030082
0P80GEeM0`3IfMT30<c<c0<0a/K60P3UiND30<C4a0<0dM7A0`2g]kL20<S8b0<0hN7Q0`33`l<30:RX
Z080RXZ:0`2o_kl30;>c/`<0/K6a0P2^[Zh308Z:RP<0HF5Q0P1@D50306i^KP<0Rh^;0`2_[jl20;Ng
]`<0Zj^[0`1ZJVX307=cL`80QHF50`2HV9P30:ZZZP<0YjNW0P1CDe<304A4A0<0?Cdm0`0l?3`202DU
9@<08b<S0`1>CTh3079bLP80OGem0`1oOgl306i^KP<0>c/k0P0Z:RX303Lg=`<0QhN70P2QXJ430<[:
bP<0DE5A0`11@D4203hn?P<09BDU0`0K6a/300d=3@8010@40`00000300410@<02PX:1@00000300X:
2P<000000P051@D;000000<030`<0`0410@2000000P0oooo00060?ooo`<01PH60`0410@300000080
0P820`00000300410@<000000P010@4300<30`H000000P0410@300820P<000000`061PH200820Ph0
00000`030`<500820P<03Ph>0`00000202HV9P<01PH60`0@410300/;2`80;Rh^0`2l_;`30<S8b0<0
fMWI0P3MgMd30=CDe0<0hN7Q0`3MgMd20>GUi@<0k^k^0`3alO430=SHf080Rh^;0`1bLW83065QH@<0
FUYJ0P1BDU83055AD@<0GEeM0P1]KFd30:2PX0<0W9bL0`2b/[820;Jf]P<0X:2P0`1oOgl304m?C`80
@d=30`1BDU83071`L0<0W9bL0P2h^;P30<C4a0<0SHf=0`1`L70505ADE0<0HF5Q0`1^KVh207moO`<0
RHV90`1]KFd30492@P80;Bd]0`1@D503096AT@80PH610`22PX8303lo?`<0<S8b0P0B4Q8300410@<0
30`<0`051@D200410@H000000`071`L200820P<000000`010@43000000800`<30`00000300410@/0
00000P010@480?ooo`001P3oool300H61P<010@40`00000200820P<000000`010@43000000800@41
0`030`<60000008010@40`020P83000000<01PH60P020P8>000000<00`<31@020P8300h>3P<00000
0P0V9RH300H61P<0410@0`0;2`/202h^;P<0_;bl0`38b<P30=WIf@80gMgM0`3De=@30>7Qh@<0gMgM
0P3UiND30>k^kP<0lO7a0`3Hf=P208^;R`<0LW9b0`1QHF4305YJFP80DU9B0`1ADE4305eMG@80KFe]
0`2PX:0309bLW0<0/[:b0P2f][H30:2PX0<0Ogmo0`1?Cdl204=3@`<0DU9B0`1`L70309bLW080^;Rh
0`34a<@308f=S@<0L71`1@1DE5@3065QH@<0KVi^0P1oOgl308V9R@<0KFe]0`12@T8202d];@<0D51@
0`2ATI420861P@<0PX:20`0o?cl3038b<P804Q8B0`010@4300`<30<01@D50P010@46000000<01`L7
0P020P83000000<00@410`00000200<30`<000000`010@4;000000800@41203oool000H0oooo0`07
1`L300<30`h000000P010@4;000000<00`<30`00000500@411<000001P020P83000000806QXJ0`04
10@301<C4`<01PH60P0C4a<307QhN0<0[Jf]0`3Bd]820=oOg`<0h>3P0`3Hf=P30=_Kf`80j^[Z0`3V
i^H30=_Kf`<0Ti>C0P0e=CD300X:2P<03`l?0`0C4a<201`L70<0>CTi0`1WIfL209fMW@<0d];B0`2m
_Kd30<[:bP80_[jn0`2/[:`30;jn_P<0Ti>C0P1TI6@3055AD@<0D51@0`1]KFd209jNWP<0^;Rh0`2C
Ti<3071`L080EeMG0`1TI6@3079bLP<0Ng]k0P2:RXX308j>SP<0K6a/0`1;Bd/203Hf=P<0HF5Q0`29
RHT2075aL@<0De=C0`0c<c<301/K6`801PH60`00000300P820<01PH60P030`<6000000<01@D51@02
0P8;000000<00@412`00000200L71`P0oooo00060?ooo`<01`L70`030`<>000000800@412`000003
00<30`<000001@0410@C000000H00P820`00000201XJ6P<010@40`0C4a<300H61P804a<C0`1hN7P3
0:f][@<0d];B0P3Ogml30>3Ph0<0f=SH0`3Kfm/20>[ZjP<0i^KV0`3Kfm/309>CT`80=CDe0`0:2PX3
00l?3`<04a<C0P0L71`303Ti>@<0IfMW0P2MWId30=;BdP<0_Kfm0`3:b/X20;jn_P<0[:b/0`2n_[h3
09>CT`80I6AT0`1ADE43051@D0<0KFe]0P2NWYh30;Rh^0<0Ti>C0`1`L70205MGE`<0I6AT0`1bLW83
07]kN`80RXZ:0`2>SXh306a/K0<0Bd];0P0f=SH3065QH@<0RHV90P1aLG4305=CD`<0<c<c0`0K6a/2
00H61P<000000`0820P300H61P800`<31P00000300D51@D00P822`00000300410@/000000P071`L8
0?ooo`001P3oool300L71`<00`<33P00000200410@/000000`030`<3000000D010@44`0000060082
0P<000000P0J6QX300@410<04a<C0`061PH201<C4`<0N7Qh0`2][Jd30=;BdP80gmoO0`3Ph>030=SH
f0<0fm_K0P3Zj^X30>KViP<0fm_K0`2CTi<203De=@<02PX:0`0?3`l301<C4`8071`L0`0i>CT306MW
I`80WIfM0`3Bd]830;fm_@<0b/[:0P2n_[h30:b/[0<0_[jn0`2CTi<206ATI0<0DE5A0`1@D50306e]
K@80WYjN0`2h^;P309>CT`<0L71`0P1GEeL306ATI0<0LW9b0`1kNg/208Z:RP<0SXj>0`1/K6`304];
B`80=SHf0`1QHF4308V9R@80LG5a0`1CDe<303<c<`<06a/K0P061PH3000000<020P80`061PH200<3
0`H000000`051@D500820P/000000`010@4;000000801`L7203oool000H0oooo8@00000300410@<0
0`<31@00000300410@h000000P010@4300820P<000000`051@D200L71`<00P820`051@D300000080
3@d=0`0Q8B4308V9R@<0dM7A0P3]kNd30=KFeP<0a<C40`3=cLd20>SXj0<0i>CT0`3AdM4307EeM@80
;Bd]0`0F5QH301lO7`<020P80P0I6AT3030`<0<0HF5Q0P2e]KD30=CDe0<0_;bl0`30`<020;Jf]P<0
VIVI1P2j^[X20:2PX0<0QHF50`1]KFd305QHF080@T920`1KFe/306ATI0<0BTY:0P1IFET306][J`<0
NWYj0`2>SXh208n?S`<0P8200`1YJFT304A4A080=SHf0`1XJ6P307MgM`80GUiN0`0T92@3018B4P<0
2`/;0P0?3`l6000000<010@40P010@46000000<01@D50P010@4300H61P<000000`020P8200D51A40
00000P071`L80?ooo`001P3ooolQ000000<00@410`030`<5000000<00@413P00000200410@<00P82
0`00000300D51@801`L70`020P8300D51@<000000P0=3@d3024Q8@<0RHV90`3AdM420>g]k@<0e]KF
0`34a<@30<g=c@80j>SX0`3Ti>@30=7Ad@<0MGEe0P0];Bd301HF5P<07alO0`0820P201TI6@<0<30`
0`1QHF420;Fe]@<0e=CD0`2l_;`30<30`080][Jf0`2IVIT60;Zj^P80X:2P0`25QHD306e]K@<0F5QH
0P12@T8305]KF`<0I6AT0`1:BTX205UIF@<0Jf][0`1jNWX308j>SP80Shn?0`20P80306UYJ@<0A4A4
0P0f=SH306QXJ0<0MgMg0P1NGUh302@T90<04Q8B0`0;2`/200l?3`H000000`0410@200410@H00000
0`051@D200410@<01PH60`00000300820P801@D54@00000200L71`P0oooo00060?ooob4000000`01
0@4300<30`D000000`010@4>000000800@410`020P83000000<01@D50P071`L300820P<01@D50`00
000200d=3@<08B4Q0`29RHT30=7Ad@80kNg]0`3Fe]H30<C4a0<0cLg=0P3Xj>P30>CTi0<0dM7A0`1e
MGD202d];@<05QHF0`0O7al300P820806ATI0`0`<303065QH@80]KFe0`3De=@30;bl_0<0`<300P2f
][H309VIV@H0^[Zj0P2PX:0308F5Q@<0KFe]0`1HF5P20492@P<0Fe]K0`1TI6@304Y:BP80FEUI0`1[
Jf/307YjNP<0SXj>0P2?Shl30820P0<0JFUY0`14A4@203Hf=P<0J6QX0`1gMgL205iNGP<092@T0`0B
4Q8300/;2`803`l?1P00000300@410800@411P00000300D51@800@410`061PH3000000<00P820P05
1@DA000000801`L7203oool000H0oooo2@00000200820P<000000`010@4>000000D00P820`010@43
00D51@8000000`0410@;000000<00@412000000300820P801@D53P00000305UIF@<0/k>c0P3Lg=`3
0>SXj0<0eMGE0`3Hf=P20=kNgP<0clo?0`3;bl/309JFUP80Ng]k0`1lO7`306m_K`<0=CDe0P0`<303
03Hf=P<0CTi>0P2[Zj/30<_;b`<0YZJV0`2f][H20;jn_PH0T92@0`2CTi<20:2PX0<0Z:RX0`2YZJT3
09RHV080H61P0`1]KFd306IVIP<0@D510P1bLW8308V9R@<0Ph>30`2<S8`208>3P`<0J6QX0`1EEED3
03hn?P80>3Ph0`1gMgL307YjNP80@T922@00000200820Q4000000`030`<8000000<01@D50P030`<3
00H61P<000000`051@D2000000<00@410`030`<201DE5@P0oooo00060?ooo`T000000P020P830000
00<00@413P00000500820P<00@410`051@D2000000<010@42`00000300410@P000000`020P8200D5
1@h000000`1IFET30;>c/`80g=cL0`3Xj>P30=GEe@<0f=SH0P3Ng]h30<o?c`<0bl_;0`2FUYH207]k
N`<0O7al0`1_Kfl303De=@80<30`0`0f=SH304i>CP80Zj^[0`3;bl/30:JVYP<0][Jf0P2n_[h6092@
T0<0Ti>C0P2PX:030:RXZ0<0ZJVY0`2HV9P2061PH0<0KFe]0`1VIVH30451@@80LW9b0`29RHT308>3
P`<0S8b<0P23Ph<306QXJ0<0EEEE0`0n?Sh203Ph>0<0MgMg0`1jNWX20492@PT000000P020P8A0000
00<00`<32000000300D51@800`<30`061PH3000000<01@D50P00000300410@<00`<30P0E5AD80?oo
o`001P3oool9000000800P820`00000300410@h000001@020P8300410@<01@D50P00000300@410/0
00000`010@48000000<00P820P051@D>000000<0FEUI0`2c/k<20=cLg0<0j>SX0`3EeMD30=SHf080
g]kN0`3?cll30<_;b`<0UYJF0P1kNg/307alO0<0Kfm_0`0e=CD2030`<0<0=SHf0`1>CTh20:^[Z`<0
bl_;0`2VYZH30;Jf]P80_[jn1P2@T90309>CT`80X:2P0`2XZ:P30:VYZ@<0V9RH0P1PH60306e]K@<0
IVIV0`11@D42079bLP<0RHV90`23Ph<308b<S080Ph>30`1XJ6P305EEE@<0?Shn0P0h>3P307MgM`<0
NWYj0P12@T89000000800P824@00000300<30`P000000`051@D200<30`<01PH60`00000300D51@80
00000`010@4300<30`805ADE203oool000H0oooo0`030`<6000000801`L70`00000300820PP00000
0`051@D300820P8010@42@00000200410A<000000`030`<>000000<00P820P00000300D51@H06QXJ
0P11@D430>;RhP<0k>c/0`3WinL20>CTi0<0bl_;0`2b/[830:b/[080bl_;0`3Shn<30<C4a0<0SHf=
0P1MGEd305UIF@<0<c<c0P2;Rh/30<_;b`<0XZ:R0`2^[Zh50<G5a@<0`/;20`2d];@20;2`/0<0_;bl
0`2^[Zh30;jn_P80_;bl0`2SXj<306MWI`<0>3Ph0P1GEeL307inOP<0U9BD0`2EUID208f=S@<0OWin
0`1EEED30492@P80@D510`1MGEd304];B`807QhN4@00000300410@800`<30`00000300820PP00000
0`010@4300D51@8000000`030`<6000000800`<31P010@4203@d=0P0oooo00060?ooo`<00`<31P00
000200L71`<000000`020P88000000<01@D50`020P8200@410T000000P010@4C000000<00`<33P00
000300820P8000000`051@D601XJ6P80@D510`3Rh^830>c/k0<0inOW0P3Ti>@30<_;b`<0/[:b0`2/
[:`20<_;b`<0hn?S0`34a<@308f=S@80GEeM0`1IFET303<c<`80Rh^;0`3;bl/30::RXP<0[Zj^1@35
aLD30<;2`P<0];Bd0P2`/;030;bl_0<0[Zj^0`2n_[h20;bl_0<0Xj>S0`1WIfL303Ph>080EeMG0`1n
OWh309BDU0<0UIFE0P2=SHd307inOP<0EEEE0`12@T820451@@<0GEeM0`1;Bd/201hN7Q4000000`01
0@4200<30`<000000`020P88000000<00@410`051@D2000000<00`<31P00000200<30`H00@410P0d
=3@80?ooo`001P3oool9000000800P822@00000200820P<000000`092@T3000000800P820`000003
00D51@<000000P030`<300410@H000000P010@48000000<051@D4`00000300T92@<00`<30`000002
00l?3`<0OGem0`2ZZZX30:n_[`80dm?C0`3AdM430;Vi^@<0XZ:R0P30`<030>OWi`<0jNWY0`38b<P2
08N7Q`<0O7al0`0^;Rh2075aL@<0^k^k0`2c/k<30:2PX080W9bL0`2[Zj/30:VYZ@<0/k>c0P2/[:`3
0;Jf]P<0XZ:R0`2IVIT207moO`<0G5aL0`13@d<303`l?080FUYJ0`1aLG4308n?S`<0W9bL0P2<S8`3
07alO0<0JVYZ0`11@D4204A4A0<0Bd];0`0Q8B4;000000801PH63P00000300H61P<00@411@000003
00D51A0000000`030`<300@410806ATI203oool000H0oooo2@00000200820PT000000P020P830000
00<02@T90`00000200820P<000000`051@D3000000800`<30`010@46000000800@412000000301@D
51<000000`092@T300<30`<000000P0?3`l307emO@<0ZZZZ0`2_[jl20=?Cd`<0dM7A0`2i^KT30::R
XP80`<300`3WinL30>WYj@<0b<S80P27QhL307alO0<0;Rh^0P1aLG430;^k^`<0/k>c0`2PX:0209bL
W0<0Zj^[0`2YZJT30;>c/`80[:b/0`2f][H30::RXP<0VIVI0P1oOgl305aLG0<0@d=30`0l?3`205YJ
FP<0LG5a0`2?Shl309bLW080S8b<0`1lO7`306YZJP<0@D510P14A4@304];B`<08B4Q2`00000200H6
1Ph000000`061PH300410@D000000`051@D@000000<00`<30`0410@201TI6@P0oooo00060?ooo`T0
00000P020P89000000800P820`00000300T92@<000000P020P83000000<01@D50`00000200<30`<0
0@411P00000200410@P000000`0D51@C000000<02@T90`030`<3000000803`l?0`1mOGd30:ZZZP<0
[jn_0P3Cdm<30=7Ad@<0^KVi0`2RXZ820<30`0<0inOW0`3YjNT30<S8b080QhN70`1lO7`302h^;P80
LG5a0`2k^k/30;>c/`<0X:2P0P2LW9`30:^[Z`<0ZJVY0`2c/k<20:b/[0<0][Jf0`2RXZ8309VIV@80
Ogmo0`1LG5`304=3@`<0?3`l0P1JFUX3075aL@<0Shn?0`2LW9`208b<S0<0O7al0`1ZJVX30451@@80
A4A40`1;Bd/3024Q8@/000000P061PH>000000<01PH60`010@45000000<01@D54000000300<30`<0
10@40P0I6AT80?ooo`001P3oool3000000<01@D50`010@4;000000801@D50`00000300H61P<00@41
1@00000300@410<000000P010@49000000802@T90`00000500820P<09BDU1P00000200/;2`<010@4
2000000300h>3P<04A4A0`030`<2000000<06ATI0`1TI6@308:2PP80aLG50`3;bl/30;Zj^P<0Vi^K
0P2XZ:P30<g=c@<0dm?C0`2f][H207alO0<0NGUi0`0/;2`2069RHP<0[jn_0`3EeMD30<30`080aLG5
0`3<c<`30;Jf]P<0/[:b0P2QXJ4309BDU0<0KFe]0`1FEUH502h^;P<0=CDe0`1CDe<207AdM0<0MGEe
0`1nOWh308^;R`80Q8B40`1`L70305mOG`<0:BTY0P0Z:RX302`/;0<020P82000000300/;2`801`L7
0`020P8;000000<01@D50`00000200D51@<00P820`0=3@d5000000<00P82400000080?ooo`001P3o
ool3000000<01@D50`010@4;000000801@D50`00000300H61P<00@411@00000300@410<000000P01
0@49000000802@T90`00000500820P<09BDU1P00000200/;2`<010@42000000300h>3P<04A4A0`03
0`<2000000<06ATI0`1TI6@308:2PP80aLG50`3;bl/30;Zj^P<0Vi^K0P2XZ:P30<g=c@<0dm?C0`2f
][H207alO0<0NGUi0`0/;2`2069RHP<0[jn_0`3EeMD30<30`080aLG50`3<c<`30;Jf]P<0/[:b0P2Q
XJ4309BDU0<0KFe]0`1FEUH502h^;P<0=CDe0`1CDe<207AdM0<0MGEe0`1nOWh308^;R`80Q8B40`1`
L70305mOG`<0:BTY0P0Z:RX302`/;0<020P82000000300/;2`801`L70`020P8;000000<01@D50`00
000200D51@<00P820`0=3@d5000000<00P82400000080?ooo`001P3oool3000000<01@D50`010@4;
000000801@D50`00000300H61P<00@411@00000300@410<000000P010@49000000802@T90`000005
00820P<09BDU1P00000200/;2`<010@42000000300h>3P<04A4A0`030`<2000000<06ATI0`1TI6@3
08:2PP80aLG50`3;bl/30;Zj^P<0Vi^K0P2XZ:P30<g=c@<0dm?C0`2f][H207alO0<0NGUi0`0/;2`2
069RHP<0[jn_0`3EeMD30<30`080aLG50`3<c<`30;Jf]P<0/[:b0P2QXJ4309BDU0<0KFe]0`1FEUH5
02h^;P<0=CDe0`1CDe<207AdM0<0MGEe0`1nOWh308^;R`80Q8B40`1`L70305mOG`<0:BTY0P0Z:RX3
02`/;0<020P82000000300/;2`801`L70`020P8;000000<01@D50`00000200D51@<00P820`0=3@d5
000000<00P82400000080?ooo`001P3oool3000000<030`<0`061PH200<30`T000000P030`<30000
00<00`<31@00000300410@<01`L70`0410@;0000008010@40`00000300410@800`<30`0P82060000
00804A4A0`0410@300l?3`<03Ph>0P00000300410@<02PX:0`0=3@d5000000<04a<C0`0V9RH2061P
H0<0NGUi0`1lO7`307UiN@80MGEe0`20P80309>CT`<0UYJF0P21PH4306][J`<0@d=30P1FEUH308Z:
RP<0XZ:R0`2NWYh20:>SX`<0_Kfm0`2o_kl30;Zj^P80MWIf0`0o?cl301lO7`<0410@0P0b<S8303Ti
>@<0Cdm?0`1TI6@206UYJ@<0OWin0`2BTY8307inOP80QHF50`1/K6`304U9B@<0:2PX0P0P820302d]
;@<02`/;3@00000300820P/000000`071`L3000000800`<30`0820P300d=3@D00@412@0000050041
0@D00000203oool000H0oooo0`00000300`<30<01PH60P030`<9000000800`<30`00000300<30`D0
00000`010@4300L71`<010@42`00000200@410<000000`010@4200<30`<0820P1P000002014A4@<0
10@40`0?3`l300h>3P8000000`010@4300X:2P<03@d=1@00000301<C4`<09RHV0P1PH60307UiN@<0
O7al0`1iNGT207EeM@<0P8200`2CTi<309JFUP80PH610`1[Jf/304=3@`80EUIF0`2:RXX30::RXP<0
WYjN0P2SXj<30;fm_@<0_kno0`2j^[X207IfMP<0?clo0`0O7al3010@4080<S8b0`0i>CT304m?C`<0
I6AT0P1YJFT307inOP<0TY:B0`1nOWh208F5Q@<0K6a/0`19BDT302PX:080820P0`0];Bd300/;2`d0
00000`020P8;000000<01`L70`00000200<30`<020P80`0=3@d500410@T000001@010@45000000P0
oooo00060?ooo`<000000`0:2PX300820P801PH64@00000300D51@8000000`020P8300410@<02@T9
4000000300<30`800@410`0@410300T92@<000000P0E5AD300410@<04Q8B0`0:2PX2000000H010@4
0`0=3@d5000000<00`<30`0820P201LG5`<0:2PX0`10@40306i^KP80O7al0`29RHT308^;R`<0R8R8
0P1hN7P305eMG@<0@D510P0l?3`305YJFP<0JFUY0`1jNWX208V9R@<0SXj>0`1PH6030410@08071`L
0`030`<300h>3P<061PH0P13@d<304i>CP<0De=C0`1SHf<206m_K`<0PX:20`1oOgl305IFEP80Fe]K
0`11@D4301hN7P<051@D0P0@4103020P80<06ATI1@051@DF000000<01`L72000000300T92@<00000
0P010@4300@410h000000P010@480?ooo`001P3oool3000000<02PX:0`020P8200H61Q4000000`05
1@D2000000<00P820`010@4300T92A0000000`030`<200410@<0410@0`092@T3000000805ADE0`01
0@43018B4P<02PX:0P00000600@410<03@d=1@00000300<30`<020P80P0G5aL302PX:0<0@4100`1^
KVh207alO0<0RHV90`2;Rh/308R8R080N7Qh0`1MGEd30451@@80?3`l0`1JFUX306UYJ@<0NWYj0P29
RHT308j>SP<0H61P0`10@40201`L70<00`<30`0>3Ph301PH6080@d=30`1>CTh305=CD`<0Hf=S0P1_
Kfl308:2PP<0Ogmo0`1FEUH205]KF`<0@D510`0N7Qh301@D5080410@0`0P820301TI6@D01@D55P00
000300L71`P000000`092@T3000000800@410`0410@>000000800@41203oool000H0oooo0`000003
00X:2P<00P820P061PHA000000<01@D50P00000300820P<00@410`092@T@000000<00`<30P010@43
010@40<02@T90`00000201DE5@<00@410`0B4Q8300X:2P8000001P0410@300d=3@D000000`030`<3
00P820805aLG0`0X:2P30410@0<0KVi^0P1lO7`308V9R@<0Rh^;0`28R8P207QhN0<0GEeM0`11@D42
03`l?0<0FUYJ0`1YJFT307YjNP80RHV90`2>SXh3061PH0<0@4100P0L71`300<30`<03Ph>0`0H61P2
04=3@`<0CTi>0`1CDe<306=SH`80Kfm_0`22PX8307moO`<0EUIF0P1KFe/30451@@<07QhN0`0D51@2
010@40<0820P0`0I6AT500D51AH000000`071`L8000000<02@T90`00000200410@<010@43P000002
00410@P0oooo00060?ooo`H000000`020P8200H61Ph000000`010@4300820PD000000`051@D50000
00<00P823P00000200410@<01`L70`0410@3000000802@T94@00000300820PD000000`0820P300H6
1P802PX:0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0KFe]0`1QHF4205EEE@<0@D510`0e=CD20492
@P<0Cdm?0`1@D50304i>CP80ADE50`16ATH301XJ6P<02`/;0P092@T301<C4`<09bLW0`0Z:RX20492
@P<0?Cdm0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C
4`<06QXJ0`0D51@200T92@<00P820`051@D3000000800@410`071`L;000000<02`/;2`0000030041
0@801@D50`010@43000000<00`<31@00000500410@P0oooo00060?ooo`H000000`020P8200H61Ph0
00000`010@4300820PD000000`051@D5000000<00P823P00000200410@<01`L70`0410@300000080
2@T94@00000300820PD000000`0820P300H61P802PX:0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0
KFe]0`1QHF4205EEE@<0@D510`0e=CD20492@P<0Cdm?0`1@D50304i>CP80ADE50`16ATH301XJ6P<0
2`/;0P092@T301<C4`<09bLW0`0Z:RX20492@P<0?Cdm0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0
MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C4`<06QXJ0`0D51@200T92@<00P820`051@D300000080
0@410`071`L;000000<02`/;2`00000300410@801@D50`010@43000000<00`<31@00000500410@P0
oooo00060?ooo`H000000`020P8200H61Ph000000`010@4300820PD000000`051@D5000000<00P82
3P00000200410@<01`L70`0410@3000000802@T94@00000300820PD000000`0820P300H61P802PX:
0`0G5aL302/[:`<0E5AD0P1PH60306QXJ0<0KFe]0`1QHF4205EEE@<0@D510`0e=CD20492@P<0Cdm?
0`1@D50304i>CP80ADE50`16ATH301XJ6P<02`/;0P092@T301<C4`<09bLW0`0Z:RX20492@P<0?Cdm
0`1=CDd306MWI`80Ph>30`2=SHd309BDU0<0MgMg0P1ZJVX304Y:BP<0;Rh^0`0F5QH201<C4`<06QXJ
0`0D51@200T92@<00P820`051@D3000000800@410`071`L;000000<02`/;2`00000300410@801@D5
0`010@43000000<00`<31@00000500410@P0oooo00060?ooo`<00P820`00000300D51@80410@2`00
000300410@/000000`010@45000000<00P823P00000500410@H000000P061PHD000000801@D50`00
000600410@801@D50`0?3`l302/[:`<0I6AT0P1]KFd306m_K`<0JFUY0`1CDe<204i>CP<0:BTY0`0Q
8B4201lO7`H07QhN0`0F5QH200X:2P<03Ph>0`0?3`l301LG5`8061PH0`0K6a/302`/;0<0:b/[0P18
B4P304Y:BP<0H61P0`1hN7P208Z:RP<0MgMg0`22PX8307=cL`80J6QX0`1>CTh303<c<`<04Q8B0P03
0`<300P820<000000P010@43000000<020P80`0;2`/5014A4@/000000`092@T300410@D000001P02
0P8200P820H000000`020P82000000<00@411@0000080?ooo`001P3oool300820P<000000`051@D2
010@40/000000`010@4;000000<00@411@00000300820Ph000001@010@46000000801PH650000002
00D51@<000001P010@4200D51@<03`l?0`0[:b/306ATI080KFe]0`1_Kfl306UYJ@<0De=C0P1>CTh3
02TY:@<08B4Q0P0O7al601hN7P<05QHF0P0:2PX300h>3P<03`l?0`0G5aL201PH60<06a/K0`0/;2`3
02/[:`80B4Q80`1:BTX3061PH0<0N7Qh0P2:RXX307MgM`<0PX:20`1cLg<206QXJ0<0CTi>0`0c<c<3
018B4P800`<30`0820P3000000800@410`00000300P820<02`/;1@0A4A4;000000<02@T90`010@45
000000H00P820P0820P6000000<00P820P00000300410@D00000203oool000H0oooo0`020P830000
00<01@D50P0@410;000000<00@412`00000300410@D000000`020P8>000000D00@411P00000200H6
1Q@000000P051@D3000000H00@410P051@D300l?3`<0:b/[0`1TI6@206e]K@<0Kfm_0`1YJFT305=C
D`80CTi>0`0Y:BT3024Q8@807alO1P0N7Qh301HF5P802PX:0`0>3Ph300l?3`<05aLG0P0H61P301/K
6`<0;2`/0`0[:b/204Q8B0<0BTY:0`1PH60307QhN080RXZ:0`1gMgL308:2PP<0Lg=c0P1XJ6P304i>
CP<0<c<c0`0B4Q8200<30`<020P80`00000200410@<000000`0820P300/;2`D04A4A2`00000300T9
2@<00@411@00000600820P8020P81P00000300820P8000000`010@45000000P0oooo00060?ooo`<0
1PH60`00000300820P804a<C2`00000300820Q<000000`020P8;000000<00@411@030`<600000080
3@d=1P030`<300T92@8010@41P00000300820P801@D52`00000300h>3P<0;bl_0`1[Jf/206i^KP<0
G5aL0`1KFe/305MGE`80D51@0`0Z:RX302PX:0D07alO0`0F5QH300/;2`802@T90`0F5QH301/K6`<0
7AdM0P0H61P302HV9P<0?Cdm0`1=CDd208N7Q`<0Lg=c0`1aLG4307IfMP80O7al0`1jNWX308R8R0<0
KFe]0P1MGEd304A4A0<09bLW0`0>3Ph200@410<02`/;2000000300`<30<01`L70P020P83014A4@<0
1`L70`0410@5000000<01PH60`020P85000000<00@411@061PH90000008010@41P00000200410@P0
oooo00060?ooo`<01PH60`00000300820P804a<C2`00000300820Q<000000`020P8;000000<00@41
1@030`<6000000803@d=1P030`<300T92@8010@41P00000300820P801@D52`00000300h>3P<0;bl_
0`1[Jf/206i^KP<0G5aL0`1KFe/305MGE`80D51@0`0Z:RX302PX:0D07alO0`0F5QH300/;2`802@T9
0`0F5QH301/K6`<07AdM0P0H61P302HV9P<0?Cdm0`1=CDd208N7Q`<0Lg=c0`1aLG4307IfMP80O7al
0`1jNWX308R8R0<0KFe]0P1MGEd304A4A0<09bLW0`0>3Ph200@410<02`/;2000000300`<30<01`L7
0P020P83014A4@<01`L70`0410@5000000<01PH60`020P85000000<00@411@061PH90000008010@4
1P00000200410@P0oooo00060?ooo`<01`L70`010@4300D51@8071`L7000000300820P8000000`02
0P8;000000D00`<30`00000300820P<000000P092@T300410@<00P822000000300<30`<05ADE0P0N
7Qh300820P/000000`0L71`3071`L080Q8B40`27QhL307alO0<0MWIf0P22PX8304I6AP<0A4A40P0R
8R8301@D50H05ADE0P0G5aL301XJ6P<0:2PX0`0c<c<202/[:`<0:2PX0`0k>c/30492@P80JFUY0`1L
G5`306ATI0<0L71`0P1iNGT3075aL@<0Q8B40`1YJFT2069RHP<0@T920`0I6AT=000000<00@410`0C
4a<3010@40803@d=0`0D51@300`<30<020P80P010@43000000<01@D52000000300D51@<00`<30P0:
2PX;000000<01@D51@0000080?ooo`001P3oool300L71`<00@410`051@D201`L71`000000`020P82
000000<00P822`00000500<30`<000000`020P83000000802@T90`010@4300820PP000000`030`<3
01DE5@807QhN0`020P8;000000<071`L0`1`L70208B4Q0<0QhN70`1lO7`307IfMP80PX:20`16ATH3
04A4A0808R8R0`0D51@601DE5@805aLG0`0J6QX302PX:0<0<c<c0P0[:b/302PX:0<0>c/k0`12@T82
06UYJ@<0G5aL0`1TI6@3071`L080NGUi0`1aLG4308B4Q0<0JFUY0P1RHV830492@P<06ATI3@000003
00410@<04a<C0`0@410200d=3@<051@D0`0<30`300P820800@410`00000300D51@P000000`051@D3
00<30`802PX:2`00000300D51@D00000203oool000H0oooo0`071`L300410@<01@D50P0L71`L0000
00<00P820P00000300820P/000001@030`<3000000<00P820`00000200T92@<00@410`020P880000
00<00`<30`0E5AD201hN7P<00P822`00000301`L70<0L71`0P24Q8@308N7Q`<0O7al0`1fMWH208:2
PP<0ATI60`14A4@2028R8P<051@D1P0E5AD201LG5`<06QXJ0`0X:2P303<c<`80:b/[0`0X:2P303/k
>`<0@T920P1YJFT305aLG0<0I6AT0`1`L70207UiN@<0LG5a0`24Q8@306UYJ@80HV9R0`12@T8301TI
6@d000000`010@4301<C4`<0410@0P0=3@d301@D50<030`<0`0820P200410@<000000`051@D80000
00<01@D50`030`<200X:2P/000000`051@D5000000P0oooo00060?ooo`<02@T90`00000300L71`80
5ADE8@00000300410@/000000`020P8200410@T000000P020P86000000<01@D50P071`L900000080
1`L73P00000300d=3@<0JFUY0P2=SHd3092@T0<0PX:20`1^KVh207QhN0<0B4Q80`1;Bd/2034a<@<0
61PH0`0>3Ph301DE5@80820P0`0S8b<302d];@<0<30`0P0/;2`301lO7`H0<c<c0P1SHf<306QXJ0<0
O7al0`1iNGT207emO@<0Jf][0`1/K6`304];B`80@D510`0W9bL300`<30<01@D50P00000300H61P<0
0`<30P0410@3000000<00@410`00000200X:2P<02`/;0`051@D300410@D000000`030`<8000000<0
0`<31@092@T300H61PH000000P030`<300820P<000000P051@D80?ooo`001P3oool300T92@<00000
0`071`L201DE5B4000000`010@4;000000<00P820P010@49000000800P821P00000300D51@801`L7
2@00000200L71`h000000`0=3@d306UYJ@80SHf=0`2@T90308:2PP<0KVi^0P1hN7P304Q8B0<0Bd];
0P0a<C4301PH60<03Ph>0`0E5AD2020P80<08b<S0`0];Bd3030`<080;2`/0`0O7al603<c<`80Hf=S
0`1XJ6P307alO0<0NGUi0P1mOGd306][J`<0K6a/0`1;Bd/20451@@<09bLW0`0<30`300D51@800000
0`061PH300<30`8010@40`00000300410@<000000P0:2PX300/;2`<01@D50`010@45000000<00`<3
2000000300<30`D02@T90`061PH6000000800`<30`020P83000000801@D5203oool000H0oooo0`09
2@T3000000<01`L70P0E5ADQ000000<00@412`00000300820P800@412@00000200820PH000000`05
1@D200L71`T000000P071`L>000000<03@d=0`1YJFT208f=S@<0T92@0`22PX8306i^KP80N7Qh0`18
B4P304];B`80<C4a0`0H61P300h>3P<05ADE0P0P820302<S8`<0;Bd]0`0`<30202`/;0<07alO1P0c
<c<206=SH`<0J6QX0`1lO7`307UiN@80OGem0`1[Jf/306a/K0<0Bd];0P11@D4302LW9`<030`<0`05
1@D2000000<01PH60`030`<200@410<000000`010@43000000802PX:0`0;2`/300D51@<00@411@00
000300<30`P000000`030`<500T92@<01PH61P00000200<30`<00P820`00000200D51@P0oooo0006
0?ooo`<010@40`00000300410@804a<C0`00000300<30`h000000P0410@;000000<00P822`000003
00<30`D000000`030`<3000000800P822@00000200<30`/000000`0820P300X:2P<020P81@000003
01HF5P<0MgMg0P2][Jd30<C4a0<0Z:RX0`2:RXX208>3P`<0F5QH0`14A4@202XZ:P<07QhN0`0M7Ad3
02@T9080<30`0`0U9BD301HF5P<04A4A0P0`<30304E5A@<0IFEU0`1/K6`207EeM@<0M7Ad0`1aLG43
06e]K@80MWIf0`1BDU8304I6AP<0<c<c0P0U9BD3018B4P<01PH62000000300820PP000000`092@T2
00P820<01@D50`010@48000000<00@412000000300<30`<000000P051@D300H61P<000000`061PH2
000000<00P820`00000200D51@P0oooo00060?ooo`<010@40`00000300410@804a<C0`00000300<3
0`h000000P0410@;000000<00P822`00000300<30`D000000`030`<3000000800P822@00000200<3
0`/000000`0820P300X:2P<020P81@00000301HF5P<0MgMg0P2][Jd30<C4a0<0Z:RX0`2:RXX208>3
P`<0F5QH0`14A4@202XZ:P<07QhN0`0M7Ad302@T9080<30`0`0U9BD301HF5P<04A4A0P0`<30304E5
A@<0IFEU0`1/K6`207EeM@<0M7Ad0`1aLG4306e]K@80MWIf0`1BDU8304I6AP<0<c<c0P0U9BD3018B
4P<01PH62000000300820PP000000`092@T200P820<01@D50`010@48000000<00@412000000300<3
0`<000000P051@D300H61P<000000`061PH2000000<00P820`00000200D51@P0oooo00060?ooo`T0
00000P0>3Ph3000000<00@410`030`<500820PH000000P051@D3000000<00@410`0410@2000000<0
0`<31P00000200<30`<000000`030`<5000000<00@410`00000200410@H000000`020P8200H61P<0
1@D51P00000200l?3`h000000`0D51@3051@D080NGUi0`2HV9P308^;R`<0QhN70P1mOGd305EEE@<0
<30`0P0:2PX300/;2`<05aLG0`0R8R82034a<@<0;Bd]0`0a<C4303hn?P80F5QH0`1^KVh308^;R`<0
SXj>0P26QXH307MgM`<0MGEe0`1ZJVX2065QH@<0>SXj0`0];Bd3020P80803`l?0`010@4300820P<0
10@40P00000300<30`D000000`010@43000000<030`<0P020P8A000000<00@411@00000300H61PD0
00000`010@48000000<01`L71@0000080?ooo`001P3oool9000000803Ph>0`00000300410@<00`<3
1@020P86000000801@D50`00000300410@<010@40P00000300<30`H000000P030`<3000000<00`<3
1@00000300410@<000000P010@46000000<00P820P061PH300D51@H000000P0?3`l>000000<051@D
0`1@D50207UiN@<0V9RH0`2;Rh/308N7Q`80OGem0`1EEED3030`<0802PX:0`0;2`/301LG5`<08R8R
0P0a<C4302d];@<0<C4a0`0n?Sh205QHF0<0KVi^0`2;Rh/308j>SP80QXJ60`1gMgL307EeM@<0JVYZ
0P1QHF4303Xj>P<0;Bd]0`0P820200l?3`<00@410`020P8300@4108000000`030`<5000000<00@41
0`00000300`<30800P824@00000300410@D000000`061PH5000000<00@412000000300L71`D00000
203oool000H0oooo2@00000200h>3P<000000`010@4300<30`D00P821P00000200D51@<000000`01
0@4300@4108000000`030`<6000000800`<30`00000300<30`D000000`010@43000000800@411P00
000300820P801PH60`051@D6000000803`l?3P00000301@D50<0D51@0P1iNGT309RHV0<0Rh^;0`27
QhL207emO@<0EEEE0`0`<30200X:2P<02`/;0`0G5aL3028R8P80<C4a0`0];Bd3034a<@<0?Shn0P1H
F5P306i^KP<0Rh^;0`2>SXh208J6QP<0MgMg0`1eMGD306YZJP80HF5Q0`0j>SX302d];@<0820P0P0?
3`l300410@<00P820`0410@2000000<00`<31@00000300410@<000000`0<30`200820Q4000000`01
0@45000000<01PH61@00000300410@P000000`071`L5000000P0oooo00060?ooo`<010@40`020P83
000000803Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`000003
00@410/000000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@000003
01hN7P<0FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT3
02d];@80>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV82
04e=C@<06ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I
000000<01@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<010@40`020P830000
00803Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`00000300@4
10/000000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@00000301hN
7P<0FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT302d]
;@80>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV8204e=
C@<06ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I0000
00<01@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<010@40`020P8300000080
3Ph>0`00000300820P<010@42`00000200@410H000000`0410@;000000800`<30`00000300@410/0
00000P010@46000000<010@40P071`L300820PH000000P071`L6000000<00`<31@00000301hN7P<0
FEUI0P1oOgl309:BTP<0PH610`1eMGD207AdM0<0EeMG0`13@d<202@T90<08R8R0`0Y:BT302d];@80
>3Ph0`0a<C4304Y:BP<0D51@0P1NGUh3069RHPH0LW9b0P1hN7P307alO0<0N7Qh0`1RHV8204e=C@<0
6ATI0`061PH300410@P000000`0410@2000000<010@40`020P88000000<02PX:0P020P8I000000<0
1@D51@00000300@410P000000`0410@5000000P0oooo00060?ooo`<020P80`010@43000000804a<C
1P00000300P820/000000P092@T6000000<01@D54000000300D51@800P821P00000300820P800@41
2`00000300`<30h000000`0820P200T92@<05aLG0`0/;2`306=SH`80Q8B40`2ATI4307YjNP<0K6a/
0P1dM7@305ADE0<0B4Q80P0^;Rh6034a<@<0;bl_0P0`<303034a<@<0GUiN0`1aLG4207AdM0<0LG5a
0`1iNGT307MgM`80OGem0`1hN7P3069RHP<0?clo0P0I6AT>000000<03@d=0`0;2`/2000000<01@D5
0`0410@200410@H010@40`0=3@d200H61QT000000`0820P3000000801`L70`010@43000000<00P82
0P00000300@410<000000P010@480?ooo`001P3oool300P820<00@410`00000201<C4`H000000`08
20P;000000802@T91P00000300D51A0000000`051@D200820PH000000`020P8200410@/000000`0<
30`>000000<020P80P092@T301LG5`<0;2`/0`1SHf<208B4Q0<0TI6A0`1jNWX306a/K080M7Ad0`1D
E5@304Q8B080;Rh^1P0a<C4302l_;`80<30`0`0a<C4305iNGP<0LG5a0P1dM7@3075aL@<0NGUi0`1g
MgL207emO@<0N7Qh0`1RHV8303lo?`806ATI3P00000300d=3@<02`/;0P00000300D51@<010@40P01
0@4600@410<03@d=0P061PHI000000<020P80`00000200L71`<00@410`00000300820P8000000`04
10@3000000800@41203oool000H0oooo0`0820P300410@<000000P0C4a<6000000<020P82`000002
00T92@H000000`051@D@000000<01@D50P020P86000000<00P820P010@4;000000<030`<3P000003
00P820802@T90`0G5aL302`/;0<0Hf=S0P24Q8@3096AT@<0NWYj0`1/K6`207AdM0<0E5AD0`18B4P2
02h^;PH0<C4a0`0_;bl2030`<0<0<C4a0`1NGUh3075aL@80M7Ad0`1aLG4307UiN@<0MgMg0P1mOGd3
07QhN0<0HV9R0`0o?cl201TI6@h000000`0=3@d300/;2`8000000`051@D300@410800@411P0410@3
00d=3@801PH66@00000300P820<000000P071`L300410@<000000`020P82000000<010@40`000002
00410@P0oooo00060?ooo`<00`<31P00000201HF5PH000000`051@D;0000008030`<0`020P830000
00<02`/;4000000300D51@800P820`00000300H61P/000000`092@T=000000<01@D52000000300L7
1`<0410@0`1<C4`207QhN0<0Shn?0`1`L70306ATI080LG5a0`19BDT30451@@80=3@d0`0f=SH302h^
;P<0>c/k0P1;Bd/304Q8B0<0DU9B0`1TI6@206i^KP<0Ng]k0`26QXH308^;R`80OGem0`1QHF4303dm
?@<061PH0P051@D6000000<00@410P020P8300410@P000000`020P8300@4108000000`0:2PX300@4
10<00@411@00000300D51@<01PH60P010@4>000000<020P80`00000200h>3P<00@410`00000300D5
1@8000000`0410@300410@803@d=203oool000H0oooo0`030`<6000000805QHF1P00000300D51@/0
00000P0<30`300820P<000000`0;2`/@000000<01@D50P020P83000000<01PH62`00000300T92@d0
00000`051@D8000000<01`L70`0@410304a<C080N7Qh0`2?Shl3071`L0<0I6AT0P1aLG4304U9B@<0
@D510P0d=3@303Hf=P<0;Rh^0`0k>c/204];B`<0B4Q80`1BDU8306ATI080KVi^0`1kNg/308J6QP<0
Rh^;0P1mOGd3065QH@<0?Cdm0`0H61P200D51@H000000`010@4200820P<00@412000000300820P<0
10@40P00000300X:2P<010@40`010@45000000<01@D50`061PH200410@h000000`0820P300000080
3Ph>0`010@43000000<01@D50P00000300@410<00@410P0=3@d80?ooo`001P3oool9000000803@d=
1P00000300L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<00000
0`061PH;000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=
0`1YJFT3059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO
0`1SHf<3071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@41
0P020P8C000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<00000
0P0;2`/6000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool9000000803@d=1P00
000300L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<000000`06
1PH;000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=0`1Y
JFT3059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO0`1S
Hf<3071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@410P02
0P8C000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<000000P0;
2`/6000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool9000000803@d=1P000003
00L71`/000000P092@T300820P<000000`0;2`/200410@h000000`030`<200410@<000000`061PH;
000000<03@d=3@00000300<30`<000000`020P8200D51@<02`/;0`0410@302DU9@80CDe=0`1YJFT3
059BDP<0D51@0P1OGel304Q8B0<0@4100P0m?Cd304A4A0<0ADE50`1CDe<206ATI0<0GemO0`1SHf<3
071`L080MWIf0`1nOWh307]kN`<0NWYj0P1LG5`304=3@`<09BDU0`092@T8000000<00@410P020P8C
000000<03Ph>0`051@D300820PD000000`0:2PX300P820800P823P00000300L71`<000000P0;2`/6
000000<00`<30P00000300<30`<000000P0<30`80?ooo`001P3oool3000000H00`<30P010@460000
00<00`<31@00000300410@<000000P020P83000000<00`<30`0410@2000000<00@411P00000200l?
3`<000000`010@42000000<00P820`010@4>000000802`/;1P00000300410@8030`<2@00000200P8
20<03Ph>0`00000300T92@80>c/k0`1kNg/307AdM0<0KFe]0P1eMGD305]KF`<0=cLg0P0Z:RX302LW
9`<0@T920`1CDe<206IVIP<0GEeM0`1HF5P307EeM@80OWin0`1]KFd305YJFP<0<c<c2`00000200H6
1PH000000`020P8200410A4000000P071`L301<C4`H000000P0>3PhF000000<00`<30`0:2PX30000
00800@410`030`<8000000<02PX:0`020P82000000P0oooo00060?ooo`<000001P030`<200410@H0
00000`030`<5000000<00@410`00000200820P<000000`030`<300@4108000000`010@4600000080
3`l?0`00000300410@8000000`020P8300410@h000000P0;2`/6000000<00@410P0<30`900000080
20P80`0>3Ph3000000<02@T90P0k>c/307]kN`<0M7Ad0`1]KFd207EeM@<0Fe]K0`0g=cL202XZ:P<0
9bLW0`12@T8305=CD`80IVIV0`1MGEd305QHF0<0MGEe0P1nOWh306e]K@<0FUYJ0`0c<c<;00000080
1PH61P00000300820P800@414@00000200L71`<04a<C1P00000200h>3QH000000`030`<300X:2P<0
00000P010@4300<30`P000000`0:2PX300820P800000203oool000H0oooo0`00000600<30`800@41
1P00000300<30`D000000`010@43000000800P820`00000300<30`<010@40P00000300410@H00000
0P0?3`l3000000<00@410P00000300820P<00@413P00000200/;2`H000000`010@4200`<30T00000
0P0820P300h>3P<000000`092@T203/k>`<0Ng]k0`1dM7@306e]K@80MGEe0`1KFe/303Lg=`80:RXZ
0`0W9bL30492@P<0De=C0P1VIVH305eMG@<0F5QH0`1eMGD207inOP<0KFe]0`1JFUX303<c<`/00000
0P061PH6000000<00P820P010@4A000000801`L70`0C4a<6000000803Ph>5P00000300<30`<02PX:
0`00000200410@<00`<32000000300X:2P<00P820P0000080?ooo`001P3oool3000000<00P820`01
0@45000000<00@410`0820P200@410<000000`010@43000000D00@410`030`<300X:2P800`<32@00
000200D51@P000000`0820P;000000<020P80`0=3@d200L71`<02`/;2000000300/;2`H01PH60P0G
5aL301`L70<030`<0`0410@2024Q8@<0B4Q80`1DE5@306m_K`80K6a/0`1TI6@30451@@80<S8b0`19
BDT305YJFP<0H61P0P1TI6@306QXJ0<0Jf][0`1/K6`205MGE`<0ATI60`0k>c/3038b<P807QhN0`0@
410300/;2`<010@41@00000300H61P<000000P010@46000000D00P822000000300T92@<00P822000
000600410@d000000`020P8300H61Q0000000`051@D5000000P0oooo00060?ooo`<000000`020P83
00410@D000000`010@4300P8208010@40`00000300410@<000001@010@4300<30`<02PX:0P030`<9
000000801@D52000000300P820/000000`0820P300d=3@801`L70`0;2`/8000000<02`/;1P061PH2
01LG5`<071`L0`0<30`300@410808B4Q0`18B4P305ADE0<0Kfm_0P1/K6`306ATI0<0@D510P0b<S83
04U9B@<0FUYJ0`1PH60206ATI0<0J6QX0`1[Jf/306a/K080EeMG0`16ATH303/k>`<0<S8b0P0N7Qh3
010@40<02`/;0`0410@5000000<01PH60`00000200410@H000001@020P88000000<02@T90`020P88
000000H00@413@00000300820P<01PH64000000300D51@D00000203oool000H0oooo0`0000030082
0P<00@411@00000300410@<020P80P0410@3000000<00@410`00000500410@<00`<30`0:2PX200<3
0`T000000P051@D8000000<020P82`00000300P820<03@d=0P071`L300/;2`P000000`0;2`/600H6
1P805aLG0`0L71`300`<30<010@40P0Q8B4304Q8B0<0E5AD0`1_Kfl206a/K0<0I6AT0`11@D42038b
<P<0BDU90`1JFUX3061PH080I6AT0`1XJ6P306][J`<0K6a/0P1GEeL304I6AP<0>c/k0`0b<S8201hN
7P<0410@0`0;2`/300@410D000000`061PH3000000800@411P00000500820PP000000`092@T30082
0PP000001P010@4=000000<00P820`061PH@000000<01@D51@0000080?ooo`001P3oool3000000<0
0@412000000300410@<00P820P010@43000000<01PH60`00000500820PH020P80P00000300410@<0
00000`010@4200@410<000001@010@4300P820<000000`010@42000000<00`<30`0=3@d3030`<080
;2`/1P00000300`<30800`<32@00000200@410<05QHF0`0:2PX3000000805QHF0`0Y:BT303hn?P<0
EeMG0P1PH60305eMG@<0EeMG0P1JFUX3065QH@<0Hf=S0`1PH60206=SH`<0IFEU0`1HF5P305]KF`80
Cdm?0`1:BTX30492@P<0=3@d0P0Q8B4600<30`D000000`0F5QH3024Q8@<04Q8B0P092@T900000080
2@T90`0<30`300<30`D000000`030`<8000000<03@d=0`092@T;000000800P820`030`<300410@<0
1@D52`00000200@410<000000`030`<2000000P0oooo00060?ooo`<000000`010@48000000<00@41
0`020P8200410@<000000`061PH3000000D00P821P0820P2000000<00@410`00000300410@8010@4
0`00000500410@<020P80`00000300410@8000000`030`<300d=3@<0<30`0P0/;2`6000000<030`<
0P030`<90000008010@40`0F5QH300X:2P<000000P0F5QH302TY:@<0?Shn0`1GEeL2061PH0<0GEeM
0`1GEeL205YJFP<0HF5Q0`1SHf<3061PH080Hf=S0`1UIFD305QHF0<0Fe]K0P1?Cdl304Y:BP<0@T92
0`0d=3@2024Q8@H00`<31@00000301HF5P<08B4Q0`0B4Q8200T92@T000000P092@T300`<30<00`<3
1@00000300<30`P000000`0=3@d300T92@/000000P020P8300<30`<00@410`051@D;0000008010@4
0`00000300<30`800000203oool000H0oooo0`00000300D51@/000000`030`<5000000<00P820`00
000200820P<00@410`030`<300L71`800P822@00000200<30`P000000`030`<300820PP000000`01
0@48000000<00@410`0?3`l200@410H000000`030`<200l?3`<05ADE0`0820P300<30`8061PH0`0f
=SH303Ph>0<0@4100P1@D503055AD@<0CTi>0P1CDe<305eMG@<0IfMW0`1/K6`206ATI0<0FUYJ0`1D
E5@305IFEP80D51@0`14A4@303Ti>@<09bLW1@0410@300L71`<010@42`00000200@410<000000`03
0`<300820P8000000`020P8300T92@8030`<0`0B4Q8300D51@P000000`030`<300820Q0000000`03
0`<30000008010@41P00000300410@8000000`010@45000000P0oooo00060?ooo`<000000`051@D;
000000<00`<31@00000300820P<000000P020P8300410@<00`<30`071`L200820PT000000P030`<8
000000<00`<30`020P88000000<00@412000000300410@<03`l?0P0410@6000000<00`<30P0?3`l3
01DE5@<020P80`030`<201PH60<0=SHf0`0h>3P30410@080D51@0`1ADE4304i>CP80De=C0`1MGEd3
06MWI`<0K6a/0P1TI6@305YJFP<0E5AD0`1FEUH2051@D0<0A4A40`0i>CT302LW9`D010@40`071`L3
00@410/000000P0410@3000000<00`<30`020P82000000<00P820`092@T200`<30<04Q8B0`051@D8
000000<00`<30`020P8@000000<00`<30`00000200@410H000000`010@42000000<00@411@000008
0?ooo`001P3oool3000000<01@D52`00000300<30`D000000`020P83000000800P820`010@4300<3
0`<01`L70P020P89000000800`<32000000300<30`<00P822000000300410@P000000`010@4300l?
3`8010@41P00000300<30`803`l?0`0E5AD300P820<00`<30P0H61P303Hf=P<0>3Ph0`10@402051@
D0<0DE5A0`1>CTh205=CD`<0GEeM0`1WIfL306a/K080I6AT0`1JFUX305ADE0<0EUIF0P1@D50304A4
A0<0>CTi0`0W9bL500@410<01`L70`0410@;0000008010@40`00000300<30`<00P820P0000030082
0P<02@T90P0<30`3018B4P<01@D52000000300<30`<00P824000000300<30`<000000P0410@60000
00<00@410P00000300410@D00000203oool000H0oooo0`00000300D51@<00@412000000300410@D0
00000`020P85000000H00@410`0410@200410@T000000P061PH6000000800@410`030`<3000000<0
0@412000000300T92@801`L71P00000300d=3@P000000`0820P201@D50<06ATI0`0=3@d300P82080
6QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1QHF4306EUI@<0JVYZ0`1UIFD205aLG0<0
DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00000300L71`<00`<32000000300820P80
0`<30`00000300<30`P000000`010@4200H61P<00@410`020P88000000<01PH60`0410@=000000<0
0P820`010@4300<30`801@D52@00000200410@P00000203oool000H0oooo0`00000300D51@<00@41
2000000300410@D000000`020P85000000H00@410`0410@200410@T000000P061PH6000000800@41
0`030`<3000000<00@412000000300T92@801`L71P00000300d=3@P000000`0820P201@D50<06ATI
0`0=3@d300P820806QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1QHF4306EUI@<0JVYZ
0`1UIFD205aLG0<0DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00000300L71`<00`<3
2000000300820P800`<30`00000300<30`P000000`010@4200H61P<00@410`020P88000000<01PH6
0`0410@=000000<00P820`010@4300<30`801@D52@00000200410@P00000203oool000H0oooo0`00
000300D51@<00@412000000300410@D000000`020P85000000H00@410`0410@200410@T000000P06
1PH6000000800@410`030`<3000000<00@412000000300T92@801`L71P00000300d=3@P000000`08
20P201@D50<06ATI0`0=3@d300P820806QXJ0`0];Bd3034a<@<0<S8b0P14A4@304];B`<0De=C0P1Q
HF4306EUI@<0JVYZ0`1UIFD205aLG0<0DU9B0`1GEeL305QHF080Cdm?0`0n?Sh302/[:`<05QHF1@00
000300L71`<00`<32000000300820P800`<30`00000300<30`P000000`010@4200H61P<00@410`02
0P88000000<01PH60`0410@=000000<00P820`010@4300<30`801@D52@00000200410@P00000203o
ool000H0oooo0`00000300410@<010@40P020P86000000<00P821@00000300D51AT000000P020P8;
000000<00`<32`00000300`<30801`L74@00000300l?3`802`/;0`0820P3000000<01`L70P0X:2P3
03Hf=P<09RHV0`0I6AT202d];@<0=SHf0`18B4P2069RHP<0Hf=S0`1JFUX305iNGP80HV9R0`1PH603
06=SH`<0FEUI0P19BDT3030`<0<04Q8B0`071`L200D51@<030`<0`051@D;000000<00@410P092@T3
00L71`/000000`020P8200X:2P<00`<30`061PH5000000<00`<30`0A4A4300P820800P822`000003
00820P<00@410`0820P200h>3P<010@40`00000300820P801@D51P000002010@40P0oooo00060?oo
o`<000000`010@4300@410800P821P00000300820PD000000`051@DI000000800P822`00000300<3
0`/000000`0<30`200L71a4000000`0?3`l200/;2`<020P80`00000300L71`80:2PX0`0f=SH302HV
9P<06ATI0P0];Bd303Hf=P<0B4Q80P1RHV8306=SH`<0FUYJ0`1NGUh2069RHP<0H61P0`1SHf<305UI
F@80BDU90`0`<303018B4P<01`L70P051@D300`<30<01@D52`00000300410@802@T90`071`L;0000
00<00P820P0:2PX300<30`<01PH61@00000300<30`<04A4A0`0820P200820P/000000`020P830041
0@<020P80P0>3Ph300@410<000000`020P8200D51@H000000P0@41080?ooo`001P3oool3000000<0
10@40`030`<8000000<00`<31@00000300@411T000000P051@D8000000<010@40`010@4;000000<0
1`L70P061PHA000000<0410@0P0F5QH301LG5`<02`/;0`0H61P203Lg=`<0Bd];0`14A4@303Xj>P80
@d=31P1:BTX205YJFP<0HV9R0`1TI6@3065QH@80GemO0`1NGUh3069RHP<0FEUI0P15ADD302LW9`<0
2`/;1@00000300H61P<01`L70`010@4;000000801PH60`0820P300@410<00P820P010@4600000080
10@40`00000300820PD000000`030`<300P820<00`<33@00000300820P<00`<30`051@D200P820<0
0`<31P00000200<30`H000000P071`L80?ooo`001P3oool3000000<010@40`030`<8000000<00`<3
1@00000300@411T000000P051@D8000000<010@40`010@4;000000<01`L70P061PHA000000<0410@
0P0F5QH301LG5`<02`/;0`0H61P203Lg=`<0Bd];0`14A4@303Xj>P80@d=31P1:BTX205YJFP<0HV9R
0`1TI6@3065QH@80GemO0`1NGUh3069RHP<0FEUI0P15ADD302LW9`<02`/;1@00000300H61P<01`L7
0`010@4;000000801PH60`0820P300@410<00P820P010@460000008010@40`00000300820PD00000
0`030`<300P820<00`<33@00000300820P<00`<30`051@D200P820<00`<31P00000200<30`H00000
0P071`L80?ooo`001P3oool3000000<010@40`030`<8000000<00`<31@00000300@411T000000P05
1@D8000000<010@40`010@4;000000<01`L70P061PHA000000<0410@0P0F5QH301LG5`<02`/;0`0H
61P203Lg=`<0Bd];0`14A4@303Xj>P80@d=31P1:BTX205YJFP<0HV9R0`1TI6@3065QH@80GemO0`1N
GUh3069RHP<0FEUI0P15ADD302LW9`<02`/;1@00000300H61P<01`L70`010@4;000000801PH60`08
20P300@410<00P820P010@460000008010@40`00000300820PD000000`030`<300P820<00`<33@00
000300820P<00`<30`051@D200P820<00`<31P00000200<30`H000000P071`L80?ooo`001P3oool3
00<30`<01`L70`020P8200<30`<000000`030`<300410@D000000`010@45000000<00@410`000003
00X:2Q0000000`020P82000000<00`<31P00000500410@<030`<2`00000300d=3@8000000`0:2PX3
00820P<030`<0P0A4A4301TI6@<05QHF0`0P820203hn?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<3
06][J`80IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069RHP<0EUIF0P0g=cL3014A4@<02@T91@000003
00H61P<020P80`010@4C000000<00P820P00000300L71`<020P88`00000300410@H00P822`000002
00<30`<00@411@0000080?ooo`001P3oool300<30`<01`L70`020P8200<30`<000000`030`<30041
0@D000000`010@45000000<00@410`00000300X:2Q0000000`020P82000000<00`<31P0000050041
0@<030`<2`00000300d=3@8000000`0:2PX300820P<030`<0P0A4A4301TI6@<05QHF0`0P820203hn
?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<306][J`80IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069R
HP<0EUIF0P0g=cL3014A4@<02@T91@00000300H61P<020P80`010@4C000000<00P820P00000300L7
1`<020P88`00000300410@H00P822`00000200<30`<00@411@0000080?ooo`001P3oool300<30`<0
1`L70`020P8200<30`<000000`030`<300410@D000000`010@45000000<00@410`00000300X:2Q00
00000`020P82000000<00`<31P00000500410@<030`<2`00000300d=3@8000000`0:2PX300820P<0
30`<0P0A4A4301TI6@<05QHF0`0P820203hn?P<0FUYJ0`1TI6@306a/K080MgMg0`1cLg<306][J`80
IVIV0`1_Kfl6079bLP80IVIV0`1NGUh3069RHP<0EUIF0P0g=cL3014A4@<02@T91@00000300H61P<0
20P80`010@4C000000<00P820P00000300L71`<020P88`00000300410@H00P822`00000200<30`<0
0@411@0000080?ooo`001P3oool300<30`<020P80`030`<200820P<000001P030`<=000000<00@41
0`00000300L71`800@412@00000200410@<000000`010@42000000<010@41P00000500820P<02`/;
0`061PH5000000<00P820`0>3Ph2000000<010@40`00000300/;2`804Q8B0`0J6QX301DE5@<07alO
0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH306e]K@<0LG5a0`1/K6`205mOG`<0FEUI
0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX300H61PD000000`010@430000008010@4
0`030`<300410@P000000`020P8200<30`<000000`071`L8000000<010@40`010@4=000000H00P82
0`030`<;0000008010@4200000080?ooo`001P3oool300<30`<020P80`030`<200820P<000001P03
0`<=000000<00@410`00000300L71`800@412@00000200410@<000000`010@42000000<010@41P00
000500820P<02`/;0`061PH5000000<00P820`0>3Ph2000000<010@40`00000300/;2`804Q8B0`0J
6QX301DE5@<07alO0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH306e]K@<0LG5a0`1/
K6`205mOG`<0FEUI0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX300H61PD000000`01
0@430000008010@40`030`<300410@P000000`020P8200<30`<000000`071`L8000000<010@40`01
0@4=000000H00P820`030`<;0000008010@4200000080?ooo`001P3oool300<30`<020P80`030`<2
00820P<000001P030`<=000000<00@410`00000300L71`800@412@00000200410@<000000`010@42
000000<010@41P00000500820P<02`/;0`061PH5000000<00P820`0>3Ph2000000<010@40`000003
00/;2`804Q8B0`0J6QX301DE5@<07alO0P0e=CD304M7A`<0DE5A0`1LG5`506][J`<0K6a/0P1VIVH3
06e]K@<0LG5a0`1/K6`205mOG`<0FEUI0`1RHV83059BDP80<30`0`092@T8000000<02@T90`0:2PX3
00H61PD000000`010@430000008010@40`030`<300410@P000000`020P8200<30`<000000`071`L8
000000<010@40`010@4=000000H00P820`030`<;0000008010@4200000080?ooo`001P3oool30082
0P<01PH60`0410@200410@<000000`0410@300<30`D000000`010@45000000<00@410`00000300H6
1P800@415P00000300<30`P000000`051@D300820PP000000`010@42000000<0410@0`061PH3010@
40801`L70`030`<3000000<02`/;0P0/;2`304A4A0<0@D510`17AdL205UIF@<0HF5Q0`1XJ6P206UY
J@H0KFe]0`1cLg<206e]K@<0HV9R0`1HF5P303/k>`808R8R0`030`<8000000<03@d=0`061PH30041
0@8000000`051@D300H61P<000000P030`<>000000<00`<30P0820P300T92@<02PX:2000000300d=
3@<010@44`00000300@410800P822@00000200@410H000000P071`L80?ooo`001P3oool300820P<0
1PH60`0410@200410@<000000`0410@300<30`D000000`010@45000000<00@410`00000300H61P80
0@415P00000300<30`P000000`051@D300820PP000000`010@42000000<0410@0`061PH3010@4080
1`L70`030`<3000000<02`/;0P0/;2`304A4A0<0@D510`17AdL205UIF@<0HF5Q0`1XJ6P206UYJ@H0
KFe]0`1cLg<206e]K@<0HV9R0`1HF5P303/k>`808R8R0`030`<8000000<03@d=0`061PH300410@80
00000`051@D300H61P<000000P030`<>000000<00`<30P0820P300T92@<02PX:2000000300d=3@<0
10@44`00000300@410800P822@00000200@410H000000P071`L80?ooo`001P3oool3000000<02@T9
2000000300@410<00@411@00000300@410<00@410P00000300410@<000000`0820P200410@h00000
0`010@42000000<01`L70`010@43000000801PH60`020P8300/;2`<01PH60P00000300D51@<00`<3
0`0:2PX5000000<020P80`0H61P2020P80<09BDU0`0O7al3020P8080<C4a0`13@d<304a<C0<0D51@
0P1ADE4305iNGP<0EeMG0P1OGel3079bLP<0Ng]k0`1gMgL206a/K0<0HF5Q0`1<C4`3030`<0806a/K
0`051@D8000000<01PH60`010@4300@410800`<30`0820P300410@<000001@020P8300@410<00`<3
0P0410@300H61P<03@d=0P0410@O000000800@410`00000300410@h000000P030`<8000000P0oooo
00060?ooo`<000000`092@T8000000<010@40`010@45000000<010@40`010@42000000<00@410`00
000300P820800@413P00000300410@8000000`071`L300410@<000000P061PH300820P<02`/;0`06
1PH2000000<01@D50`030`<300X:2PD000000`0820P301PH6080820P0`0U9BD301lO7`<0820P0P0a
<C4304=3@`<0C4a<0`1@D502055AD@<0GUiN0`1GEeL205mOG`<0LW9b0`1kNg/307MgM`80K6a/0`1Q
HF4304a<C0<0<30`0P0K6a/300D51@P000000`061PH300410@<010@40P030`<300P820<00@410`00
000500820P<010@40`030`<200@410<01PH60`0=3@d200@411l000000P010@43000000<00@413P00
000200<30`P00000203oool000H0oooo0`00000300T92@P000000`0410@300410@D000000`0410@3
00410@8000000`010@43000000<020P80P010@4>000000<00@410P00000300L71`<00@410`000002
00H61P<00P820`0;2`/300H61P8000000`051@D300<30`<02PX:1@00000300P820<061PH0P0P8203
02DU9@<07alO0`0P8202034a<@<0@d=30`1<C4`3051@D080DE5A0`1NGUh305MGE`80GemO0`1bLW83
07]kN`<0MgMg0P1/K6`3065QH@<0C4a<0`0`<30201/K6`<01@D52000000300H61P<00@410`0410@2
00<30`<020P80`010@43000000D00P820`0410@300<30`8010@40`061PH300d=3@8010@47`000002
00410@<000000`010@4>000000800`<3200000080?ooo`001P3oool3000000<02PX:2000000300H6
1P<00@411@00000300<30`D000000`010@43000000<01PH60P010@4>000000<00@410P00000300D5
1@H000000P071`L300@410<030`<1@051@D300`<30<02PX:0`0B4Q85000000<00`<30`0D51@201TI
6@<07alO0`0L71`3020P8080<C4a0`11@D43055AD@<0FEUI0P1NGUh6071`L080Lg=c0`1mOGd308J6
QP<0N7Qh0P1PH60304i>CP<0<c<c0`0A4A4200<30a4000000`061PH200P820<02@T90`010@480000
00<00`<32000000300T92@8010@40`00000300H61PP000000`030`<>000000800`<31P0000030041
0@/000000P051@D8000000P0oooo00060?ooo`<000000`0:2PX8000000<01PH60`010@45000000<0
0`<31@00000300410@<000000`061PH200410@h000000`010@42000000<01@D51P00000200L71`<0
10@40`0<30`500D51@<030`<0`0:2PX3018B4PD000000`030`<301@D50806ATI0`0O7al301`L70<0
820P0P0a<C430451@@<0DE5A0`1IFET205iNGPH0L71`0P1cLg<307emO@<0QXJ60`1hN7P2061PH0<0
CTi>0`0c<c<3014A4@800`<34@00000300H61P8020P80`092@T300410@P000000`030`<8000000<0
2@T90P0410@3000000<01PH62000000300<30`h000000P030`<6000000<00@412`00000200D51@P0
0000203oool000H0oooo0`00000300X:2PP000000`061PH300410@D000000`030`<5000000<00@41
0`00000300H61P800@413P00000300410@8000000`051@D6000000801`L70`0410@300`<30D01@D5
0`0<30`300X:2P<04Q8B1@00000300<30`<051@D0P0I6AT301lO7`<071`L0`0P8202034a<@<0@D51
0`1ADE4305UIF@80GUiN1P1`L70207=cL`<0OGem0`26QXH307QhN080H61P0`1>CTh303<c<`<04A4A
0P030`<A000000<01PH60P0820P300T92@<00@412000000300<30`P000000`092@T200@410<00000
0`061PH8000000<00`<33P00000200<30`H000000`010@4;000000801@D5200000080?ooo`001P3o
ool3000000<01PH62000000300H61P<010@41@00000300D51@<000000P020P86000000<01@D50P03
0`<>000000<00P820P00000300D51@<010@40`00000200D51@<00P820`061PH300820P8000000`0;
2`/;000000<01`L70`0J6QX501PH60<03`l?0`0U9BD204I6APH0EUIF0`1BDU8205=CD`H0IfMW0P1g
MgL308F5Q@<0R8R80`1fMWH205iNGP<0Bd];0`0Q8B48000000<00P820`071`L200D51@<020P81P00
000200820P<00`<32`00000300410A0000000`0<30`5000000<00@410`0<30`300820P/000000P02
0P86000000<00@410P0410@6000000<01@D50P061PH8000000P0oooo00060?ooo`<000000`061PH8
000000<01PH60`0410@5000000<01@D50`00000200820PH000000`051@D200<30`h000000`020P82
000000<01@D50`0410@3000000801@D50`020P8300H61P<00P820P00000300/;2`/000000`071`L3
01XJ6PD061PH0`0?3`l302DU9@80ATI61P1FEUH3059BDP80De=C1P1WIfL207MgM`<0QHF50`28R8P3
07IfMP80GUiN0`1;Bd/3024Q8@P000000`020P8300L71`801@D50`0820P6000000800P820`030`<;
000000<00@414000000300`<30D000000`010@4300`<30<00P822`00000200820PH000000`010@42
00@410H000000`051@D200H61PP00000203oool000H0oooo0`00000300D51@P000000`0:2PX30041
0A<000000`0410@200<30`<00P822`00000300410@P000000`0410@200D51@<010@40`051@D30000
00800P820`0F5QH300l?3`<0410@0P092@T301/K6`<09BDU0`0g=cL202h^;P<08R8R0`0I6AT302LW
9`80@d=30`1DE5@305QHF0D0EeMG0`1`L703079bLP80N7Qh0`1lO7`308:2PP<0IfMW0P18B4P302HV
9P<01PH62000000300<30`<01`L70P00000300<30`H000000P0A4A4300D51Ah000001P0>3Ph20000
00<00P820`0>3Ph300<30`/000000P0410@6000000<00P821@00000300410@<00P820P061PH80000
00P0oooo00060?ooo`<000000`051@D8000000<02PX:0`010@4C000000<010@40P030`<300820P/0
00000`010@48000000<010@40P051@D300@410<01@D50`00000200820P<05QHF0`0?3`l3010@4080
2@T90`0K6a/302DU9@<0=cLg0P0^;Rh3028R8P<06ATI0`0W9bL204=3@`<0E5AD0`1HF5P505MGE`<0
L71`0`1bLW8207QhN0<0O7al0`22PX8306MWI`80B4Q80`0V9RH300H61PP000000`030`<300L71`80
00000`030`<6000000804A4A0`051@DN000000H03Ph>0P00000300820P<03Ph>0`030`<;00000080
10@41P00000300820PD000000`010@4300820P801PH6200000080?ooo`001P3oool3000000<01@D5
2000000300X:2P<00@414`00000300@410800`<30`020P8;000000<00@412000000300@410801@D5
0`0410@300D51@<000000P020P8301HF5P<03`l?0`0@410200T92@<06a/K0`0U9BD303Lg=`80;Rh^
0`0R8R8301TI6@<09bLW0P13@d<305ADE0<0F5QH1@1GEeL3071`L0<0LW9b0P1hN7P307alO0<0PX:2
0`1WIfL204Q8B0<09RHV0`061PH8000000<00`<30`071`L2000000<00`<31P000002014A4@<01@D5
7P00000600h>3P8000000`020P8300h>3P<00`<32`00000200@410H000000`020P85000000<00@41
0`020P8200H61PP00000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P00
000200410@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`07
1`L3000000800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U
9BD302d];@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F
5QH300`<30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`07
1`L200410@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`00
000300820P800000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P000002
00410@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`071`L3
000000800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U9BD3
02d];@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F5QH3
00`<30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`071`L2
00410@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`000003
00820P800000203oool000H0oooo0`020P8300<30`<000000P010@43000000<01`L73P0000020041
0@<000001P020P8200410@<00P822`00000300410@P000000`061PH200@410<01@D50`071`L30000
00800P820`0820P300L71`<051@D0P0A4A43018B4P<05QHF0`0P820201dM7@<092@T0`0U9BD302d]
;@80@D510`1?Cdl3065QH@<0Hf=S0P1UIFD8071`L0<0LG5a0`1/K6`3055AD@80:BTY0`0F5QH300`<
30P000000`0820P;000000<00@410P051@D>000000<03Ph>0`00000200410@<000000`071`L20041
0@<000000`092@TI000000800`<31P00000300820PD000000`010@43000000801@D50`0000030082
0P800000203oool000H0oooo1P020P88000000<02PX:0`00000200820PH00@410`00000200<30`<0
00000`030`<300@410800P820`030`<3000000<00@411@00000300410@P000000`061PH200`<30<0
20P80`0<30`300820P80410@0`0X:2P3010@40<04Q8B0P0?3`l301@D50<08R8R0`0X:2P2028R8P<0
:BTY0`0/;2`3034a<@80@4100`1:BTX3065QH@<0KVi^0P1QHF43079bLP<0IfMW0P1QHF4306YZJP<0
JFUY0`19BDT201lO7`<02PX:2`00000300L71`D03@d=0`061PH6000000800`<30`020P8;000000<0
3@d=0`00000200@410<000000`0:2PX5000000<03Ph>0`061PH5000000<00`<32`00000300820P80
1PH63P00000300820P<000000P051@D3000000<00P820P0000080?ooo`001P3oool600820PP00000
0`0:2PX3000000800P821P010@43000000800`<30`00000300<30`<010@40P020P8300<30`<00000
0`010@45000000<00@412000000300H61P8030`<0`0820P300`<30<00P820P0@410302PX:0<0410@
0`0B4Q8200l?3`<051@D0`0R8R8302PX:0808R8R0`0Y:BT302`/;0<0<C4a0P10@40304Y:BP<0HF5Q
0`1^KVh2065QH@<0LW9b0`1WIfL2065QH@<0JVYZ0`1YJFT304U9B@807alO0`0:2PX;000000<01`L7
1@0=3@d300H61PH000000P030`<300820P/000000`0=3@d30000008010@40`00000300X:2PD00000
0`0>3Ph300H61PD000000`030`<;000000<00P820P061PH>000000<00P820`00000200D51@<00000
0`020P82000000P0oooo00060?ooo`H00P822000000300X:2P<000000P020P8600410@<000000P03
0`<3000000<00`<30`0410@200820P<00`<30`00000300410@D000000`010@48000000<01PH60P0<
30`300P820<030`<0`020P82010@40<0:2PX0`0@4103018B4P803`l?0`0D51@3028R8P<0:2PX0P0R
8R8302TY:@<0;2`/0`0a<C420410@0<0BTY:0`1QHF4306i^KP80HF5Q0`1bLW8306MWI`80HF5Q0`1Z
JVX306UYJ@<0BDU90P0O7al300X:2P/000000`071`L500d=3@<01PH61P00000200<30`<00P822`00
000300d=3@<000000P0410@3000000<02PX:1@00000300h>3P<01PH61@00000300<30`/000000`02
0P8200H61Ph000000`020P83000000801@D50`00000300820P800000203oool000H0oooo0`092@T6
0000008020P80`00000300410A<000000`071`L3000000D00@411P00000200<30`<000000`010@42
00820PH000000`0;2`/200410@<01@D50`020P830000008010@40`061PH300P820<0410@0P0G5aL3
01@D50<04a<C0`0J6QX202<S8`<0=cLg0`0h>3P303`l?080ATI60`1;Bd/3069RHP<0IfMW0P1]KFd6
06EUI@80GemO0`1MGEd3055AD@<0;Bd]0P00000300410@<0:2PX0`0e=CD2020P80<01`L70`061PH8
000000<01PH60`0410@5000000<00@410`0;2`/200`<30<05ADE0`0U9BD3010@40802`/;0`092@T5
00<30`<000000`0A4A43000000801@D50`0820P3000000<00@412000000500410@H000000`0410@5
000000<00@410`00000200@410<000000`020P82000000P0oooo00060?ooo`<02@T91P00000200P8
20<000000`010@4C000000<01`L70`00000500410@H000000P030`<3000000<00@410P020P860000
00<02`/;0P010@4300D51@<00P820`00000200@410<01PH60`0820P3010@40805aLG0`0D51@301<C
4`<06QXJ0P0S8b<303Lg=`<0>3Ph0`0l?3`204I6AP<0Bd];0`1RHV8306MWI`80KFe]1P1UIFD205mO
G`<0GEeM0`1ADE4302d];@8000000`010@4302PX:0<0=CDe0P0P820300L71`<01PH62000000300H6
1P<010@41@00000300410@<02`/;0P0<30`301DE5@<09BDU0`0@410200/;2`<02@T91@030`<30000
00<04A4A0`00000200D51@<020P80`00000300410@P000001@010@46000000<010@41@0000030041
0@<000000P0410@3000000<00P820P0000080?ooo`001P3oool300H61P<00@410`00000200<30`<0
00000`0820P3000000800P825P00000300<30`<000000`020P8200P820<000001@020P8300410@<0
00000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00000300820P<04Q8B0P0M7Ad301TI6@<0
51@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17AdL3065QH@<0HV9R0P1JFUX3061PH0<0
HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00000200410@<000000`030`<>00000080
20P80`051@D300<30`P000000`051@DH000000<00`<31P010@48000000<00@410P0820P6000000<0
410@1@00000300H61P<000000P0A4A43000000<00P820P0000080?ooo`001P3oool300H61P<00@41
0`00000200<30`<000000`0820P3000000800P825P00000300<30`<000000`020P8200P820<00000
1@020P8300410@<000000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00000300820P<04Q8B
0P0M7Ad301TI6@<051@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17AdL3065QH@<0HV9R
0P1JFUX3061PH0<0HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00000200410@<00000
0`030`<>0000008020P80`051@D300<30`P000000`051@DH000000<00`<31P010@48000000<00@41
0P0820P6000000<0410@1@00000300H61P<000000P0A4A43000000<00P820P0000080?ooo`001P3o
ool300H61P<00@410`00000200<30`<000000`0820P3000000800P825P00000300<30`<000000`02
0P8200P820<000001@020P8300410@<000000`0<30`200L71`<02`/;0`0:2PX301`L7080:BTY0`00
000300820P<04Q8B0P0M7Ad301TI6@<051@D0`0R8R8202@T90<0;bl_0`0k>c/30451@@80DE5A0`17
AdL3065QH@<0HV9R0P1JFUX3061PH0<0HV9R0P1MGEd3051@D0<0ADE50`0F5QH5000000<00`<30`00
000200410@<000000`030`<>0000008020P80`051@D300<30`P000000`051@DH000000<00`<31P01
0@48000000<00@410P0820P6000000<0410@1@00000300H61P<000000P0A4A43000000<00P820P00
00080?ooo`001P3oool300P820H000000P0820P3000000<010@43P00000200820P/000000`010@4;
000000<00P820P010@46000000<01PH6200410@300H61P8051@D0`0:2PX300/;2`<05ADE0P0H61P3
01dM7@<05aLG0`0K6a/201@D50<08B4Q0`0Z:RX30492@P80EEEE0`1FEUH305eMG@<0EeMG0P1IFET3
04i>CP<0DE5A0P18B4P303/k>`<0;Bd]0`0F5QH5000000<00@412000000300@410<000000P051@D3
00820P/000001P020P82000000<00`<30`0<30`8000000<00`<30P010@43000000<02@T90`000002
00410@<01PH60`0410@300820P/000000P010@46000000<01@D50P010@43000000<00@410`000002
00H61P<000000`020P82000000P0oooo00060?ooo`<020P81P00000200P820<000000`0410@>0000
00800P822`00000300410@/000000`020P8200410@H000000`061PH800@410<01PH60P0D51@300X:
2P<02`/;0`0E5AD201PH60<07AdM0`0G5aL301/K6`8051@D0`0Q8B4302XZ:P<0@T920P1EEED305IF
EP<0GEeM0`1GEeL205UIF@<0CTi>0`1ADE4204Q8B0<0>c/k0`0];Bd301HF5PD000000`010@480000
00<010@40`00000200D51@<00P822`00000600820P8000000`030`<300`<30P000000`030`<20041
0@<000000`092@T3000000800@410`061PH300@410<00P822`00000200410@H000000`051@D20041
0@<000000`010@43000000801PH60`00000300820P800000203oool000H0oooo0`0820P600000080
20P80`00000300@410h000000P020P8;000000<00@412`00000300820P800@411P00000300H61PP0
10@40`061PH201@D50<02PX:0`0;2`/301DE5@8061PH0`0M7Ad301LG5`<06a/K0P0D51@3024Q8@<0
:RXZ0`12@T8205EEE@<0EUIF0`1MGEd305MGE`80FEUI0`1>CTh3055AD@80B4Q80`0k>c/302d];@<0
5QHF1@00000300410@P000000`0410@3000000801@D50`020P8;000000H00P820P00000300<30`<0
30`<2000000300<30`800@410`00000300T92@<000000P010@4300H61P<010@40`020P8;00000080
0@411P00000300D51@800@410`00000300410@<000000P061PH3000000<00P820P0000080?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {243.75, 0}} -> {-2.5436, -2.12545, 0.366158, 
  0.366158}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Not a perfect job, but hey that huge clef was in the original too.\
\>", "Text"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
AutoGeneratedPackage->None,
WindowSize->{629, 418},
WindowMargins->{{2, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 161, 4, 66, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1895, 57, 69, 0, 54, "Subtitle"],

Cell[CellGroupData[{
Cell[1989, 61, 110, 3, 74, "Section"],

Cell[CellGroupData[{
Cell[2124, 68, 68, 0, 47, "Subsection"],
Cell[2195, 70, 161, 3, 52, "Text"],
Cell[2359, 75, 104, 2, 50, "Input",
  InitializationCell->True],
Cell[2466, 79, 2032, 41, 530, "Input",
  InitializationCell->True],
Cell[4501, 122, 2113, 39, 590, "Input",
  InitializationCell->True],
Cell[6617, 163, 2402, 42, 690, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9056, 210, 70, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[9151, 214, 57, 1, 30, "Input"],
Cell[9211, 217, 193, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9441, 228, 45, 1, 30, "Input"],
Cell[9489, 231, 420, 6, 82, "Print"]
}, Open  ]],
Cell[9924, 240, 43, 1, 30, "Input"],
Cell[9970, 243, 1186, 18, 223, "Text"],

Cell[CellGroupData[{
Cell[11181, 265, 68, 1, 30, "Input"],
Cell[11252, 268, 26681, 544, 296, 4060, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37970, 817, 45, 1, 30, "Input"],
Cell[38018, 820, 439, 7, 82, "Print"]
}, Open  ]],
Cell[38472, 830, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[38540, 835, 83, 1, 30, "Input"],
Cell[38626, 838, 29363, 577, 296, 4089, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68026, 1420, 55, 0, 30, "Input"],
Cell[68084, 1422, 471, 10, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68592, 1437, 55, 1, 30, "Input"],
Cell[68650, 1440, 29318, 576, 296, 4089, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98005, 2021, 66, 1, 30, "Input"],
Cell[98074, 2024, 29777, 581, 296, 4145, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[127912, 2612, 93, 2, 33, "Section"],
Cell[128008, 2616, 219, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[128252, 2625, 37, 0, 47, "Subsection"],
Cell[128292, 2627, 91, 2, 33, "Text"],
Cell[128386, 2631, 301, 12, 210, "Input"],
Cell[128690, 2645, 27, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[128742, 2649, 108, 2, 43, "Subsubsection"],
Cell[128853, 2653, 250, 4, 52, "Text"],
Cell[129106, 2659, 33, 0, 30, "Input"],
Cell[129142, 2661, 92, 2, 30, "Input"],
Cell[129237, 2665, 46, 0, 30, "Input"],
Cell[129286, 2667, 38, 0, 30, "Input"],
Cell[129327, 2669, 26, 0, 30, "Input"],
Cell[129356, 2671, 45, 0, 33, "Text"],
Cell[129404, 2673, 18, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129459, 2678, 56, 0, 43, "Subsubsection"],
Cell[129518, 2680, 172, 3, 52, "Text"],
Cell[129693, 2685, 80, 3, 48, "Input"],
Cell[129776, 2690, 112, 3, 33, "Text"],
Cell[129891, 2695, 20, 0, 30, "Input"],
Cell[129914, 2697, 36, 0, 30, "Input"],
Cell[129953, 2699, 117, 3, 33, "Text"],
Cell[130073, 2704, 20, 0, 30, "Input"],
Cell[130096, 2706, 130, 3, 33, "Text"],
Cell[130229, 2711, 22, 0, 30, "Input"],
Cell[130254, 2713, 43, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130334, 2718, 103, 2, 43, "Subsubsection"],
Cell[130440, 2722, 125, 3, 33, "Text"],
Cell[130568, 2727, 26, 0, 30, "Input"],
Cell[130597, 2729, 495, 8, 90, "Text"],
Cell[131095, 2739, 29, 0, 30, "Input"],
Cell[131127, 2741, 34, 0, 30, "Input"],
Cell[131164, 2743, 39, 0, 30, "Input"],
Cell[131206, 2745, 26, 0, 30, "Input"],
Cell[131235, 2747, 46, 0, 33, "Text"],
Cell[131284, 2749, 18, 0, 30, "Input"],
Cell[131305, 2751, 532, 9, 128, "Text"],
Cell[131840, 2762, 26, 0, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[131915, 2768, 39, 0, 31, "Subsection"],
Cell[131957, 2770, 577, 9, 109, "Text"],
Cell[132537, 2781, 207, 4, 66, "Input"],
Cell[132747, 2787, 208, 4, 52, "Text"],
Cell[132958, 2793, 30, 0, 30, "Input"],
Cell[132991, 2795, 95, 2, 33, "Text"],
Cell[133089, 2799, 145, 8, 138, "Input"],
Cell[133237, 2809, 36, 0, 30, "Input"],
Cell[133276, 2811, 533, 8, 109, "Text"],
Cell[133812, 2821, 99, 2, 33, "Text"],
Cell[133914, 2825, 41, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[133980, 2829, 39, 0, 43, "Subsubsection"],
Cell[134022, 2831, 472, 10, 109, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134531, 2846, 49, 0, 43, "Subsubsection"],
Cell[134583, 2848, 327, 5, 71, "Text"],
Cell[134913, 2855, 101, 4, 66, "Input"],
Cell[135017, 2861, 94, 2, 33, "Text"],
Cell[135114, 2865, 51, 0, 30, "Input"],
Cell[135168, 2867, 258, 5, 52, "Text"],
Cell[135429, 2874, 22, 0, 30, "Input"],
Cell[135454, 2876, 226, 4, 52, "Text"],
Cell[135683, 2882, 31, 0, 30, "Input"],
Cell[135717, 2884, 91, 4, 66, "Input"],
Cell[135811, 2890, 99, 3, 48, "Input"],
Cell[135913, 2895, 121, 3, 33, "Text"],
Cell[136037, 2900, 52, 0, 30, "Input"],
Cell[136092, 2902, 225, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136354, 2911, 115, 3, 43, "Subsubsection"],
Cell[136472, 2916, 314, 6, 90, "Text"],
Cell[136789, 2924, 307, 9, 156, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[137145, 2939, 37, 0, 31, "Subsection"],
Cell[137185, 2941, 175, 4, 52, "Text"],
Cell[137363, 2947, 116, 4, 66, "Input"],
Cell[137482, 2953, 72, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[137579, 2957, 128, 3, 43, "Subsubsection"],
Cell[137710, 2962, 115, 3, 33, "Text"],
Cell[137828, 2967, 101, 4, 66, "Input"],
Cell[137932, 2973, 51, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138020, 2978, 106, 2, 43, "Subsubsection"],
Cell[138129, 2982, 311, 9, 156, "Input"],
Cell[138443, 2993, 53, 0, 33, "Text"],
Cell[138499, 2995, 135, 3, 48, "Input"],
Cell[138637, 3000, 90, 2, 33, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[138788, 3009, 94, 2, 33, "Section"],
Cell[138885, 3013, 219, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[139129, 3022, 37, 0, 47, "Subsection"],
Cell[139169, 3024, 91, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[139285, 3030, 301, 12, 210, "Input"],
Cell[139589, 3044, 347, 8, 80, "Output"],
Cell[139939, 3054, 284, 8, 80, "Output"],
Cell[140226, 3064, 505, 13, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140768, 3082, 27, 0, 30, "Input"],
Cell[140798, 3084, 597, 16, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141432, 3105, 108, 2, 43, "Subsubsection"],
Cell[141543, 3109, 250, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[141818, 3117, 33, 0, 30, "Input"],
Cell[141854, 3119, 385, 10, 44, "Output"]
}, Open  ]],
Cell[142254, 3132, 92, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[142371, 3138, 46, 0, 30, "Input"],
Cell[142420, 3140, 216, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142673, 3151, 38, 0, 30, "Input"],
Cell[142714, 3153, 271, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143022, 3166, 26, 0, 30, "Input"],
Cell[143051, 3168, 597, 16, 80, "Output"]
}, Open  ]],
Cell[143663, 3187, 45, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[143733, 3191, 18, 0, 30, "Input"],
Cell[143754, 3193, 597, 16, 80, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[144400, 3215, 56, 0, 43, "Subsubsection"],
Cell[144459, 3217, 172, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[144656, 3224, 80, 3, 48, "Input"],
Cell[144739, 3229, 717, 14, 62, "Output"]
}, Open  ]],
Cell[145471, 3246, 112, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[145608, 3253, 20, 0, 30, "Input"],
Cell[145631, 3255, 446, 10, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146114, 3270, 36, 0, 30, "Input"],
Cell[146153, 3272, 418, 8, 80, "Output"]
}, Open  ]],
Cell[146586, 3283, 117, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[146728, 3290, 20, 0, 30, "Input"],
Cell[146751, 3292, 391, 10, 44, "Output"]
}, Open  ]],
Cell[147157, 3305, 130, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[147312, 3312, 22, 0, 30, "Input"],
Cell[147337, 3314, 100, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147474, 3321, 43, 0, 30, "Input"],
Cell[147520, 3323, 233, 6, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[147802, 3335, 103, 2, 43, "Subsubsection"],
Cell[147908, 3339, 125, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[148058, 3346, 26, 0, 30, "Input"],
Cell[148087, 3348, 599, 16, 80, "Output"]
}, Open  ]],
Cell[148701, 3367, 495, 8, 90, "Text"],

Cell[CellGroupData[{
Cell[149221, 3379, 29, 0, 30, "Input"],
Cell[149253, 3381, 189, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149479, 3391, 34, 0, 30, "Input"],
Cell[149516, 3393, 271, 7, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149824, 3405, 39, 0, 30, "Input"],
Cell[149866, 3407, 313, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150216, 3420, 26, 0, 30, "Input"],
Cell[150245, 3422, 601, 16, 80, "Output"]
}, Open  ]],
Cell[150861, 3441, 46, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[150932, 3445, 18, 0, 30, "Input"],
Cell[150953, 3447, 597, 16, 80, "Output"]
}, Open  ]],
Cell[151565, 3466, 532, 9, 128, "Text"],

Cell[CellGroupData[{
Cell[152122, 3479, 26, 0, 30, "Input"],
Cell[152151, 3481, 601, 16, 80, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[152813, 3504, 39, 0, 31, "Subsection"],
Cell[152855, 3506, 577, 9, 109, "Text"],
Cell[153435, 3517, 207, 4, 66, "Input"],
Cell[153645, 3523, 208, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[153878, 3531, 30, 0, 30, "Input"],
Cell[153911, 3533, 845, 12, 124, "Output"]
}, Open  ]],
Cell[154771, 3548, 95, 2, 33, "Text"],
Cell[154869, 3552, 145, 8, 138, "Input"],

Cell[CellGroupData[{
Cell[155039, 3564, 36, 0, 30, "Input"],
Cell[155078, 3566, 86029, 1316, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[241122, 4885, 533, 8, 109, "Text"],
Cell[241658, 4895, 99, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[241782, 4901, 41, 0, 30, "Input"],
Cell[241826, 4903, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241918, 4909, 39, 0, 43, "Subsubsection"],
Cell[241960, 4911, 548, 17, 242, "Text"],

Cell[CellGroupData[{
Cell[242533, 4932, 57, 1, 30, "Input"],
Cell[242593, 4935, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[242698, 4942, 49, 0, 43, "Subsubsection"],
Cell[242750, 4944, 327, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[243102, 4953, 101, 4, 66, "Input"],
Cell[243206, 4959, 53, 1, 29, "Output"]
}, Open  ]],
Cell[243274, 4963, 94, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[243393, 4969, 51, 0, 30, "Input"],
Cell[243447, 4971, 56, 1, 29, "Output"]
}, Open  ]],
Cell[243518, 4975, 258, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[243801, 4984, 22, 0, 30, "Input"],
Cell[243826, 4986, 1764, 25, 162, "Output"]
}, Open  ]],
Cell[245605, 5014, 226, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[245856, 5022, 31, 0, 30, "Input"],
Cell[245890, 5024, 945, 14, 86, "Output"]
}, Open  ]],
Cell[246850, 5041, 91, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[246966, 5049, 99, 3, 48, "Input"],
Cell[247068, 5054, 95935, 1438, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[343018, 6495, 121, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[343164, 6502, 52, 0, 30, "Input"],
Cell[343219, 6504, 55, 1, 29, "Output"]
}, Open  ]],
Cell[343289, 6508, 225, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[343551, 6517, 115, 3, 29, "Subsubsection"],
Cell[343669, 6522, 314, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[344008, 6532, 309, 9, 156, "Input"],

Cell[CellGroupData[{
Cell[344342, 6545, 86029, 1316, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"],
Cell[430374, 7863, 101159, 1502, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[531548, 9368, 55, 1, 29, "Output"]
}, Open  ]],
Cell[531618, 9372, 65, 0, 33, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[531732, 9378, 37, 0, 31, "Subsection"],
Cell[531772, 9380, 175, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[531972, 9388, 116, 4, 66, "Input"],
Cell[532091, 9394, 89086, 1353, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[621192, 10750, 72, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[621289, 10754, 128, 3, 43, "Subsubsection"],
Cell[621420, 10759, 115, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[621560, 10766, 101, 4, 66, "Input"],
Cell[621664, 10772, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[621754, 10778, 51, 0, 30, "Input"],
Cell[621808, 10780, 56, 1, 29, "Output"]
}, Open  ]],
Cell[621879, 10784, 367, 6, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622283, 10795, 106, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[622414, 10801, 311, 9, 156, "Input"],

Cell[CellGroupData[{
Cell[622750, 10814, 89086, 1353, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"],
Cell[711839, 12169, 139574, 1977, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[851428, 14149, 55, 1, 29, "Output"]
}, Open  ]],
Cell[851498, 14153, 53, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[851576, 14157, 135, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[851736, 14164, 86029, 1316, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"],
Cell[937768, 15482, 139574, 1977, 253, 18144, 473, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1077369, 17463, 90, 2, 33, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

