(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12125,        397]*)
(*NotebookOutlinePosition[     12870,        423]*)
(*  CellTagsIndexPosition[     12826,        419]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mathematica Notebooks for ATLAST", "Subtitle"],

Cell["by Richard D. Neidinger, Davidson College,  6/1/98.", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Preface -- Please read to better understand contents.", "Section",
  PageWidth->PaperWidth],

Cell[TextData[{
  "This is an incomplete collection of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " materials to accompany ",
  StyleBox["ATLAST Computer Exercises for Linear Algebra",
    FontSlant->"Italic"],
  ", by Leon, Herman and Faulkenberry, Prentice Hall, New Jersey, 1996.  \
Readers are expected to have this book.  For each chapter, there is an \
exercise and/or project notebook containing solutions, instructions and/or \
tutorials for selected ATLAST exercises and projects.  Instructions and \
tutorials are intended for students and should retain their unevaluated (no \
output) form.  Tutorials prepare students for later parts of the problem or \
immediately following problems.  Solutions do include output, so that \
instructors may browse.  If not labeled as instructions or tutorial, then the \
material is a solution to an ATLAST exercise or project that either requires \
no special instructions (except the book) or was only considered but not used \
in my classes.  The notebooks were developed for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 on a Windows platform but they should work on a Mac as well."
}], "Text",
  PageWidth->PaperWidth],

Cell[TextData[{
  "The few chosen exercises and projects cover the major concepts of every \
chapter.  There are more than enough for one semester.  Most have been used \
in at least one of three offerings of Davidson's \"sophomore\" Linear Algebra \
course.  They were usually assigned (sometimes several at a time) to \
(rotating) lab partners with some time in class and some out.  About 8 \
classes periods were entirely devoted to these assignments.  These only \
supplement a standard text and lectures where the topics are introduced.  \
Steven J. Leon's text matches the ATLAST chapters well.  David C. Lay's text \
introduces span and transformation early, enabling 4.2; 1 (cogame) and 2.2; 4 \
& 7 (Markov processes) very early and 5.2; 2 (computer graphics) anytime \
after matrix multiplication is introduced.  Many ATLAST exercises are \
missing, in particular there are no notebooks for ATLAST sections 3.1, 5.1, \
7.2, or 8.1, though these topics are covered in the other half of the \
chapter.  In general, applications and geometry are emphasized over \
exploration of matrix properties and special matrices.  My philosophy also \
emphasizes teaching students to use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " system with (hopefully) simple and clear input and organization, so that \
they be enabled to use the tool \"from scratch.\"  It is tempting to do many \
slick and impressive things with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " but I try to keep all input understandable, with the exception of a few \
programs such as cogame and eigshow (still accessible)."
}], "Text",
  PageWidth->PaperWidth],

Cell["\<\
I thank my Davidson College colleagues Stephen L. Davis and Todd G. Will, who \
helped develop some of the exercises and projects.  Please direct any \
comments, questions, additions, suggestions, praise or appreciation to me at:
rineidinger@davidson.edu\
\>", "Text",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["The computer files", "Section"],

Cell["Mathematica Notebooks for ATLAST consists of 14 files:", "Text"],

Cell["\<\
CONTENTS.nb
ATLAST11.nb
ATLAST12.nb
ATLAST21.nb
ATLAST22.nb
ATLAST32.nb
ATLAST41.nb
ATLAST42.nb
ATLAST52.nb
ATLAST61.nb
ATLAST62.nb
ATLAST71.nb
ATLAST82.nb
HAND.RAW (data file for image compression in ATLAST82.nb)\
\>", "Text",
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 0},
  FontFamily->"Courier New"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table of Contents", "Section"],

Cell[CellGroupData[{

Cell["ATLAST 1.1  Exercises on Linear Systems", "Subsection"],

Cell[TextData[{
  "Bonus:  Tutorial on Elementary Row Operations and RowReduce\nwith Intro to \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " System."
}], "Subsubsection"],

Cell["ATLAST 1.1: 1  Elementary Row Operations", "Subsubsection"],

Cell["ATLAST 1.1: 2  Row Reduce (randint, AppendRows)", "Subsubsection"],

Cell["ATLAST 1.1; 7  Magic Square Application", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 1.2  Projects on Linear Systems", "Subsection"],

Cell["\<\
Bonus:  Tutorial on LinearSolve, vectors and numerical values\
\>", "Subsubsection"],

Cell["ATLAST 1.2; 3 -- Ski Jump -- Tutorial and Instructions.", 
  "Subsubsection"],

Cell["ATLAST 1.2; 3 -- Ski Jump -- Solutions", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 2.1  Exercises on Matrix Algebra", "Subsection"],

Cell["\<\
Initializations -- randint (clear 3-argument and obscure 4-argument)\
\>", "Subsubsection"],

Cell[TextData[{
  "Bonus:  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Tutorial on matrix creation and algebra"
}], "Subsubsection"],

Cell["ATLAST 2.1; 9  Solving for commutator", "Subsubsection"],

Cell["ATLAST 2.1; 10  Homogeneous and nonhomogeneous solutions", 
  "Subsubsection"],

Cell["\<\
Spirit of 2.1; 10  Tutorial on solutions to linear systems in parametric \
vector form using LinearSolve + NullSpace.\
\>", "Subsubsection"],

Cell["\<\
ATLAST 2.1; 11  LinearSolve vs. Inverse -- Instructions Only \
\>", "Subsubsection"],

Cell["ATLAST 2.1; 11  LinearSolve vs. Inverse -- Solutions ", "Subsubsection"],

Cell["\<\
ATLAST 2.1;18 extended -- Roots of Identity -- Instructions Only \
\>", "Subsubsection"],

Cell["ATLAST 2.1;18 extended -- Roots of Identity -- Solutions", 
  "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 2.2  Projects on Matrix Algebra", "Subsection"],

Cell["ATLAST 2.2; 3 -- Graphs and Airline Flight Routes", "Subsubsection"],

Cell["ATLAST 2.2; 4 -- Intro to Markov Processes -- Tutorial", "Subsubsection"],

Cell["ATLAST 2.2; 7-- A Risky Markov Process -- Instructions Only", 
  "Subsubsection"],

Cell["ATLAST 2.2; 7-- A Risky Markov Process -- Solutions", "Subsubsection"],

Cell["\<\
ATLAST 2.2; 15 -- How many singular matrices are there? -- Instructions Only
(Suggested after Determinant and area.)\
\>", "Subsubsection"],

Cell["\<\
ATLAST 2.2; 15 -- How many singular matrices are there? -- Solutions
(Suggested after Determinant and area.)\
\>", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 3.2  Projects on Determinants", "Subsection"],

Cell["ATLAST 3.2; 3  Determinant pattern with parameter", "Subsubsection"],

Cell["\<\
ATLAST 3.2; 5 -- Theory of Interpolation -- Instructions Only\
\>", "Subsubsection"],

Cell["ATLAST 3.2; 5  Theory of interpolation -- Solutions", "Subsubsection"],

Cell["ATLAST 3.2; 6  Theory of Interpolation cont.", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 4.1  Exercises on Vector Space Concepts", "Subsection"],

Cell["ATLAST 4.1; 7  four space dimensions", "Subsubsection"],

Cell["ATLAST 4.1; 8  four space bases", "Subsubsection"],

Cell["ATLAST 4.1; 16  testing two bases", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 4.2  Projects on Vector Space Concepts", "Subsection"],

Cell[TextData[{
  "ATLAST 4.2; 1 -- a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version of cogame for students"
}], "Subsubsection"],

Cell[TextData[{
  "ATLAST 4.2; 1 -- a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version of cogame -- Example Solutions"
}], "Subsubsection"],

Cell["ATLAST 4.2; 5  A Concrete Application (extended)", "Subsubsection"],

Cell["ATLAST 4.2; 6  Row and Null Space Geometry (never used)", 
  "Subsubsection"],

Cell[TextData[{
  "ATLAST 4.2; 9 -- Commute with Me -- ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " help for (c)"
}], "Subsubsection"],

Cell["ATLAST 4.2; 9 -- Commute with Me (centralizer) -- Solutions", 
  "Subsubsection"],

Cell["\<\
ATLAST 4.2; 11  Basis for the Intersection of Two Vector Spaces\
\>", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 5.2  Projects on Linear Transformations", "Subsection"],

Cell["\<\
ATLAST 5.2; 2 -- Computer Graphics -- Tutorial & Instructions\
\>", "Subsubsection"],

Cell["ATLAST 5.2; 2 -- Computer Graphics -- Solutions", "Subsubsection"],

Cell["\<\
Spirit of 5.2; 2 -- Graphics Transformations -- Tutorial & Instructions
(5.2; 2 alternative focused on compositions & homogeneous coordinates).\
\>", "Subsubsection"],

Cell["\<\
Spirit of 5.2; 2 -- Graphics Transformations -- Solutions
(5.2; 2 alternative focused on compositions & homogeneous coordinates).\
\>", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 6.1  Exercises on Orthogonality", "Subsection"],

Cell["ATLAST 6.1; 1 -- Orthogonal Matrices -- Instructions", "Subsubsection"],

Cell["ATLAST 6.1; 1 -- Orthogonal Matrices -- Solutions", "Subsubsection"],

Cell["Spirit of 6.1; 2  -- Gram-Schmidt and alternatives", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 6.2 Projects on Orthogonality", "Subsection"],

Cell["\<\
 Bonus:  Intersection of Two Vector Spaces -- Instructions
(Idea of ATLAST 4.2; 11 but using orthogonal complements.)\
\>", "Subsubsection"],

Cell["\<\
 Bonus:  Intersection of Two Vector Spaces -- Solutions
(Idea of ATLAST 4.2; 11 but using orthogonal complements.)\
\>", "Subsubsection"],

Cell["ATLAST 6.2; 1  Computing Least-Squares Circles -- Tutorial", 
  "Subsubsection"],

Cell["\<\
ATLAST 6.2; 2  Computing Least-Squares Circles -- Instructions\
\>", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 7.1  Exercises on Eigenvalues", "Subsection"],

Cell["\<\
ATLAST 7.1; 1 -- eigshow -- Tutorial
A Geometric View of Eigenvalues and Eigenvectors\
\>", "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ATLAST 8.2  Singular Value Decomposition Projects", "Subsection"],

Cell["\<\
ATLAST 8.2; 1 -- svdshow -- Tutorial
Visualizing the Singular Value Decompososition\
\>", "Subsubsection"],

Cell["\<\
Spirit of 8.2; 2  The SVD and Digital Image Processing -- Tutorial\
\>", "Subsubsection"],

Cell["\<\
Spirit of 8.2; 2  The SVD and Digital Image Processing -- Solutions\
\>", "Subsubsection"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{552, 330},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 52, 0, 33, "Subtitle"],
Cell[1786, 53, 74, 0, 32, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1885, 57, 97, 1, 85, "Section"],
Cell[1985, 60, 1201, 22, 195, "Text"],
Cell[3189, 84, 1660, 27, 280, "Text"],
Cell[4852, 113, 303, 6, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5192, 124, 37, 0, 85, "Section"],
Cell[5232, 126, 70, 0, 25, "Text"],
Cell[5305, 128, 317, 18, 218, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5659, 151, 36, 0, 85, "Section"],

Cell[CellGroupData[{
Cell[5720, 155, 61, 0, 40, "Subsection"],
Cell[5784, 157, 188, 6, 54, "Subsubsection"],
Cell[5975, 165, 65, 0, 37, "Subsubsection"],
Cell[6043, 167, 72, 0, 37, "Subsubsection"],
Cell[6118, 169, 64, 0, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6219, 174, 60, 0, 40, "Subsection"],
Cell[6282, 176, 94, 2, 37, "Subsubsection"],
Cell[6379, 180, 83, 1, 37, "Subsubsection"],
Cell[6465, 183, 63, 0, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6565, 188, 61, 0, 40, "Subsection"],
Cell[6629, 190, 101, 2, 37, "Subsubsection"],
Cell[6733, 194, 147, 5, 37, "Subsubsection"],
Cell[6883, 201, 62, 0, 37, "Subsubsection"],
Cell[6948, 203, 84, 1, 37, "Subsubsection"],
Cell[7035, 206, 150, 3, 54, "Subsubsection"],
Cell[7188, 211, 94, 2, 37, "Subsubsection"],
Cell[7285, 215, 78, 0, 37, "Subsubsection"],
Cell[7366, 217, 98, 2, 37, "Subsubsection"],
Cell[7467, 221, 84, 1, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7588, 227, 60, 0, 40, "Subsection"],
Cell[7651, 229, 74, 0, 37, "Subsubsection"],
Cell[7728, 231, 79, 0, 37, "Subsubsection"],
Cell[7810, 233, 87, 1, 37, "Subsubsection"],
Cell[7900, 236, 76, 0, 37, "Subsubsection"],
Cell[7979, 238, 149, 3, 54, "Subsubsection"],
Cell[8131, 243, 141, 3, 54, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8309, 251, 58, 0, 40, "Subsection"],
Cell[8370, 253, 74, 0, 37, "Subsubsection"],
Cell[8447, 255, 94, 2, 37, "Subsubsection"],
Cell[8544, 259, 76, 0, 37, "Subsubsection"],
Cell[8623, 261, 69, 0, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8729, 266, 68, 0, 40, "Subsection"],
Cell[8800, 268, 61, 0, 37, "Subsubsection"],
Cell[8864, 270, 56, 0, 37, "Subsubsection"],
Cell[8923, 272, 58, 0, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9018, 277, 67, 0, 40, "Subsection"],
Cell[9088, 279, 149, 5, 37, "Subsubsection"],
Cell[9240, 286, 157, 5, 37, "Subsubsection"],
Cell[9400, 293, 73, 0, 37, "Subsubsection"],
Cell[9476, 295, 83, 1, 37, "Subsubsection"],
Cell[9562, 298, 148, 5, 37, "Subsubsection"],
Cell[9713, 305, 87, 1, 37, "Subsubsection"],
Cell[9803, 308, 96, 2, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9936, 315, 68, 0, 40, "Subsection"],
Cell[10007, 317, 94, 2, 37, "Subsubsection"],
Cell[10104, 321, 72, 0, 37, "Subsubsection"],
Cell[10179, 323, 176, 3, 54, "Subsubsection"],
Cell[10358, 328, 162, 3, 54, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10557, 336, 60, 0, 40, "Subsection"],
Cell[10620, 338, 77, 0, 37, "Subsubsection"],
Cell[10700, 340, 74, 0, 37, "Subsubsection"],
Cell[10777, 342, 75, 0, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10889, 347, 58, 0, 40, "Subsection"],
Cell[10950, 349, 150, 3, 54, "Subsubsection"],
Cell[11103, 354, 147, 3, 54, "Subsubsection"],
Cell[11253, 359, 86, 1, 37, "Subsubsection"],
Cell[11342, 362, 95, 2, 37, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11474, 369, 58, 0, 40, "Subsection"],
Cell[11535, 371, 118, 3, 54, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11690, 379, 71, 0, 40, "Subsection"],
Cell[11764, 381, 116, 3, 54, "Subsubsection"],
Cell[11883, 386, 99, 2, 37, "Subsubsection"],
Cell[11985, 390, 100, 2, 37, "Subsubsection"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

